/**
 ******************************************************************************
 * @file  HC32F460.h
 * @brief Headerfile for HC32F460 series MCU
 @verbatim
   Change Logs:
   Date             Author          Notes
   2021-10-13       CDT          First version
 @endverbatim
 ******************************************************************************
 * Copyright (C) 2020, Huada Semiconductor Co., Ltd. All rights reserved.
 *
 * This software component is licensed by HDSC under BSD 3-Clause license
 * (the "License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at:
 *                    opensource.org/licenses/BSD-3-Clause
 *
 ******************************************************************************
 **/

#ifndef __HC32F460_H__
#define __HC32F460_H__

#ifdef __cplusplus
extern "C" {
#endif

/*******************************************************************************
 * Configuration of the Cortex-M4 Processor and Core Peripherals
 ******************************************************************************/
#define __CM4_REV                 1       /*!< Core revision r0p1                                   */
#define __MPU_PRESENT             1       /*!< HC32F460 provides an MPU                             */
#define __NVIC_PRIO_BITS          4       /*!< HC32F460 uses 4 Bits for the Priority Levels         */
#define __Vendor_SysTickConfig    0       /*!< Set to 1 if different SysTick Config is used         */
#define __FPU_PRESENT             1       /*!< FPU present                                          */

/*******************************************************************************
 * Interrupt Number Definition
 ******************************************************************************/
typedef enum IRQn
{
    NMI_IRQn                    = -14, /*  2 Non Maskable                            */
    HardFault_IRQn              = -13, /*  3 Hard Fault                              */
    MemManageFault_IRQn         = -12, /*  4 MemManage Fault                         */
    BusFault_IRQn               = -11, /*  5 Bus Fault                               */
    UsageFault_IRQn             = -10, /*  6 Usage Fault                             */
    SVC_IRQn                    = -5,  /* 11 SV Call                                 */
    DebugMonitor_IRQn           = -4,  /* 12 Debug Monitor                           */
    PendSV_IRQn                 = -2,  /* 14 Pend SV                                 */
    SysTick_IRQn                = -1,  /* 15 System Tick                             */
    Int000_IRQn                 = 0,
    Int001_IRQn                 = 1,
    Int002_IRQn                 = 2,
    Int003_IRQn                 = 3,
    Int004_IRQn                 = 4,
    Int005_IRQn                 = 5,
    Int006_IRQn                 = 6,
    Int007_IRQn                 = 7,
    Int008_IRQn                 = 8,
    Int009_IRQn                 = 9,
    Int010_IRQn                 = 10,
    Int011_IRQn                 = 11,
    Int012_IRQn                 = 12,
    Int013_IRQn                 = 13,
    Int014_IRQn                 = 14,
    Int015_IRQn                 = 15,
    Int016_IRQn                 = 16,
    Int017_IRQn                 = 17,
    Int018_IRQn                 = 18,
    Int019_IRQn                 = 19,
    Int020_IRQn                 = 20,
    Int021_IRQn                 = 21,
    Int022_IRQn                 = 22,
    Int023_IRQn                 = 23,
    Int024_IRQn                 = 24,
    Int025_IRQn                 = 25,
    Int026_IRQn                 = 26,
    Int027_IRQn                 = 27,
    Int028_IRQn                 = 28,
    Int029_IRQn                 = 29,
    Int030_IRQn                 = 30,
    Int031_IRQn                 = 31,
    Int032_IRQn                 = 32,
    Int033_IRQn                 = 33,
    Int034_IRQn                 = 34,
    Int035_IRQn                 = 35,
    Int036_IRQn                 = 36,
    Int037_IRQn                 = 37,
    Int038_IRQn                 = 38,
    Int039_IRQn                 = 39,
    Int040_IRQn                 = 40,
    Int041_IRQn                 = 41,
    Int042_IRQn                 = 42,
    Int043_IRQn                 = 43,
    Int044_IRQn                 = 44,
    Int045_IRQn                 = 45,
    Int046_IRQn                 = 46,
    Int047_IRQn                 = 47,
    Int048_IRQn                 = 48,
    Int049_IRQn                 = 49,
    Int050_IRQn                 = 50,
    Int051_IRQn                 = 51,
    Int052_IRQn                 = 52,
    Int053_IRQn                 = 53,
    Int054_IRQn                 = 54,
    Int055_IRQn                 = 55,
    Int056_IRQn                 = 56,
    Int057_IRQn                 = 57,
    Int058_IRQn                 = 58,
    Int059_IRQn                 = 59,
    Int060_IRQn                 = 60,
    Int061_IRQn                 = 61,
    Int062_IRQn                 = 62,
    Int063_IRQn                 = 63,
    Int064_IRQn                 = 64,
    Int065_IRQn                 = 65,
    Int066_IRQn                 = 66,
    Int067_IRQn                 = 67,
    Int068_IRQn                 = 68,
    Int069_IRQn                 = 69,
    Int070_IRQn                 = 70,
    Int071_IRQn                 = 71,
    Int072_IRQn                 = 72,
    Int073_IRQn                 = 73,
    Int074_IRQn                 = 74,
    Int075_IRQn                 = 75,
    Int076_IRQn                 = 76,
    Int077_IRQn                 = 77,
    Int078_IRQn                 = 78,
    Int079_IRQn                 = 79,
    Int080_IRQn                 = 80,
    Int081_IRQn                 = 81,
    Int082_IRQn                 = 82,
    Int083_IRQn                 = 83,
    Int084_IRQn                 = 84,
    Int085_IRQn                 = 85,
    Int086_IRQn                 = 86,
    Int087_IRQn                 = 87,
    Int088_IRQn                 = 88,
    Int089_IRQn                 = 89,
    Int090_IRQn                 = 90,
    Int091_IRQn                 = 91,
    Int092_IRQn                 = 92,
    Int093_IRQn                 = 93,
    Int094_IRQn                 = 94,
    Int095_IRQn                 = 95,
    Int096_IRQn                 = 96,
    Int097_IRQn                 = 97,
    Int098_IRQn                 = 98,
    Int099_IRQn                 = 99,
    Int100_IRQn                 = 100,
    Int101_IRQn                 = 101,
    Int102_IRQn                 = 102,
    Int103_IRQn                 = 103,
    Int104_IRQn                 = 104,
    Int105_IRQn                 = 105,
    Int106_IRQn                 = 106,
    Int107_IRQn                 = 107,
    Int108_IRQn                 = 108,
    Int109_IRQn                 = 109,
    Int110_IRQn                 = 110,
    Int111_IRQn                 = 111,
    Int112_IRQn                 = 112,
    Int113_IRQn                 = 113,
    Int114_IRQn                 = 114,
    Int115_IRQn                 = 115,
    Int116_IRQn                 = 116,
    Int117_IRQn                 = 117,
    Int118_IRQn                 = 118,
    Int119_IRQn                 = 119,
    Int120_IRQn                 = 120,
    Int121_IRQn                 = 121,
    Int122_IRQn                 = 122,
    Int123_IRQn                 = 123,
    Int124_IRQn                 = 124,
    Int125_IRQn                 = 125,
    Int126_IRQn                 = 126,
    Int127_IRQn                 = 127,
    Int128_IRQn                 = 128,
    Int129_IRQn                 = 129,
    Int130_IRQn                 = 130,
    Int131_IRQn                 = 131,
    Int132_IRQn                 = 132,
    Int133_IRQn                 = 133,
    Int134_IRQn                 = 134,
    Int135_IRQn                 = 135,
    Int136_IRQn                 = 136,
    Int137_IRQn                 = 137,
    Int138_IRQn                 = 138,
    Int139_IRQn                 = 139,
    Int140_IRQn                 = 140,
    Int141_IRQn                 = 141,
    Int142_IRQn                 = 142,
    Int143_IRQn                 = 143,

}IRQn_Type;

#include <core_cm4.h>
#include <stdint.h>

/**
 *******************************************************************************
 ** \brief Event number enumeration
 ******************************************************************************/
typedef enum en_event_src
{
    EVT_SWI_IRQ0            = 0U,
    EVT_SWI_IRQ1            = 1U,
    EVT_SWI_IRQ2            = 2U,
    EVT_SWI_IRQ3            = 3U,
    EVT_SWI_IRQ4            = 4U,
    EVT_SWI_IRQ5            = 5U,
    EVT_SWI_IRQ6            = 6U,
    EVT_SWI_IRQ7            = 7U,
    EVT_SWI_IRQ8            = 8U,
    EVT_SWI_IRQ9            = 9U,
    EVT_SWI_IRQ10           = 10U,
    EVT_SWI_IRQ11           = 11U,
    EVT_SWI_IRQ12           = 12U,
    EVT_SWI_IRQ13           = 13U,
    EVT_SWI_IRQ14           = 14U,
    EVT_SWI_IRQ15           = 15U,
    EVT_SWI_IRQ16           = 16U,
    EVT_SWI_IRQ17           = 17U,
    EVT_SWI_IRQ18           = 18U,
    EVT_SWI_IRQ19           = 19U,
    EVT_SWI_IRQ20           = 20U,
    EVT_SWI_IRQ21           = 21U,
    EVT_SWI_IRQ22           = 22U,
    EVT_SWI_IRQ23           = 23U,
    EVT_SWI_IRQ24           = 24U,
    EVT_SWI_IRQ25           = 25U,
    EVT_SWI_IRQ26           = 26U,
    EVT_SWI_IRQ27           = 27U,
    EVT_SWI_IRQ28           = 28U,
    EVT_SWI_IRQ29           = 29U,
    EVT_SWI_IRQ30           = 30U,
    EVT_SWI_IRQ31           = 31U,

    /* External Interrupt. */
    EVT_PORT_EIRQ0          = 0U,
    EVT_PORT_EIRQ1          = 1U,
    EVT_PORT_EIRQ2          = 2U,
    EVT_PORT_EIRQ3          = 3U,
    EVT_PORT_EIRQ4          = 4U,
    EVT_PORT_EIRQ5          = 5U,
    EVT_PORT_EIRQ6          = 6U,
    EVT_PORT_EIRQ7          = 7U,
    EVT_PORT_EIRQ8          = 8U,
    EVT_PORT_EIRQ9          = 9U,
    EVT_PORT_EIRQ10         = 10U,
    EVT_PORT_EIRQ11         = 11U,
    EVT_PORT_EIRQ12         = 12U,
    EVT_PORT_EIRQ13         = 13U,
    EVT_PORT_EIRQ14         = 14U,
    EVT_PORT_EIRQ15         = 15U,

    /* DMAC */
    EVT_DMA1_TC0            = 32U,
    EVT_DMA1_TC1            = 33U,
    EVT_DMA1_TC2            = 34U,
    EVT_DMA1_TC3            = 35U,
    EVT_DMA2_TC0            = 36U,
    EVT_DMA2_TC1            = 37U,
    EVT_DMA2_TC2            = 38U,
    EVT_DMA2_TC3            = 39U,
    EVT_DMA1_BTC0           = 40U,
    EVT_DMA1_BTC1           = 41U,
    EVT_DMA1_BTC2           = 42U,
    EVT_DMA1_BTC3           = 43U,
    EVT_DMA2_BTC0           = 44U,
    EVT_DMA2_BTC1           = 45U,
    EVT_DMA2_BTC2           = 46U,
    EVT_DMA2_BTC3           = 47U,

    /* EFM */
    EVT_EFM_OPTEND          = 52U,

    /* USB SOF */
    EVT_USBFS_SOF           = 53U,

    /* DCU */
    EVT_DCU1                = 55U,
    EVT_DCU2                = 56U,
    EVT_DCU3                = 57U,
    EVT_DCU4                = 58U,

    /* TIMER 0 */
    EVT_TMR01_GCMA          = 64U,
    EVT_TMR01_GCMB          = 65U,
    EVT_TMR02_GCMA          = 66U,
    EVT_TMR02_GCMB          = 67U,

    /* RTC */
    EVT_RTC_ALM             = 81U,
    EVT_RTC_PRD             = 82U,

    /* TIMER 6 */
    EVT_TMR61_GCMA          = 96U,
    EVT_TMR61_GCMB          = 97U,
    EVT_TMR61_GCMC          = 98U,
    EVT_TMR61_GCMD          = 99U,
    EVT_TMR61_GCME          = 100U,
    EVT_TMR61_GCMF          = 101U,
    EVT_TMR61_GOVF          = 102U,
    EVT_TMR61_GUDF          = 103U,
    EVT_TMR61_SCMA          = 107U,
    EVT_TMR61_SCMB          = 108U,
    EVT_TMR62_GCMA          = 112U,
    EVT_TMR62_GCMB          = 113U,
    EVT_TMR62_GCMC          = 114U,
    EVT_TMR62_GCMD          = 115U,
    EVT_TMR62_GCME          = 116U,
    EVT_TMR62_GCMF          = 117U,
    EVT_TMR62_GOVF          = 118U,
    EVT_TMR62_GUDF          = 119U,
    EVT_TMR62_SCMA          = 123U,
    EVT_TMR62_SCMB          = 124U,
    EVT_TMR63_GCMA          = 128U,
    EVT_TMR63_GCMB          = 129U,
    EVT_TMR63_GCMC          = 130U,
    EVT_TMR63_GCMD          = 131U,
    EVT_TMR63_GCME          = 132U,
    EVT_TMR63_GCMF          = 133U,
    EVT_TMR63_GOVF          = 134U,
    EVT_TMR63_GUDF          = 135U,
    EVT_TMR63_SCMA          = 139U,
    EVT_TMR63_SCMB          = 140U,

    /* TIMER A */
    EVT_TMRA1_OVF           = 256U,
    EVT_TMRA1_UDF           = 257U,
    EVT_TMRA1_CMP           = 258U,
    EVT_TMRA2_OVF           = 259U,
    EVT_TMRA2_UDF           = 260U,
    EVT_TMRA2_CMP           = 261U,
    EVT_TMRA3_OVF           = 262U,
    EVT_TMRA3_UDF           = 263U,
    EVT_TMRA3_CMP           = 264U,
    EVT_TMRA4_OVF           = 265U,
    EVT_TMRA4_UDF           = 266U,
    EVT_TMRA4_CMP           = 267U,
    EVT_TMRA5_OVF           = 268U,
    EVT_TMRA5_UDF           = 269U,
    EVT_TMRA5_CMP           = 270U,
    EVT_TMRA6_OVF           = 272U,
    EVT_TMRA6_UDF           = 273U,
    EVT_TMRA6_CMP           = 274U,

    /* USART */
    EVT_USART1_EI           = 278U,
    EVT_USART1_RI           = 279U,
    EVT_USART1_TI           = 280U,
    EVT_USART1_TCI          = 281U,
    EVT_USART1_RTO          = 282U,
    EVT_USART2_EI           = 283U,
    EVT_USART2_RI           = 284U,
    EVT_USART2_TI           = 285U,
    EVT_USART2_TCI          = 286U,
    EVT_USART2_RTO          = 287U,
    EVT_USART3_EI           = 288U,
    EVT_USART3_RI           = 289U,
    EVT_USART3_TI           = 290U,
    EVT_USART3_TCI          = 291U,
    EVT_USART3_RTO          = 292U,
    EVT_USART4_EI           = 293U,
    EVT_USART4_RI           = 294U,
    EVT_USART4_TI           = 295U,
    EVT_USART4_TCI          = 296U,
    EVT_USART4_RTO          = 297U,

    /* SPI */
    EVT_SPI1_SPRI           = 299U,
    EVT_SPI1_SPTI           = 300U,
    EVT_SPI1_SPII           = 301U,
    EVT_SPI1_SPEI           = 302U,
    EVT_SPI1_SPTEND         = 303U,
    EVT_SPI2_SPRI           = 304U,
    EVT_SPI2_SPTI           = 305U,
    EVT_SPI2_SPII           = 306U,
    EVT_SPI2_SPEI           = 307U,
    EVT_SPI2_SPTEND         = 308U,
    EVT_SPI3_SPRI           = 309U,
    EVT_SPI3_SPTI           = 310U,
    EVT_SPI3_SPII           = 311U,
    EVT_SPI3_SPEI           = 312U,
    EVT_SPI3_SPTEND         = 313U,
    EVT_SPI4_SPRI           = 314U,
    EVT_SPI4_SPTI           = 315U,
    EVT_SPI4_SPII           = 316U,
    EVT_SPI4_SPEI           = 317U,
    EVT_SPI4_SPTEND         = 318U,

    /* AOS */
    EVT_AOS_STRG            = 319U,

    /* TIMER 4 */
    EVT_TMR41_SCMUH         = 368U,
    EVT_TMR41_SCMUL         = 369U,
    EVT_TMR41_SCMVH         = 370U,
    EVT_TMR41_SCMVL         = 371U,
    EVT_TMR41_SCMWH         = 372U,
    EVT_TMR41_SCMWL         = 373U,
    EVT_TMR42_SCMUH         = 374U,
    EVT_TMR42_SCMUL         = 375U,
    EVT_TMR42_SCMVH         = 376U,
    EVT_TMR42_SCMVL         = 377U,
    EVT_TMR42_SCMWH         = 378U,
    EVT_TMR42_SCMWL         = 379U,
    EVT_TMR43_SCMUH         = 384U,
    EVT_TMR43_SCMUL         = 385U,
    EVT_TMR43_SCMVH         = 386U,
    EVT_TMR43_SCMVL         = 387U,
    EVT_TMR43_SCMWH         = 388U,
    EVT_TMR43_SCMWL         = 389U,

    /* EVENT PORT */
    EVT_EVENT_PORT1         = 394U,
    EVT_EVENT_PORT2         = 395U,
    EVT_EVENT_PORT3         = 396U,
    EVT_EVENT_PORT4         = 397U,

    /* I2S */
    EVT_I2S1_TXIRQOUT       = 400U,
    EVT_I2S1_RXIRQOUT       = 401U,
    EVT_I2S2_TXIRQOUT       = 403U,
    EVT_I2S2_RXIRQOUT       = 404U,
    EVT_I2S3_TXIRQOUT       = 406U,
    EVT_I2S3_RXIRQOUT       = 407U,
    EVT_I2S4_TXIRQOUT       = 409U,
    EVT_I2S4_RXIRQOUT       = 410U,

    /* COMPARATOR */
    EVT_ACMP1               = 416U,
    EVT_ACMP2               = 417U,
    EVT_ACMP3               = 418U,

    /* I2C */
    EVT_I2C1_RXI            = 420U,
    EVT_I2C1_TXI            = 421U,
    EVT_I2C1_TEI            = 422U,
    EVT_I2C1_EEI            = 423U,
    EVT_I2C2_RXI            = 424U,
    EVT_I2C2_TXI            = 425U,
    EVT_I2C2_TEI            = 426U,
    EVT_I2C2_EEI            = 427U,
    EVT_I2C3_RXI            = 428U,
    EVT_I2C3_TXI            = 429U,
    EVT_I2C3_TEI            = 430U,
    EVT_I2C3_EEI            = 431U,

    /* PVD */
    EVT_PVD_PVD1            = 433U,
    EVT_PVD_PVD2            = 434U,

    /* OTS */
    EVT_OTS                 = 435U,

    /* WDT */
    EVT_WDT_REFUDF          = 439U,

    /* ADC */
    EVT_ADC1_EOCA           = 448U,
    EVT_ADC1_EOCB           = 449U,
    EVT_ADC1_CHCMP          = 450U,
    EVT_ADC1_SEQCMP         = 451U,
    EVT_ADC2_EOCA           = 452U,
    EVT_ADC2_EOCB           = 453U,
    EVT_ADC2_CHCMP          = 454U,
    EVT_ADC2_SEQCMP         = 455U,

    /* TRNG */
    EVT_TRNG_END            = 456U,

    /* SDIO */
    EVT_SDIOC1_DMAR         = 480U,
    EVT_SDIOC1_DMAW         = 481U,
    EVT_SDIOC2_DMAR         = 483U,
    EVT_SDIOC2_DMAW         = 484U,
    EVT_MAX                 = 511U,
}en_event_src_t;

/**
 *******************************************************************************
 ** \brief Interrupt number enumeration
 ******************************************************************************/
typedef enum en_int_src
{
    INT_SWI_IRQ0            = 0U,
    INT_SWI_IRQ1            = 1U,
    INT_SWI_IRQ2            = 2U,
    INT_SWI_IRQ3            = 3U,
    INT_SWI_IRQ4            = 4U,
    INT_SWI_IRQ5            = 5U,
    INT_SWI_IRQ6            = 6U,
    INT_SWI_IRQ7            = 7U,
    INT_SWI_IRQ8            = 8U,
    INT_SWI_IRQ9            = 9U,
    INT_SWI_IRQ10           = 10U,
    INT_SWI_IRQ11           = 11U,
    INT_SWI_IRQ12           = 12U,
    INT_SWI_IRQ13           = 13U,
    INT_SWI_IRQ14           = 14U,
    INT_SWI_IRQ15           = 15U,
    INT_SWI_IRQ16           = 16U,
    INT_SWI_IRQ17           = 17U,
    INT_SWI_IRQ18           = 18U,
    INT_SWI_IRQ19           = 19U,
    INT_SWI_IRQ20           = 20U,
    INT_SWI_IRQ21           = 21U,
    INT_SWI_IRQ22           = 22U,
    INT_SWI_IRQ23           = 23U,
    INT_SWI_IRQ24           = 24U,
    INT_SWI_IRQ25           = 25U,
    INT_SWI_IRQ26           = 26U,
    INT_SWI_IRQ27           = 27U,
    INT_SWI_IRQ28           = 28U,
    INT_SWI_IRQ29           = 29U,
    INT_SWI_IRQ30           = 30U,
    INT_SWI_IRQ31           = 31U,

    /* External Interrupt. */
    INT_PORT_EIRQ0          = 0U,
    INT_PORT_EIRQ1          = 1U,
    INT_PORT_EIRQ2          = 2U,
    INT_PORT_EIRQ3          = 3U,
    INT_PORT_EIRQ4          = 4U,
    INT_PORT_EIRQ5          = 5U,
    INT_PORT_EIRQ6          = 6U,
    INT_PORT_EIRQ7          = 7U,
    INT_PORT_EIRQ8          = 8U,
    INT_PORT_EIRQ9          = 9U,
    INT_PORT_EIRQ10         = 10U,
    INT_PORT_EIRQ11         = 11U,
    INT_PORT_EIRQ12         = 12U,
    INT_PORT_EIRQ13         = 13U,
    INT_PORT_EIRQ14         = 14U,
    INT_PORT_EIRQ15         = 15U,

    /* DMAC */
    INT_DMA1_TC0            = 32U,
    INT_DMA1_TC1            = 33U,
    INT_DMA1_TC2            = 34U,
    INT_DMA1_TC3            = 35U,
    INT_DMA2_TC0            = 36U,
    INT_DMA2_TC1            = 37U,
    INT_DMA2_TC2            = 38U,
    INT_DMA2_TC3            = 39U,
    INT_DMA1_BTC0           = 40U,
    INT_DMA1_BTC1           = 41U,
    INT_DMA1_BTC2           = 42U,
    INT_DMA1_BTC3           = 43U,
    INT_DMA2_BTC0           = 44U,
    INT_DMA2_BTC1           = 45U,
    INT_DMA2_BTC2           = 46U,
    INT_DMA2_BTC3           = 47U,
    INT_DMA1_ERR            = 48U,
    INT_DMA2_ERR            = 49U,

    /* EFM */
    INT_EFM_PEERR           = 50U,
    INT_EFM_COLERR          = 51U,
    INT_EFM_OPTEND          = 52U,

    /* QSPI */
    INT_QSPI_INTR           = 54U,

    /* DCU */
    INT_DCU1                = 55U,
    INT_DCU2                = 56U,
    INT_DCU3                = 57U,
    INT_DCU4                = 58U,

    /* TIMER 0 */
    INT_TMR01_GCMA          = 64U,
    INT_TMR01_GCMB          = 65U,
    INT_TMR02_GCMA          = 66U,
    INT_TMR02_GCMB          = 67U,

    /* RTC */
    INT_RTC_ALM             = 81U,
    INT_RTC_PRD             = 82U,

    /* XTAL32 stop */
    INT_XTAL32_STOP         = 84U,

    /* XTAL stop */
    INT_XTAL_STOP           = 85U,

    /* wake-up timer */
    INT_WKTM_PRD            = 86U,

    /* SWDT */
    INT_SWDT_REFUDF         = 87U,

    /* TIMER 6 */
    INT_TMR61_GCMA          = 96U,
    INT_TMR61_GCMB          = 97U,
    INT_TMR61_GCMC          = 98U,
    INT_TMR61_GCMD          = 99U,
    INT_TMR61_GCME          = 100U,
    INT_TMR61_GCMF          = 101U,
    INT_TMR61_GOVF          = 102U,
    INT_TMR61_GUDF          = 103U,
    INT_TMR61_GDTE          = 104U,
    INT_TMR61_SCMA          = 107U,
    INT_TMR61_SCMB          = 108U,
    INT_TMR62_GCMA          = 112U,
    INT_TMR62_GCMB          = 113U,
    INT_TMR62_GCMC          = 114U,
    INT_TMR62_GCMD          = 115U,
    INT_TMR62_GCME          = 116U,
    INT_TMR62_GCMF          = 117U,
    INT_TMR62_GOVF          = 118U,
    INT_TMR62_GUDF          = 119U,
    INT_TMR62_GDTE          = 120U,
    INT_TMR62_SCMA          = 123U,
    INT_TMR62_SCMB          = 124U,
    INT_TMR63_GCMA          = 128U,
    INT_TMR63_GCMB          = 129U,
    INT_TMR63_GCMC          = 130U,
    INT_TMR63_GCMD          = 131U,
    INT_TMR63_GCME          = 132U,
    INT_TMR63_GCMF          = 133U,
    INT_TMR63_GOVF          = 134U,
    INT_TMR63_GUDF          = 135U,
    INT_TMR63_GDTE          = 136U,
    INT_TMR63_SCMA          = 139U,
    INT_TMR63_SCMB          = 140U,

    /* TIMER A */
    INT_TMRA1_OVF           = 256U,
    INT_TMRA1_UDF           = 257U,
    INT_TMRA1_CMP           = 258U,
    INT_TMRA2_OVF           = 259U,
    INT_TMRA2_UDF           = 260U,
    INT_TMRA2_CMP           = 261U,
    INT_TMRA3_OVF           = 262U,
    INT_TMRA3_UDF           = 263U,
    INT_TMRA3_CMP           = 264U,
    INT_TMRA4_OVF           = 265U,
    INT_TMRA4_UDF           = 266U,
    INT_TMRA4_CMP           = 267U,
    INT_TMRA5_OVF           = 268U,
    INT_TMRA5_UDF           = 269U,
    INT_TMRA5_CMP           = 270U,
    INT_TMRA6_OVF           = 272U,
    INT_TMRA6_UDF           = 273U,
    INT_TMRA6_CMP           = 274U,

    /* USB FS */
    INT_USBFS_GLB           = 275U,

    /* USRAT */
    INT_USART1_EI           = 278U,
    INT_USART1_RI           = 279U,
    INT_USART1_TI           = 280U,
    INT_USART1_TCI          = 281U,
    INT_USART1_RTO          = 282U,
    INT_USART1_WUPI         = 432U,
    INT_USART2_EI           = 283U,
    INT_USART2_RI           = 284U,
    INT_USART2_TI           = 285U,
    INT_USART2_TCI          = 286U,
    INT_USART2_RTO          = 287U,
    INT_USART3_EI           = 288U,
    INT_USART3_RI           = 289U,
    INT_USART3_TI           = 290U,
    INT_USART3_TCI          = 291U,
    INT_USART3_RTO          = 292U,
    INT_USART4_EI           = 293U,
    INT_USART4_RI           = 294U,
    INT_USART4_TI           = 295U,
    INT_USART4_TCI          = 296U,
    INT_USART4_RTO          = 297U,

    /* SPI */
    INT_SPI1_SPRI           = 299U,
    INT_SPI1_SPTI           = 300U,
    INT_SPI1_SPII           = 301U,
    INT_SPI1_SPEI           = 302U,
    INT_SPI2_SPRI           = 304U,
    INT_SPI2_SPTI           = 305U,
    INT_SPI2_SPII           = 306U,
    INT_SPI2_SPEI           = 307U,
    INT_SPI3_SPRI           = 309U,
    INT_SPI3_SPTI           = 310U,
    INT_SPI3_SPII           = 311U,
    INT_SPI3_SPEI           = 312U,
    INT_SPI4_SPRI           = 314U,
    INT_SPI4_SPTI           = 315U,
    INT_SPI4_SPII           = 316U,
    INT_SPI4_SPEI           = 317U,

    /* TIMER 4 */
    INT_TMR41_GCMUH         = 320U,
    INT_TMR41_GCMUL         = 321U,
    INT_TMR41_GCMVH         = 322U,
    INT_TMR41_GCMVL         = 323U,
    INT_TMR41_GCMWH         = 324U,
    INT_TMR41_GCMWL         = 325U,
    INT_TMR41_GOVF          = 326U,
    INT_TMR41_GUDF          = 327U,
    INT_TMR41_RLOU          = 328U,
    INT_TMR41_RLOV          = 329U,
    INT_TMR41_RLOW          = 330U,
    INT_TMR42_GCMUH         = 336U,
    INT_TMR42_GCMUL         = 337U,
    INT_TMR42_GCMVH         = 338U,
    INT_TMR42_GCMVL         = 339U,
    INT_TMR42_GCMWH         = 340U,
    INT_TMR42_GCMWL         = 341U,
    INT_TMR42_GOVF          = 342U,
    INT_TMR42_GUDF          = 343U,
    INT_TMR42_RLOU          = 344U,
    INT_TMR42_RLOV          = 345U,
    INT_TMR42_RLOW          = 346U,
    INT_TMR43_GCMUH         = 352U,
    INT_TMR43_GCMUL         = 353U,
    INT_TMR43_GCMVH         = 354U,
    INT_TMR43_GCMVL         = 355U,
    INT_TMR43_GCMWH         = 356U,
    INT_TMR43_GCMWL         = 357U,
    INT_TMR43_GOVF          = 358U,
    INT_TMR43_GUDF          = 359U,
    INT_TMR43_RLOU          = 360U,
    INT_TMR43_RLOV          = 361U,
    INT_TMR43_RLOW          = 362U,

    /* EMB */
    INT_EMB_GR0             = 390U,
    INT_EMB_GR1             = 391U,
    INT_EMB_GR2             = 392U,
    INT_EMB_GR3             = 393U,

    /* EVENT PORT */
    INT_EVENT_PORT1         = 394U,
    INT_EVENT_PORT2         = 395U,
    INT_EVENT_PORT3         = 396U,
    INT_EVENT_PORT4         = 397U,

    /* I2S */
    INT_I2S1_TXIRQOUT       = 400U,
    INT_I2S1_RXIRQOUT       = 401U,
    INT_I2S1_ERRIRQOUT      = 402U,
    INT_I2S2_TXIRQOUT       = 403U,
    INT_I2S2_RXIRQOUT       = 404U,
    INT_I2S2_ERRIRQOUT      = 405U,
    INT_I2S3_TXIRQOUT       = 406U,
    INT_I2S3_RXIRQOUT       = 407U,
    INT_I2S3_ERRIRQOUT      = 408U,
    INT_I2S4_TXIRQOUT       = 409U,
    INT_I2S4_RXIRQOUT       = 410U,
    INT_I2S4_ERRIRQOUT      = 411U,

    /* COMPARATOR */
    INT_ACMP1               = 416U,
    INT_ACMP2               = 417U,
    INT_ACMP3               = 418U,

    /* I2C */
    INT_I2C1_RXI            = 420U,
    INT_I2C1_TXI            = 421U,
    INT_I2C1_TEI            = 422U,
    INT_I2C1_EEI            = 423U,
    INT_I2C2_RXI            = 424U,
    INT_I2C2_TXI            = 425U,
    INT_I2C2_TEI            = 426U,
    INT_I2C2_EEI            = 427U,
    INT_I2C3_RXI            = 428U,
    INT_I2C3_TXI            = 429U,
    INT_I2C3_TEI            = 430U,
    INT_I2C3_EEI            = 431U,

    /* PVD */
    INT_PVD_PVD1            = 433U,
    INT_PVD_PVD2            = 434U,

    /* Temp. sensor */
    INT_OTS                 = 435U,

    /* FCM */
    INT_FCMFERRI            = 436U,
    INT_FCMMENDI            = 437U,
    INT_FCMCOVFI            = 438U,

    /* WDT */
    INT_WDT_REFUDF          = 439U,

    /* ADC */
    INT_ADC1_EOCA           = 448U,
    INT_ADC1_EOCB           = 449U,
    INT_ADC1_CHCMP          = 450U,
    INT_ADC1_SEQCMP         = 451U,
    INT_ADC2_EOCA           = 452U,
    INT_ADC2_EOCB           = 453U,
    INT_ADC2_CHCMP          = 454U,
    INT_ADC2_SEQCMP         = 455U,

    /* TRNG */
    INT_TRNG_END            = 456U,

    /* SDIOC */
    INT_SDIOC1_SD           = 482U,
    INT_SDIOC2_SD           = 485U,

    /* CAN */
    INT_CAN_INT             = 486U,

    INT_MAX                 = 511U,
}en_int_src_t;

/******************************************************************************/
/*                Device Specific Peripheral Registers structures             */
/******************************************************************************/

#if defined ( __CC_ARM   )
#pragma anon_unions
#endif

typedef struct
{
    __IO uint8_t STRT                       : 1;
    uint8_t RESERVED1                       : 7;
} stc_adc_str_field_t;

typedef struct
{
    __IO uint16_t MS                        : 2;
    uint16_t RESERVED2                      : 2;
    __IO uint16_t ACCSEL                    : 2;
    __IO uint16_t CLREN                     : 1;
    __IO uint16_t DFMT                      : 1;
    __IO uint16_t AVCNT                     : 3;
    uint16_t RESERVED11                     : 5;
} stc_adc_cr0_field_t;

typedef struct
{
    uint16_t RESERVED0                      : 2;
    __IO uint16_t RSCHSEL                   : 1;
    uint16_t RESERVED3                      :13;
} stc_adc_cr1_field_t;

typedef struct
{
    __IO uint16_t TRGSELA                   : 3;
    uint16_t RESERVED3                      : 4;
    __IO uint16_t TRGENA                    : 1;
    __IO uint16_t TRGSELB                   : 3;
    uint16_t RESERVED11                     : 4;
    __IO uint16_t TRGENB                    : 1;
} stc_adc_trgsr_field_t;

typedef struct
{
    __IO uint16_t CHSELA16                  : 1;
    uint16_t RESERVED1                      :15;
} stc_adc_chselra1_field_t;

typedef struct
{
    __IO uint16_t CHSELB16                  : 1;
    uint16_t RESERVED1                      :15;
} stc_adc_chselrb1_field_t;

typedef struct
{
    __IO uint16_t AVCHSEL16                 : 1;
    uint16_t RESERVED1                      :15;
} stc_adc_avchselr1_field_t;

typedef struct
{
    __IO uint16_t CH00MUX                   : 4;
    __IO uint16_t CH01MUX                   : 4;
    __IO uint16_t CH02MUX                   : 4;
    __IO uint16_t CH03MUX                   : 4;
} stc_adc_chmuxr0_field_t;

typedef struct
{
    __IO uint16_t CH04MUX                   : 4;
    __IO uint16_t CH05MUX                   : 4;
    __IO uint16_t CH06MUX                   : 4;
    __IO uint16_t CH07MUX                   : 4;
} stc_adc_chmuxr1_field_t;

typedef struct
{
    __IO uint16_t CH08MUX                   : 4;
    __IO uint16_t CH09MUX                   : 4;
    __IO uint16_t CH10MUX                   : 4;
    __IO uint16_t CH11MUX                   : 4;
} stc_adc_chmuxr2_field_t;

typedef struct
{
    __IO uint16_t CH12MUX                   : 4;
    __IO uint16_t CH13MUX                   : 4;
    __IO uint16_t CH14MUX                   : 4;
    __IO uint16_t CH15MUX                   : 4;
} stc_adc_chmuxr3_field_t;

typedef struct
{
    __IO uint8_t EOCAF                      : 1;
    __IO uint8_t EOCBF                      : 1;
    uint8_t RESERVED2                       : 6;
} stc_adc_isr_field_t;

typedef struct
{
    __IO uint8_t EOCAIEN                    : 1;
    __IO uint8_t EOCBIEN                    : 1;
    uint8_t RESERVED2                       : 6;
} stc_adc_icr_field_t;

typedef struct
{
    __IO uint16_t SYNCEN                    : 1;
    uint16_t RESERVED1                      : 3;
    __IO uint16_t SYNCMD                    : 3;
    uint16_t RESERVED7                      : 1;
    __IO uint16_t SYNCDLY                   : 8;
} stc_adc_synccr_field_t;

typedef struct
{
    __IO uint16_t AWDEN                     : 1;
    uint16_t RESERVED1                      : 3;
    __IO uint16_t AWDMD                     : 1;
    uint16_t RESERVED5                      : 1;
    __IO uint16_t AWDSS                     : 2;
    __IO uint16_t AWDIEN                    : 1;
    uint16_t RESERVED9                      : 7;
} stc_adc_awdcr_field_t;

typedef struct
{
    __IO uint16_t AWDCH16                   : 1;
    uint16_t RESERVED1                      :15;
} stc_adc_awdchsr1_field_t;

typedef struct
{
    __IO uint16_t AWDF16                    : 1;
    uint16_t RESERVED1                      :15;
} stc_adc_awdsr1_field_t;

typedef struct
{
    __IO uint16_t PGACTL                    : 4;
    uint16_t RESERVED4                      :12;
} stc_adc_pgacr_field_t;

typedef struct
{
    __IO uint16_t GAIN                      : 4;
    uint16_t RESERVED4                      :12;
} stc_adc_pgagsr_field_t;

typedef struct
{
    __IO uint16_t PGAINSEL                  : 9;
    uint16_t RESERVED9                      : 7;
} stc_adc_pgainsr0_field_t;

typedef struct
{
    __IO uint16_t PGAVSSEN                  : 1;
    uint16_t RESERVED1                      :15;
} stc_adc_pgainsr1_field_t;

typedef struct
{
    __IO uint32_t START                     : 1;
    __IO uint32_t MODE                      : 1;
    uint32_t RESERVED2                      :30;
} stc_aes_cr_field_t;

typedef struct
{
    __O  uint32_t STRG                      : 1;
    uint32_t RESERVED1                      :31;
} stc_aos_int_sfttrg_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_dcu1_trgsel_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_dcu2_trgsel_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_dcu3_trgsel_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_dcu4_trgsel_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_dma1_trgsel_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_dma1_trgsel3_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_dma2_trgsel_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_dma_trgselrc_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_tmr6_htssr_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_tmr0_htssr_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_pevnttrgsr12_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_pevnttrgsr34_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_tmra_htssr_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_ots_trg_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_adc1_itrgselr_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :21;
    __IO uint32_t COMTRG_EN                 : 2;
} stc_aos_adc2_itrgselr_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :23;
} stc_aos_comtrg1_field_t;

typedef struct
{
    __IO uint32_t TRGSEL                    : 9;
    uint32_t RESERVED9                      :23;
} stc_aos_comtrg2_field_t;

typedef struct
{
    __IO uint32_t PDIR00                    : 1;
    __IO uint32_t PDIR01                    : 1;
    __IO uint32_t PDIR02                    : 1;
    __IO uint32_t PDIR03                    : 1;
    __IO uint32_t PDIR04                    : 1;
    __IO uint32_t PDIR05                    : 1;
    __IO uint32_t PDIR06                    : 1;
    __IO uint32_t PDIR07                    : 1;
    __IO uint32_t PDIR08                    : 1;
    __IO uint32_t PDIR09                    : 1;
    __IO uint32_t PDIR10                    : 1;
    __IO uint32_t PDIR11                    : 1;
    __IO uint32_t PDIR12                    : 1;
    __IO uint32_t PDIR13                    : 1;
    __IO uint32_t PDIR14                    : 1;
    __IO uint32_t PDIR15                    : 1;
    uint32_t RESERVED16                     :16;
} stc_aos_pevntdirr_field_t;

typedef struct
{
    __I  uint32_t PIN00                     : 1;
    __I  uint32_t PIN01                     : 1;
    __I  uint32_t PIN02                     : 1;
    __I  uint32_t PIN03                     : 1;
    __I  uint32_t PIN04                     : 1;
    __I  uint32_t PIN05                     : 1;
    __I  uint32_t PIN06                     : 1;
    __I  uint32_t PIN07                     : 1;
    __I  uint32_t PIN08                     : 1;
    __I  uint32_t PIN09                     : 1;
    __I  uint32_t PIN10                     : 1;
    __I  uint32_t PIN11                     : 1;
    __I  uint32_t PIN12                     : 1;
    __I  uint32_t PIN13                     : 1;
    __I  uint32_t PIN14                     : 1;
    __I  uint32_t PIN15                     : 1;
    uint32_t RESERVED16                     :16;
} stc_aos_pevntidr_field_t;

typedef struct
{
    __IO uint32_t POUT00                    : 1;
    __IO uint32_t POUT01                    : 1;
    __IO uint32_t POUT02                    : 1;
    __IO uint32_t POUT03                    : 1;
    __IO uint32_t POUT04                    : 1;
    __IO uint32_t POUT05                    : 1;
    __IO uint32_t POUT06                    : 1;
    __IO uint32_t POUT07                    : 1;
    __IO uint32_t POUT08                    : 1;
    __IO uint32_t POUT09                    : 1;
    __IO uint32_t POUT10                    : 1;
    __IO uint32_t POUT11                    : 1;
    __IO uint32_t POUT12                    : 1;
    __IO uint32_t POUT13                    : 1;
    __IO uint32_t POUT14                    : 1;
    __IO uint32_t POUT15                    : 1;
    uint32_t RESERVED16                     :16;
} stc_aos_pevntodr_field_t;

typedef struct
{
    __IO uint32_t POR00                     : 1;
    __IO uint32_t POR01                     : 1;
    __IO uint32_t POR02                     : 1;
    __IO uint32_t POR03                     : 1;
    __IO uint32_t POR04                     : 1;
    __IO uint32_t POR05                     : 1;
    __IO uint32_t POR06                     : 1;
    __IO uint32_t POR07                     : 1;
    __IO uint32_t POR08                     : 1;
    __IO uint32_t POR09                     : 1;
    __IO uint32_t POR10                     : 1;
    __IO uint32_t POR11                     : 1;
    __IO uint32_t POR12                     : 1;
    __IO uint32_t POR13                     : 1;
    __IO uint32_t POR14                     : 1;
    __IO uint32_t POR15                     : 1;
    uint32_t RESERVED16                     :16;
} stc_aos_pevntorr_field_t;

typedef struct
{
    __IO uint32_t POS00                     : 1;
    __IO uint32_t POS01                     : 1;
    __IO uint32_t POS02                     : 1;
    __IO uint32_t POS03                     : 1;
    __IO uint32_t POS04                     : 1;
    __IO uint32_t POS05                     : 1;
    __IO uint32_t POS06                     : 1;
    __IO uint32_t POS07                     : 1;
    __IO uint32_t POS08                     : 1;
    __IO uint32_t POS09                     : 1;
    __IO uint32_t POS10                     : 1;
    __IO uint32_t POS11                     : 1;
    __IO uint32_t POS12                     : 1;
    __IO uint32_t POS13                     : 1;
    __IO uint32_t POS14                     : 1;
    __IO uint32_t POS15                     : 1;
    uint32_t RESERVED16                     :16;
} stc_aos_pevntosr_field_t;

typedef struct
{
    __IO uint32_t RIS00                     : 1;
    __IO uint32_t RIS01                     : 1;
    __IO uint32_t RIS02                     : 1;
    __IO uint32_t RIS03                     : 1;
    __IO uint32_t RIS04                     : 1;
    __IO uint32_t RIS05                     : 1;
    __IO uint32_t RIS06                     : 1;
    __IO uint32_t RIS07                     : 1;
    __IO uint32_t RIS08                     : 1;
    __IO uint32_t RIS09                     : 1;
    __IO uint32_t RIS10                     : 1;
    __IO uint32_t RIS11                     : 1;
    __IO uint32_t RIS12                     : 1;
    __IO uint32_t RIS13                     : 1;
    __IO uint32_t RIS14                     : 1;
    __IO uint32_t RIS15                     : 1;
    uint32_t RESERVED16                     :16;
} stc_aos_pevntrisr_field_t;

typedef struct
{
    __IO uint32_t FAL00                     : 1;
    __IO uint32_t FAL01                     : 1;
    __IO uint32_t FAL02                     : 1;
    __IO uint32_t FAL03                     : 1;
    __IO uint32_t FAL04                     : 1;
    __IO uint32_t FAL05                     : 1;
    __IO uint32_t FAL06                     : 1;
    __IO uint32_t FAL07                     : 1;
    __IO uint32_t FAL08                     : 1;
    __IO uint32_t FAL09                     : 1;
    __IO uint32_t FAL10                     : 1;
    __IO uint32_t FAL11                     : 1;
    __IO uint32_t FAL12                     : 1;
    __IO uint32_t FAL13                     : 1;
    __IO uint32_t FAL14                     : 1;
    __IO uint32_t FAL15                     : 1;
    uint32_t RESERVED16                     :16;
} stc_aos_pevntfal_field_t;

typedef struct
{
    __IO uint32_t NFEN1                     : 1;
    __IO uint32_t DIVS1                     : 2;
    uint32_t RESERVED3                      : 5;
    __IO uint32_t NFEN2                     : 1;
    __IO uint32_t DIVS2                     : 2;
    uint32_t RESERVED11                     : 5;
    __IO uint32_t NFEN3                     : 1;
    __IO uint32_t DIVS3                     : 2;
    uint32_t RESERVED19                     : 5;
    __IO uint32_t NFEN4                     : 1;
    __IO uint32_t DIVS4                     : 2;
    uint32_t RESERVED27                     : 5;
} stc_aos_pevntnfcr_field_t;

typedef struct
{
    __IO uint8_t BUSOFF                     : 1;
    __I  uint8_t TACTIVE                    : 1;
    __I  uint8_t RACTIVE                    : 1;
    __IO uint8_t TSSS                       : 1;
    __IO uint8_t TPSS                       : 1;
    __IO uint8_t LBMI                       : 1;
    __IO uint8_t LBME                       : 1;
    __IO uint8_t RESET                      : 1;
} stc_can_cfg_stat_field_t;

typedef struct
{
    __IO uint8_t TSA                        : 1;
    __IO uint8_t TSALL                      : 1;
    __IO uint8_t TSONE                      : 1;
    __IO uint8_t TPA                        : 1;
    __IO uint8_t TPE                        : 1;
    uint8_t RESERVED5                       : 1;
    __IO uint8_t LOM                        : 1;
    __IO uint8_t TBSEL                      : 1;
} stc_can_tcmd_field_t;

typedef struct
{
    __I  uint8_t TSSTAT                     : 2;
    uint8_t RESERVED2                       : 2;
    __IO uint8_t TTTBM                      : 1;
    __IO uint8_t TSMODE                     : 1;
    __IO uint8_t TSNEXT                     : 1;
    uint8_t RESERVED7                       : 1;
} stc_can_tctrl_field_t;

typedef struct
{
    __I  uint8_t RSTAT                      : 2;
    uint8_t RESERVED2                       : 1;
    __IO uint8_t RBALL                      : 1;
    __IO uint8_t RREL                       : 1;
    __I  uint8_t ROV                        : 1;
    __IO uint8_t ROM                        : 1;
    __IO uint8_t SACK                       : 1;
} stc_can_rctrl_field_t;

typedef struct
{
    __I  uint8_t TSFF                       : 1;
    __IO uint8_t EIE                        : 1;
    __IO uint8_t TSIE                       : 1;
    __IO uint8_t TPIE                       : 1;
    __IO uint8_t RAFIE                      : 1;
    __IO uint8_t RFIE                       : 1;
    __IO uint8_t ROIE                       : 1;
    __IO uint8_t RIE                        : 1;
} stc_can_rtie_field_t;

typedef struct
{
    __IO uint8_t AIF                        : 1;
    __IO uint8_t EIF                        : 1;
    __IO uint8_t TSIF                       : 1;
    __IO uint8_t TPIF                       : 1;
    __IO uint8_t RAFIF                      : 1;
    __IO uint8_t RFIF                       : 1;
    __IO uint8_t ROIF                       : 1;
    __IO uint8_t RIF                        : 1;
} stc_can_rtif_field_t;

typedef struct
{
    __IO uint8_t BEIF                       : 1;
    __IO uint8_t BEIE                       : 1;
    __IO uint8_t ALIF                       : 1;
    __IO uint8_t ALIE                       : 1;
    __IO uint8_t EPIF                       : 1;
    __IO uint8_t EPIE                       : 1;
    __I  uint8_t EPASS                      : 1;
    __I  uint8_t EWARN                      : 1;
} stc_can_errint_field_t;

typedef struct
{
    __IO uint8_t EWL                        : 4;
    __IO uint8_t AFWL                       : 4;
} stc_can_limit_field_t;

typedef struct
{
    __IO uint32_t SEG_1                     : 8;
    __IO uint32_t SEG_2                     : 7;
    uint32_t RESERVED15                     : 1;
    __IO uint32_t SJW                       : 7;
    uint32_t RESERVED23                     : 1;
    __IO uint32_t PRESC                     : 8;
} stc_can_bt_field_t;

typedef struct
{
    __I  uint8_t ALC                        : 5;
    __I  uint8_t KOER                       : 3;
} stc_can_ealcap_field_t;

typedef struct
{
    __IO uint8_t ACFADR                     : 4;
    uint8_t RESERVED4                       : 1;
    __IO uint8_t SELMASK                    : 1;
    uint8_t RESERVED6                       : 2;
} stc_can_acfctrl_field_t;

typedef struct
{
    __IO uint8_t AE_1                       : 1;
    __IO uint8_t AE_2                       : 1;
    __IO uint8_t AE_3                       : 1;
    __IO uint8_t AE_4                       : 1;
    __IO uint8_t AE_5                       : 1;
    __IO uint8_t AE_6                       : 1;
    __IO uint8_t AE_7                       : 1;
    __IO uint8_t AE_8                       : 1;
} stc_can_acfen_field_t;

typedef struct
{
    __IO uint32_t ACODEORAMASK              :29;
    __IO uint32_t AIDE                      : 1;
    __IO uint32_t AIDEE                     : 1;
    uint32_t RESERVED31                     : 1;
} stc_can_acf_field_t;

typedef struct
{
    __IO uint8_t TBPTR                      : 6;
    __IO uint8_t TBF                        : 1;
    __IO uint8_t TBE                        : 1;
} stc_can_tbslot_field_t;

typedef struct
{
    __IO uint8_t TTEN                       : 1;
    __IO uint8_t T_PRESC                    : 2;
    __IO uint8_t TTIF                       : 1;
    __IO uint8_t TTIE                       : 1;
    __IO uint8_t TEIF                       : 1;
    __IO uint8_t WTIF                       : 1;
    __IO uint8_t WTIE                       : 1;
} stc_can_ttcfg_field_t;

typedef struct
{
    __IO uint32_t REF_ID                    :29;
    uint32_t RESERVED29                     : 2;
    __IO uint32_t REF_IDE                   : 1;
} stc_can_ref_msg_field_t;

typedef struct
{
    __IO uint16_t TTPTR                     : 6;
    uint16_t RESERVED6                      : 2;
    __IO uint16_t TTYPE                     : 3;
    uint16_t RESERVED11                     : 1;
    __IO uint16_t TEW                       : 4;
} stc_can_trg_cfg_field_t;

typedef struct
{
    __IO uint16_t FLTSL                     : 3;
    uint16_t RESERVED3                      : 2;
    __IO uint16_t EDGSL                     : 2;
    __IO uint16_t IEN                       : 1;
    __IO uint16_t CVSEN                     : 1;
    uint16_t RESERVED9                      : 3;
    __IO uint16_t OUTEN                     : 1;
    __IO uint16_t INV                       : 1;
    __IO uint16_t CMPOE                     : 1;
    __IO uint16_t CMPON                     : 1;
} stc_cmp_ctrl_field_t;

typedef struct
{
    __IO uint16_t RVSL                      : 4;
    uint16_t RESERVED4                      : 4;
    __IO uint16_t CVSL                      : 4;
    __IO uint16_t C4SL                      : 3;
    uint16_t RESERVED15                     : 1;
} stc_cmp_vltsel_field_t;

typedef struct
{
    __I  uint16_t OMON                      : 1;
    uint16_t RESERVED1                      : 7;
    __I  uint16_t CVST                      : 4;
    uint16_t RESERVED12                     : 4;
} stc_cmp_outmon_field_t;

typedef struct
{
    __IO uint16_t STB                       : 4;
    uint16_t RESERVED4                      :12;
} stc_cmp_cvsstb_field_t;

typedef struct
{
    __IO uint16_t PRD                       : 8;
    uint16_t RESERVED8                      : 8;
} stc_cmp_cvsprd_field_t;

typedef struct
{
    __IO uint16_t DATA                      : 8;
    uint16_t RESERVED8                      : 8;
} stc_cmp_cr_dadr1_field_t;

typedef struct
{
    __IO uint16_t DATA                      : 8;
    uint16_t RESERVED8                      : 8;
} stc_cmp_cr_dadr2_field_t;

typedef struct
{
    __IO uint16_t DA1EN                     : 1;
    __IO uint16_t DA2EN                     : 1;
    uint16_t RESERVED2                      :14;
} stc_cmp_cr_dacr_field_t;

typedef struct
{
    __IO uint16_t DA1SW                     : 1;
    __IO uint16_t DA2SW                     : 1;
    uint16_t RESERVED2                      : 2;
    __IO uint16_t VREFSW                    : 1;
    uint16_t RESERVED5                      : 3;
    __IO uint16_t WPRT                      : 8;
} stc_cmp_cr_rvadc_field_t;

typedef struct
{
    uint32_t RESERVED0                      : 1;
    __IO uint32_t CRC_SEL                   : 1;
    __IO uint32_t REFIN                     : 1;
    __IO uint32_t REFOUT                    : 1;
    __IO uint32_t XOROUT                    : 1;
    uint32_t RESERVED5                      :27;
} stc_crc_cr_field_t;

typedef struct
{
    __IO uint32_t CRC_REG                   :16;
    __I  uint32_t CRCFLAG_16                : 1;
    uint32_t RESERVED17                     :15;
} stc_crc_reslt_field_t;

typedef struct
{
    __I  uint32_t FLAG                      : 1;
    uint32_t RESERVED1                      :31;
} stc_crc_flg_field_t;

typedef struct
{
    __IO uint32_t AUTH                      : 1;
    __IO uint32_t REMVLOCK                  : 1;
    __IO uint32_t SAFTYLOCK1                : 1;
    __IO uint32_t SAFTYLOCK2                : 1;
    uint32_t RESERVED4                      : 4;
    __IO uint32_t CPUSTOP                   : 1;
    __IO uint32_t CPUSLEEP                  : 1;
    uint32_t RESERVED10                     :22;
} stc_dbgc_mcustat_field_t;

typedef struct
{
    __IO uint32_t EDBGRQ                    : 1;
    __IO uint32_t RESTART                   : 1;
    uint32_t RESERVED2                      : 6;
    __IO uint32_t DIRQ                      : 1;
    uint32_t RESERVED9                      :23;
} stc_dbgc_mcuctl_field_t;

typedef struct
{
    __IO uint32_t ERASEREQ                  : 1;
    __IO uint32_t ERASEACK                  : 1;
    __IO uint32_t ERASEERR                  : 1;
    uint32_t RESERVED3                      :29;
} stc_dbgc_fmcctl_field_t;

typedef struct
{
    __IO uint32_t CDBGPWRUPREQ              : 1;
    __IO uint32_t CDBGPWRUPACK              : 1;
    uint32_t RESERVED2                      :30;
} stc_dbgc_mcudbgstat_field_t;

typedef struct
{
    __IO uint32_t SWDTSTP                   : 1;
    __IO uint32_t WDTSTP                    : 1;
    __IO uint32_t RTCSTP                    : 1;
    __IO uint32_t PVD0STP                   : 1;
    __IO uint32_t PVD1STP                   : 1;
    __IO uint32_t PVD2STP                   : 1;
    uint32_t RESERVED6                      : 8;
    __IO uint32_t TMR01STP                  : 1;
    __IO uint32_t TMR02STP                  : 1;
    uint32_t RESERVED16                     : 4;
    __IO uint32_t TMR41STP                  : 1;
    __IO uint32_t TMR42STP                  : 1;
    __IO uint32_t TMR43STP                  : 1;
    __IO uint32_t TM61STP                   : 1;
    __IO uint32_t TM62STP                   : 1;
    __IO uint32_t TMR63STP                  : 1;
    __IO uint32_t TMRA1STP                  : 1;
    __IO uint32_t TMRA2STP                  : 1;
    __IO uint32_t TMRA3STP                  : 1;
    __IO uint32_t TMRA4STP                  : 1;
    __IO uint32_t TMRA5STP                  : 1;
    __IO uint32_t TMRA6STP                  : 1;
} stc_dbgc_mcustpctl_field_t;

typedef struct
{
    __IO uint32_t TRACEMODE                 : 2;
    __IO uint32_t TRACEIOEN                 : 1;
    uint32_t RESERVED3                      :29;
} stc_dbgc_mcutracectl_field_t;

typedef struct
{
    __IO uint32_t MODE                      : 3;
    __IO uint32_t DATASIZE                  : 2;
    uint32_t RESERVED5                      : 3;
    __IO uint32_t COMP_TRG                  : 1;
    uint32_t RESERVED9                      :22;
    __IO uint32_t INTEN                     : 1;
} stc_dcu_ctl_field_t;

typedef struct
{
    __I  uint32_t FLAG_OP                   : 1;
    __I  uint32_t FLAG_LS2                  : 1;
    __I  uint32_t FLAG_EQ2                  : 1;
    __I  uint32_t FLAG_GT2                  : 1;
    __I  uint32_t FLAG_LS1                  : 1;
    __I  uint32_t FLAG_EQ1                  : 1;
    __I  uint32_t FLAG_GT1                  : 1;
    uint32_t RESERVED7                      :25;
} stc_dcu_flag_field_t;

typedef struct
{
    __O  uint32_t CLR_OP                    : 1;
    __O  uint32_t CLR_LS2                   : 1;
    __O  uint32_t CLR_EQ2                   : 1;
    __O  uint32_t CLR_GT2                   : 1;
    __O  uint32_t CLR_LS1                   : 1;
    __O  uint32_t CLR_EQ1                   : 1;
    __O  uint32_t CLR_GT1                   : 1;
    uint32_t RESERVED7                      :25;
} stc_dcu_flagclr_field_t;

typedef struct
{
    __IO uint32_t INT_OP                    : 1;
    __IO uint32_t INT_LS2                   : 1;
    __IO uint32_t INT_EQ2                   : 1;
    __IO uint32_t INT_GT2                   : 1;
    __IO uint32_t INT_LS1                   : 1;
    __IO uint32_t INT_EQ1                   : 1;
    __IO uint32_t INT_GT1                   : 1;
    __IO uint32_t INT_WIN                   : 2;
    uint32_t RESERVED9                      :23;
} stc_dcu_intsel_field_t;

typedef struct
{
    __IO uint32_t EN                        : 1;
    uint32_t RESERVED1                      :31;
} stc_dma_en_field_t;

typedef struct
{
    __I  uint32_t TRNERR                    : 4;
    uint32_t RESERVED4                      :12;
    __I  uint32_t REQERR                    : 4;
    uint32_t RESERVED20                     :12;
} stc_dma_intstat0_field_t;

typedef struct
{
    __I  uint32_t TC                        : 4;
    uint32_t RESERVED4                      :12;
    __I  uint32_t BTC                       : 4;
    uint32_t RESERVED20                     :12;
} stc_dma_intstat1_field_t;

typedef struct
{
    __IO uint32_t MSKTRNERR                 : 4;
    uint32_t RESERVED4                      :12;
    __IO uint32_t MSKREQERR                 : 4;
    uint32_t RESERVED20                     :12;
} stc_dma_intmask0_field_t;

typedef struct
{
    __IO uint32_t MSKTC                     : 4;
    uint32_t RESERVED4                      :12;
    __IO uint32_t MSKBTC                    : 4;
    uint32_t RESERVED20                     :12;
} stc_dma_intmask1_field_t;

typedef struct
{
    __O  uint32_t CLRTRNERR                 : 4;
    uint32_t RESERVED4                      :12;
    __O  uint32_t CLRREQERR                 : 4;
    uint32_t RESERVED20                     :12;
} stc_dma_intclr0_field_t;

typedef struct
{
    __O  uint32_t CLRTC                     : 4;
    uint32_t RESERVED4                      :12;
    __O  uint32_t CLRBTC                    : 4;
    uint32_t RESERVED20                     :12;
} stc_dma_intclr1_field_t;

typedef struct
{
    __IO uint32_t CHEN                      : 4;
    uint32_t RESERVED4                      :28;
} stc_dma_chen_field_t;

typedef struct
{
    __I  uint32_t CHREQ                     : 4;
    uint32_t RESERVED4                      :11;
    __I  uint32_t RCFGREQ                   : 1;
    uint32_t RESERVED16                     :16;
} stc_dma_reqstat_field_t;

typedef struct
{
    __I  uint32_t DMAACT                    : 1;
    __I  uint32_t RCFGACT                   : 1;
    uint32_t RESERVED2                      :14;
    __I  uint32_t CHACT                     : 4;
    uint32_t RESERVED20                     :12;
} stc_dma_chstat_field_t;

typedef struct
{
    __IO uint32_t RCFGEN                    : 1;
    __IO uint32_t RCFGLLP                   : 1;
    uint32_t RESERVED2                      : 6;
    __IO uint32_t RCFGCHS                   : 4;
    uint32_t RESERVED12                     : 4;
    __IO uint32_t SARMD                     : 2;
    __IO uint32_t DARMD                     : 2;
    __IO uint32_t CNTMD                     : 2;
    uint32_t RESERVED22                     :10;
} stc_dma_rcfgctl_field_t;

typedef struct
{
    __IO uint32_t BLKSIZE                   :10;
    uint32_t RESERVED10                     : 6;
    __IO uint32_t CNT                       :16;
} stc_dma_dtctl_field_t;

typedef struct
{
    __IO uint32_t SRPT                      :10;
    uint32_t RESERVED10                     : 6;
    __IO uint32_t DRPT                      :10;
    uint32_t RESERVED26                     : 6;
} stc_dma_rpt_field_t;

typedef struct
{
    __IO uint32_t SRPTB                     :10;
    uint32_t RESERVED10                     : 6;
    __IO uint32_t DRPTB                     :10;
    uint32_t RESERVED26                     : 6;
} stc_dma_rptb_field_t;

typedef struct
{
    __IO uint32_t SOFFSET                   :20;
    __IO uint32_t SNSCNT                    :12;
} stc_dma_snseqctl_field_t;

typedef struct
{
    __IO uint32_t SNSDIST                   :20;
    __IO uint32_t SNSCNTB                   :12;
} stc_dma_snseqctlb_field_t;

typedef struct
{
    __IO uint32_t DOFFSET                   :20;
    __IO uint32_t DNSCNT                    :12;
} stc_dma_dnseqctl_field_t;

typedef struct
{
    __IO uint32_t DNSDIST                   :20;
    __IO uint32_t DNSCNTB                   :12;
} stc_dma_dnseqctlb_field_t;

typedef struct
{
    uint32_t RESERVED0                      : 2;
    __IO uint32_t LLP                       :30;
} stc_dma_llp_field_t;

typedef struct
{
    __IO uint32_t SINC                      : 2;
    __IO uint32_t DINC                      : 2;
    __IO uint32_t SRPTEN                    : 1;
    __IO uint32_t DRPTEN                    : 1;
    __IO uint32_t SNSEQEN                   : 1;
    __IO uint32_t DNSEQEN                   : 1;
    __IO uint32_t HSIZE                     : 2;
    __IO uint32_t LLPEN                     : 1;
    __IO uint32_t LLPRUN                    : 1;
    __IO uint32_t IE                        : 1;
    uint32_t RESERVED13                     :19;
} stc_dma_chctl_field_t;

typedef struct
{
    __I  uint32_t BLKSIZE                   :10;
    uint32_t RESERVED10                     : 6;
    __I  uint32_t CNT                       :16;
} stc_dma_mondtctl_field_t;

typedef struct
{
    __I  uint32_t SRPT                      :10;
    uint32_t RESERVED10                     : 6;
    __I  uint32_t DRPT                      :10;
    uint32_t RESERVED26                     : 6;
} stc_dma_monrpt_field_t;

typedef struct
{
    __I  uint32_t SOFFSET                   :20;
    __I  uint32_t SNSCNT                    :12;
} stc_dma_monsnseqctl_field_t;

typedef struct
{
    __I  uint32_t DOFFSET                   :20;
    __I  uint32_t DNSCNT                    :12;
} stc_dma_mondnseqctl_field_t;

typedef struct
{
    __IO uint32_t FAPRT                     :16;
    uint32_t RESERVED16                     :16;
} stc_efm_faprt_field_t;

typedef struct
{
    __IO uint32_t FSTP                      : 1;
    uint32_t RESERVED1                      :31;
} stc_efm_fstp_field_t;

typedef struct
{
    __IO uint32_t SLPMD                     : 1;
    uint32_t RESERVED1                      : 3;
    __IO uint32_t FLWT                      : 4;
    __IO uint32_t LVM                       : 1;
    uint32_t RESERVED9                      : 7;
    __IO uint32_t CACHE                     : 1;
    uint32_t RESERVED17                     : 7;
    __IO uint32_t CRST                      : 1;
    uint32_t RESERVED25                     : 7;
} stc_efm_frmc_field_t;

typedef struct
{
    __IO uint32_t PEMODE                    : 1;
    uint32_t RESERVED1                      : 3;
    __IO uint32_t PEMOD                     : 3;
    uint32_t RESERVED7                      : 1;
    __IO uint32_t BUSHLDCTL                 : 1;
    uint32_t RESERVED9                      :23;
} stc_efm_fwmc_field_t;

typedef struct
{
    __I  uint32_t PEWERR                    : 1;
    __I  uint32_t PEPRTERR                  : 1;
    __I  uint32_t PGSZERR                   : 1;
    __I  uint32_t PGMISMTCH                 : 1;
    __I  uint32_t OPTEND                    : 1;
    __I  uint32_t COLERR                    : 1;
    uint32_t RESERVED6                      : 2;
    __I  uint32_t RDY                       : 1;
    uint32_t RESERVED9                      :23;
} stc_efm_fsr_field_t;

typedef struct
{
    __IO uint32_t PEWERRCLR                 : 1;
    __IO uint32_t PEPRTERRCLR               : 1;
    __IO uint32_t PGSZERRCLR                : 1;
    __IO uint32_t PGMISMTCHCLR              : 1;
    __IO uint32_t OPTENDCLR                 : 1;
    __IO uint32_t COLERRCLR                 : 1;
    uint32_t RESERVED6                      :26;
} stc_efm_fsclr_field_t;

typedef struct
{
    __IO uint32_t PEERRITE                  : 1;
    __IO uint32_t OPTENDITE                 : 1;
    __IO uint32_t COLERRITE                 : 1;
    uint32_t RESERVED3                      :29;
} stc_efm_fite_field_t;

typedef struct
{
    __I  uint32_t FSWP                      : 1;
    uint32_t RESERVED1                      :31;
} stc_efm_fswp_field_t;

typedef struct
{
    __IO uint32_t FPMTSW                    :19;
    uint32_t RESERVED19                     :13;
} stc_efm_fpmtsw_field_t;

typedef struct
{
    __IO uint32_t FPMTEW                    :19;
    uint32_t RESERVED19                     :13;
} stc_efm_fpmtew_field_t;

typedef struct
{
    __IO uint32_t REMPRT                    :16;
    uint32_t RESERVED16                     :16;
} stc_efm_mmf_remprt_field_t;

typedef struct
{
    __IO uint32_t RM0SIZE                   : 5;
    uint32_t RESERVED5                      : 7;
    __IO uint32_t RM0TADDR                  :17;
    uint32_t RESERVED29                     : 2;
    __IO uint32_t EN0                       : 1;
} stc_efm_mmf_remcr0_field_t;

typedef struct
{
    __IO uint32_t RM1SIZE                   : 5;
    uint32_t RESERVED5                      : 7;
    __IO uint32_t RM1TADDR                  :17;
    uint32_t RESERVED29                     : 2;
    __IO uint32_t EN1                       : 1;
} stc_efm_mmf_remcr1_field_t;

typedef struct
{
    uint32_t RESERVED0                      : 1;
    __IO uint32_t FRANDS                    :14;
    uint32_t RESERVED15                     : 1;
    __IO uint32_t FRANDFG                   : 1;
    uint32_t RESERVED17                     :15;
} stc_efm_frands_field_t;

typedef struct
{
    __IO uint32_t PORTINEN                  : 1;
    __IO uint32_t CMPEN                     : 3;
    uint32_t RESERVED4                      : 1;
    __IO uint32_t OSCSTPEN                  : 1;
    __IO uint32_t PWMSEN                    : 3;
    uint32_t RESERVED9                      :19;
    __IO uint32_t NFSEL                     : 2;
    __IO uint32_t NFEN                      : 1;
    __IO uint32_t INVSEL                    : 1;
} stc_emb_ctl_field_t;

typedef struct
{
    __IO uint32_t PWMLV                     : 3;
    uint32_t RESERVED3                      :29;
} stc_emb_pwmlv_field_t;

typedef struct
{
    __IO uint32_t SOE                       : 1;
    uint32_t RESERVED1                      :31;
} stc_emb_soe_field_t;

typedef struct
{
    __I  uint32_t PORTINF                   : 1;
    __I  uint32_t PWMSF                     : 1;
    __I  uint32_t CMPF                      : 1;
    __I  uint32_t OSF                       : 1;
    __I  uint32_t PORTINST                  : 1;
    __I  uint32_t PWMST                     : 1;
    uint32_t RESERVED6                      :26;
} stc_emb_stat_field_t;

typedef struct
{
    __O  uint32_t PORTINFCLR                : 1;
    __O  uint32_t PWMSFCLR                  : 1;
    __O  uint32_t CMPFCLR                   : 1;
    __O  uint32_t OSFCLR                    : 1;
    uint32_t RESERVED4                      :28;
} stc_emb_statclr_field_t;

typedef struct
{
    __IO uint32_t PORTINTEN                 : 1;
    __IO uint32_t PWMINTEN                  : 1;
    __IO uint32_t CMPINTEN                  : 1;
    __IO uint32_t OSINTEN                   : 1;
    uint32_t RESERVED4                      :28;
} stc_emb_inten_field_t;

typedef struct
{
    __IO uint32_t LVR                       :16;
    uint32_t RESERVED16                     :16;
} stc_fcm_lvr_field_t;

typedef struct
{
    __IO uint32_t UVR                       :16;
    uint32_t RESERVED16                     :16;
} stc_fcm_uvr_field_t;

typedef struct
{
    __I  uint32_t CNTR                      :16;
    uint32_t RESERVED16                     :16;
} stc_fcm_cntr_field_t;

typedef struct
{
    __IO uint32_t START                     : 1;
    uint32_t RESERVED1                      :31;
} stc_fcm_str_field_t;

typedef struct
{
    __IO uint32_t MDIVS                     : 2;
    uint32_t RESERVED2                      : 2;
    __IO uint32_t MCKS                      : 4;
    uint32_t RESERVED8                      :24;
} stc_fcm_mccr_field_t;

typedef struct
{
    __IO uint32_t RDIVS                     : 2;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t RCKS                      : 4;
    __IO uint32_t INEXS                     : 1;
    __IO uint32_t DNFS                      : 2;
    uint32_t RESERVED10                     : 2;
    __IO uint32_t EDGES                     : 2;
    uint32_t RESERVED14                     : 1;
    __IO uint32_t EXREFE                    : 1;
    uint32_t RESERVED16                     :16;
} stc_fcm_rccr_field_t;

typedef struct
{
    __IO uint32_t ERRIE                     : 1;
    __IO uint32_t MENDIE                    : 1;
    __IO uint32_t OVFIE                     : 1;
    uint32_t RESERVED3                      : 1;
    __IO uint32_t ERRINTRS                  : 1;
    uint32_t RESERVED5                      : 2;
    __IO uint32_t ERRE                      : 1;
    uint32_t RESERVED8                      :24;
} stc_fcm_rier_field_t;

typedef struct
{
    __I  uint32_t ERRF                      : 1;
    __I  uint32_t MENDF                     : 1;
    __I  uint32_t OVF                       : 1;
    uint32_t RESERVED3                      :29;
} stc_fcm_sr_field_t;

typedef struct
{
    __O  uint32_t ERRFCLR                   : 1;
    __O  uint32_t MENDFCLR                  : 1;
    __O  uint32_t OVFCLR                    : 1;
    uint32_t RESERVED3                      :29;
} stc_fcm_clr_field_t;

typedef struct
{
    __IO uint32_t START                     : 1;
    __IO uint32_t FST_GRP                   : 1;
    uint32_t RESERVED2                      :30;
} stc_hash_cr_field_t;

typedef struct
{
    __IO uint32_t PE                        : 1;
    __IO uint32_t SMBUS                     : 1;
    __IO uint32_t SMBALRTEN                 : 1;
    __IO uint32_t SMBDEFAULTEN              : 1;
    __IO uint32_t SMBHOSTEN                 : 1;
    uint32_t RESERVED5                      : 1;
    __IO uint32_t ENGC                      : 1;
    __IO uint32_t RESTART                   : 1;
    __IO uint32_t START                     : 1;
    __IO uint32_t STOP                      : 1;
    __IO uint32_t ACK                       : 1;
    uint32_t RESERVED11                     : 4;
    __IO uint32_t SWRST                     : 1;
    uint32_t RESERVED16                     :16;
} stc_i2c_cr1_field_t;

typedef struct
{
    __IO uint32_t STARTIE                   : 1;
    __IO uint32_t SLADDR0IE                 : 1;
    __IO uint32_t SLADDR1IE                 : 1;
    __IO uint32_t TENDIE                    : 1;
    __IO uint32_t STOPIE                    : 1;
    uint32_t RESERVED5                      : 1;
    __IO uint32_t RFULLIE                   : 1;
    __IO uint32_t TEMPTYIE                  : 1;
    uint32_t RESERVED8                      : 1;
    __IO uint32_t ARLOIE                    : 1;
    uint32_t RESERVED10                     : 2;
    __IO uint32_t NACKIE                    : 1;
    uint32_t RESERVED13                     : 1;
    __IO uint32_t TMOUTIE                   : 1;
    uint32_t RESERVED15                     : 5;
    __IO uint32_t GENCALLIE                 : 1;
    __IO uint32_t SMBDEFAULTIE              : 1;
    __IO uint32_t SMBHOSTIE                 : 1;
    __IO uint32_t SMBALRTIE                 : 1;
    uint32_t RESERVED24                     : 8;
} stc_i2c_cr2_field_t;

typedef struct
{
    __IO uint32_t TMOUTEN                   : 1;
    __IO uint32_t LTMOUT                    : 1;
    __IO uint32_t HTMOUT                    : 1;
    uint32_t RESERVED3                      : 4;
    __IO uint32_t FACKEN                    : 1;
    uint32_t RESERVED8                      :24;
} stc_i2c_cr3_field_t;

typedef struct
{
    uint32_t RESERVED0                      :10;
    __IO uint32_t BUSWAIT                   : 1;
    uint32_t RESERVED11                     :21;
} stc_i2c_cr4_field_t;

typedef struct
{
    __IO uint32_t SLADDR0                   :10;
    uint32_t RESERVED10                     : 2;
    __IO uint32_t SLADDR0EN                 : 1;
    uint32_t RESERVED13                     : 2;
    __IO uint32_t ADDRMOD0                  : 1;
    uint32_t RESERVED16                     :16;
} stc_i2c_slr0_field_t;

typedef struct
{
    __IO uint32_t SLADDR1                   :10;
    uint32_t RESERVED10                     : 2;
    __IO uint32_t SLADDR1EN                 : 1;
    uint32_t RESERVED13                     : 2;
    __IO uint32_t ADDRMOD1                  : 1;
    uint32_t RESERVED16                     :16;
} stc_i2c_slr1_field_t;

typedef struct
{
    __IO uint32_t TOUTLOW                   :16;
    __IO uint32_t TOUTHIGH                  :16;
} stc_i2c_sltr_field_t;

typedef struct
{
    __IO uint32_t STARTF                    : 1;
    __IO uint32_t SLADDR0F                  : 1;
    __IO uint32_t SLADDR1F                  : 1;
    __IO uint32_t TENDF                     : 1;
    __IO uint32_t STOPF                     : 1;
    uint32_t RESERVED5                      : 1;
    __IO uint32_t RFULLF                    : 1;
    __IO uint32_t TEMPTYF                   : 1;
    uint32_t RESERVED8                      : 1;
    __IO uint32_t ARLOF                     : 1;
    __IO uint32_t ACKRF                     : 1;
    uint32_t RESERVED11                     : 1;
    __IO uint32_t NACKF                     : 1;
    uint32_t RESERVED13                     : 1;
    __IO uint32_t TMOUTF                    : 1;
    uint32_t RESERVED15                     : 1;
    __IO uint32_t MSL                       : 1;
    __IO uint32_t BUSY                      : 1;
    __IO uint32_t TRA                       : 1;
    uint32_t RESERVED19                     : 1;
    __IO uint32_t GENCALLF                  : 1;
    __IO uint32_t SMBDEFAULTF               : 1;
    __IO uint32_t SMBHOSTF                  : 1;
    __IO uint32_t SMBALRTF                  : 1;
    uint32_t RESERVED24                     : 8;
} stc_i2c_sr_field_t;

typedef struct
{
    __O  uint32_t STARTFCLR                 : 1;
    __O  uint32_t SLADDR0FCLR               : 1;
    __O  uint32_t SLADDR1FCLR               : 1;
    __O  uint32_t TENDFCLR                  : 1;
    __O  uint32_t STOPFCLR                  : 1;
    uint32_t RESERVED5                      : 1;
    __O  uint32_t RFULLFCLR                 : 1;
    __O  uint32_t TEMPTYFCLR                : 1;
    uint32_t RESERVED8                      : 1;
    __O  uint32_t ARLOFCLR                  : 1;
    uint32_t RESERVED10                     : 2;
    __O  uint32_t NACKFCLR                  : 1;
    uint32_t RESERVED13                     : 1;
    __O  uint32_t TMOUTFCLR                 : 1;
    uint32_t RESERVED15                     : 5;
    __O  uint32_t GENCALLFCLR               : 1;
    __O  uint32_t SMBDEFAULTFCLR            : 1;
    __O  uint32_t SMBHOSTFCLR               : 1;
    __O  uint32_t SMBALRTFCLR               : 1;
    uint32_t RESERVED24                     : 8;
} stc_i2c_clr_field_t;

typedef struct
{
    __O  uint8_t DT                         : 8;
} stc_i2c_dtr_field_t;

typedef struct
{
    __I  uint8_t DR                         : 8;
} stc_i2c_drr_field_t;

typedef struct
{
    __IO uint32_t SLOWW                     : 5;
    uint32_t RESERVED5                      : 3;
    __IO uint32_t SHIGHW                    : 5;
    uint32_t RESERVED13                     : 3;
    __IO uint32_t FREQ                      : 3;
    uint32_t RESERVED19                     :13;
} stc_i2c_ccr_field_t;

typedef struct
{
    __IO uint32_t DNF                       : 2;
    uint32_t RESERVED2                      : 2;
    __IO uint32_t DNFEN                     : 1;
    __IO uint32_t ANFEN                     : 1;
    uint32_t RESERVED6                      :26;
} stc_i2c_fltr_field_t;

typedef struct
{
    __IO uint32_t TXE                       : 1;
    __IO uint32_t TXIE                      : 1;
    __IO uint32_t RXE                       : 1;
    __IO uint32_t RXIE                      : 1;
    __IO uint32_t EIE                       : 1;
    __IO uint32_t WMS                       : 1;
    __IO uint32_t ODD                       : 1;
    __IO uint32_t MCKOE                     : 1;
    __IO uint32_t TXBIRQWL                  : 3;
    uint32_t RESERVED11                     : 1;
    __IO uint32_t RXBIRQWL                  : 3;
    uint32_t RESERVED15                     : 1;
    __IO uint32_t FIFOR                     : 1;
    __IO uint32_t CODECRC                   : 1;
    __IO uint32_t I2SPLLSEL                 : 1;
    __IO uint32_t SDOE                      : 1;
    __IO uint32_t LRCKOE                    : 1;
    __IO uint32_t CKOE                      : 1;
    __IO uint32_t DUPLEX                    : 1;
    __IO uint32_t CLKSEL                    : 1;
    uint32_t RESERVED24                     : 8;
} stc_i2s_ctrl_field_t;

typedef struct
{
    __I  uint32_t TXBA                      : 1;
    __I  uint32_t RXBA                      : 1;
    __I  uint32_t TXBE                      : 1;
    __I  uint32_t TXBF                      : 1;
    __I  uint32_t RXBE                      : 1;
    __I  uint32_t RXBF                      : 1;
    uint32_t RESERVED6                      :26;
} stc_i2s_sr_field_t;

typedef struct
{
    __IO uint32_t TXERR                     : 1;
    __IO uint32_t RXERR                     : 1;
    uint32_t RESERVED2                      :30;
} stc_i2s_er_field_t;

typedef struct
{
    __IO uint32_t I2SSTD                    : 2;
    __IO uint32_t DATLEN                    : 2;
    __IO uint32_t CHLEN                     : 1;
    __IO uint32_t PCMSYNC                   : 1;
    uint32_t RESERVED6                      :26;
} stc_i2s_cfgr_field_t;

typedef struct
{
    __IO uint32_t I2SDIV                    : 8;
    uint32_t RESERVED8                      :24;
} stc_i2s_pr_field_t;

typedef struct
{
    __I  uint32_t SWDTAUTS                  : 1;
    __I  uint32_t SWDTITS                   : 1;
    __I  uint32_t SWDTPERI                  : 2;
    __I  uint32_t SWDTCKS                   : 4;
    __I  uint32_t SWDTWDPT                  : 4;
    __I  uint32_t SWDTSLPOFF                : 1;
    uint32_t RESERVED13                     : 3;
    __I  uint32_t WDTAUTS                   : 1;
    __I  uint32_t WDTITS                    : 1;
    __I  uint32_t WDTPERI                   : 2;
    __I  uint32_t WDTCKS                    : 4;
    __I  uint32_t WDTWDPT                   : 4;
    __I  uint32_t WDTSLPOFF                 : 1;
    uint32_t RESERVED29                     : 3;
} stc_icg_icg0_field_t;

typedef struct
{
    __I  uint32_t HRCFREQSEL                : 1;
    uint32_t RESERVED1                      : 7;
    __I  uint32_t HRCSTOP                   : 1;
    uint32_t RESERVED9                      : 7;
    __I  uint32_t BOR_LEV                   : 2;
    __I  uint32_t BORDIS                    : 1;
    uint32_t RESERVED19                     : 7;
    __I  uint32_t SMPCLK                    : 2;
    __I  uint32_t NMITRG                    : 1;
    __I  uint32_t NMIENR                    : 1;
    __I  uint32_t NFEN                      : 1;
    __I  uint32_t NMIICGENA                 : 1;
} stc_icg_icg1_field_t;

typedef struct
{
    __IO uint32_t NMITRG                    : 1;
    uint32_t RESERVED1                      : 3;
    __IO uint32_t NSMPCLK                   : 2;
    uint32_t RESERVED6                      : 1;
    __IO uint32_t NFEN                      : 1;
    uint32_t RESERVED8                      :24;
} stc_intc_nmicr_field_t;

typedef struct
{
    __IO uint32_t NMIENR                    : 1;
    __IO uint32_t SWDTENR                   : 1;
    __IO uint32_t PVD1ENR                   : 1;
    __IO uint32_t PVD2ENR                   : 1;
    uint32_t RESERVED4                      : 1;
    __IO uint32_t XTALSTPENR                : 1;
    uint32_t RESERVED6                      : 2;
    __IO uint32_t REPENR                    : 1;
    __IO uint32_t RECCENR                   : 1;
    __IO uint32_t BUSMENR                   : 1;
    __IO uint32_t WDTENR                    : 1;
    uint32_t RESERVED12                     :20;
} stc_intc_nmienr_field_t;

typedef struct
{
    __IO uint32_t NMIFR                     : 1;
    __IO uint32_t SWDTFR                    : 1;
    __IO uint32_t PVD1FR                    : 1;
    __IO uint32_t PVD2FR                    : 1;
    uint32_t RESERVED4                      : 1;
    __IO uint32_t XTALSTPFR                 : 1;
    uint32_t RESERVED6                      : 2;
    __IO uint32_t REPFR                     : 1;
    __IO uint32_t RECCFR                    : 1;
    __IO uint32_t BUSMFR                    : 1;
    __IO uint32_t WDTFR                     : 1;
    uint32_t RESERVED12                     :20;
} stc_intc_nmifr_field_t;

typedef struct
{
    __IO uint32_t NMICFR                    : 1;
    __IO uint32_t SWDTCFR                   : 1;
    __IO uint32_t PVD1CFR                   : 1;
    __IO uint32_t PVD2CFR                   : 1;
    uint32_t RESERVED4                      : 1;
    __IO uint32_t XTALSTPCFR                : 1;
    uint32_t RESERVED6                      : 2;
    __IO uint32_t REPCFR                    : 1;
    __IO uint32_t RECCCFR                   : 1;
    __IO uint32_t BUSMCFR                   : 1;
    __IO uint32_t WDTCFR                    : 1;
    uint32_t RESERVED12                     :20;
} stc_intc_nmicfr_field_t;

typedef struct
{
    __IO uint32_t EIRQTRG                   : 2;
    uint32_t RESERVED2                      : 2;
    __IO uint32_t EISMPCLK                  : 2;
    uint32_t RESERVED6                      : 1;
    __IO uint32_t EFEN                      : 1;
    uint32_t RESERVED8                      :24;
} stc_intc_eirqcr_field_t;

typedef struct
{
    __IO uint32_t EIRQWUEN                  :16;
    __IO uint32_t SWDTWUEN                  : 1;
    __IO uint32_t PVD1WUEN                  : 1;
    __IO uint32_t PVD2WUEN                  : 1;
    __IO uint32_t CMPI0WUEN                 : 1;
    __IO uint32_t WKTMWUEN                  : 1;
    __IO uint32_t RTCALMWUEN                : 1;
    __IO uint32_t RTCPRDWUEN                : 1;
    __IO uint32_t TMR0WUEN                  : 1;
    uint32_t RESERVED24                     : 1;
    __IO uint32_t RXWUEN                    : 1;
    uint32_t RESERVED26                     : 6;
} stc_intc_wupen_field_t;

typedef struct
{
    __IO uint32_t EIFR0                     : 1;
    __IO uint32_t EIFR1                     : 1;
    __IO uint32_t EIFR2                     : 1;
    __IO uint32_t EIFR3                     : 1;
    __IO uint32_t EIFR4                     : 1;
    __IO uint32_t EIFR5                     : 1;
    __IO uint32_t EIFR6                     : 1;
    __IO uint32_t EIFR7                     : 1;
    __IO uint32_t EIFR8                     : 1;
    __IO uint32_t EIFR9                     : 1;
    __IO uint32_t EIFR10                    : 1;
    __IO uint32_t EIFR11                    : 1;
    __IO uint32_t EIFR12                    : 1;
    __IO uint32_t EIFR13                    : 1;
    __IO uint32_t EIFR14                    : 1;
    __IO uint32_t EIFR15                    : 1;
    uint32_t RESERVED16                     :16;
} stc_intc_eifr_field_t;

typedef struct
{
    __IO uint32_t EICFR0                    : 1;
    __IO uint32_t EICFR1                    : 1;
    __IO uint32_t EICFR2                    : 1;
    __IO uint32_t EICFR3                    : 1;
    __IO uint32_t EICFR4                    : 1;
    __IO uint32_t EICFR5                    : 1;
    __IO uint32_t EICFR6                    : 1;
    __IO uint32_t EICFR7                    : 1;
    __IO uint32_t EICFR8                    : 1;
    __IO uint32_t EICFR9                    : 1;
    __IO uint32_t EICFR10                   : 1;
    __IO uint32_t EICFR11                   : 1;
    __IO uint32_t EICFR12                   : 1;
    __IO uint32_t EICFR13                   : 1;
    __IO uint32_t EICFR14                   : 1;
    __IO uint32_t EICFR15                   : 1;
    uint32_t RESERVED16                     :16;
} stc_intc_eicfr_field_t;

typedef struct
{
    __IO uint32_t INTSEL                    : 9;
    uint32_t RESERVED9                      :23;
} stc_intc_sel_field_t;

typedef struct
{
    __IO uint32_t VSEL0                     : 1;
    __IO uint32_t VSEL1                     : 1;
    __IO uint32_t VSEL2                     : 1;
    __IO uint32_t VSEL3                     : 1;
    __IO uint32_t VSEL4                     : 1;
    __IO uint32_t VSEL5                     : 1;
    __IO uint32_t VSEL6                     : 1;
    __IO uint32_t VSEL7                     : 1;
    __IO uint32_t VSEL8                     : 1;
    __IO uint32_t VSEL9                     : 1;
    __IO uint32_t VSEL10                    : 1;
    __IO uint32_t VSEL11                    : 1;
    __IO uint32_t VSEL12                    : 1;
    __IO uint32_t VSEL13                    : 1;
    __IO uint32_t VSEL14                    : 1;
    __IO uint32_t VSEL15                    : 1;
    __IO uint32_t VSEL16                    : 1;
    __IO uint32_t VSEL17                    : 1;
    __IO uint32_t VSEL18                    : 1;
    __IO uint32_t VSEL19                    : 1;
    __IO uint32_t VSEL20                    : 1;
    __IO uint32_t VSEL21                    : 1;
    __IO uint32_t VSEL22                    : 1;
    __IO uint32_t VSEL23                    : 1;
    __IO uint32_t VSEL24                    : 1;
    __IO uint32_t VSEL25                    : 1;
    __IO uint32_t VSEL26                    : 1;
    __IO uint32_t VSEL27                    : 1;
    __IO uint32_t VSEL28                    : 1;
    __IO uint32_t VSEL29                    : 1;
    __IO uint32_t VSEL30                    : 1;
    __IO uint32_t VSEL31                    : 1;
} stc_intc_vssel_field_t;

typedef struct
{
    __IO uint32_t SWIE0                     : 1;
    __IO uint32_t SWIE1                     : 1;
    __IO uint32_t SWIE2                     : 1;
    __IO uint32_t SWIE3                     : 1;
    __IO uint32_t SWIE4                     : 1;
    __IO uint32_t SWIE5                     : 1;
    __IO uint32_t SWIE6                     : 1;
    __IO uint32_t SWIE7                     : 1;
    __IO uint32_t SWIE8                     : 1;
    __IO uint32_t SWIE9                     : 1;
    __IO uint32_t SWIE10                    : 1;
    __IO uint32_t SWIE11                    : 1;
    __IO uint32_t SWIE12                    : 1;
    __IO uint32_t SWIE13                    : 1;
    __IO uint32_t SWIE14                    : 1;
    __IO uint32_t SWIE15                    : 1;
    __IO uint32_t SWIE16                    : 1;
    __IO uint32_t SWIE17                    : 1;
    __IO uint32_t SWIE18                    : 1;
    __IO uint32_t SWIE19                    : 1;
    __IO uint32_t SWIE20                    : 1;
    __IO uint32_t SWIE21                    : 1;
    __IO uint32_t SWIE22                    : 1;
    __IO uint32_t SWIE23                    : 1;
    __IO uint32_t SWIE24                    : 1;
    __IO uint32_t SWIE25                    : 1;
    __IO uint32_t SWIE26                    : 1;
    __IO uint32_t SWIE27                    : 1;
    __IO uint32_t SWIE28                    : 1;
    __IO uint32_t SWIE29                    : 1;
    __IO uint32_t SWIE30                    : 1;
    __IO uint32_t SWIE31                    : 1;
} stc_intc_swier_field_t;

typedef struct
{
    __IO uint32_t EVTE0                     : 1;
    __IO uint32_t EVTE1                     : 1;
    __IO uint32_t EVTE2                     : 1;
    __IO uint32_t EVTE3                     : 1;
    __IO uint32_t EVTE4                     : 1;
    __IO uint32_t EVTE5                     : 1;
    __IO uint32_t EVTE6                     : 1;
    __IO uint32_t EVTE7                     : 1;
    __IO uint32_t EVTE8                     : 1;
    __IO uint32_t EVTE9                     : 1;
    __IO uint32_t EVTE10                    : 1;
    __IO uint32_t EVTE11                    : 1;
    __IO uint32_t EVTE12                    : 1;
    __IO uint32_t EVTE13                    : 1;
    __IO uint32_t EVTE14                    : 1;
    __IO uint32_t EVTE15                    : 1;
    __IO uint32_t EVTE16                    : 1;
    __IO uint32_t EVTE17                    : 1;
    __IO uint32_t EVTE18                    : 1;
    __IO uint32_t EVTE19                    : 1;
    __IO uint32_t EVTE20                    : 1;
    __IO uint32_t EVTE21                    : 1;
    __IO uint32_t EVTE22                    : 1;
    __IO uint32_t EVTE23                    : 1;
    __IO uint32_t EVTE24                    : 1;
    __IO uint32_t EVTE25                    : 1;
    __IO uint32_t EVTE26                    : 1;
    __IO uint32_t EVTE27                    : 1;
    __IO uint32_t EVTE28                    : 1;
    __IO uint32_t EVTE29                    : 1;
    __IO uint32_t EVTE30                    : 1;
    __IO uint32_t EVTE31                    : 1;
} stc_intc_evter_field_t;

typedef struct
{
    __IO uint32_t IER0                      : 1;
    __IO uint32_t IER1                      : 1;
    __IO uint32_t IER2                      : 1;
    __IO uint32_t IER3                      : 1;
    __IO uint32_t IER4                      : 1;
    __IO uint32_t IER5                      : 1;
    __IO uint32_t IER6                      : 1;
    __IO uint32_t IER7                      : 1;
    __IO uint32_t IER8                      : 1;
    __IO uint32_t IER9                      : 1;
    __IO uint32_t IER10                     : 1;
    __IO uint32_t IER11                     : 1;
    __IO uint32_t IER12                     : 1;
    __IO uint32_t IER13                     : 1;
    __IO uint32_t IER14                     : 1;
    __IO uint32_t IER15                     : 1;
    __IO uint32_t IER16                     : 1;
    __IO uint32_t IER17                     : 1;
    __IO uint32_t IER18                     : 1;
    __IO uint32_t IER19                     : 1;
    __IO uint32_t IER20                     : 1;
    __IO uint32_t IER21                     : 1;
    __IO uint32_t IER22                     : 1;
    __IO uint32_t IER23                     : 1;
    __IO uint32_t IER24                     : 1;
    __IO uint32_t IER25                     : 1;
    __IO uint32_t IER26                     : 1;
    __IO uint32_t IER27                     : 1;
    __IO uint32_t IER28                     : 1;
    __IO uint32_t IER29                     : 1;
    __IO uint32_t IER30                     : 1;
    __IO uint32_t IER31                     : 1;
} stc_intc_ier_field_t;

typedef struct
{
    __IO uint32_t KEYINSEL                  :16;
    __IO uint32_t KEYOUTSEL                 : 3;
    uint32_t RESERVED19                     : 1;
    __IO uint32_t CKSEL                     : 2;
    uint32_t RESERVED22                     : 2;
    __IO uint32_t T_LLEVEL                  : 5;
    __IO uint32_t T_HIZ                     : 3;
} stc_keyscan_scr_field_t;

typedef struct
{
    __IO uint32_t SEN                       : 1;
    uint32_t RESERVED1                      :31;
} stc_keyscan_ser_field_t;

typedef struct
{
    __IO uint32_t INDEX                     : 3;
    uint32_t RESERVED3                      :29;
} stc_keyscan_ssr_field_t;

typedef struct
{
    __IO uint32_t MPURGSIZE                 : 5;
    __IO uint32_t MPURGADDR                 :27;
} stc_mpu_rgd_field_t;

typedef struct
{
    __IO uint32_t S2RG0RP                   : 1;
    __IO uint32_t S2RG0WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG0E                    : 1;
    __IO uint32_t S1RG0RP                   : 1;
    __IO uint32_t S1RG0WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG0E                    : 1;
    __IO uint32_t FRG0RP                    : 1;
    __IO uint32_t FRG0WP                    : 1;
    uint32_t RESERVED18                     : 5;
    __IO uint32_t FRG0E                     : 1;
    uint32_t RESERVED24                     : 8;
} stc_mpu_rgcr0_field_t;

typedef struct
{
    __IO uint32_t S2RG1RP                   : 1;
    __IO uint32_t S2RG1WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG1E                    : 1;
    __IO uint32_t S1RG1RP                   : 1;
    __IO uint32_t S1RG1WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG1E                    : 1;
    __IO uint32_t FRG1RP                    : 1;
    __IO uint32_t FRG1WP                    : 1;
    uint32_t RESERVED18                     : 5;
    __IO uint32_t FRG1E                     : 1;
    uint32_t RESERVED24                     : 8;
} stc_mpu_rgcr1_field_t;

typedef struct
{
    __IO uint32_t S2RG2RP                   : 1;
    __IO uint32_t S2RG2WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG2E                    : 1;
    __IO uint32_t S1RG2RP                   : 1;
    __IO uint32_t S1RG2WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG2E                    : 1;
    __IO uint32_t FRG2RP                    : 1;
    __IO uint32_t FRG2WP                    : 1;
    uint32_t RESERVED18                     : 5;
    __IO uint32_t FRG2E                     : 1;
    uint32_t RESERVED24                     : 8;
} stc_mpu_rgcr2_field_t;

typedef struct
{
    __IO uint32_t S2RG3RP                   : 1;
    __IO uint32_t S2RG3WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG3E                    : 1;
    __IO uint32_t S1RG3RP                   : 1;
    __IO uint32_t S1RG3WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG3E                    : 1;
    __IO uint32_t FRG3RP                    : 1;
    __IO uint32_t FRG3WP                    : 1;
    uint32_t RESERVED18                     : 5;
    __IO uint32_t FRG3E                     : 1;
    uint32_t RESERVED24                     : 8;
} stc_mpu_rgcr3_field_t;

typedef struct
{
    __IO uint32_t S2RG4RP                   : 1;
    __IO uint32_t S2RG4WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG4E                    : 1;
    __IO uint32_t S1RG4RP                   : 1;
    __IO uint32_t S1RG4WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG4E                    : 1;
    __IO uint32_t FRG4RP                    : 1;
    __IO uint32_t FRG4WP                    : 1;
    uint32_t RESERVED18                     : 5;
    __IO uint32_t FRG4E                     : 1;
    uint32_t RESERVED24                     : 8;
} stc_mpu_rgcr4_field_t;

typedef struct
{
    __IO uint32_t S2RG5RP                   : 1;
    __IO uint32_t S2RG5WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG5E                    : 1;
    __IO uint32_t S1RG5RP                   : 1;
    __IO uint32_t S1RG5WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG5E                    : 1;
    __IO uint32_t FRG5RP                    : 1;
    __IO uint32_t FRG5WP                    : 1;
    uint32_t RESERVED18                     : 5;
    __IO uint32_t FRG5E                     : 1;
    uint32_t RESERVED24                     : 8;
} stc_mpu_rgcr5_field_t;

typedef struct
{
    __IO uint32_t S2RG6RP                   : 1;
    __IO uint32_t S2RG6WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG6E                    : 1;
    __IO uint32_t S1RG6RP                   : 1;
    __IO uint32_t S1RG6WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG6E                    : 1;
    __IO uint32_t FRG6RP                    : 1;
    __IO uint32_t FRG6WP                    : 1;
    uint32_t RESERVED18                     : 5;
    __IO uint32_t FRG6E                     : 1;
    uint32_t RESERVED24                     : 8;
} stc_mpu_rgcr6_field_t;

typedef struct
{
    __IO uint32_t S2RG7RP                   : 1;
    __IO uint32_t S2RG7WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG7E                    : 1;
    __IO uint32_t S1RG7RP                   : 1;
    __IO uint32_t S1RG7WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG7E                    : 1;
    __IO uint32_t FRG7RP                    : 1;
    __IO uint32_t FRG7WP                    : 1;
    uint32_t RESERVED18                     : 5;
    __IO uint32_t FRG7E                     : 1;
    uint32_t RESERVED24                     : 8;
} stc_mpu_rgcr7_field_t;

typedef struct
{
    __IO uint32_t S2RG8RP                   : 1;
    __IO uint32_t S2RG8WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG8E                    : 1;
    __IO uint32_t S1RG8RP                   : 1;
    __IO uint32_t S1RG8WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG8E                    : 1;
    uint32_t RESERVED16                     :16;
} stc_mpu_rgcr8_field_t;

typedef struct
{
    __IO uint32_t S2RG9RP                   : 1;
    __IO uint32_t S2RG9WP                   : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG9E                    : 1;
    __IO uint32_t S1RG9RP                   : 1;
    __IO uint32_t S1RG9WP                   : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG9E                    : 1;
    uint32_t RESERVED16                     :16;
} stc_mpu_rgcr9_field_t;

typedef struct
{
    __IO uint32_t S2RG10RP                  : 1;
    __IO uint32_t S2RG10WP                  : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG10E                   : 1;
    __IO uint32_t S1RG10RP                  : 1;
    __IO uint32_t S1RG10WP                  : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG10E                   : 1;
    uint32_t RESERVED16                     :16;
} stc_mpu_rgcr10_field_t;

typedef struct
{
    __IO uint32_t S2RG11RP                  : 1;
    __IO uint32_t S2RG11WP                  : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG11E                   : 1;
    __IO uint32_t S1RG11RP                  : 1;
    __IO uint32_t S1RG11WP                  : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG11E                   : 1;
    uint32_t RESERVED16                     :16;
} stc_mpu_rgcr11_field_t;

typedef struct
{
    __IO uint32_t S2RG12RP                  : 1;
    __IO uint32_t S2RG12WP                  : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG12E                   : 1;
    __IO uint32_t S1RG12RP                  : 1;
    __IO uint32_t S1RG12WP                  : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG12E                   : 1;
    uint32_t RESERVED16                     :16;
} stc_mpu_rgcr12_field_t;

typedef struct
{
    __IO uint32_t S2RG13RP                  : 1;
    __IO uint32_t S2RG13WP                  : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG13E                   : 1;
    __IO uint32_t S1RG13RP                  : 1;
    __IO uint32_t S1RG13WP                  : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG13E                   : 1;
    uint32_t RESERVED16                     :16;
} stc_mpu_rgcr13_field_t;

typedef struct
{
    __IO uint32_t S2RG14RP                  : 1;
    __IO uint32_t S2RG14WP                  : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG14E                   : 1;
    __IO uint32_t S1RG14RP                  : 1;
    __IO uint32_t S1RG14WP                  : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG14E                   : 1;
    uint32_t RESERVED16                     :16;
} stc_mpu_rgcr14_field_t;

typedef struct
{
    __IO uint32_t S2RG15RP                  : 1;
    __IO uint32_t S2RG15WP                  : 1;
    uint32_t RESERVED2                      : 5;
    __IO uint32_t S2RG15E                   : 1;
    __IO uint32_t S1RG15RP                  : 1;
    __IO uint32_t S1RG15WP                  : 1;
    uint32_t RESERVED10                     : 5;
    __IO uint32_t S1RG15E                   : 1;
    uint32_t RESERVED16                     :16;
} stc_mpu_rgcr15_field_t;

typedef struct
{
    __IO uint32_t SMPU2BRP                  : 1;
    __IO uint32_t SMPU2BWP                  : 1;
    __IO uint32_t SMPU2ACT                  : 2;
    uint32_t RESERVED4                      : 3;
    __IO uint32_t SMPU2E                    : 1;
    __IO uint32_t SMPU1BRP                  : 1;
    __IO uint32_t SMPU1BWP                  : 1;
    __IO uint32_t SMPU1ACT                  : 2;
    uint32_t RESERVED12                     : 3;
    __IO uint32_t SMPU1E                    : 1;
    __IO uint32_t FMPUBRP                   : 1;
    __IO uint32_t FMPUBWP                   : 1;
    __IO uint32_t FMPUACT                   : 2;
    uint32_t RESERVED20                     : 3;
    __IO uint32_t FMPUE                     : 1;
    uint32_t RESERVED24                     : 8;
} stc_mpu_cr_field_t;

typedef struct
{
    __I  uint32_t SMPU2EAF                  : 1;
    uint32_t RESERVED1                      : 7;
    __I  uint32_t SMPU1EAF                  : 1;
    uint32_t RESERVED9                      : 7;
    __I  uint32_t FMPUEAF                   : 1;
    uint32_t RESERVED17                     :15;
} stc_mpu_sr_field_t;

typedef struct
{
    __O  uint32_t SMPU2ECLR                 : 1;
    uint32_t RESERVED1                      : 7;
    __O  uint32_t SMPU1ECLR                 : 1;
    uint32_t RESERVED9                      : 7;
    __O  uint32_t FMPUECLR                  : 1;
    uint32_t RESERVED17                     :15;
} stc_mpu_eclr_field_t;

typedef struct
{
    __IO uint32_t MPUWE                     : 1;
    __O  uint32_t WKEY                      :15;
    uint32_t RESERVED16                     :16;
} stc_mpu_wp_field_t;

typedef struct
{
    __IO uint32_t SRAMH                     : 1;
    uint32_t RESERVED1                      : 3;
    __IO uint32_t SRAM12                    : 1;
    uint32_t RESERVED5                      : 3;
    __IO uint32_t SRAM3                     : 1;
    uint32_t RESERVED9                      : 1;
    __IO uint32_t SRAMRET                   : 1;
    uint32_t RESERVED11                     : 3;
    __IO uint32_t DMA1                      : 1;
    __IO uint32_t DMA2                      : 1;
    __IO uint32_t FCM                       : 1;
    __IO uint32_t AOS                       : 1;
    uint32_t RESERVED18                     : 2;
    __IO uint32_t AES                       : 1;
    __IO uint32_t HASH                      : 1;
    __IO uint32_t TRNG                      : 1;
    __IO uint32_t CRC                       : 1;
    __IO uint32_t DCU1                      : 1;
    __IO uint32_t DCU2                      : 1;
    __IO uint32_t DCU3                      : 1;
    __IO uint32_t DCU4                      : 1;
    uint32_t RESERVED28                     : 3;
    __IO uint32_t KEY                       : 1;
} stc_mstp_fcg0_field_t;

typedef struct
{
    __IO uint32_t CAN                       : 1;
    uint32_t RESERVED1                      : 2;
    __IO uint32_t QSPI                      : 1;
    __IO uint32_t IIC1                      : 1;
    __IO uint32_t IIC2                      : 1;
    __IO uint32_t IIC3                      : 1;
    uint32_t RESERVED7                      : 1;
    __IO uint32_t USBFS                     : 1;
    uint32_t RESERVED9                      : 1;
    __IO uint32_t SDIOC1                    : 1;
    __IO uint32_t SDIOC2                    : 1;
    __IO uint32_t I2S1                      : 1;
    __IO uint32_t I2S2                      : 1;
    __IO uint32_t I2S3                      : 1;
    __IO uint32_t I2S4                      : 1;
    __IO uint32_t SPI1                      : 1;
    __IO uint32_t SPI2                      : 1;
    __IO uint32_t SPI3                      : 1;
    __IO uint32_t SPI4                      : 1;
    uint32_t RESERVED20                     : 4;
    __IO uint32_t USART1                    : 1;
    __IO uint32_t USART2                    : 1;
    __IO uint32_t USART3                    : 1;
    __IO uint32_t USART4                    : 1;
    uint32_t RESERVED28                     : 4;
} stc_mstp_fcg1_field_t;

typedef struct
{
    __IO uint32_t TIMER0_1                  : 1;
    __IO uint32_t TIMER0_2                  : 1;
    __IO uint32_t TIMERA_1                  : 1;
    __IO uint32_t TIMERA_2                  : 1;
    __IO uint32_t TIMERA_3                  : 1;
    __IO uint32_t TIMERA_4                  : 1;
    __IO uint32_t TIMERA_5                  : 1;
    __IO uint32_t TIMERA_6                  : 1;
    __IO uint32_t TIMER4_1                  : 1;
    __IO uint32_t TIMER4_2                  : 1;
    __IO uint32_t TIMER4_3                  : 1;
    uint32_t RESERVED11                     : 4;
    __IO uint32_t EMB                       : 1;
    __IO uint32_t TIMER6_1                  : 1;
    __IO uint32_t TIMER6_2                  : 1;
    __IO uint32_t TIMER6_3                  : 1;
    uint32_t RESERVED19                     :13;
} stc_mstp_fcg2_field_t;

typedef struct
{
    __IO uint32_t ADC1                      : 1;
    __IO uint32_t ADC2                      : 1;
    uint32_t RESERVED2                      : 6;
    __IO uint32_t CMP                       : 1;
    uint32_t RESERVED9                      : 3;
    __IO uint32_t OTS                       : 1;
    uint32_t RESERVED13                     :19;
} stc_mstp_fcg3_field_t;

typedef struct
{
    __IO uint32_t PRT0                      : 1;
    uint32_t RESERVED1                      :15;
    __O  uint32_t FCG0PCWE                  :16;
} stc_mstp_fcg0pc_field_t;

typedef struct
{
    __IO uint16_t OTSST                     : 1;
    __IO uint16_t OTSCK                     : 1;
    __IO uint16_t OTSIE                     : 1;
    __IO uint16_t TSSTP                     : 1;
    uint16_t RESERVED4                      :12;
} stc_ots_ctl_field_t;

typedef struct
{
    __I  uint32_t TSOFS                     : 8;
    __I  uint32_t TSSLP                     :24;
} stc_ots_lpr_field_t;

typedef struct
{
    __IO uint32_t DFB                       : 1;
    __IO uint32_t SOFEN                     : 1;
    uint32_t RESERVED2                      :30;
} stc_peric_usbfs_syctlreg_field_t;

typedef struct
{
    uint32_t RESERVED0                      : 1;
    __IO uint32_t SELMMC1                   : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t SELMMC2                   : 1;
    uint32_t RESERVED4                      :28;
} stc_peric_sdioc_syctlreg_field_t;

typedef struct
{
    __I  uint16_t PIN00                     : 1;
    __I  uint16_t PIN01                     : 1;
    __I  uint16_t PIN02                     : 1;
    __I  uint16_t PIN03                     : 1;
    __I  uint16_t PIN04                     : 1;
    __I  uint16_t PIN05                     : 1;
    __I  uint16_t PIN06                     : 1;
    __I  uint16_t PIN07                     : 1;
    __I  uint16_t PIN08                     : 1;
    __I  uint16_t PIN09                     : 1;
    __I  uint16_t PIN10                     : 1;
    __I  uint16_t PIN11                     : 1;
    __I  uint16_t PIN12                     : 1;
    __I  uint16_t PIN13                     : 1;
    __I  uint16_t PIN14                     : 1;
    __I  uint16_t PIN15                     : 1;
} stc_port_pidr_field_t;

typedef struct
{
    __IO uint16_t POUT00                    : 1;
    __IO uint16_t POUT01                    : 1;
    __IO uint16_t POUT02                    : 1;
    __IO uint16_t POUT03                    : 1;
    __IO uint16_t POUT04                    : 1;
    __IO uint16_t POUT05                    : 1;
    __IO uint16_t POUT06                    : 1;
    __IO uint16_t POUT07                    : 1;
    __IO uint16_t POUT08                    : 1;
    __IO uint16_t POUT09                    : 1;
    __IO uint16_t POUT10                    : 1;
    __IO uint16_t POUT11                    : 1;
    __IO uint16_t POUT12                    : 1;
    __IO uint16_t POUT13                    : 1;
    __IO uint16_t POUT14                    : 1;
    __IO uint16_t POUT15                    : 1;
} stc_port_podr_field_t;

typedef struct
{
    __IO uint16_t POUTE00                   : 1;
    __IO uint16_t POUTE01                   : 1;
    __IO uint16_t POUTE02                   : 1;
    __IO uint16_t POUTE03                   : 1;
    __IO uint16_t POUTE04                   : 1;
    __IO uint16_t POUTE05                   : 1;
    __IO uint16_t POUTE06                   : 1;
    __IO uint16_t POUTE07                   : 1;
    __IO uint16_t POUTE08                   : 1;
    __IO uint16_t POUTE09                   : 1;
    __IO uint16_t POUTE10                   : 1;
    __IO uint16_t POUTE11                   : 1;
    __IO uint16_t POUTE12                   : 1;
    __IO uint16_t POUTE13                   : 1;
    __IO uint16_t POUTE14                   : 1;
    __IO uint16_t POUTE15                   : 1;
} stc_port_poer_field_t;

typedef struct
{
    __IO uint16_t POS00                     : 1;
    __IO uint16_t POS01                     : 1;
    __IO uint16_t POS02                     : 1;
    __IO uint16_t POS03                     : 1;
    __IO uint16_t POS04                     : 1;
    __IO uint16_t POS05                     : 1;
    __IO uint16_t POS06                     : 1;
    __IO uint16_t POS07                     : 1;
    __IO uint16_t POS08                     : 1;
    __IO uint16_t POS09                     : 1;
    __IO uint16_t POS10                     : 1;
    __IO uint16_t POS11                     : 1;
    __IO uint16_t POS12                     : 1;
    __IO uint16_t POS13                     : 1;
    __IO uint16_t POS14                     : 1;
    __IO uint16_t POS15                     : 1;
} stc_port_posr_field_t;

typedef struct
{
    __IO uint16_t POR00                     : 1;
    __IO uint16_t POR01                     : 1;
    __IO uint16_t POR02                     : 1;
    __IO uint16_t POR03                     : 1;
    __IO uint16_t POR04                     : 1;
    __IO uint16_t POR05                     : 1;
    __IO uint16_t POR06                     : 1;
    __IO uint16_t POR07                     : 1;
    __IO uint16_t POR08                     : 1;
    __IO uint16_t POR09                     : 1;
    __IO uint16_t POR10                     : 1;
    __IO uint16_t POR11                     : 1;
    __IO uint16_t POR12                     : 1;
    __IO uint16_t POR13                     : 1;
    __IO uint16_t POR14                     : 1;
    __IO uint16_t POR15                     : 1;
} stc_port_porr_field_t;

typedef struct
{
    __IO uint16_t POT00                     : 1;
    __IO uint16_t POT01                     : 1;
    __IO uint16_t POT02                     : 1;
    __IO uint16_t POT03                     : 1;
    __IO uint16_t POT04                     : 1;
    __IO uint16_t POT05                     : 1;
    __IO uint16_t POT06                     : 1;
    __IO uint16_t POT07                     : 1;
    __IO uint16_t POT08                     : 1;
    __IO uint16_t POT09                     : 1;
    __IO uint16_t POT10                     : 1;
    __IO uint16_t POT11                     : 1;
    __IO uint16_t POT12                     : 1;
    __IO uint16_t POT13                     : 1;
    __IO uint16_t POT14                     : 1;
    __IO uint16_t POT15                     : 1;
} stc_port_potr_field_t;

typedef struct
{
    __I  uint16_t PIN00                     : 1;
    __I  uint16_t PIN01                     : 1;
    __I  uint16_t PIN02                     : 1;
    uint16_t RESERVED3                      :13;
} stc_port_pidrh_field_t;

typedef struct
{
    __IO uint16_t POUT00                    : 1;
    __IO uint16_t POUT01                    : 1;
    __IO uint16_t POUT02                    : 1;
    uint16_t RESERVED3                      :13;
} stc_port_podrh_field_t;

typedef struct
{
    __IO uint16_t POUTE00                   : 1;
    __IO uint16_t POUTE01                   : 1;
    __IO uint16_t POUTE02                   : 1;
    uint16_t RESERVED3                      :13;
} stc_port_poerh_field_t;

typedef struct
{
    __IO uint16_t POS00                     : 1;
    __IO uint16_t POS01                     : 1;
    __IO uint16_t POS02                     : 1;
    uint16_t RESERVED3                      :13;
} stc_port_posrh_field_t;

typedef struct
{
    __IO uint16_t POR00                     : 1;
    __IO uint16_t POR01                     : 1;
    __IO uint16_t POR02                     : 1;
    uint16_t RESERVED3                      :13;
} stc_port_porrh_field_t;

typedef struct
{
    __IO uint16_t POT00                     : 1;
    __IO uint16_t POT01                     : 1;
    __IO uint16_t POT02                     : 1;
    uint16_t RESERVED3                      :13;
} stc_port_potrh_field_t;

typedef struct
{
    __IO uint16_t SPFE                      : 5;
    uint16_t RESERVED5                      :11;
} stc_port_pspcr_field_t;

typedef struct
{
    __IO uint16_t BFSEL                     : 4;
    uint16_t RESERVED4                      :10;
    __IO uint16_t RDWT                      : 2;
} stc_port_pccr_field_t;

typedef struct
{
    __IO uint16_t PINAE                     : 6;
    uint16_t RESERVED6                      :10;
} stc_port_pinaer_field_t;

typedef struct
{
    __IO uint16_t WE                        : 1;
    uint16_t RESERVED1                      : 7;
    __O  uint16_t WP                        : 8;
} stc_port_pwpr_field_t;

typedef struct
{
    __IO uint16_t POUT                      : 1;
    __IO uint16_t POUTE                     : 1;
    __IO uint16_t NOD                       : 1;
    uint16_t RESERVED3                      : 1;
    __IO uint16_t DRV                       : 2;
    __IO uint16_t PUU                       : 1;
    uint16_t RESERVED7                      : 1;
    __I  uint16_t PIN                       : 1;
    __IO uint16_t INVE                      : 1;
    uint16_t RESERVED10                     : 2;
    __IO uint16_t INTE                      : 1;
    uint16_t RESERVED13                     : 1;
    __IO uint16_t LTE                       : 1;
    __IO uint16_t DDIS                      : 1;
} stc_port_pcr_field_t;

typedef struct
{
    __IO uint16_t FSEL                      : 6;
    uint16_t RESERVED6                      : 2;
    __IO uint16_t BFE                       : 1;
    uint16_t RESERVED9                      : 7;
} stc_port_pfsr_field_t;

typedef struct
{
    __IO uint32_t MDSEL                     : 3;
    __IO uint32_t PFE                       : 1;
    __IO uint32_t PFSAE                     : 1;
    __IO uint32_t DCOME                     : 1;
    __IO uint32_t XIPE                      : 1;
    __IO uint32_t SPIMD3                    : 1;
    __IO uint32_t IPRSL                     : 2;
    __IO uint32_t APRSL                     : 2;
    __IO uint32_t DPRSL                     : 2;
    uint32_t RESERVED14                     : 2;
    __IO uint32_t DIV                       : 6;
    uint32_t RESERVED22                     :10;
} stc_qspi_cr_field_t;

typedef struct
{
    __IO uint32_t SSHW                      : 4;
    __IO uint32_t SSNW                      : 2;
    uint32_t RESERVED6                      :26;
} stc_qspi_cscr_field_t;

typedef struct
{
    __IO uint32_t AWSL                      : 2;
    __IO uint32_t FOUR_BIC                  : 1;
    uint32_t RESERVED3                      : 1;
    __IO uint32_t SSNHD                     : 1;
    __IO uint32_t SSNLD                     : 1;
    __IO uint32_t WPOL                      : 1;
    uint32_t RESERVED7                      : 1;
    __IO uint32_t DMCYCN                    : 4;
    uint32_t RESERVED12                     : 3;
    __IO uint32_t DUTY                      : 1;
    uint32_t RESERVED16                     :16;
} stc_qspi_fcr_field_t;

typedef struct
{
    __IO uint32_t BUSY                      : 1;
    uint32_t RESERVED1                      : 5;
    __IO uint32_t XIPF                      : 1;
    __IO uint32_t RAER                      : 1;
    __IO uint32_t PFNUM                     : 5;
    uint32_t RESERVED13                     : 1;
    __IO uint32_t PFFUL                     : 1;
    __IO uint32_t PFAN                      : 1;
    uint32_t RESERVED16                     :16;
} stc_qspi_sr_field_t;

typedef struct
{
    __IO uint32_t DCOM                      : 8;
    uint32_t RESERVED8                      :24;
} stc_qspi_dcom_field_t;

typedef struct
{
    __IO uint32_t RIC                       : 8;
    uint32_t RESERVED8                      :24;
} stc_qspi_ccmd_field_t;

typedef struct
{
    __IO uint32_t XIPMC                     : 8;
    uint32_t RESERVED8                      :24;
} stc_qspi_xcmd_field_t;

typedef struct
{
    uint32_t RESERVED0                      : 7;
    __O  uint32_t RAERCLR                   : 1;
    uint32_t RESERVED8                      :24;
} stc_qspi_sr2_field_t;

typedef struct
{
    uint32_t RESERVED0                      :26;
    __IO uint32_t EXADR                     : 6;
} stc_qspi_exar_field_t;

typedef struct
{
    __IO uint8_t RESET                      : 1;
    uint8_t RESERVED1                       : 7;
} stc_rtc_cr0_field_t;

typedef struct
{
    __IO uint8_t PRDS                       : 3;
    __IO uint8_t AMPM                       : 1;
    __IO uint8_t ALMFCLR                    : 1;
    __IO uint8_t ONEHZOE                    : 1;
    __IO uint8_t ONEHZSEL                   : 1;
    __IO uint8_t START                      : 1;
} stc_rtc_cr1_field_t;

typedef struct
{
    __IO uint8_t RWREQ                      : 1;
    __IO uint8_t RWEN                       : 1;
    uint8_t RESERVED2                       : 1;
    __IO uint8_t ALMF                       : 1;
    uint8_t RESERVED4                       : 1;
    __IO uint8_t PRDIE                      : 1;
    __IO uint8_t ALMIE                      : 1;
    __IO uint8_t ALME                       : 1;
} stc_rtc_cr2_field_t;

typedef struct
{
    uint8_t RESERVED0                       : 4;
    __IO uint8_t LRCEN                      : 1;
    uint8_t RESERVED5                       : 2;
    __IO uint8_t RCKSEL                     : 1;
} stc_rtc_cr3_field_t;

typedef struct
{
    __IO uint8_t SECU                       : 4;
    __IO uint8_t SECD                       : 3;
    uint8_t RESERVED7                       : 1;
} stc_rtc_sec_field_t;

typedef struct
{
    __IO uint8_t MINU                       : 4;
    __IO uint8_t MIND                       : 3;
    uint8_t RESERVED7                       : 1;
} stc_rtc_min_field_t;

typedef struct
{
    __IO uint8_t HOURU                      : 4;
    __IO uint8_t HOURD                      : 2;
    uint8_t RESERVED6                       : 2;
} stc_rtc_hour_field_t;

typedef struct
{
    __IO uint8_t WEEK                       : 3;
    uint8_t RESERVED3                       : 5;
} stc_rtc_week_field_t;

typedef struct
{
    __IO uint8_t DAYU                       : 4;
    __IO uint8_t DAYD                       : 2;
    uint8_t RESERVED6                       : 2;
} stc_rtc_day_field_t;

typedef struct
{
    __IO uint8_t MON                        : 5;
    uint8_t RESERVED5                       : 3;
} stc_rtc_mon_field_t;

typedef struct
{
    __IO uint8_t YEARU                      : 4;
    __IO uint8_t YEARD                      : 4;
} stc_rtc_year_field_t;

typedef struct
{
    __IO uint8_t ALMMINU                    : 4;
    __IO uint8_t ALMMIND                    : 3;
    uint8_t RESERVED7                       : 1;
} stc_rtc_almmin_field_t;

typedef struct
{
    __IO uint8_t ALMHOURU                   : 4;
    __IO uint8_t ALMHOURD                   : 2;
    uint8_t RESERVED6                       : 2;
} stc_rtc_almhour_field_t;

typedef struct
{
    __IO uint8_t ALMWEEK                    : 7;
    uint8_t RESERVED7                       : 1;
} stc_rtc_almweek_field_t;

typedef struct
{
    __IO uint8_t COMP8                      : 1;
    uint8_t RESERVED1                       : 6;
    __IO uint8_t COMPEN                     : 1;
} stc_rtc_errcrh_field_t;

typedef struct
{
    __IO uint8_t COMP                       : 8;
} stc_rtc_errcrl_field_t;

typedef struct
{
    __IO uint16_t TBS                       :12;
    uint16_t RESERVED12                     : 4;
} stc_sdioc_blksize_field_t;

typedef struct
{
    uint16_t RESERVED0                      : 1;
    __IO uint16_t BCE                       : 1;
    __IO uint16_t ATCEN                     : 2;
    __IO uint16_t DDIR                      : 1;
    __IO uint16_t MULB                      : 1;
    uint16_t RESERVED6                      :10;
} stc_sdioc_transmode_field_t;

typedef struct
{
    __IO uint16_t RESTYP                    : 2;
    uint16_t RESERVED2                      : 1;
    __IO uint16_t CCE                       : 1;
    __IO uint16_t ICE                       : 1;
    __IO uint16_t DAT                       : 1;
    __IO uint16_t TYP                       : 2;
    __IO uint16_t IDX                       : 6;
    uint16_t RESERVED14                     : 2;
} stc_sdioc_cmd_field_t;

typedef struct
{
    __I  uint32_t CIC                       : 1;
    __I  uint32_t CID                       : 1;
    __I  uint32_t DA                        : 1;
    uint32_t RESERVED3                      : 5;
    __I  uint32_t WTA                       : 1;
    __I  uint32_t RTA                       : 1;
    __I  uint32_t BWE                       : 1;
    __I  uint32_t BRE                       : 1;
    uint32_t RESERVED12                     : 4;
    __I  uint32_t CIN                       : 1;
    __I  uint32_t CSS                       : 1;
    __I  uint32_t CDL                       : 1;
    __I  uint32_t WPL                       : 1;
    __I  uint32_t DATL                      : 4;
    __I  uint32_t CMDL                      : 1;
    uint32_t RESERVED25                     : 7;
} stc_sdioc_pstat_field_t;

typedef struct
{
    uint8_t RESERVED0                       : 1;
    __IO uint8_t DW                         : 1;
    __IO uint8_t HSEN                       : 1;
    uint8_t RESERVED3                       : 2;
    __IO uint8_t EXDW                       : 1;
    __IO uint8_t CDTL                       : 1;
    __IO uint8_t CDSS                       : 1;
} stc_sdioc_hostcon_field_t;

typedef struct
{
    __IO uint8_t PWON                       : 1;
    uint8_t RESERVED1                       : 7;
} stc_sdioc_pwrcon_field_t;

typedef struct
{
    __IO uint8_t SABGR                      : 1;
    __IO uint8_t CR                         : 1;
    __IO uint8_t RWC                        : 1;
    __IO uint8_t IABG                       : 1;
    uint8_t RESERVED4                       : 4;
} stc_sdioc_blkgpcon_field_t;

typedef struct
{
    __IO uint16_t ICE                       : 1;
    uint16_t RESERVED1                      : 1;
    __IO uint16_t CE                        : 1;
    uint16_t RESERVED3                      : 5;
    __IO uint16_t FS                        : 8;
} stc_sdioc_clkcon_field_t;

typedef struct
{
    __IO uint8_t DTO                        : 4;
    uint8_t RESERVED4                       : 4;
} stc_sdioc_toutcon_field_t;

typedef struct
{
    __IO uint8_t RSTA                       : 1;
    __IO uint8_t RSTC                       : 1;
    __IO uint8_t RSTD                       : 1;
    uint8_t RESERVED3                       : 5;
} stc_sdioc_sftrst_field_t;

typedef struct
{
    __IO uint16_t CC                        : 1;
    __IO uint16_t TC                        : 1;
    __IO uint16_t BGE                       : 1;
    uint16_t RESERVED3                      : 1;
    __IO uint16_t BWR                       : 1;
    __IO uint16_t BRR                       : 1;
    __IO uint16_t CIST                      : 1;
    __IO uint16_t CRM                       : 1;
    __I  uint16_t CINT                      : 1;
    uint16_t RESERVED9                      : 6;
    __I  uint16_t EI                        : 1;
} stc_sdioc_norintst_field_t;

typedef struct
{
    __IO uint16_t CTOE                      : 1;
    __IO uint16_t CCE                       : 1;
    __IO uint16_t CEBE                      : 1;
    __IO uint16_t CIE                       : 1;
    __IO uint16_t DTOE                      : 1;
    __IO uint16_t DCE                       : 1;
    __IO uint16_t DEBE                      : 1;
    uint16_t RESERVED7                      : 1;
    __IO uint16_t ACE                       : 1;
    uint16_t RESERVED9                      : 7;
} stc_sdioc_errintst_field_t;

typedef struct
{
    __IO uint16_t CCEN                      : 1;
    __IO uint16_t TCEN                      : 1;
    __IO uint16_t BGEEN                     : 1;
    uint16_t RESERVED3                      : 1;
    __IO uint16_t BWREN                     : 1;
    __IO uint16_t BRREN                     : 1;
    __IO uint16_t CISTEN                    : 1;
    __IO uint16_t CRMEN                     : 1;
    __IO uint16_t CINTEN                    : 1;
    uint16_t RESERVED9                      : 7;
} stc_sdioc_norintsten_field_t;

typedef struct
{
    __IO uint16_t CTOEEN                    : 1;
    __IO uint16_t CCEEN                     : 1;
    __IO uint16_t CEBEEN                    : 1;
    __IO uint16_t CIEEN                     : 1;
    __IO uint16_t DTOEEN                    : 1;
    __IO uint16_t DCEEN                     : 1;
    __IO uint16_t DEBEEN                    : 1;
    uint16_t RESERVED7                      : 1;
    __IO uint16_t ACEEN                     : 1;
    uint16_t RESERVED9                      : 7;
} stc_sdioc_errintsten_field_t;

typedef struct
{
    __IO uint16_t CCSEN                     : 1;
    __IO uint16_t TCSEN                     : 1;
    __IO uint16_t BGESEN                    : 1;
    uint16_t RESERVED3                      : 1;
    __IO uint16_t BWRSEN                    : 1;
    __IO uint16_t BRRSEN                    : 1;
    __IO uint16_t CISTSEN                   : 1;
    __IO uint16_t CRMSEN                    : 1;
    __IO uint16_t CINTSEN                   : 1;
    uint16_t RESERVED9                      : 7;
} stc_sdioc_norintsgen_field_t;

typedef struct
{
    __IO uint16_t CTOESEN                   : 1;
    __IO uint16_t CCESEN                    : 1;
    __IO uint16_t CEBESEN                   : 1;
    __IO uint16_t CIESEN                    : 1;
    __IO uint16_t DTOESEN                   : 1;
    __IO uint16_t DCESEN                    : 1;
    __IO uint16_t DEBESEN                   : 1;
    uint16_t RESERVED7                      : 1;
    __IO uint16_t ACESEN                    : 1;
    uint16_t RESERVED9                      : 7;
} stc_sdioc_errintsgen_field_t;

typedef struct
{
    __I  uint16_t NE                        : 1;
    __I  uint16_t TOE                       : 1;
    __I  uint16_t CE                        : 1;
    __I  uint16_t EBE                       : 1;
    __I  uint16_t IE                        : 1;
    uint16_t RESERVED5                      : 2;
    __I  uint16_t CMDE                      : 1;
    uint16_t RESERVED8                      : 8;
} stc_sdioc_atcerrst_field_t;

typedef struct
{
    __O  uint16_t FNE                       : 1;
    __O  uint16_t FTOE                      : 1;
    __O  uint16_t FCE                       : 1;
    __O  uint16_t FEBE                      : 1;
    __O  uint16_t FIE                       : 1;
    uint16_t RESERVED5                      : 2;
    __O  uint16_t FCMDE                     : 1;
    uint16_t RESERVED8                      : 8;
} stc_sdioc_fea_field_t;

typedef struct
{
    __O  uint16_t FCTOE                     : 1;
    __O  uint16_t FCCE                      : 1;
    __O  uint16_t FCEBE                     : 1;
    __O  uint16_t FCIE                      : 1;
    __O  uint16_t FDTOE                     : 1;
    __O  uint16_t FDCE                      : 1;
    __O  uint16_t FDEBE                     : 1;
    uint16_t RESERVED7                      : 1;
    __O  uint16_t FACE                      : 1;
    uint16_t RESERVED9                      : 7;
} stc_sdioc_fee_field_t;

typedef struct
{
    __IO uint32_t SPIMDS                    : 1;
    __IO uint32_t TXMDS                     : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t MSTR                      : 1;
    __IO uint32_t SPLPBK                    : 1;
    __IO uint32_t SPLPBK2                   : 1;
    __IO uint32_t SPE                       : 1;
    __IO uint32_t CSUSPE                    : 1;
    __IO uint32_t EIE                       : 1;
    __IO uint32_t TXIE                      : 1;
    __IO uint32_t RXIE                      : 1;
    __IO uint32_t IDIE                      : 1;
    __IO uint32_t MODFE                     : 1;
    __IO uint32_t PATE                      : 1;
    __IO uint32_t PAOE                      : 1;
    __IO uint32_t PAE                       : 1;
    uint32_t RESERVED16                     :16;
} stc_spi_cr1_field_t;

typedef struct
{
    __IO uint32_t FTHLV                     : 2;
    uint32_t RESERVED2                      : 4;
    __IO uint32_t SPRDTD                    : 1;
    uint32_t RESERVED7                      : 1;
    __IO uint32_t SS0PV                     : 1;
    __IO uint32_t SS1PV                     : 1;
    __IO uint32_t SS2PV                     : 1;
    __IO uint32_t SS3PV                     : 1;
    uint32_t RESERVED12                     : 8;
    __IO uint32_t MSSI                      : 3;
    uint32_t RESERVED23                     : 1;
    __IO uint32_t MSSDL                     : 3;
    uint32_t RESERVED27                     : 1;
    __IO uint32_t MIDI                      : 3;
    uint32_t RESERVED31                     : 1;
} stc_spi_cfg1_field_t;

typedef struct
{
    __IO uint32_t OVRERF                    : 1;
    __I  uint32_t IDLNF                     : 1;
    __IO uint32_t MODFERF                   : 1;
    __IO uint32_t PERF                      : 1;
    __IO uint32_t UDRERF                    : 1;
    __IO uint32_t TDEF                      : 1;
    uint32_t RESERVED6                      : 1;
    __IO uint32_t RDFF                      : 1;
    uint32_t RESERVED8                      :24;
} stc_spi_sr_field_t;

typedef struct
{
    __IO uint32_t CPHA                      : 1;
    __IO uint32_t CPOL                      : 1;
    __IO uint32_t MBR                       : 3;
    __IO uint32_t SSA                       : 3;
    __IO uint32_t DSIZE                     : 4;
    __IO uint32_t LSBF                      : 1;
    __IO uint32_t MIDIE                     : 1;
    __IO uint32_t MSSDLE                    : 1;
    __IO uint32_t MSSIE                     : 1;
    uint32_t RESERVED16                     :16;
} stc_spi_cfg2_field_t;

typedef struct
{
    __IO uint32_t SRAM12_RWT                : 3;
    uint32_t RESERVED3                      : 1;
    __IO uint32_t SRAM12_WWT                : 3;
    uint32_t RESERVED7                      : 1;
    __IO uint32_t SRAM3_RWT                 : 3;
    uint32_t RESERVED11                     : 1;
    __IO uint32_t SRAM3_WWT                 : 3;
    uint32_t RESERVED15                     : 1;
    __IO uint32_t SRAMH_RWT                 : 3;
    uint32_t RESERVED19                     : 1;
    __IO uint32_t SRAMH_WWT                 : 3;
    uint32_t RESERVED23                     : 1;
    __IO uint32_t SRAMR_RWT                 : 3;
    uint32_t RESERVED27                     : 1;
    __IO uint32_t SRAMR_WWT                 : 3;
    uint32_t RESERVED31                     : 1;
} stc_sramc_wtcr_field_t;

typedef struct
{
    __IO uint32_t WTPRC                     : 1;
    __IO uint32_t WTPRKW                    : 7;
    uint32_t RESERVED8                      :24;
} stc_sramc_wtpr_field_t;

typedef struct
{
    __IO uint32_t PYOAD                     : 1;
    uint32_t RESERVED1                      :15;
    __IO uint32_t ECCOAD                    : 1;
    uint32_t RESERVED17                     : 7;
    __IO uint32_t ECCMOD                    : 2;
    uint32_t RESERVED26                     : 6;
} stc_sramc_ckcr_field_t;

typedef struct
{
    __IO uint32_t CKPRC                     : 1;
    __IO uint32_t CKPRKW                    : 7;
    uint32_t RESERVED8                      :24;
} stc_sramc_ckpr_field_t;

typedef struct
{
    __IO uint32_t SRAM3_1ERR                : 1;
    __IO uint32_t SRAM3_2ERR                : 1;
    __IO uint32_t SRAM12_PYERR              : 1;
    __IO uint32_t SRAMH_PYERR               : 1;
    __IO uint32_t SRAMR_PYERR               : 1;
    uint32_t RESERVED5                      :27;
} stc_sramc_cksr_field_t;

typedef struct
{
    __I  uint32_t CNT                       :16;
    __IO uint32_t UDF                       : 1;
    __IO uint32_t REF                       : 1;
    uint32_t RESERVED18                     :14;
} stc_swdt_sr_field_t;

typedef struct
{
    __IO uint32_t RF                        :16;
    uint32_t RESERVED16                     :16;
} stc_swdt_rr_field_t;

typedef struct
{
    __IO uint16_t FLNWT                     : 1;
    __IO uint16_t CKSMRC                    : 1;
    uint16_t RESERVED2                      :13;
    __IO uint16_t STOP                      : 1;
} stc_sysreg_pwr_stpmcr_field_t;

typedef struct
{
    __IO uint16_t PERICKSEL                 : 4;
    uint16_t RESERVED4                      :12;
} stc_sysreg_cmu_pericksel_field_t;

typedef struct
{
    __IO uint16_t I2S1CKSEL                 : 4;
    __IO uint16_t I2S2CKSEL                 : 4;
    __IO uint16_t I2S3CKSEL                 : 4;
    __IO uint16_t I2S4CKSEL                 : 4;
} stc_sysreg_cmu_i2scksel_field_t;

typedef struct
{
    __IO uint32_t RAMPDC0                   : 1;
    __IO uint32_t RAMPDC1                   : 1;
    __IO uint32_t RAMPDC2                   : 1;
    __IO uint32_t RAMPDC3                   : 1;
    __IO uint32_t RAMPDC4                   : 1;
    __IO uint32_t RAMPDC5                   : 1;
    __IO uint32_t RAMPDC6                   : 1;
    __IO uint32_t RAMPDC7                   : 1;
    __IO uint32_t RAMPDC8                   : 1;
    uint32_t RESERVED9                      :23;
} stc_sysreg_pwr_rampc0_field_t;

typedef struct
{
    __IO uint32_t AESRDP                    : 1;
    __IO uint32_t AESWRP                    : 1;
    __IO uint32_t HASHRDP                   : 1;
    __IO uint32_t HASHWRP                   : 1;
    __IO uint32_t TRNGRDP                   : 1;
    __IO uint32_t TRNGWRP                   : 1;
    __IO uint32_t CRCRDP                    : 1;
    __IO uint32_t CRCWRP                    : 1;
    __IO uint32_t FMCRDP                    : 1;
    __IO uint32_t FMCWRP                    : 1;
    uint32_t RESERVED10                     : 2;
    __IO uint32_t WDTRDP                    : 1;
    __IO uint32_t WDTWRP                    : 1;
    __IO uint32_t SWDTRDP                   : 1;
    __IO uint32_t SWDTWRP                   : 1;
    __IO uint32_t BKSRAMRDP                 : 1;
    __IO uint32_t BKSRAMWRP                 : 1;
    __IO uint32_t RTCRDP                    : 1;
    __IO uint32_t RTCWRP                    : 1;
    __IO uint32_t DMPURDP                   : 1;
    __IO uint32_t DMPUWRP                   : 1;
    __IO uint32_t SRAMCRDP                  : 1;
    __IO uint32_t SRAMCWRP                  : 1;
    __IO uint32_t INTCRDP                   : 1;
    __IO uint32_t INTCWRP                   : 1;
    __IO uint32_t SYSCRDP                   : 1;
    __IO uint32_t SYSCWRP                   : 1;
    __IO uint32_t MSTPRDP                   : 1;
    __IO uint32_t MSTPWRP                   : 1;
    uint32_t RESERVED30                     : 1;
    __IO uint32_t BUSERRE                   : 1;
} stc_sysreg_mpu_ippr_field_t;

typedef struct
{
    __IO uint32_t PCLK0S                    : 3;
    uint32_t RESERVED3                      : 1;
    __IO uint32_t PCLK1S                    : 3;
    uint32_t RESERVED7                      : 1;
    __IO uint32_t PCLK2S                    : 3;
    uint32_t RESERVED11                     : 1;
    __IO uint32_t PCLK3S                    : 3;
    uint32_t RESERVED15                     : 1;
    __IO uint32_t PCLK4S                    : 3;
    uint32_t RESERVED19                     : 1;
    __IO uint32_t EXCKS                     : 3;
    uint32_t RESERVED23                     : 1;
    __IO uint32_t HCLKS                     : 3;
    uint32_t RESERVED27                     : 5;
} stc_sysreg_cmu_scfgr_field_t;

typedef struct
{
    uint8_t RESERVED0                       : 4;
    __IO uint8_t USBCKS                     : 4;
} stc_sysreg_cmu_ufsckcfgr_field_t;

typedef struct
{
    __IO uint8_t CKSW                       : 3;
    uint8_t RESERVED3                       : 5;
} stc_sysreg_cmu_ckswr_field_t;

typedef struct
{
    __IO uint8_t MPLLOFF                    : 1;
    uint8_t RESERVED1                       : 7;
} stc_sysreg_cmu_pllcr_field_t;

typedef struct
{
    __IO uint8_t UPLLOFF                    : 1;
    uint8_t RESERVED1                       : 7;
} stc_sysreg_cmu_upllcr_field_t;

typedef struct
{
    __IO uint8_t XTALSTP                    : 1;
    uint8_t RESERVED1                       : 7;
} stc_sysreg_cmu_xtalcr_field_t;

typedef struct
{
    __IO uint8_t HRCSTP                     : 1;
    uint8_t RESERVED1                       : 7;
} stc_sysreg_cmu_hrccr_field_t;

typedef struct
{
    __IO uint8_t MRCSTP                     : 1;
    uint8_t RESERVED1                       : 7;
} stc_sysreg_cmu_mrccr_field_t;

typedef struct
{
    __IO uint8_t HRCSTBF                    : 1;
    uint8_t RESERVED1                       : 2;
    __IO uint8_t XTALSTBF                   : 1;
    uint8_t RESERVED4                       : 1;
    __IO uint8_t MPLLSTBF                   : 1;
    __IO uint8_t UPLLSTBF                   : 1;
    uint8_t RESERVED7                       : 1;
} stc_sysreg_cmu_oscstbsr_field_t;

typedef struct
{
    __IO uint8_t MCO1SEL                    : 4;
    __IO uint8_t MCO1DIV                    : 3;
    __IO uint8_t MCO1EN                     : 1;
} stc_sysreg_cmu_mco1cfgr_field_t;

typedef struct
{
    __IO uint8_t MCO2SEL                    : 4;
    __IO uint8_t MCO2DIV                    : 3;
    __IO uint8_t MCO2EN                     : 1;
} stc_sysreg_cmu_mco2cfgr_field_t;

typedef struct
{
    __IO uint8_t TPIUCKS                    : 2;
    uint8_t RESERVED2                       : 5;
    __IO uint8_t TPIUCKOE                   : 1;
} stc_sysreg_cmu_tpiuckcfgr_field_t;

typedef struct
{
    __IO uint8_t XTALSTDIE                  : 1;
    __IO uint8_t XTALSTDRE                  : 1;
    __IO uint8_t XTALSTDRIS                 : 1;
    uint8_t RESERVED3                       : 4;
    __IO uint8_t XTALSTDE                   : 1;
} stc_sysreg_cmu_xtalstdcr_field_t;

typedef struct
{
    __IO uint8_t XTALSTDF                   : 1;
    uint8_t RESERVED1                       : 7;
} stc_sysreg_cmu_xtalstdsr_field_t;

typedef struct
{
    __IO uint8_t XTALSTB                    : 4;
    uint8_t RESERVED4                       : 4;
} stc_sysreg_cmu_xtalstbcr_field_t;

typedef struct
{
    __IO uint16_t PORF                      : 1;
    __IO uint16_t PINRF                     : 1;
    __IO uint16_t BORF                      : 1;
    __IO uint16_t PVD1RF                    : 1;
    __IO uint16_t PVD2RF                    : 1;
    __IO uint16_t WDRF                      : 1;
    __IO uint16_t SWDRF                     : 1;
    __IO uint16_t PDRF                      : 1;
    __IO uint16_t SWRF                      : 1;
    __IO uint16_t MPUERF                    : 1;
    __IO uint16_t RAPERF                    : 1;
    __IO uint16_t RAECRF                    : 1;
    __IO uint16_t CKFERF                    : 1;
    __IO uint16_t XTALERF                   : 1;
    __IO uint16_t MULTIRF                   : 1;
    __IO uint16_t CLRF                      : 1;
} stc_sysreg_rmu_rstf0_field_t;

typedef struct
{
    __IO uint8_t PVD1NMIS                   : 1;
    uint8_t RESERVED1                       : 3;
    __IO uint8_t PVD2NMIS                   : 1;
    uint8_t RESERVED5                       : 3;
} stc_sysreg_pwr_pvdicr_field_t;

typedef struct
{
    __IO uint8_t PVD1MON                    : 1;
    __IO uint8_t PVD1DETFLG                 : 1;
    uint8_t RESERVED2                       : 2;
    __IO uint8_t PVD2MON                    : 1;
    __IO uint8_t PVD2DETFLG                 : 1;
    uint8_t RESERVED6                       : 2;
} stc_sysreg_pwr_pvddsr_field_t;

typedef struct
{
    __IO uint32_t MPLLM                     : 5;
    uint32_t RESERVED5                      : 2;
    __IO uint32_t PLLSRC                    : 1;
    __IO uint32_t MPLLN                     : 9;
    uint32_t RESERVED17                     : 3;
    __IO uint32_t MPLLR                     : 4;
    __IO uint32_t MPLLQ                     : 4;
    __IO uint32_t MPLLP                     : 4;
} stc_sysreg_cmu_pllcfgr_field_t;

typedef struct
{
    __IO uint32_t UPLLM                     : 5;
    uint32_t RESERVED5                      : 3;
    __IO uint32_t UPLLN                     : 9;
    uint32_t RESERVED17                     : 3;
    __IO uint32_t UPLLR                     : 4;
    __IO uint32_t UPLLQ                     : 4;
    __IO uint32_t UPLLP                     : 4;
} stc_sysreg_cmu_upllcfgr_field_t;

typedef struct
{
    __IO uint16_t FPRCB0                    : 1;
    __IO uint16_t FPRCB1                    : 1;
    __IO uint16_t FPRCB2                    : 1;
    __IO uint16_t FPRCB3                    : 1;
    uint16_t RESERVED4                      : 4;
    __IO uint16_t FPRCWE                    : 8;
} stc_sysreg_pwr_fprc_field_t;

typedef struct
{
    __IO uint8_t PDMDS                      : 2;
    __IO uint8_t VVDRSD                     : 1;
    __IO uint8_t RETRAMSD                   : 1;
    __IO uint8_t IORTN                      : 2;
    uint8_t RESERVED6                       : 1;
    __IO uint8_t PWDN                       : 1;
} stc_sysreg_pwr_pwrc0_field_t;

typedef struct
{
    __IO uint8_t VPLLSD                     : 1;
    __IO uint8_t VHRCSD                     : 1;
    uint8_t RESERVED2                       : 4;
    __IO uint8_t STPDAS                     : 2;
} stc_sysreg_pwr_pwrc1_field_t;

typedef struct
{
    __IO uint8_t DDAS                       : 4;
    __IO uint8_t DVS                        : 2;
    uint8_t RESERVED6                       : 2;
} stc_sysreg_pwr_pwrc2_field_t;

typedef struct
{
    uint8_t RESERVED0                       : 2;
    __IO uint8_t PDTS                       : 1;
    uint8_t RESERVED3                       : 5;
} stc_sysreg_pwr_pwrc3_field_t;

typedef struct
{
    __IO uint8_t WKE00                      : 1;
    __IO uint8_t WKE01                      : 1;
    __IO uint8_t WKE02                      : 1;
    __IO uint8_t WKE03                      : 1;
    __IO uint8_t WKE10                      : 1;
    __IO uint8_t WKE11                      : 1;
    __IO uint8_t WKE12                      : 1;
    __IO uint8_t WKE13                      : 1;
} stc_sysreg_pwr_pdwke0_field_t;

typedef struct
{
    __IO uint8_t WKE20                      : 1;
    __IO uint8_t WKE21                      : 1;
    __IO uint8_t WKE22                      : 1;
    __IO uint8_t WKE23                      : 1;
    __IO uint8_t WKE30                      : 1;
    __IO uint8_t WKE31                      : 1;
    __IO uint8_t WKE32                      : 1;
    __IO uint8_t WKE33                      : 1;
} stc_sysreg_pwr_pdwke1_field_t;

typedef struct
{
    __IO uint8_t VD1WKE                     : 1;
    __IO uint8_t VD2WKE                     : 1;
    __IO uint8_t NMIWKE                     : 1;
    uint8_t RESERVED3                       : 1;
    __IO uint8_t RTCPRDWKE                  : 1;
    __IO uint8_t RTCALMWKE                  : 1;
    uint8_t RESERVED6                       : 1;
    __IO uint8_t WKTMWKE                    : 1;
} stc_sysreg_pwr_pdwke2_field_t;

typedef struct
{
    __IO uint8_t WK0EGS                     : 1;
    __IO uint8_t WK1EGS                     : 1;
    __IO uint8_t WK2EGS                     : 1;
    __IO uint8_t WK3EGS                     : 1;
    __IO uint8_t VD1EGS                     : 1;
    __IO uint8_t VD2EGS                     : 1;
    __IO uint8_t NMIEGS                     : 1;
    uint8_t RESERVED7                       : 1;
} stc_sysreg_pwr_pdwkes_field_t;

typedef struct
{
    __IO uint8_t PTWK0F                     : 1;
    __IO uint8_t PTWK1F                     : 1;
    __IO uint8_t PTWK2F                     : 1;
    __IO uint8_t PTWK3F                     : 1;
    __IO uint8_t VD1WKF                     : 1;
    __IO uint8_t VD2WKF                     : 1;
    __IO uint8_t NMIWKF                     : 1;
    uint8_t RESERVED7                       : 1;
} stc_sysreg_pwr_pdwkf0_field_t;

typedef struct
{
    uint8_t RESERVED0                       : 4;
    __IO uint8_t RTCPRDWKF                  : 1;
    __IO uint8_t RTCALMWKF                  : 1;
    uint8_t RESERVED6                       : 1;
    __IO uint8_t WKTMWKF                    : 1;
} stc_sysreg_pwr_pdwkf1_field_t;

typedef struct
{
    uint8_t RESERVED0                       : 7;
    __IO uint8_t ADBUFE                     : 1;
} stc_sysreg_pwr_pwcmr_field_t;

typedef struct
{
    uint8_t RESERVED0                       : 4;
    __IO uint8_t XTALDRV                    : 2;
    __IO uint8_t XTALMS                     : 1;
    __IO uint8_t SUPDRV                     : 1;
} stc_sysreg_cmu_xtalcfgr_field_t;

typedef struct
{
    __IO uint8_t EXVCCINEN                  : 1;
    uint8_t RESERVED1                       : 4;
    __IO uint8_t PVD1EN                     : 1;
    __IO uint8_t PVD2EN                     : 1;
    uint8_t RESERVED7                       : 1;
} stc_sysreg_pwr_pvdcr0_field_t;

typedef struct
{
    __IO uint8_t PVD1IRE                    : 1;
    __IO uint8_t PVD1IRS                    : 1;
    __IO uint8_t PVD1CMPOE                  : 1;
    uint8_t RESERVED3                       : 1;
    __IO uint8_t PVD2IRE                    : 1;
    __IO uint8_t PVD2IRS                    : 1;
    __IO uint8_t PVD2CMPOE                  : 1;
    uint8_t RESERVED7                       : 1;
} stc_sysreg_pwr_pvdcr1_field_t;

typedef struct
{
    __IO uint8_t PVD1NFDIS                  : 1;
    __IO uint8_t PVD1NFCKS                  : 2;
    uint8_t RESERVED3                       : 1;
    __IO uint8_t PVD2NFDIS                  : 1;
    __IO uint8_t PVD2NFCKS                  : 2;
    uint8_t RESERVED7                       : 1;
} stc_sysreg_pwr_pvdfcr_field_t;

typedef struct
{
    __IO uint8_t PVD1LVL                    : 3;
    uint8_t RESERVED3                       : 1;
    __IO uint8_t PVD2LVL                    : 3;
    uint8_t RESERVED7                       : 1;
} stc_sysreg_pwr_pvdlcr_field_t;

typedef struct
{
    __IO uint8_t XTAL32STP                  : 1;
    uint8_t RESERVED1                       : 7;
} stc_sysreg_cmu_xtal32cr_field_t;

typedef struct
{
    __IO uint8_t XTAL32DRV                  : 3;
    uint8_t RESERVED3                       : 5;
} stc_sysreg_cmu_xtal32cfgr_field_t;

typedef struct
{
    __IO uint8_t XTAL32NF                   : 2;
    uint8_t RESERVED2                       : 6;
} stc_sysreg_cmu_xtal32nfr_field_t;

typedef struct
{
    __IO uint8_t LRCSTP                     : 1;
    uint8_t RESERVED1                       : 7;
} stc_sysreg_cmu_lrccr_field_t;

typedef struct
{
    uint8_t RESERVED0                       : 7;
    __IO uint8_t CSDIS                      : 1;
} stc_sysreg_pwr_xtal32cs_field_t;

typedef struct
{
    __IO uint32_t CNTA                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr0_cntar_field_t;

typedef struct
{
    __IO uint32_t CNTB                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr0_cntbr_field_t;

typedef struct
{
    __IO uint32_t CMPA                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr0_cmpar_field_t;

typedef struct
{
    __IO uint32_t CMPB                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr0_cmpbr_field_t;

typedef struct
{
    __IO uint32_t CSTA                      : 1;
    __IO uint32_t CAPMDA                    : 1;
    __IO uint32_t INTENA                    : 1;
    uint32_t RESERVED3                      : 1;
    __IO uint32_t CKDIVA                    : 4;
    __IO uint32_t SYNSA                     : 1;
    __IO uint32_t SYNCLKA                   : 1;
    __IO uint32_t ASYNCLKA                  : 1;
    uint32_t RESERVED11                     : 1;
    __IO uint32_t HSTAA                     : 1;
    __IO uint32_t HSTPA                     : 1;
    __IO uint32_t HCLEA                     : 1;
    __IO uint32_t HICPA                     : 1;
    __IO uint32_t CSTB                      : 1;
    __IO uint32_t CAPMDB                    : 1;
    __IO uint32_t INTENB                    : 1;
    uint32_t RESERVED19                     : 1;
    __IO uint32_t CKDIVB                    : 4;
    __IO uint32_t SYNSB                     : 1;
    __IO uint32_t SYNCLKB                   : 1;
    __IO uint32_t ASYNCLKB                  : 1;
    uint32_t RESERVED27                     : 1;
    __IO uint32_t HSTAB                     : 1;
    __IO uint32_t HSTPB                     : 1;
    __IO uint32_t HCLEB                     : 1;
    __IO uint32_t HICPB                     : 1;
} stc_tmr0_bconr_field_t;

typedef struct
{
    __IO uint32_t CMAF                      : 1;
    uint32_t RESERVED1                      :15;
    __IO uint32_t CMBF                      : 1;
    uint32_t RESERVED17                     :15;
} stc_tmr0_stflr_field_t;

typedef struct
{
    __IO uint16_t OCEH                      : 1;
    __IO uint16_t OCEL                      : 1;
    __IO uint16_t OCPH                      : 1;
    __IO uint16_t OCPL                      : 1;
    __IO uint16_t OCIEH                     : 1;
    __IO uint16_t OCIEL                     : 1;
    __IO uint16_t OCFH                      : 1;
    __IO uint16_t OCFL                      : 1;
    uint16_t RESERVED8                      : 8;
} stc_tmr4_ocsr_field_t;

typedef struct
{
    __IO uint16_t CHBUFEN                   : 2;
    __IO uint16_t CLBUFEN                   : 2;
    __IO uint16_t MHBUFEN                   : 2;
    __IO uint16_t MLBUFEN                   : 2;
    __IO uint16_t LMCH                      : 1;
    __IO uint16_t LMCL                      : 1;
    __IO uint16_t LMMH                      : 1;
    __IO uint16_t LMML                      : 1;
    __IO uint16_t MCECH                     : 1;
    __IO uint16_t MCECL                     : 1;
    uint16_t RESERVED14                     : 2;
} stc_tmr4_ocer_field_t;

typedef struct
{
    __IO uint16_t OCFDCH                    : 1;
    __IO uint16_t OCFPKH                    : 1;
    __IO uint16_t OCFUCH                    : 1;
    __IO uint16_t OCFZRH                    : 1;
    __IO uint16_t OPDCH                     : 2;
    __IO uint16_t OPPKH                     : 2;
    __IO uint16_t OPUCH                     : 2;
    __IO uint16_t OPZRH                     : 2;
    __IO uint16_t OPNPKH                    : 2;
    __IO uint16_t OPNZRH                    : 2;
} stc_tmr4_ocmrh_field_t;

typedef struct
{
    __IO uint32_t OCFDCL                    : 1;
    __IO uint32_t OCFPKL                    : 1;
    __IO uint32_t OCFUCL                    : 1;
    __IO uint32_t OCFZRL                    : 1;
    __IO uint32_t OPDCL                     : 2;
    __IO uint32_t OPPKL                     : 2;
    __IO uint32_t OPUCL                     : 2;
    __IO uint32_t OPZRL                     : 2;
    __IO uint32_t OPNPKL                    : 2;
    __IO uint32_t OPNZRL                    : 2;
    __IO uint32_t EOPNDCL                   : 2;
    __IO uint32_t EOPNUCL                   : 2;
    __IO uint32_t EOPDCL                    : 2;
    __IO uint32_t EOPPKL                    : 2;
    __IO uint32_t EOPUCL                    : 2;
    __IO uint32_t EOPZRL                    : 2;
    __IO uint32_t EOPNPKL                   : 2;
    __IO uint32_t EOPNZRL                   : 2;
} stc_tmr4_ocmrl_field_t;

typedef struct
{
    __IO uint16_t CKDIV                     : 4;
    __IO uint16_t CLEAR                     : 1;
    __IO uint16_t MODE                      : 1;
    __IO uint16_t STOP                      : 1;
    __IO uint16_t BUFEN                     : 1;
    __IO uint16_t IRQPEN                    : 1;
    __IO uint16_t IRQPF                     : 1;
    uint16_t RESERVED10                     : 3;
    __IO uint16_t IRQZEN                    : 1;
    __IO uint16_t IRQZF                     : 1;
    __IO uint16_t ECKEN                     : 1;
} stc_tmr4_ccsr_field_t;

typedef struct
{
    __IO uint16_t ZIM                       : 4;
    __IO uint16_t PIM                       : 4;
    __I  uint16_t ZIC                       : 4;
    __I  uint16_t PIC                       : 4;
} stc_tmr4_cvpr_field_t;

typedef struct
{
    __IO uint16_t DIVCK                     : 4;
    __IO uint16_t PWMMD                     : 2;
    __IO uint16_t LVLS                      : 2;
    uint16_t RESERVED8                      : 8;
} stc_tmr4_pocr_field_t;

typedef struct
{
    __IO uint16_t RTIDU                     : 1;
    __IO uint16_t RTIDV                     : 1;
    __IO uint16_t RTIDW                     : 1;
    uint16_t RESERVED3                      : 1;
    __I  uint16_t RTIFU                     : 1;
    __IO uint16_t RTICU                     : 1;
    __IO uint16_t RTEU                      : 1;
    __IO uint16_t RTSU                      : 1;
    __I  uint16_t RTIFV                     : 1;
    __IO uint16_t RTICV                     : 1;
    __IO uint16_t RTEV                      : 1;
    __IO uint16_t RTSV                      : 1;
    __I  uint16_t RTIFW                     : 1;
    __IO uint16_t RTICW                     : 1;
    __IO uint16_t RTEW                      : 1;
    __IO uint16_t RTSW                      : 1;
} stc_tmr4_rcsr_field_t;

typedef struct
{
    __IO uint16_t BUFEN                     : 2;
    __IO uint16_t EVTOS                     : 3;
    __IO uint16_t LMC                       : 1;
    uint16_t RESERVED6                      : 2;
    __IO uint16_t EVTMS                     : 1;
    __IO uint16_t EVTDS                     : 1;
    uint16_t RESERVED10                     : 2;
    __IO uint16_t DEN                       : 1;
    __IO uint16_t PEN                       : 1;
    __IO uint16_t UEN                       : 1;
    __IO uint16_t ZEN                       : 1;
} stc_tmr4_scsr_field_t;

typedef struct
{
    __IO uint16_t AMC                       : 4;
    uint16_t RESERVED4                      : 2;
    __IO uint16_t MZCE                      : 1;
    __IO uint16_t MPCE                      : 1;
    uint16_t RESERVED8                      : 8;
} stc_tmr4_scmr_field_t;

typedef struct
{
    uint16_t RESERVED0                      : 7;
    __IO uint16_t HOLD                      : 1;
    uint16_t RESERVED8                      : 8;
} stc_tmr4_ecsr_field_t;

typedef struct
{
    __IO uint16_t EMBVAL                    : 2;
    uint16_t RESERVED2                      :14;
} stc_tmr4_cr_ecer1_field_t;

typedef struct
{
    __IO uint16_t EMBVAL                    : 2;
    uint16_t RESERVED2                      :14;
} stc_tmr4_cr_ecer2_field_t;

typedef struct
{
    __IO uint16_t EMBVAL                    : 2;
    uint16_t RESERVED2                      :14;
} stc_tmr4_cr_ecer3_field_t;

typedef struct
{
    __IO uint32_t CNT                       :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_cnter_field_t;

typedef struct
{
    __IO uint32_t PERA                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_perar_field_t;

typedef struct
{
    __IO uint32_t PERB                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_perbr_field_t;

typedef struct
{
    __IO uint32_t PERC                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_percr_field_t;

typedef struct
{
    __IO uint32_t GCMA                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_gcmar_field_t;

typedef struct
{
    __IO uint32_t GCMB                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_gcmbr_field_t;

typedef struct
{
    __IO uint32_t GCMC                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_gcmcr_field_t;

typedef struct
{
    __IO uint32_t GCMD                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_gcmdr_field_t;

typedef struct
{
    __IO uint32_t GCME                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_gcmer_field_t;

typedef struct
{
    __IO uint32_t GCMF                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_gcmfr_field_t;

typedef struct
{
    __IO uint32_t SCMA                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_scmar_field_t;

typedef struct
{
    __IO uint32_t SCMB                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_scmbr_field_t;

typedef struct
{
    __IO uint32_t SCMC                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_scmcr_field_t;

typedef struct
{
    __IO uint32_t SCMD                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_scmdr_field_t;

typedef struct
{
    __IO uint32_t SCME                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_scmer_field_t;

typedef struct
{
    __IO uint32_t SCMF                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_scmfr_field_t;

typedef struct
{
    __IO uint32_t DTUA                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_dtuar_field_t;

typedef struct
{
    __IO uint32_t DTDA                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_dtdar_field_t;

typedef struct
{
    __IO uint32_t DTUB                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_dtubr_field_t;

typedef struct
{
    __IO uint32_t DTDB                      :16;
    uint32_t RESERVED16                     :16;
} stc_tmr6_dtdbr_field_t;

typedef struct
{
    __IO uint32_t START                     : 1;
    __IO uint32_t MODE                      : 3;
    __IO uint32_t CKDIV                     : 3;
    uint32_t RESERVED7                      : 1;
    __IO uint32_t DIR                       : 1;
    uint32_t RESERVED9                      : 7;
    __IO uint32_t ZMSKREV                   : 1;
    __IO uint32_t ZMSKPOS                   : 1;
    __IO uint32_t ZMSKVAL                   : 2;
    uint32_t RESERVED20                     :12;
} stc_tmr6_gconr_field_t;

typedef struct
{
    __IO uint32_t INTENA                    : 1;
    __IO uint32_t INTENB                    : 1;
    __IO uint32_t INTENC                    : 1;
    __IO uint32_t INTEND                    : 1;
    __IO uint32_t INTENE                    : 1;
    __IO uint32_t INTENF                    : 1;
    __IO uint32_t INTENOVF                  : 1;
    __IO uint32_t INTENUDF                  : 1;
    __IO uint32_t INTENDTE                  : 1;
    uint32_t RESERVED9                      : 7;
    __IO uint32_t INTENSAU                  : 1;
    __IO uint32_t INTENSAD                  : 1;
    __IO uint32_t INTENSBU                  : 1;
    __IO uint32_t INTENSBD                  : 1;
    uint32_t RESERVED20                     :12;
} stc_tmr6_iconr_field_t;

typedef struct
{
    __IO uint32_t CAPMDA                    : 1;
    __IO uint32_t STACA                     : 1;
    __IO uint32_t STPCA                     : 1;
    __IO uint32_t STASTPSA                  : 1;
    __IO uint32_t CMPCA                     : 2;
    __IO uint32_t PERCA                     : 2;
    __IO uint32_t OUTENA                    : 1;
    uint32_t RESERVED9                      : 2;
    __IO uint32_t EMBVALA                   : 2;
    uint32_t RESERVED13                     : 3;
    __IO uint32_t CAPMDB                    : 1;
    __IO uint32_t STACB                     : 1;
    __IO uint32_t STPCB                     : 1;
    __IO uint32_t STASTPSB                  : 1;
    __IO uint32_t CMPCB                     : 2;
    __IO uint32_t PERCB                     : 2;
    __IO uint32_t OUTENB                    : 1;
    uint32_t RESERVED25                     : 2;
    __IO uint32_t EMBVALB                   : 2;
    uint32_t RESERVED29                     : 3;
} stc_tmr6_pconr_field_t;

typedef struct
{
    __IO uint32_t BENA                      : 1;
    __IO uint32_t BSEA                      : 1;
    __IO uint32_t BENB                      : 1;
    __IO uint32_t BSEB                      : 1;
    uint32_t RESERVED4                      : 4;
    __IO uint32_t BENP                      : 1;
    __IO uint32_t BSEP                      : 1;
    uint32_t RESERVED10                     : 6;
    __IO uint32_t BENSPA                    : 1;
    __IO uint32_t BSESPA                    : 1;
    uint32_t RESERVED18                     : 2;
    __IO uint32_t BTRSPA                    : 2;
    uint32_t RESERVED22                     : 2;
    __IO uint32_t BENSPB                    : 1;
    __IO uint32_t BSESPB                    : 1;
    uint32_t RESERVED26                     : 2;
    __IO uint32_t BTRSPB                    : 2;
    uint32_t RESERVED30                     : 2;
} stc_tmr6_bconr_field_t;

typedef struct
{
    __IO uint32_t DTCEN                     : 1;
    uint32_t RESERVED1                      : 3;
    __IO uint32_t DTBENU                    : 1;
    __IO uint32_t DTBEND                    : 1;
    uint32_t RESERVED6                      : 2;
    __IO uint32_t SEPA                      : 1;
    uint32_t RESERVED9                      :23;
} stc_tmr6_dconr_field_t;

typedef struct
{
    __IO uint32_t NOFIENGA                  : 1;
    __IO uint32_t NOFICKGA                  : 2;
    uint32_t RESERVED3                      : 1;
    __IO uint32_t NOFIENGB                  : 1;
    __IO uint32_t NOFICKGB                  : 2;
    uint32_t RESERVED7                      : 9;
    __IO uint32_t NOFIENTA                  : 1;
    __IO uint32_t NOFICKTA                  : 2;
    uint32_t RESERVED19                     : 1;
    __IO uint32_t NOFIENTB                  : 1;
    __IO uint32_t NOFICKTB                  : 2;
    uint32_t RESERVED23                     : 9;
} stc_tmr6_fconr_field_t;

typedef struct
{
    uint32_t RESERVED0                      : 8;
    __IO uint32_t SPPERIA                   : 1;
    __IO uint32_t SPPERIB                   : 1;
    uint32_t RESERVED10                     : 6;
    __IO uint32_t PCNTE                     : 2;
    __IO uint32_t PCNTS                     : 3;
    uint32_t RESERVED21                     :11;
} stc_tmr6_vperr_field_t;

typedef struct
{
    __IO uint32_t CMAF                      : 1;
    __IO uint32_t CMBF                      : 1;
    __IO uint32_t CMCF                      : 1;
    __IO uint32_t CMDF                      : 1;
    __IO uint32_t CMEF                      : 1;
    __IO uint32_t CMFF                      : 1;
    __IO uint32_t OVFF                      : 1;
    __IO uint32_t UDFF                      : 1;
    __I  uint32_t DTEF                      : 1;
    __IO uint32_t CMSAUF                    : 1;
    __IO uint32_t CMSADF                    : 1;
    __IO uint32_t CMSBUF                    : 1;
    __IO uint32_t CMSBDF                    : 1;
    uint32_t RESERVED13                     : 8;
    __I  uint32_t VPERNUM                   : 3;
    uint32_t RESERVED24                     : 7;
    __I  uint32_t DIRF                      : 1;
} stc_tmr6_stflr_field_t;

typedef struct
{
    __IO uint32_t HSTA0                     : 1;
    __IO uint32_t HSTA1                     : 1;
    uint32_t RESERVED2                      : 2;
    __IO uint32_t HSTA4                     : 1;
    __IO uint32_t HSTA5                     : 1;
    __IO uint32_t HSTA6                     : 1;
    __IO uint32_t HSTA7                     : 1;
    __IO uint32_t HSTA8                     : 1;
    __IO uint32_t HSTA9                     : 1;
    __IO uint32_t HSTA10                    : 1;
    __IO uint32_t HSTA11                    : 1;
    uint32_t RESERVED12                     :19;
    __IO uint32_t STARTS                    : 1;
} stc_tmr6_hstar_field_t;

typedef struct
{
    __IO uint32_t HSTP0                     : 1;
    __IO uint32_t HSTP1                     : 1;
    uint32_t RESERVED2                      : 2;
    __IO uint32_t HSTP4                     : 1;
    __IO uint32_t HSTP5                     : 1;
    __IO uint32_t HSTP6                     : 1;
    __IO uint32_t HSTP7                     : 1;
    __IO uint32_t HSTP8                     : 1;
    __IO uint32_t HSTP9                     : 1;
    __IO uint32_t HSTP10                    : 1;
    __IO uint32_t HSTP11                    : 1;
    uint32_t RESERVED12                     :19;
    __IO uint32_t STOPS                     : 1;
} stc_tmr6_hstpr_field_t;

typedef struct
{
    __IO uint32_t HCLE0                     : 1;
    __IO uint32_t HCLE1                     : 1;
    uint32_t RESERVED2                      : 2;
    __IO uint32_t HCLE4                     : 1;
    __IO uint32_t HCLE5                     : 1;
    __IO uint32_t HCLE6                     : 1;
    __IO uint32_t HCLE7                     : 1;
    __IO uint32_t HCLE8                     : 1;
    __IO uint32_t HCLE9                     : 1;
    __IO uint32_t HCLE10                    : 1;
    __IO uint32_t HCLE11                    : 1;
    uint32_t RESERVED12                     :19;
    __IO uint32_t CLEARS                    : 1;
} stc_tmr6_hclrr_field_t;

typedef struct
{
    __IO uint32_t HCPA0                     : 1;
    __IO uint32_t HCPA1                     : 1;
    uint32_t RESERVED2                      : 2;
    __IO uint32_t HCPA4                     : 1;
    __IO uint32_t HCPA5                     : 1;
    __IO uint32_t HCPA6                     : 1;
    __IO uint32_t HCPA7                     : 1;
    __IO uint32_t HCPA8                     : 1;
    __IO uint32_t HCPA9                     : 1;
    __IO uint32_t HCPA10                    : 1;
    __IO uint32_t HCPA11                    : 1;
    uint32_t RESERVED12                     :20;
} stc_tmr6_hcpar_field_t;

typedef struct
{
    __IO uint32_t HCPB0                     : 1;
    __IO uint32_t HCPB1                     : 1;
    uint32_t RESERVED2                      : 2;
    __IO uint32_t HCPB4                     : 1;
    __IO uint32_t HCPB5                     : 1;
    __IO uint32_t HCPB6                     : 1;
    __IO uint32_t HCPB7                     : 1;
    __IO uint32_t HCPB8                     : 1;
    __IO uint32_t HCPB9                     : 1;
    __IO uint32_t HCPB10                    : 1;
    __IO uint32_t HCPB11                    : 1;
    uint32_t RESERVED12                     :20;
} stc_tmr6_hcpbr_field_t;

typedef struct
{
    __IO uint32_t HCUP0                     : 1;
    __IO uint32_t HCUP1                     : 1;
    __IO uint32_t HCUP2                     : 1;
    __IO uint32_t HCUP3                     : 1;
    __IO uint32_t HCUP4                     : 1;
    __IO uint32_t HCUP5                     : 1;
    __IO uint32_t HCUP6                     : 1;
    __IO uint32_t HCUP7                     : 1;
    __IO uint32_t HCUP8                     : 1;
    __IO uint32_t HCUP9                     : 1;
    __IO uint32_t HCUP10                    : 1;
    __IO uint32_t HCUP11                    : 1;
    uint32_t RESERVED12                     : 4;
    __IO uint32_t HCUP16                    : 1;
    __IO uint32_t HCUP17                    : 1;
    uint32_t RESERVED18                     :14;
} stc_tmr6_hcupr_field_t;

typedef struct
{
    __IO uint32_t HCDO0                     : 1;
    __IO uint32_t HCDO1                     : 1;
    __IO uint32_t HCDO2                     : 1;
    __IO uint32_t HCDO3                     : 1;
    __IO uint32_t HCDO4                     : 1;
    __IO uint32_t HCDO5                     : 1;
    __IO uint32_t HCDO6                     : 1;
    __IO uint32_t HCDO7                     : 1;
    __IO uint32_t HCDO8                     : 1;
    __IO uint32_t HCDO9                     : 1;
    __IO uint32_t HCDO10                    : 1;
    __IO uint32_t HCDO11                    : 1;
    uint32_t RESERVED12                     : 4;
    __IO uint32_t HCDO16                    : 1;
    __IO uint32_t HCDO17                    : 1;
    uint32_t RESERVED18                     :14;
} stc_tmr6_hcdor_field_t;

typedef struct
{
    __IO uint32_t SSTA1                     : 1;
    __IO uint32_t SSTA2                     : 1;
    __IO uint32_t SSTA3                     : 1;
    uint32_t RESERVED3                      :13;
    __IO uint32_t RESV0                     : 1;
    uint32_t RESERVED17                     : 7;
    __IO uint32_t RESV                      : 1;
    uint32_t RESERVED25                     : 7;
} stc_tmr6_cr_sstar_field_t;

typedef struct
{
    __IO uint32_t SSTP1                     : 1;
    __IO uint32_t SSTP2                     : 1;
    __IO uint32_t SSTP3                     : 1;
    uint32_t RESERVED3                      :29;
} stc_tmr6_cr_sstpr_field_t;

typedef struct
{
    __IO uint32_t SCLE1                     : 1;
    __IO uint32_t SCLE2                     : 1;
    __IO uint32_t SCLE3                     : 1;
    uint32_t RESERVED3                      :29;
} stc_tmr6_cr_sclrr_field_t;

typedef struct
{
    __IO uint16_t CNT                       :16;
} stc_tmra_cnter_field_t;

typedef struct
{
    __IO uint16_t PER                       :16;
} stc_tmra_perar_field_t;

typedef struct
{
    __IO uint16_t CMP                       :16;
} stc_tmra_cmpar_field_t;

typedef struct
{
    __IO uint16_t START                     : 1;
    __IO uint16_t DIR                       : 1;
    __IO uint16_t MODE                      : 1;
    __IO uint16_t SYNST                     : 1;
    __IO uint16_t CKDIV                     : 4;
    uint16_t RESERVED8                      : 4;
    __IO uint16_t ITENOVF                   : 1;
    __IO uint16_t ITENUDF                   : 1;
    __IO uint16_t OVFF                      : 1;
    __IO uint16_t UDFF                      : 1;
} stc_tmra_bcstr_field_t;

typedef struct
{
    __IO uint16_t HSTA0                     : 1;
    __IO uint16_t HSTA1                     : 1;
    __IO uint16_t HSTA2                     : 1;
    uint16_t RESERVED3                      : 1;
    __IO uint16_t HSTP0                     : 1;
    __IO uint16_t HSTP1                     : 1;
    __IO uint16_t HSTP2                     : 1;
    uint16_t RESERVED7                      : 1;
    __IO uint16_t HCLE0                     : 1;
    __IO uint16_t HCLE1                     : 1;
    __IO uint16_t HCLE2                     : 1;
    uint16_t RESERVED11                     : 1;
    __IO uint16_t HCLE3                     : 1;
    __IO uint16_t HCLE4                     : 1;
    __IO uint16_t HCLE5                     : 1;
    __IO uint16_t HCLE6                     : 1;
} stc_tmra_hconr_field_t;

typedef struct
{
    __IO uint16_t HCUP0                     : 1;
    __IO uint16_t HCUP1                     : 1;
    __IO uint16_t HCUP2                     : 1;
    __IO uint16_t HCUP3                     : 1;
    __IO uint16_t HCUP4                     : 1;
    __IO uint16_t HCUP5                     : 1;
    __IO uint16_t HCUP6                     : 1;
    __IO uint16_t HCUP7                     : 1;
    __IO uint16_t HCUP8                     : 1;
    __IO uint16_t HCUP9                     : 1;
    __IO uint16_t HCUP10                    : 1;
    __IO uint16_t HCUP11                    : 1;
    __IO uint16_t HCUP12                    : 1;
    uint16_t RESERVED13                     : 3;
} stc_tmra_hcupr_field_t;

typedef struct
{
    __IO uint16_t HCDO0                     : 1;
    __IO uint16_t HCDO1                     : 1;
    __IO uint16_t HCDO2                     : 1;
    __IO uint16_t HCDO3                     : 1;
    __IO uint16_t HCDO4                     : 1;
    __IO uint16_t HCDO5                     : 1;
    __IO uint16_t HCDO6                     : 1;
    __IO uint16_t HCDO7                     : 1;
    __IO uint16_t HCDO8                     : 1;
    __IO uint16_t HCDO9                     : 1;
    __IO uint16_t HCDO10                    : 1;
    __IO uint16_t HCDO11                    : 1;
    __IO uint16_t HCDO12                    : 1;
    uint16_t RESERVED13                     : 3;
} stc_tmra_hcdor_field_t;

typedef struct
{
    __IO uint16_t ITEN1                     : 1;
    __IO uint16_t ITEN2                     : 1;
    __IO uint16_t ITEN3                     : 1;
    __IO uint16_t ITEN4                     : 1;
    __IO uint16_t ITEN5                     : 1;
    __IO uint16_t ITEN6                     : 1;
    __IO uint16_t ITEN7                     : 1;
    __IO uint16_t ITEN8                     : 1;
    uint16_t RESERVED8                      : 8;
} stc_tmra_iconr_field_t;

typedef struct
{
    __IO uint16_t ETEN1                     : 1;
    __IO uint16_t ETEN2                     : 1;
    __IO uint16_t ETEN3                     : 1;
    __IO uint16_t ETEN4                     : 1;
    __IO uint16_t ETEN5                     : 1;
    __IO uint16_t ETEN6                     : 1;
    __IO uint16_t ETEN7                     : 1;
    __IO uint16_t ETEN8                     : 1;
    uint16_t RESERVED8                      : 8;
} stc_tmra_econr_field_t;

typedef struct
{
    __IO uint16_t NOFIENTG                  : 1;
    __IO uint16_t NOFICKTG                  : 2;
    uint16_t RESERVED3                      : 5;
    __IO uint16_t NOFIENCA                  : 1;
    __IO uint16_t NOFICKCA                  : 2;
    uint16_t RESERVED11                     : 1;
    __IO uint16_t NOFIENCB                  : 1;
    __IO uint16_t NOFICKCB                  : 2;
    uint16_t RESERVED15                     : 1;
} stc_tmra_fconr_field_t;

typedef struct
{
    __IO uint16_t CMPF1                     : 1;
    __IO uint16_t CMPF2                     : 1;
    __IO uint16_t CMPF3                     : 1;
    __IO uint16_t CMPF4                     : 1;
    __IO uint16_t CMPF5                     : 1;
    __IO uint16_t CMPF6                     : 1;
    __IO uint16_t CMPF7                     : 1;
    __IO uint16_t CMPF8                     : 1;
    uint16_t RESERVED8                      : 8;
} stc_tmra_stflr_field_t;

typedef struct
{
    __IO uint16_t BEN                       : 1;
    __IO uint16_t BSE0                      : 1;
    __IO uint16_t BSE1                      : 1;
    uint16_t RESERVED3                      :13;
} stc_tmra_bconr_field_t;

typedef struct
{
    __IO uint16_t CAPMD                     : 1;
    uint16_t RESERVED1                      : 3;
    __IO uint16_t HICP0                     : 1;
    __IO uint16_t HICP1                     : 1;
    __IO uint16_t HICP2                     : 1;
    uint16_t RESERVED7                      : 1;
    __IO uint16_t HICP3                     : 1;
    __IO uint16_t HICP4                     : 1;
    uint16_t RESERVED10                     : 2;
    __IO uint16_t NOFIENCP                  : 1;
    __IO uint16_t NOFICKCP                  : 2;
    uint16_t RESERVED15                     : 1;
} stc_tmra_cconr_field_t;

typedef struct
{
    __IO uint16_t STAC                      : 2;
    __IO uint16_t STPC                      : 2;
    __IO uint16_t CMPC                      : 2;
    __IO uint16_t PERC                      : 2;
    __IO uint16_t FORC                      : 2;
    uint16_t RESERVED10                     : 2;
    __IO uint16_t OUTEN                     : 1;
    uint16_t RESERVED13                     : 3;
} stc_tmra_pconr_field_t;

typedef struct
{
    __IO uint32_t EN                        : 1;
    __IO uint32_t RUN                       : 1;
    uint32_t RESERVED2                      :30;
} stc_trng_cr_field_t;

typedef struct
{
    __IO uint32_t LOAD                      : 1;
    uint32_t RESERVED1                      : 1;
    __IO uint32_t CNT                       : 3;
    uint32_t RESERVED5                      :27;
} stc_trng_mr_field_t;

typedef struct
{
    __I  uint32_t PE                        : 1;
    __I  uint32_t FE                        : 1;
    uint32_t RESERVED2                      : 1;
    __I  uint32_t ORE                       : 1;
    uint32_t RESERVED4                      : 1;
    __I  uint32_t RXNE                      : 1;
    __I  uint32_t TC                        : 1;
    __I  uint32_t TXE                       : 1;
    __I  uint32_t RTOF                      : 1;
    uint32_t RESERVED9                      : 7;
    __I  uint32_t MPB                       : 1;
    uint32_t RESERVED17                     :15;
} stc_usart_sr_field_t;

typedef struct
{
    __IO uint32_t TDR                       : 9;
    __IO uint32_t MPID                      : 1;
    uint32_t RESERVED10                     : 6;
    __IO uint32_t RDR                       : 9;
    uint32_t RESERVED25                     : 7;
} stc_usart_dr_field_t;

typedef struct
{
    __IO uint32_t DIV_FRACTION              : 7;
    uint32_t RESERVED7                      : 1;
    __IO uint32_t DIV_INTEGER               : 8;
    uint32_t RESERVED16                     :16;
} stc_usart_brr_field_t;

typedef struct
{
    __IO uint32_t RTOE                      : 1;
    __IO uint32_t RTOIE                     : 1;
    __IO uint32_t RE                        : 1;
    __IO uint32_t TE                        : 1;
    __IO uint32_t SLME                      : 1;
    __IO uint32_t RIE                       : 1;
    __IO uint32_t TCIE                      : 1;
    __IO uint32_t TXEIE                     : 1;
    uint32_t RESERVED8                      : 1;
    __IO uint32_t PS                        : 1;
    __IO uint32_t PCE                       : 1;
    uint32_t RESERVED11                     : 1;
    __IO uint32_t M                         : 1;
    uint32_t RESERVED13                     : 2;
    __IO uint32_t OVER8                     : 1;
    __O  uint32_t CPE                       : 1;
    __O  uint32_t CFE                       : 1;
    uint32_t RESERVED18                     : 1;
    __O  uint32_t CORE                      : 1;
    __O  uint32_t CRTOF                     : 1;
    uint32_t RESERVED21                     : 3;
    __IO uint32_t MS                        : 1;
    uint32_t RESERVED25                     : 3;
    __IO uint32_t ML                        : 1;
    __IO uint32_t FBME                      : 1;
    __IO uint32_t NFE                       : 1;
    __IO uint32_t SBS                       : 1;
} stc_usart_cr1_field_t;

typedef struct
{
    __IO uint32_t MPE                       : 1;
    uint32_t RESERVED1                      :10;
    __IO uint32_t CLKC                      : 2;
    __IO uint32_t STOP                      : 1;
    uint32_t RESERVED14                     :18;
} stc_usart_cr2_field_t;

typedef struct
{
    uint32_t RESERVED0                      : 5;
    __IO uint32_t SCEN                      : 1;
    uint32_t RESERVED6                      : 3;
    __IO uint32_t CTSE                      : 1;
    uint32_t RESERVED10                     :11;
    __IO uint32_t BCN                       : 3;
    uint32_t RESERVED24                     : 8;
} stc_usart_cr3_field_t;

typedef struct
{
    __IO uint32_t PSC                       : 2;
    uint32_t RESERVED2                      :30;
} stc_usart_pr_field_t;

typedef struct
{
    uint32_t RESERVED0                      : 6;
    __IO uint32_t VBUSOVEN                  : 1;
    __IO uint32_t VBUSVAL                   : 1;
    uint32_t RESERVED8                      :24;
} stc_usbfs_gvbuscfg_field_t;

typedef struct
{
    __IO uint32_t GINTMSK                   : 1;
    __IO uint32_t HBSTLEN                   : 4;
    __IO uint32_t DMAEN                     : 1;
    uint32_t RESERVED6                      : 1;
    __IO uint32_t TXFELVL                   : 1;
    __IO uint32_t PTXFELVL                  : 1;
    uint32_t RESERVED9                      :23;
} stc_usbfs_gahbcfg_field_t;

typedef struct
{
    __IO uint32_t TOCAL                     : 3;
    uint32_t RESERVED3                      : 3;
    __IO uint32_t PHYSEL                    : 1;
    uint32_t RESERVED7                      : 3;
    __IO uint32_t TRDT                      : 4;
    uint32_t RESERVED14                     :15;
    __IO uint32_t FHMOD                     : 1;
    __IO uint32_t FDMOD                     : 1;
    uint32_t RESERVED31                     : 1;
} stc_usbfs_gusbcfg_field_t;

typedef struct
{
    __IO uint32_t CSRST                     : 1;
    __IO uint32_t HSRST                     : 1;
    __IO uint32_t FCRST                     : 1;
    uint32_t RESERVED3                      : 1;
    __IO uint32_t RXFFLSH                   : 1;
    __IO uint32_t TXFFLSH                   : 1;
    __IO uint32_t TXFNUM                    : 5;
    uint32_t RESERVED11                     :19;
    __I  uint32_t DMAREQ                    : 1;
    __I  uint32_t AHBIDL                    : 1;
} stc_usbfs_grstctl_field_t;

typedef struct
{
    __I  uint32_t CMOD                      : 1;
    __IO uint32_t MMIS                      : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t SOF                       : 1;
    __I  uint32_t RXFNE                     : 1;
    __I  uint32_t NPTXFE                    : 1;
    __I  uint32_t GINAKEFF                  : 1;
    __I  uint32_t GONAKEFF                  : 1;
    uint32_t RESERVED8                      : 2;
    __IO uint32_t ESUSP                     : 1;
    __IO uint32_t USBSUSP                   : 1;
    __IO uint32_t USBRST                    : 1;
    __IO uint32_t ENUMDNE                   : 1;
    __IO uint32_t ISOODRP                   : 1;
    __IO uint32_t EOPF                      : 1;
    uint32_t RESERVED16                     : 2;
    __I  uint32_t IEPINT                    : 1;
    __I  uint32_t OEPINT                    : 1;
    __IO uint32_t IISOIXFR                  : 1;
    __IO uint32_t IPXFR_INCOMPISOOUT        : 1;
    __IO uint32_t DATAFSUSP                 : 1;
    uint32_t RESERVED23                     : 1;
    __I  uint32_t HPRTINT                   : 1;
    __I  uint32_t HCINT                     : 1;
    __I  uint32_t PTXFE                     : 1;
    uint32_t RESERVED27                     : 1;
    __IO uint32_t CIDSCHG                   : 1;
    __IO uint32_t DISCINT                   : 1;
    __IO uint32_t VBUSVINT                  : 1;
    __IO uint32_t WKUINT                    : 1;
} stc_usbfs_gintsts_field_t;

typedef struct
{
    uint32_t RESERVED0                      : 1;
    __IO uint32_t MMISM                     : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t SOFM                      : 1;
    __IO uint32_t RXFNEM                    : 1;
    __IO uint32_t NPTXFEM                   : 1;
    __IO uint32_t GINAKEFFM                 : 1;
    __IO uint32_t GONAKEFFM                 : 1;
    uint32_t RESERVED8                      : 2;
    __IO uint32_t ESUSPM                    : 1;
    __IO uint32_t USBSUSPM                  : 1;
    __IO uint32_t USBRSTM                   : 1;
    __IO uint32_t ENUMDNEM                  : 1;
    __IO uint32_t ISOODRPM                  : 1;
    __IO uint32_t EOPFM                     : 1;
    uint32_t RESERVED16                     : 2;
    __IO uint32_t IEPIM                     : 1;
    __IO uint32_t OEPIM                     : 1;
    __IO uint32_t IISOIXFRM                 : 1;
    __IO uint32_t IPXFRM_INCOMPISOOUTM      : 1;
    __IO uint32_t DATAFSUSPM                : 1;
    uint32_t RESERVED23                     : 1;
    __IO uint32_t HPRTIM                    : 1;
    __IO uint32_t HCIM                      : 1;
    __IO uint32_t PTXFEM                    : 1;
    uint32_t RESERVED27                     : 1;
    __IO uint32_t CIDSCHGM                  : 1;
    __IO uint32_t DISCIM                    : 1;
    __IO uint32_t VBUSVIM                   : 1;
    __IO uint32_t WKUIM                     : 1;
} stc_usbfs_gintmsk_field_t;

typedef struct
{
    __I  uint32_t CHNUM_EPNUM               : 4;
    __I  uint32_t BCNT                      :11;
    __I  uint32_t DPID                      : 2;
    __I  uint32_t PKTSTS                    : 4;
    uint32_t RESERVED21                     :11;
} stc_usbfs_grxstsr_field_t;

typedef struct
{
    __I  uint32_t CHNUM_EPNUM               : 4;
    __I  uint32_t BCNT                      :11;
    __I  uint32_t DPID                      : 2;
    __I  uint32_t PKTSTS                    : 4;
    uint32_t RESERVED21                     :11;
} stc_usbfs_grxstsp_field_t;

typedef struct
{
    __IO uint32_t RXFD                      :11;
    uint32_t RESERVED11                     :21;
} stc_usbfs_grxfsiz_field_t;

typedef struct
{
    __IO uint32_t NPTXFSA                   :16;
    __IO uint32_t NPTXFD                    :16;
} stc_usbfs_hnptxfsiz_field_t;

typedef struct
{
    __I  uint32_t NPTXFSAV                  :16;
    __I  uint32_t NPTQXSAV                  : 8;
    __I  uint32_t NPTXQTOP                  : 7;
    uint32_t RESERVED31                     : 1;
} stc_usbfs_hnptxsts_field_t;

typedef struct
{
    __IO uint32_t PTXSA                     :12;
    uint32_t RESERVED12                     : 4;
    __IO uint32_t PTXFD                     :11;
    uint32_t RESERVED27                     : 5;
} stc_usbfs_hptxfsiz_field_t;

typedef struct
{
    __IO uint32_t INEPTXSA                  :12;
    uint32_t RESERVED12                     : 4;
    __IO uint32_t INEPTXFD                  :10;
    uint32_t RESERVED26                     : 6;
} stc_usbfs_dieptxf_field_t;

typedef struct
{
    __IO uint32_t FSLSPCS                   : 2;
    __IO uint32_t FSLSS                     : 1;
    uint32_t RESERVED3                      :29;
} stc_usbfs_hcfg_field_t;

typedef struct
{
    __IO uint32_t FRIVL                     :16;
    uint32_t RESERVED16                     :16;
} stc_usbfs_hfir_field_t;

typedef struct
{
    __I  uint32_t FRNUM                     :16;
    __I  uint32_t FTREM                     :16;
} stc_usbfs_hfnum_field_t;

typedef struct
{
    __I  uint32_t PTXFSAVL                  :16;
    __I  uint32_t PTXQSAV                   : 8;
    __I  uint32_t PTXQTOP                   : 8;
} stc_usbfs_hptxsts_field_t;

typedef struct
{
    __I  uint32_t HAINT                     :12;
    uint32_t RESERVED12                     :20;
} stc_usbfs_haint_field_t;

typedef struct
{
    __IO uint32_t HAINTM                    :12;
    uint32_t RESERVED12                     :20;
} stc_usbfs_haintmsk_field_t;

typedef struct
{
    __I  uint32_t PCSTS                     : 1;
    __IO uint32_t PCDET                     : 1;
    __IO uint32_t PENA                      : 1;
    __IO uint32_t PENCHNG                   : 1;
    uint32_t RESERVED4                      : 2;
    __IO uint32_t PRES                      : 1;
    __IO uint32_t PSUSP                     : 1;
    __IO uint32_t PRST                      : 1;
    uint32_t RESERVED9                      : 1;
    __I  uint32_t PLSTS                     : 2;
    __IO uint32_t PWPR                      : 1;
    uint32_t RESERVED13                     : 4;
    __I  uint32_t PSPD                      : 2;
    uint32_t RESERVED19                     :13;
} stc_usbfs_hprt_field_t;

typedef struct
{
    __IO uint32_t MPSIZ                     :11;
    __IO uint32_t EPNUM                     : 4;
    __IO uint32_t EPDIR                     : 1;
    uint32_t RESERVED16                     : 1;
    __IO uint32_t LSDEV                     : 1;
    __I  uint32_t EPTYP                     : 2;
    uint32_t RESERVED20                     : 2;
    __IO uint32_t DAD                       : 7;
    __IO uint32_t ODDFRM                    : 1;
    __IO uint32_t CHDIS                     : 1;
    __IO uint32_t CHENA                     : 1;
} stc_usbfs_hcchar_field_t;

typedef struct
{
    __IO uint32_t XFRC                      : 1;
    __IO uint32_t CHH                       : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t STALL                     : 1;
    __IO uint32_t NAK                       : 1;
    __IO uint32_t ACK                       : 1;
    uint32_t RESERVED6                      : 1;
    __IO uint32_t TXERR                     : 1;
    __IO uint32_t BBERR                     : 1;
    __IO uint32_t FRMOR                     : 1;
    __IO uint32_t DTERR                     : 1;
    uint32_t RESERVED11                     :21;
} stc_usbfs_hcint_field_t;

typedef struct
{
    __IO uint32_t XFRCM                     : 1;
    __IO uint32_t CHHM                      : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t STALLM                    : 1;
    __IO uint32_t NAKM                      : 1;
    __IO uint32_t ACKM                      : 1;
    uint32_t RESERVED6                      : 1;
    __IO uint32_t TXERRM                    : 1;
    __IO uint32_t BBERRM                    : 1;
    __IO uint32_t FRMORM                    : 1;
    __IO uint32_t DTERRM                    : 1;
    uint32_t RESERVED11                     :21;
} stc_usbfs_hcintmsk_field_t;

typedef struct
{
    __IO uint32_t XFRSIZ                    :19;
    __IO uint32_t PKTCNT                    :10;
    __IO uint32_t DPID                      : 2;
    uint32_t RESERVED31                     : 1;
} stc_usbfs_hctsiz_field_t;

typedef struct
{
    __IO uint32_t DSPD                      : 2;
    __IO uint32_t NZLSOHSK                  : 1;
    uint32_t RESERVED3                      : 1;
    __IO uint32_t DAD                       : 7;
    __IO uint32_t PFIVL                     : 2;
    uint32_t RESERVED13                     :19;
} stc_usbfs_dcfg_field_t;

typedef struct
{
    __IO uint32_t RWUSIG                    : 1;
    __IO uint32_t SDIS                      : 1;
    __I  uint32_t GINSTS                    : 1;
    __I  uint32_t GONSTS                    : 1;
    uint32_t RESERVED4                      : 3;
    __O  uint32_t SGINAK                    : 1;
    __O  uint32_t CGINAK                    : 1;
    __O  uint32_t SGONAK                    : 1;
    __O  uint32_t CGONAK                    : 1;
    __IO uint32_t POPRGDNE                  : 1;
    uint32_t RESERVED12                     :20;
} stc_usbfs_dctl_field_t;

typedef struct
{
    __I  uint32_t SUSPSTS                   : 1;
    __I  uint32_t ENUMSPD                   : 2;
    __I  uint32_t EERR                      : 1;
    uint32_t RESERVED4                      : 4;
    __I  uint32_t FNSOF                     :14;
    uint32_t RESERVED22                     :10;
} stc_usbfs_dsts_field_t;

typedef struct
{
    __IO uint32_t XFRCM                     : 1;
    __IO uint32_t EPDM                      : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t TOM                       : 1;
    __IO uint32_t ITTXFEMSK                 : 1;
    __IO uint32_t INEPNMM                   : 1;
    __IO uint32_t INEPNEM                   : 1;
    uint32_t RESERVED7                      :25;
} stc_usbfs_diepmsk_field_t;

typedef struct
{
    __IO uint32_t XFRCM                     : 1;
    __IO uint32_t EPDM                      : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t STUPM                     : 1;
    __IO uint32_t OTEPDM                    : 1;
    uint32_t RESERVED5                      :27;
} stc_usbfs_doepmsk_field_t;

typedef struct
{
    __I  uint32_t IEPINT                    : 6;
    uint32_t RESERVED6                      :10;
    __I  uint32_t OEPINT                    : 6;
    uint32_t RESERVED22                     :10;
} stc_usbfs_daint_field_t;

typedef struct
{
    __I  uint32_t IEPINTM                   : 6;
    uint32_t RESERVED6                      :10;
    __I  uint32_t OEPINTM                   : 6;
    uint32_t RESERVED22                     :10;
} stc_usbfs_daintmsk_field_t;

typedef struct
{
    __IO uint32_t INEPTXFEM                 : 6;
    uint32_t RESERVED6                      :26;
} stc_usbfs_diepempmsk_field_t;

typedef struct
{
    __I  uint32_t MPSIZ                     : 2;
    uint32_t RESERVED2                      :13;
    __I  uint32_t USBAEP                    : 1;
    uint32_t RESERVED16                     : 1;
    __I  uint32_t NAKSTS                    : 1;
    __I  uint32_t EPTYP                     : 2;
    uint32_t RESERVED20                     : 1;
    __IO uint32_t STALL                     : 1;
    __IO uint32_t TXFNUM                    : 4;
    __O  uint32_t CNAK                      : 1;
    __O  uint32_t SNAK                      : 1;
    uint32_t RESERVED28                     : 2;
    __I  uint32_t EPDIS                     : 1;
    __IO uint32_t EPENA                     : 1;
} stc_usbfs_diepctl0_field_t;

typedef struct
{
    __IO uint32_t XFRC                      : 1;
    __IO uint32_t EPDISD                    : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t TOC                       : 1;
    __IO uint32_t TTXFE                     : 1;
    uint32_t RESERVED5                      : 1;
    __IO uint32_t INEPNE                    : 1;
    __I  uint32_t TXFE                      : 1;
    uint32_t RESERVED8                      :24;
} stc_usbfs_diepint0_field_t;

typedef struct
{
    __IO uint32_t XFRSIZ                    : 7;
    uint32_t RESERVED7                      :12;
    __IO uint32_t PKTCNT                    : 2;
    uint32_t RESERVED21                     :11;
} stc_usbfs_dieptsiz0_field_t;

typedef struct
{
    __I  uint32_t INEPTFSAV                 :16;
    uint32_t RESERVED16                     :16;
} stc_usbfs_dtxfsts0_field_t;

typedef struct
{
    __IO uint32_t MPSIZ                     :11;
    uint32_t RESERVED11                     : 4;
    __I  uint32_t USBAEP                    : 1;
    __I  uint32_t EONUM_DPID                : 1;
    __I  uint32_t NAKSTS                    : 1;
    __I  uint32_t EPTYP                     : 2;
    uint32_t RESERVED20                     : 1;
    __IO uint32_t STALL                     : 1;
    __IO uint32_t TXFNUM                    : 4;
    __O  uint32_t CNAK                      : 1;
    __O  uint32_t SNAK                      : 1;
    __O  uint32_t SD0PID_SEVNFRM            : 1;
    __O  uint32_t SODDFRM                   : 1;
    __I  uint32_t EPDIS                     : 1;
    __IO uint32_t EPENA                     : 1;
} stc_usbfs_diepctl_field_t;

typedef struct
{
    __IO uint32_t XFRC                      : 1;
    __IO uint32_t EPDISD                    : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t TOC                       : 1;
    __IO uint32_t TTXFE                     : 1;
    uint32_t RESERVED5                      : 1;
    __IO uint32_t INEPNE                    : 1;
    __I  uint32_t TXFE                      : 1;
    uint32_t RESERVED8                      :24;
} stc_usbfs_diepint_field_t;

typedef struct
{
    __IO uint32_t XFRSIZ                    :19;
    __IO uint32_t PKTCNT                    :10;
    uint32_t RESERVED29                     : 3;
} stc_usbfs_dieptsiz_field_t;

typedef struct
{
    __I  uint32_t INEPTFSAV                 :16;
    uint32_t RESERVED16                     :16;
} stc_usbfs_dtxfsts_field_t;

typedef struct
{
    __I  uint32_t MPSIZ                     : 2;
    uint32_t RESERVED2                      :13;
    __I  uint32_t USBAEP                    : 1;
    uint32_t RESERVED16                     : 1;
    __I  uint32_t NAKSTS                    : 1;
    __I  uint32_t EPTYP                     : 2;
    __IO uint32_t SNPM                      : 1;
    __IO uint32_t STALL                     : 1;
    uint32_t RESERVED22                     : 4;
    __O  uint32_t CNAK                      : 1;
    __O  uint32_t SNAK                      : 1;
    uint32_t RESERVED28                     : 2;
    __I  uint32_t EPDIS                     : 1;
    __IO uint32_t EPENA                     : 1;
} stc_usbfs_doepctl0_field_t;

typedef struct
{
    __IO uint32_t XFRC                      : 1;
    __IO uint32_t EPDISD                    : 1;
    uint32_t RESERVED2                      : 1;
    __IO uint32_t STUP                      : 1;
    __IO uint32_t OTEPDIS                   : 1;
    uint32_t RESERVED5                      : 1;
    __IO uint32_t B2BSTUP                   : 1;
    uint32_t RESERVED7                      :25;
} stc_usbfs_doepint_field_t;

typedef struct
{
    __IO uint32_t XFRSIZ                    : 7;
    uint32_t RESERVED7                      :12;
    __IO uint32_t PKTCNT                    : 1;
    uint32_t RESERVED20                     : 9;
    __IO uint32_t STUPCNT                   : 2;
    uint32_t RESERVED31                     : 1;
} stc_usbfs_doeptsiz0_field_t;

typedef struct
{
    __IO uint32_t MPSIZ                     :11;
    uint32_t RESERVED11                     : 4;
    __I  uint32_t USBAEP                    : 1;
    __I  uint32_t DPID                      : 1;
    __I  uint32_t NAKSTS                    : 1;
    __I  uint32_t EPTYP                     : 2;
    __IO uint32_t SNPM                      : 1;
    __IO uint32_t STALL                     : 1;
    uint32_t RESERVED22                     : 4;
    __O  uint32_t CNAK                      : 1;
    __O  uint32_t SNAK                      : 1;
    __IO uint32_t SD0PID                    : 1;
    __IO uint32_t SD1PID                    : 1;
    __I  uint32_t EPDIS                     : 1;
    __IO uint32_t EPENA                     : 1;
} stc_usbfs_doepctl_field_t;

typedef struct
{
    __IO uint32_t XFRSIZ                    :19;
    __IO uint32_t PKTCNT                    :10;
    uint32_t RESERVED29                     : 3;
} stc_usbfs_doeptsiz_field_t;

typedef struct
{
    __IO uint32_t STPPCLK                   : 1;
    __IO uint32_t GATEHCLK                  : 1;
    uint32_t RESERVED2                      :30;
} stc_usbfs_pcgcctl_field_t;

typedef struct
{
    __IO uint32_t PERI                      : 2;
    uint32_t RESERVED2                      : 2;
    __IO uint32_t CKS                       : 4;
    __IO uint32_t WDPT                      : 4;
    uint32_t RESERVED12                     : 4;
    __IO uint32_t SLPOFF                    : 1;
    uint32_t RESERVED17                     :14;
    __IO uint32_t ITS                       : 1;
} stc_wdt_cr_field_t;

typedef struct
{
    __I  uint32_t CNT                       :16;
    __IO uint32_t UDF                       : 1;
    __IO uint32_t REF                       : 1;
    uint32_t RESERVED18                     :14;
} stc_wdt_sr_field_t;

typedef struct
{
    __IO uint32_t RF                        :16;
    uint32_t RESERVED16                     :16;
} stc_wdt_rr_field_t;

typedef struct
{
    __IO uint16_t WKTMCMP                   :12;
    __IO uint16_t WKOVF                     : 1;
    __IO uint16_t WKCKS                     : 2;
    __IO uint16_t WKTCE                     : 1;
} stc_wktm_cr_field_t;


/**
 * @brief ADC
 */
typedef struct
{
    union
    {
        __IO uint8_t STR;
        stc_adc_str_field_t STR_f;
    };
    uint8_t RESERVED0[1];
    union
    {
        __IO uint16_t CR0;
        stc_adc_cr0_field_t CR0_f;
    };
    union
    {
        __IO uint16_t CR1;
        stc_adc_cr1_field_t CR1_f;
    };
    uint8_t RESERVED1[4];
    union
    {
        __IO uint16_t TRGSR;
        stc_adc_trgsr_field_t TRGSR_f;
    };
    __IO uint16_t CHSELRA0;
    union
    {
        __IO uint16_t CHSELRA1;
        stc_adc_chselra1_field_t CHSELRA1_f;
    };
    __IO uint16_t CHSELRB0;
    union
    {
        __IO uint16_t CHSELRB1;
        stc_adc_chselrb1_field_t CHSELRB1_f;
    };
    __IO uint16_t AVCHSELR0;
    union
    {
        __IO uint16_t AVCHSELR1;
        stc_adc_avchselr1_field_t AVCHSELR1_f;
    };
    uint8_t RESERVED2[8];
    __IO uint8_t SSTR0;
    __IO uint8_t SSTR1;
    __IO uint8_t SSTR2;
    __IO uint8_t SSTR3;
    __IO uint8_t SSTR4;
    __IO uint8_t SSTR5;
    __IO uint8_t SSTR6;
    __IO uint8_t SSTR7;
    __IO uint8_t SSTR8;
    __IO uint8_t SSTR9;
    __IO uint8_t SSTR10;
    __IO uint8_t SSTR11;
    __IO uint8_t SSTR12;
    __IO uint8_t SSTR13;
    __IO uint8_t SSTR14;
    __IO uint8_t SSTR15;
    __IO uint8_t SSTRL;
    uint8_t RESERVED3[7];
    union
    {
        __IO uint16_t CHMUXR0;
        stc_adc_chmuxr0_field_t CHMUXR0_f;
    };
    union
    {
        __IO uint16_t CHMUXR1;
        stc_adc_chmuxr1_field_t CHMUXR1_f;
    };
    union
    {
        __IO uint16_t CHMUXR2;
        stc_adc_chmuxr2_field_t CHMUXR2_f;
    };
    union
    {
        __IO uint16_t CHMUXR3;
        stc_adc_chmuxr3_field_t CHMUXR3_f;
    };
    uint8_t RESERVED4[6];
    union
    {
        __IO uint8_t ISR;
        stc_adc_isr_field_t ISR_f;
    };
    union
    {
        __IO uint8_t ICR;
        stc_adc_icr_field_t ICR_f;
    };
    uint8_t RESERVED5[4];
    union
    {
        __IO uint16_t SYNCCR;
        stc_adc_synccr_field_t SYNCCR_f;
    };
    uint8_t RESERVED6[2];
    __IO uint16_t DR0;
    __IO uint16_t DR1;
    __IO uint16_t DR2;
    __IO uint16_t DR3;
    __IO uint16_t DR4;
    __IO uint16_t DR5;
    __IO uint16_t DR6;
    __IO uint16_t DR7;
    __IO uint16_t DR8;
    __IO uint16_t DR9;
    __IO uint16_t DR10;
    __IO uint16_t DR11;
    __IO uint16_t DR12;
    __IO uint16_t DR13;
    __IO uint16_t DR14;
    __IO uint16_t DR15;
    __IO uint16_t DR16;
    uint8_t RESERVED7[46];
    union
    {
        __IO uint16_t AWDCR;
        stc_adc_awdcr_field_t AWDCR_f;
    };
    uint8_t RESERVED8[2];
    __IO uint16_t AWDDR0;
    __IO uint16_t AWDDR1;
    uint8_t RESERVED9[4];
    __IO uint16_t AWDCHSR0;
    union
    {
        __IO uint16_t AWDCHSR1;
        stc_adc_awdchsr1_field_t AWDCHSR1_f;
    };
    __IO uint16_t AWDSR0;
    union
    {
        __IO uint16_t AWDSR1;
        stc_adc_awdsr1_field_t AWDSR1_f;
    };
    uint8_t RESERVED10[12];
    union
    {
        __IO uint16_t PGACR;
        stc_adc_pgacr_field_t PGACR_f;
    };
    union
    {
        __IO uint16_t PGAGSR;
        stc_adc_pgagsr_field_t PGAGSR_f;
    };
    uint8_t RESERVED11[8];
    union
    {
        __IO uint16_t PGAINSR0;
        stc_adc_pgainsr0_field_t PGAINSR0_f;
    };
    union
    {
        __IO uint16_t PGAINSR1;
        stc_adc_pgainsr1_field_t PGAINSR1_f;
    };
} M4_ADC_TypeDef;

/**
 * @brief AES
 */
typedef struct
{
    union
    {
        __IO uint32_t CR;
        stc_aes_cr_field_t CR_f;
    };
    uint8_t RESERVED0[12];
    __IO uint32_t DR0;
    __IO uint32_t DR1;
    __IO uint32_t DR2;
    __IO uint32_t DR3;
    __IO uint32_t KR0;
    __IO uint32_t KR1;
    __IO uint32_t KR2;
    __IO uint32_t KR3;
} M4_AES_TypeDef;

/**
 * @brief AOS
 */
typedef struct
{
    union
    {
        __IO uint32_t INT_SFTTRG;
        stc_aos_int_sfttrg_field_t INT_SFTTRG_f;
    };
    union
    {
        __IO uint32_t DCU1_TRGSEL;
        stc_aos_dcu1_trgsel_field_t DCU1_TRGSEL_f;
    };
    union
    {
        __IO uint32_t DCU2_TRGSEL;
        stc_aos_dcu2_trgsel_field_t DCU2_TRGSEL_f;
    };
    union
    {
        __IO uint32_t DCU3_TRGSEL;
        stc_aos_dcu3_trgsel_field_t DCU3_TRGSEL_f;
    };
    union
    {
        __IO uint32_t DCU4_TRGSEL;
        stc_aos_dcu4_trgsel_field_t DCU4_TRGSEL_f;
    };
    union
    {
        __IO uint32_t DMA1_TRGSEL0;
        stc_aos_dma1_trgsel_field_t DMA1_TRGSEL0_f;
    };
    union
    {
        __IO uint32_t DMA1_TRGSEL1;
        stc_aos_dma1_trgsel_field_t DMA1_TRGSEL1_f;
    };
    union
    {
        __IO uint32_t DMA1_TRGSEL2;
        stc_aos_dma1_trgsel_field_t DMA1_TRGSEL2_f;
    };
    union
    {
        __IO uint32_t DMA1_TRGSEL3;
        stc_aos_dma1_trgsel3_field_t DMA1_TRGSEL3_f;
    };
    union
    {
        __IO uint32_t DMA2_TRGSEL0;
        stc_aos_dma2_trgsel_field_t DMA2_TRGSEL0_f;
    };
    union
    {
        __IO uint32_t DMA2_TRGSEL1;
        stc_aos_dma2_trgsel_field_t DMA2_TRGSEL1_f;
    };
    union
    {
        __IO uint32_t DMA2_TRGSEL2;
        stc_aos_dma2_trgsel_field_t DMA2_TRGSEL2_f;
    };
    union
    {
        __IO uint32_t DMA2_TRGSEL3;
        stc_aos_dma2_trgsel_field_t DMA2_TRGSEL3_f;
    };
    union
    {
        __IO uint32_t DMA_TRGSELRC;
        stc_aos_dma_trgselrc_field_t DMA_TRGSELRC_f;
    };
    union
    {
        __IO uint32_t TMR6_HTSSR0;
        stc_aos_tmr6_htssr_field_t TMR6_HTSSR0_f;
    };
    union
    {
        __IO uint32_t TMR6_HTSSR1;
        stc_aos_tmr6_htssr_field_t TMR6_HTSSR1_f;
    };
    union
    {
        __IO uint32_t TMR0_HTSSR;
        stc_aos_tmr0_htssr_field_t TMR0_HTSSR_f;
    };
    union
    {
        __IO uint32_t PEVNTTRGSR12;
        stc_aos_pevnttrgsr12_field_t PEVNTTRGSR12_f;
    };
    union
    {
        __IO uint32_t PEVNTTRGSR34;
        stc_aos_pevnttrgsr34_field_t PEVNTTRGSR34_f;
    };
    union
    {
        __IO uint32_t TMRA_HTSSR0;
        stc_aos_tmra_htssr_field_t TMRA_HTSSR0_f;
    };
    union
    {
        __IO uint32_t TMRA_HTSSR1;
        stc_aos_tmra_htssr_field_t TMRA_HTSSR1_f;
    };
    union
    {
        __IO uint32_t OTS_TRG;
        stc_aos_ots_trg_field_t OTS_TRG_f;
    };
    union
    {
        __IO uint32_t ADC1_ITRGSELR0;
        stc_aos_adc1_itrgselr_field_t ADC1_ITRGSELR0_f;
    };
    union
    {
        __IO uint32_t ADC1_ITRGSELR1;
        stc_aos_adc1_itrgselr_field_t ADC1_ITRGSELR1_f;
    };
    union
    {
        __IO uint32_t ADC2_ITRGSELR0;
        stc_aos_adc2_itrgselr_field_t ADC2_ITRGSELR0_f;
    };
    union
    {
        __IO uint32_t ADC2_ITRGSELR1;
        stc_aos_adc2_itrgselr_field_t ADC2_ITRGSELR1_f;
    };
    union
    {
        __IO uint32_t COMTRG1;
        stc_aos_comtrg1_field_t COMTRG1_f;
    };
    union
    {
        __IO uint32_t COMTRG2;
        stc_aos_comtrg2_field_t COMTRG2_f;
    };
    uint8_t RESERVED0[144];
    union
    {
        __IO uint32_t PEVNTDIRR1;
        stc_aos_pevntdirr_field_t PEVNTDIRR1_f;
    };
    union
    {
        __IO uint32_t PEVNTIDR1;
        stc_aos_pevntidr_field_t PEVNTIDR1_f;
    };
    union
    {
        __IO uint32_t PEVNTODR1;
        stc_aos_pevntodr_field_t PEVNTODR1_f;
    };
    union
    {
        __IO uint32_t PEVNTORR1;
        stc_aos_pevntorr_field_t PEVNTORR1_f;
    };
    union
    {
        __IO uint32_t PEVNTOSR1;
        stc_aos_pevntosr_field_t PEVNTOSR1_f;
    };
    union
    {
        __IO uint32_t PEVNTRISR1;
        stc_aos_pevntrisr_field_t PEVNTRISR1_f;
    };
    union
    {
        __IO uint32_t PEVNTFAL1;
        stc_aos_pevntfal_field_t PEVNTFAL1_f;
    };
    union
    {
        __IO uint32_t PEVNTDIRR2;
        stc_aos_pevntdirr_field_t PEVNTDIRR2_f;
    };
    union
    {
        __IO uint32_t PEVNTIDR2;
        stc_aos_pevntidr_field_t PEVNTIDR2_f;
    };
    union
    {
        __IO uint32_t PEVNTODR2;
        stc_aos_pevntodr_field_t PEVNTODR2_f;
    };
    union
    {
        __IO uint32_t PEVNTORR2;
        stc_aos_pevntorr_field_t PEVNTORR2_f;
    };
    union
    {
        __IO uint32_t PEVNTOSR2;
        stc_aos_pevntosr_field_t PEVNTOSR2_f;
    };
    union
    {
        __IO uint32_t PEVNTRISR2;
        stc_aos_pevntrisr_field_t PEVNTRISR2_f;
    };
    union
    {
        __IO uint32_t PEVNTFAL2;
        stc_aos_pevntfal_field_t PEVNTFAL2_f;
    };
    union
    {
        __IO uint32_t PEVNTDIRR3;
        stc_aos_pevntdirr_field_t PEVNTDIRR3_f;
    };
    union
    {
        __IO uint32_t PEVNTIDR3;
        stc_aos_pevntidr_field_t PEVNTIDR3_f;
    };
    union
    {
        __IO uint32_t PEVNTODR3;
        stc_aos_pevntodr_field_t PEVNTODR3_f;
    };
    union
    {
        __IO uint32_t PEVNTORR3;
        stc_aos_pevntorr_field_t PEVNTORR3_f;
    };
    union
    {
        __IO uint32_t PEVNTOSR3;
        stc_aos_pevntosr_field_t PEVNTOSR3_f;
    };
    union
    {
        __IO uint32_t PEVNTRISR3;
        stc_aos_pevntrisr_field_t PEVNTRISR3_f;
    };
    union
    {
        __IO uint32_t PEVNTFAL3;
        stc_aos_pevntfal_field_t PEVNTFAL3_f;
    };
    union
    {
        __IO uint32_t PEVNTDIRR4;
        stc_aos_pevntdirr_field_t PEVNTDIRR4_f;
    };
    union
    {
        __IO uint32_t PEVNTIDR4;
        stc_aos_pevntidr_field_t PEVNTIDR4_f;
    };
    union
    {
        __IO uint32_t PEVNTODR4;
        stc_aos_pevntodr_field_t PEVNTODR4_f;
    };
    union
    {
        __IO uint32_t PEVNTORR4;
        stc_aos_pevntorr_field_t PEVNTORR4_f;
    };
    union
    {
        __IO uint32_t PEVNTOSR4;
        stc_aos_pevntosr_field_t PEVNTOSR4_f;
    };
    union
    {
        __IO uint32_t PEVNTRISR4;
        stc_aos_pevntrisr_field_t PEVNTRISR4_f;
    };
    union
    {
        __IO uint32_t PEVNTFAL4;
        stc_aos_pevntfal_field_t PEVNTFAL4_f;
    };
    union
    {
        __IO uint32_t PEVNTNFCR;
        stc_aos_pevntnfcr_field_t PEVNTNFCR_f;
    };
} M4_AOS_TypeDef;

/**
 * @brief CAN
 */
typedef struct
{
    __IO uint32_t RBUF;
    uint8_t RESERVED0[76];
    __IO uint32_t TBUF;
    uint8_t RESERVED1[76];
    union
    {
        __IO uint8_t CFG_STAT;
        stc_can_cfg_stat_field_t CFG_STAT_f;
    };
    union
    {
        __IO uint8_t TCMD;
        stc_can_tcmd_field_t TCMD_f;
    };
    union
    {
        __IO uint8_t TCTRL;
        stc_can_tctrl_field_t TCTRL_f;
    };
    union
    {
        __IO uint8_t RCTRL;
        stc_can_rctrl_field_t RCTRL_f;
    };
    union
    {
        __IO uint8_t RTIE;
        stc_can_rtie_field_t RTIE_f;
    };
    union
    {
        __IO uint8_t RTIF;
        stc_can_rtif_field_t RTIF_f;
    };
    union
    {
        __IO uint8_t ERRINT;
        stc_can_errint_field_t ERRINT_f;
    };
    union
    {
        __IO uint8_t LIMIT;
        stc_can_limit_field_t LIMIT_f;
    };
    union
    {
        __IO uint32_t BT;
        stc_can_bt_field_t BT_f;
    };
    uint8_t RESERVED2[4];
    union
    {
        __IO uint8_t EALCAP;
        stc_can_ealcap_field_t EALCAP_f;
    };
    uint8_t RESERVED3[1];
    __IO uint8_t RECNT;
    __IO uint8_t TECNT;
    union
    {
        __IO uint8_t ACFCTRL;
        stc_can_acfctrl_field_t ACFCTRL_f;
    };
    uint8_t RESERVED4[1];
    union
    {
        __IO uint8_t ACFEN;
        stc_can_acfen_field_t ACFEN_f;
    };
    uint8_t RESERVED5[1];
    union
    {
        __IO uint32_t ACF;
        stc_can_acf_field_t ACF_f;
    };
    uint8_t RESERVED6[2];
    union
    {
        __IO uint8_t TBSLOT;
        stc_can_tbslot_field_t TBSLOT_f;
    };
    union
    {
        __IO uint8_t TTCFG;
        stc_can_ttcfg_field_t TTCFG_f;
    };
    union
    {
        __IO uint32_t REF_MSG;
        stc_can_ref_msg_field_t REF_MSG_f;
    };
    union
    {
        __IO uint16_t TRG_CFG;
        stc_can_trg_cfg_field_t TRG_CFG_f;
    };
    __IO uint16_t TT_TRIG;
    __IO uint16_t TT_WTRIG;
} M4_CAN_TypeDef;

/**
 * @brief CMP
 */
typedef struct
{
    union
    {
        __IO uint16_t CTRL;
        stc_cmp_ctrl_field_t CTRL_f;
    };
    union
    {
        __IO uint16_t VLTSEL;
        stc_cmp_vltsel_field_t VLTSEL_f;
    };
    union
    {
        __IO uint16_t OUTMON;
        stc_cmp_outmon_field_t OUTMON_f;
    };
    union
    {
        __IO uint16_t CVSSTB;
        stc_cmp_cvsstb_field_t CVSSTB_f;
    };
    union
    {
        __IO uint16_t CVSPRD;
        stc_cmp_cvsprd_field_t CVSPRD_f;
    };
} M4_CMP_TypeDef;

/**
 * @brief CMP_CR
 */
typedef struct
{
    uint8_t RESERVED0[256];
    union
    {
        __IO uint16_t DADR1;
        stc_cmp_cr_dadr1_field_t DADR1_f;
    };
    union
    {
        __IO uint16_t DADR2;
        stc_cmp_cr_dadr2_field_t DADR2_f;
    };
    uint8_t RESERVED1[4];
    union
    {
        __IO uint16_t DACR;
        stc_cmp_cr_dacr_field_t DACR_f;
    };
    uint8_t RESERVED2[2];
    union
    {
        __IO uint16_t RVADC;
        stc_cmp_cr_rvadc_field_t RVADC_f;
    };
} M4_CMP_CR_TypeDef;

/**
 * @brief CRC
 */
typedef struct
{
    union
    {
        __IO uint32_t CR;
        stc_crc_cr_field_t CR_f;
    };
    union
    {
        __IO uint32_t RESLT;
        stc_crc_reslt_field_t RESLT_f;
    };
    uint8_t RESERVED0[4];
    union
    {
        __IO uint32_t FLG;
        stc_crc_flg_field_t FLG_f;
    };
    uint8_t RESERVED1[112];
    __IO uint32_t DAT0;
    __IO uint32_t DAT1;
    __IO uint32_t DAT2;
    __IO uint32_t DAT3;
    __IO uint32_t DAT4;
    __IO uint32_t DAT5;
    __IO uint32_t DAT6;
    __IO uint32_t DAT7;
    __IO uint32_t DAT8;
    __IO uint32_t DAT9;
    __IO uint32_t DAT10;
    __IO uint32_t DAT11;
    __IO uint32_t DAT12;
    __IO uint32_t DAT13;
    __IO uint32_t DAT14;
    __IO uint32_t DAT15;
    __IO uint32_t DAT16;
    __IO uint32_t DAT17;
    __IO uint32_t DAT18;
    __IO uint32_t DAT19;
    __IO uint32_t DAT20;
    __IO uint32_t DAT21;
    __IO uint32_t DAT22;
    __IO uint32_t DAT23;
    __IO uint32_t DAT24;
    __IO uint32_t DAT25;
    __IO uint32_t DAT26;
    __IO uint32_t DAT27;
    __IO uint32_t DAT28;
    __IO uint32_t DAT29;
    __IO uint32_t DAT30;
    __IO uint32_t DAT31;
} M4_CRC_TypeDef;

/**
 * @brief DBGC
 */
typedef struct
{
    __IO uint32_t AUTHID0;
    __IO uint32_t AUTHID1;
    __IO uint32_t AUTHID2;
    __IO uint32_t RESV0;
    union
    {
        __IO uint32_t MCUSTAT;
        stc_dbgc_mcustat_field_t MCUSTAT_f;
    };
    union
    {
        __IO uint32_t MCUCTL;
        stc_dbgc_mcuctl_field_t MCUCTL_f;
    };
    union
    {
        __IO uint32_t FMCCTL;
        stc_dbgc_fmcctl_field_t FMCCTL_f;
    };
    union
    {
        __IO uint32_t MCUDBGSTAT;
        stc_dbgc_mcudbgstat_field_t MCUDBGSTAT_f;
    };
    union
    {
        __IO uint32_t MCUSTPCTL;
        stc_dbgc_mcustpctl_field_t MCUSTPCTL_f;
    };
    union
    {
        __IO uint32_t MCUTRACECTL;
        stc_dbgc_mcutracectl_field_t MCUTRACECTL_f;
    };
} M4_DBGC_TypeDef;

/**
 * @brief DCU
 */
typedef struct
{
    union
    {
        __IO uint32_t CTL;
        stc_dcu_ctl_field_t CTL_f;
    };
    union
    {
        __IO uint32_t FLAG;
        stc_dcu_flag_field_t FLAG_f;
    };
    __IO uint32_t DATA0;
    __IO uint32_t DATA1;
    __IO uint32_t DATA2;
    union
    {
        __IO uint32_t FLAGCLR;
        stc_dcu_flagclr_field_t FLAGCLR_f;
    };
    union
    {
        __IO uint32_t INTSEL;
        stc_dcu_intsel_field_t INTSEL_f;
    };
} M4_DCU_TypeDef;

/**
 * @brief DMA
 */
typedef struct
{
    union
    {
        __IO uint32_t EN;
        stc_dma_en_field_t EN_f;
    };
    union
    {
        __IO uint32_t INTSTAT0;
        stc_dma_intstat0_field_t INTSTAT0_f;
    };
    union
    {
        __IO uint32_t INTSTAT1;
        stc_dma_intstat1_field_t INTSTAT1_f;
    };
    union
    {
        __IO uint32_t INTMASK0;
        stc_dma_intmask0_field_t INTMASK0_f;
    };
    union
    {
        __IO uint32_t INTMASK1;
        stc_dma_intmask1_field_t INTMASK1_f;
    };
    union
    {
        __IO uint32_t INTCLR0;
        stc_dma_intclr0_field_t INTCLR0_f;
    };
    union
    {
        __IO uint32_t INTCLR1;
        stc_dma_intclr1_field_t INTCLR1_f;
    };
    union
    {
        __IO uint32_t CHEN;
        stc_dma_chen_field_t CHEN_f;
    };
    union
    {
        __IO uint32_t REQSTAT;
        stc_dma_reqstat_field_t REQSTAT_f;
    };
    union
    {
        __IO uint32_t CHSTAT;
        stc_dma_chstat_field_t CHSTAT_f;
    };
    uint8_t RESERVED0[4];
    union
    {
        __IO uint32_t RCFGCTL;
        stc_dma_rcfgctl_field_t RCFGCTL_f;
    };
    uint8_t RESERVED1[16];
    __IO uint32_t SAR0;
    __IO uint32_t DAR0;
    union
    {
        __IO uint32_t DTCTL0;
        stc_dma_dtctl_field_t DTCTL0_f;
    };
    union
    {
        __IO uint32_t RPT0;
        stc_dma_rpt_field_t RPT0_f;
        __IO uint32_t RPTB0;
        stc_dma_rptb_field_t RPTB0_f;
    };
    union
    {
        __IO uint32_t SNSEQCTL0;
        stc_dma_snseqctl_field_t SNSEQCTL0_f;
        __IO uint32_t SNSEQCTLB0;
        stc_dma_snseqctlb_field_t SNSEQCTLB0_f;
    };
    union
    {
        __IO uint32_t DNSEQCTL0;
        stc_dma_dnseqctl_field_t DNSEQCTL0_f;
        __IO uint32_t DNSEQCTLB0;
        stc_dma_dnseqctlb_field_t DNSEQCTLB0_f;
    };
    union
    {
        __IO uint32_t LLP0;
        stc_dma_llp_field_t LLP0_f;
    };
    union
    {
        __IO uint32_t CHCTL0;
        stc_dma_chctl_field_t CHCTL0_f;
    };
    __IO uint32_t MONSAR0;
    __IO uint32_t MONDAR0;
    union
    {
        __IO uint32_t MONDTCTL0;
        stc_dma_mondtctl_field_t MONDTCTL0_f;
    };
    union
    {
        __IO uint32_t MONRPT0;
        stc_dma_monrpt_field_t MONRPT0_f;
    };
    union
    {
        __IO uint32_t MONSNSEQCTL0;
        stc_dma_monsnseqctl_field_t MONSNSEQCTL0_f;
    };
    union
    {
        __IO uint32_t MONDNSEQCTL0;
        stc_dma_mondnseqctl_field_t MONDNSEQCTL0_f;
    };
    uint8_t RESERVED2[8];
    __IO uint32_t SAR1;
    __IO uint32_t DAR1;
    union
    {
        __IO uint32_t DTCTL1;
        stc_dma_dtctl_field_t DTCTL1_f;
    };
    union
    {
        __IO uint32_t RPT1;
        stc_dma_rpt_field_t RPT1_f;
        __IO uint32_t RPTB1;
        stc_dma_rptb_field_t RPTB1_f;
    };
    union
    {
        __IO uint32_t SNSEQCTL1;
        stc_dma_snseqctl_field_t SNSEQCTL1_f;
        __IO uint32_t SNSEQCTLB1;
        stc_dma_snseqctlb_field_t SNSEQCTLB1_f;
    };
    union
    {
        __IO uint32_t DNSEQCTL1;
        stc_dma_dnseqctl_field_t DNSEQCTL1_f;
        __IO uint32_t DNSEQCTLB1;
        stc_dma_dnseqctlb_field_t DNSEQCTLB1_f;
    };
    union
    {
        __IO uint32_t LLP1;
        stc_dma_llp_field_t LLP1_f;
    };
    union
    {
        __IO uint32_t CHCTL1;
        stc_dma_chctl_field_t CHCTL1_f;
    };
    __IO uint32_t MONSAR1;
    __IO uint32_t MONDAR1;
    union
    {
        __IO uint32_t MONDTCTL1;
        stc_dma_mondtctl_field_t MONDTCTL1_f;
    };
    union
    {
        __IO uint32_t MONRPT1;
        stc_dma_monrpt_field_t MONRPT1_f;
    };
    union
    {
        __IO uint32_t MONSNSEQCTL1;
        stc_dma_monsnseqctl_field_t MONSNSEQCTL1_f;
    };
    union
    {
        __IO uint32_t MONDNSEQCTL1;
        stc_dma_mondnseqctl_field_t MONDNSEQCTL1_f;
    };
    uint8_t RESERVED3[8];
    __IO uint32_t SAR2;
    __IO uint32_t DAR2;
    union
    {
        __IO uint32_t DTCTL2;
        stc_dma_dtctl_field_t DTCTL2_f;
    };
    union
    {
        __IO uint32_t RPT2;
        stc_dma_rpt_field_t RPT2_f;
        __IO uint32_t RPTB2;
        stc_dma_rptb_field_t RPTB2_f;
    };
    union
    {
        __IO uint32_t SNSEQCTL2;
        stc_dma_snseqctl_field_t SNSEQCTL2_f;
        __IO uint32_t SNSEQCTLB2;
        stc_dma_snseqctlb_field_t SNSEQCTLB2_f;
    };
    union
    {
        __IO uint32_t DNSEQCTL2;
        stc_dma_dnseqctl_field_t DNSEQCTL2_f;
        __IO uint32_t DNSEQCTLB2;
        stc_dma_dnseqctlb_field_t DNSEQCTLB2_f;
    };
    union
    {
        __IO uint32_t LLP2;
        stc_dma_llp_field_t LLP2_f;
    };
    union
    {
        __IO uint32_t CHCTL2;
        stc_dma_chctl_field_t CHCTL2_f;
    };
    __IO uint32_t MONSAR2;
    __IO uint32_t MONDAR2;
    union
    {
        __IO uint32_t MONDTCTL2;
        stc_dma_mondtctl_field_t MONDTCTL2_f;
    };
    union
    {
        __IO uint32_t MONRPT2;
        stc_dma_monrpt_field_t MONRPT2_f;
    };
    union
    {
        __IO uint32_t MONSNSEQCTL2;
        stc_dma_monsnseqctl_field_t MONSNSEQCTL2_f;
    };
    union
    {
        __IO uint32_t MONDNSEQCTL2;
        stc_dma_mondnseqctl_field_t MONDNSEQCTL2_f;
    };
    uint8_t RESERVED4[8];
    __IO uint32_t SAR3;
    __IO uint32_t DAR3;
    union
    {
        __IO uint32_t DTCTL3;
        stc_dma_dtctl_field_t DTCTL3_f;
    };
    union
    {
        __IO uint32_t RPT3;
        stc_dma_rpt_field_t RPT3_f;
        __IO uint32_t RPTB3;
        stc_dma_rptb_field_t RPTB3_f;
    };
    union
    {
        __IO uint32_t SNSEQCTL3;
        stc_dma_snseqctl_field_t SNSEQCTL3_f;
        __IO uint32_t SNSEQCTLB3;
        stc_dma_snseqctlb_field_t SNSEQCTLB3_f;
    };
    union
    {
        __IO uint32_t DNSEQCTL3;
        stc_dma_dnseqctl_field_t DNSEQCTL3_f;
        __IO uint32_t DNSEQCTLB3;
        stc_dma_dnseqctlb_field_t DNSEQCTLB3_f;
    };
    union
    {
        __IO uint32_t LLP3;
        stc_dma_llp_field_t LLP3_f;
    };
    union
    {
        __IO uint32_t CHCTL3;
        stc_dma_chctl_field_t CHCTL3_f;
    };
    __IO uint32_t MONSAR3;
    __IO uint32_t MONDAR3;
    union
    {
        __IO uint32_t MONDTCTL3;
        stc_dma_mondtctl_field_t MONDTCTL3_f;
    };
    union
    {
        __IO uint32_t MONRPT3;
        stc_dma_monrpt_field_t MONRPT3_f;
    };
    union
    {
        __IO uint32_t MONSNSEQCTL3;
        stc_dma_monsnseqctl_field_t MONSNSEQCTL3_f;
    };
    union
    {
        __IO uint32_t MONDNSEQCTL3;
        stc_dma_mondnseqctl_field_t MONDNSEQCTL3_f;
    };
} M4_DMA_TypeDef;

/**
 * @brief EFM
 */
typedef struct
{
    union
    {
        __IO uint32_t FAPRT;
        stc_efm_faprt_field_t FAPRT_f;
    };
    union
    {
        __IO uint32_t FSTP;
        stc_efm_fstp_field_t FSTP_f;
    };
    union
    {
        __IO uint32_t FRMC;
        stc_efm_frmc_field_t FRMC_f;
    };
    union
    {
        __IO uint32_t FWMC;
        stc_efm_fwmc_field_t FWMC_f;
    };
    union
    {
        __IO uint32_t FSR;
        stc_efm_fsr_field_t FSR_f;
    };
    union
    {
        __IO uint32_t FSCLR;
        stc_efm_fsclr_field_t FSCLR_f;
    };
    union
    {
        __IO uint32_t FITE;
        stc_efm_fite_field_t FITE_f;
    };
    union
    {
        __IO uint32_t FSWP;
        stc_efm_fswp_field_t FSWP_f;
    };
    union
    {
        __IO uint32_t FPMTSW;
        stc_efm_fpmtsw_field_t FPMTSW_f;
    };
    union
    {
        __IO uint32_t FPMTEW;
        stc_efm_fpmtew_field_t FPMTEW_f;
    };
    uint8_t RESERVED0[40];
    __IO uint32_t UQID1;
    __IO uint32_t UQID2;
    __IO uint32_t UQID3;
    uint8_t RESERVED1[164];
    union
    {
        __IO uint32_t MMF_REMPRT;
        stc_efm_mmf_remprt_field_t MMF_REMPRT_f;
    };
    union
    {
        __IO uint32_t MMF_REMCR0;
        stc_efm_mmf_remcr0_field_t MMF_REMCR0_f;
    };
    union
    {
        __IO uint32_t MMF_REMCR1;
        stc_efm_mmf_remcr1_field_t MMF_REMCR1_f;
    };
    uint8_t RESERVED2[248];
    union
    {
        __IO uint32_t FRANDS;
        stc_efm_frands_field_t FRANDS_f;
    };
} M4_EFM_TypeDef;

/**
 * @brief EMB
 */
typedef struct
{
    union
    {
        __IO uint32_t CTL;
        stc_emb_ctl_field_t CTL_f;
    };
    union
    {
        __IO uint32_t PWMLV;
        stc_emb_pwmlv_field_t PWMLV_f;
    };
    union
    {
        __IO uint32_t SOE;
        stc_emb_soe_field_t SOE_f;
    };
    union
    {
        __IO uint32_t STAT;
        stc_emb_stat_field_t STAT_f;
    };
    union
    {
        __IO uint32_t STATCLR;
        stc_emb_statclr_field_t STATCLR_f;
    };
    union
    {
        __IO uint32_t INTEN;
        stc_emb_inten_field_t INTEN_f;
    };
} M4_EMB_TypeDef;

/**
 * @brief FCM
 */
typedef struct
{
    union
    {
        __IO uint32_t LVR;
        stc_fcm_lvr_field_t LVR_f;
    };
    union
    {
        __IO uint32_t UVR;
        stc_fcm_uvr_field_t UVR_f;
    };
    union
    {
        __IO uint32_t CNTR;
        stc_fcm_cntr_field_t CNTR_f;
    };
    union
    {
        __IO uint32_t STR;
        stc_fcm_str_field_t STR_f;
    };
    union
    {
        __IO uint32_t MCCR;
        stc_fcm_mccr_field_t MCCR_f;
    };
    union
    {
        __IO uint32_t RCCR;
        stc_fcm_rccr_field_t RCCR_f;
    };
    union
    {
        __IO uint32_t RIER;
        stc_fcm_rier_field_t RIER_f;
    };
    union
    {
        __IO uint32_t SR;
        stc_fcm_sr_field_t SR_f;
    };
    union
    {
        __IO uint32_t CLR;
        stc_fcm_clr_field_t CLR_f;
    };
} M4_FCM_TypeDef;

/**
 * @brief HASH
 */
typedef struct
{
    union
    {
        __IO uint32_t CR;
        stc_hash_cr_field_t CR_f;
    };
    uint8_t RESERVED0[12];
    __IO uint32_t HR7;
    __IO uint32_t HR6;
    __IO uint32_t HR5;
    __IO uint32_t HR4;
    __IO uint32_t HR3;
    __IO uint32_t HR2;
    __IO uint32_t HR1;
    __IO uint32_t HR0;
    uint8_t RESERVED1[16];
    __IO uint32_t DR15;
    __IO uint32_t DR14;
    __IO uint32_t DR13;
    __IO uint32_t DR12;
    __IO uint32_t DR11;
    __IO uint32_t DR10;
    __IO uint32_t DR9;
    __IO uint32_t DR8;
    __IO uint32_t DR7;
    __IO uint32_t DR6;
    __IO uint32_t DR5;
    __IO uint32_t DR4;
    __IO uint32_t DR3;
    __IO uint32_t DR2;
    __IO uint32_t DR1;
    __IO uint32_t DR0;
} M4_HASH_TypeDef;

/**
 * @brief I2C
 */
typedef struct
{
    union
    {
        __IO uint32_t CR1;
        stc_i2c_cr1_field_t CR1_f;
    };
    union
    {
        __IO uint32_t CR2;
        stc_i2c_cr2_field_t CR2_f;
    };
    union
    {
        __IO uint32_t CR3;
        stc_i2c_cr3_field_t CR3_f;
    };
    union
    {
        __IO uint32_t CR4;
        stc_i2c_cr4_field_t CR4_f;
    };
    union
    {
        __IO uint32_t SLR0;
        stc_i2c_slr0_field_t SLR0_f;
    };
    union
    {
        __IO uint32_t SLR1;
        stc_i2c_slr1_field_t SLR1_f;
    };
    union
    {
        __IO uint32_t SLTR;
        stc_i2c_sltr_field_t SLTR_f;
    };
    union
    {
        __IO uint32_t SR;
        stc_i2c_sr_field_t SR_f;
    };
    union
    {
        __IO uint32_t CLR;
        stc_i2c_clr_field_t CLR_f;
    };
    union
    {
        __IO uint8_t DTR;
        stc_i2c_dtr_field_t DTR_f;
    };
    uint8_t RESERVED0[3];
    union
    {
        __IO uint8_t DRR;
        stc_i2c_drr_field_t DRR_f;
    };
    uint8_t RESERVED1[3];
    union
    {
        __IO uint32_t CCR;
        stc_i2c_ccr_field_t CCR_f;
    };
    union
    {
        __IO uint32_t FLTR;
        stc_i2c_fltr_field_t FLTR_f;
    };
} M4_I2C_TypeDef;

/**
 * @brief I2S
 */
typedef struct
{
    union
    {
        __IO uint32_t CTRL;
        stc_i2s_ctrl_field_t CTRL_f;
    };
    union
    {
        __IO uint32_t SR;
        stc_i2s_sr_field_t SR_f;
    };
    union
    {
        __IO uint32_t ER;
        stc_i2s_er_field_t ER_f;
    };
    union
    {
        __IO uint32_t CFGR;
        stc_i2s_cfgr_field_t CFGR_f;
    };
    __IO uint32_t TXBUF;
    __IO uint32_t RXBUF;
    union
    {
        __IO uint32_t PR;
        stc_i2s_pr_field_t PR_f;
    };
} M4_I2S_TypeDef;

/**
 * @brief ICG
 */
typedef struct
{
    union
    {
        __IO uint32_t ICG0;
        stc_icg_icg0_field_t ICG0_f;
    };
    union
    {
        __IO uint32_t ICG1;
        stc_icg_icg1_field_t ICG1_f;
    };
    __IO uint32_t ICG2;
    __IO uint32_t ICG3;
    __IO uint32_t ICG4;
    __IO uint32_t ICG5;
    __IO uint32_t ICG6;
    __IO uint32_t ICG7;
} M4_ICG_TypeDef;

/**
 * @brief INTC
 */
typedef struct
{
    union
    {
        __IO uint32_t NMICR;
        stc_intc_nmicr_field_t NMICR_f;
    };
    union
    {
        __IO uint32_t NMIENR;
        stc_intc_nmienr_field_t NMIENR_f;
    };
    union
    {
        __IO uint32_t NMIFR;
        stc_intc_nmifr_field_t NMIFR_f;
    };
    union
    {
        __IO uint32_t NMICFR;
        stc_intc_nmicfr_field_t NMICFR_f;
    };
    union
    {
        __IO uint32_t EIRQCR0;
        stc_intc_eirqcr_field_t EIRQCR0_f;
    };
    union
    {
        __IO uint32_t EIRQCR1;
        stc_intc_eirqcr_field_t EIRQCR1_f;
    };
    union
    {
        __IO uint32_t EIRQCR2;
        stc_intc_eirqcr_field_t EIRQCR2_f;
    };
    union
    {
        __IO uint32_t EIRQCR3;
        stc_intc_eirqcr_field_t EIRQCR3_f;
    };
    union
    {
        __IO uint32_t EIRQCR4;
        stc_intc_eirqcr_field_t EIRQCR4_f;
    };
    union
    {
        __IO uint32_t EIRQCR5;
        stc_intc_eirqcr_field_t EIRQCR5_f;
    };
    union
    {
        __IO uint32_t EIRQCR6;
        stc_intc_eirqcr_field_t EIRQCR6_f;
    };
    union
    {
        __IO uint32_t EIRQCR7;
        stc_intc_eirqcr_field_t EIRQCR7_f;
    };
    union
    {
        __IO uint32_t EIRQCR8;
        stc_intc_eirqcr_field_t EIRQCR8_f;
    };
    union
    {
        __IO uint32_t EIRQCR9;
        stc_intc_eirqcr_field_t EIRQCR9_f;
    };
    union
    {
        __IO uint32_t EIRQCR10;
        stc_intc_eirqcr_field_t EIRQCR10_f;
    };
    union
    {
        __IO uint32_t EIRQCR11;
        stc_intc_eirqcr_field_t EIRQCR11_f;
    };
    union
    {
        __IO uint32_t EIRQCR12;
        stc_intc_eirqcr_field_t EIRQCR12_f;
    };
    union
    {
        __IO uint32_t EIRQCR13;
        stc_intc_eirqcr_field_t EIRQCR13_f;
    };
    union
    {
        __IO uint32_t EIRQCR14;
        stc_intc_eirqcr_field_t EIRQCR14_f;
    };
    union
    {
        __IO uint32_t EIRQCR15;
        stc_intc_eirqcr_field_t EIRQCR15_f;
    };
    union
    {
        __IO uint32_t WUPEN;
        stc_intc_wupen_field_t WUPEN_f;
    };
    union
    {
        __IO uint32_t EIFR;
        stc_intc_eifr_field_t EIFR_f;
    };
    union
    {
        __IO uint32_t EICFR;
        stc_intc_eicfr_field_t EICFR_f;
    };
    union
    {
        __IO uint32_t SEL0;
        stc_intc_sel_field_t SEL0_f;
    };
    union
    {
        __IO uint32_t SEL1;
        stc_intc_sel_field_t SEL1_f;
    };
    union
    {
        __IO uint32_t SEL2;
        stc_intc_sel_field_t SEL2_f;
    };
    union
    {
        __IO uint32_t SEL3;
        stc_intc_sel_field_t SEL3_f;
    };
    union
    {
        __IO uint32_t SEL4;
        stc_intc_sel_field_t SEL4_f;
    };
    union
    {
        __IO uint32_t SEL5;
        stc_intc_sel_field_t SEL5_f;
    };
    union
    {
        __IO uint32_t SEL6;
        stc_intc_sel_field_t SEL6_f;
    };
    union
    {
        __IO uint32_t SEL7;
        stc_intc_sel_field_t SEL7_f;
    };
    union
    {
        __IO uint32_t SEL8;
        stc_intc_sel_field_t SEL8_f;
    };
    union
    {
        __IO uint32_t SEL9;
        stc_intc_sel_field_t SEL9_f;
    };
    union
    {
        __IO uint32_t SEL10;
        stc_intc_sel_field_t SEL10_f;
    };
    union
    {
        __IO uint32_t SEL11;
        stc_intc_sel_field_t SEL11_f;
    };
    union
    {
        __IO uint32_t SEL12;
        stc_intc_sel_field_t SEL12_f;
    };
    union
    {
        __IO uint32_t SEL13;
        stc_intc_sel_field_t SEL13_f;
    };
    union
    {
        __IO uint32_t SEL14;
        stc_intc_sel_field_t SEL14_f;
    };
    union
    {
        __IO uint32_t SEL15;
        stc_intc_sel_field_t SEL15_f;
    };
    union
    {
        __IO uint32_t SEL16;
        stc_intc_sel_field_t SEL16_f;
    };
    union
    {
        __IO uint32_t SEL17;
        stc_intc_sel_field_t SEL17_f;
    };
    union
    {
        __IO uint32_t SEL18;
        stc_intc_sel_field_t SEL18_f;
    };
    union
    {
        __IO uint32_t SEL19;
        stc_intc_sel_field_t SEL19_f;
    };
    union
    {
        __IO uint32_t SEL20;
        stc_intc_sel_field_t SEL20_f;
    };
    union
    {
        __IO uint32_t SEL21;
        stc_intc_sel_field_t SEL21_f;
    };
    union
    {
        __IO uint32_t SEL22;
        stc_intc_sel_field_t SEL22_f;
    };
    union
    {
        __IO uint32_t SEL23;
        stc_intc_sel_field_t SEL23_f;
    };
    union
    {
        __IO uint32_t SEL24;
        stc_intc_sel_field_t SEL24_f;
    };
    union
    {
        __IO uint32_t SEL25;
        stc_intc_sel_field_t SEL25_f;
    };
    union
    {
        __IO uint32_t SEL26;
        stc_intc_sel_field_t SEL26_f;
    };
    union
    {
        __IO uint32_t SEL27;
        stc_intc_sel_field_t SEL27_f;
    };
    union
    {
        __IO uint32_t SEL28;
        stc_intc_sel_field_t SEL28_f;
    };
    union
    {
        __IO uint32_t SEL29;
        stc_intc_sel_field_t SEL29_f;
    };
    union
    {
        __IO uint32_t SEL30;
        stc_intc_sel_field_t SEL30_f;
    };
    union
    {
        __IO uint32_t SEL31;
        stc_intc_sel_field_t SEL31_f;
    };
    union
    {
        __IO uint32_t SEL32;
        stc_intc_sel_field_t SEL32_f;
    };
    union
    {
        __IO uint32_t SEL33;
        stc_intc_sel_field_t SEL33_f;
    };
    union
    {
        __IO uint32_t SEL34;
        stc_intc_sel_field_t SEL34_f;
    };
    union
    {
        __IO uint32_t SEL35;
        stc_intc_sel_field_t SEL35_f;
    };
    union
    {
        __IO uint32_t SEL36;
        stc_intc_sel_field_t SEL36_f;
    };
    union
    {
        __IO uint32_t SEL37;
        stc_intc_sel_field_t SEL37_f;
    };
    union
    {
        __IO uint32_t SEL38;
        stc_intc_sel_field_t SEL38_f;
    };
    union
    {
        __IO uint32_t SEL39;
        stc_intc_sel_field_t SEL39_f;
    };
    union
    {
        __IO uint32_t SEL40;
        stc_intc_sel_field_t SEL40_f;
    };
    union
    {
        __IO uint32_t SEL41;
        stc_intc_sel_field_t SEL41_f;
    };
    union
    {
        __IO uint32_t SEL42;
        stc_intc_sel_field_t SEL42_f;
    };
    union
    {
        __IO uint32_t SEL43;
        stc_intc_sel_field_t SEL43_f;
    };
    union
    {
        __IO uint32_t SEL44;
        stc_intc_sel_field_t SEL44_f;
    };
    union
    {
        __IO uint32_t SEL45;
        stc_intc_sel_field_t SEL45_f;
    };
    union
    {
        __IO uint32_t SEL46;
        stc_intc_sel_field_t SEL46_f;
    };
    union
    {
        __IO uint32_t SEL47;
        stc_intc_sel_field_t SEL47_f;
    };
    union
    {
        __IO uint32_t SEL48;
        stc_intc_sel_field_t SEL48_f;
    };
    union
    {
        __IO uint32_t SEL49;
        stc_intc_sel_field_t SEL49_f;
    };
    union
    {
        __IO uint32_t SEL50;
        stc_intc_sel_field_t SEL50_f;
    };
    union
    {
        __IO uint32_t SEL51;
        stc_intc_sel_field_t SEL51_f;
    };
    union
    {
        __IO uint32_t SEL52;
        stc_intc_sel_field_t SEL52_f;
    };
    union
    {
        __IO uint32_t SEL53;
        stc_intc_sel_field_t SEL53_f;
    };
    union
    {
        __IO uint32_t SEL54;
        stc_intc_sel_field_t SEL54_f;
    };
    union
    {
        __IO uint32_t SEL55;
        stc_intc_sel_field_t SEL55_f;
    };
    union
    {
        __IO uint32_t SEL56;
        stc_intc_sel_field_t SEL56_f;
    };
    union
    {
        __IO uint32_t SEL57;
        stc_intc_sel_field_t SEL57_f;
    };
    union
    {
        __IO uint32_t SEL58;
        stc_intc_sel_field_t SEL58_f;
    };
    union
    {
        __IO uint32_t SEL59;
        stc_intc_sel_field_t SEL59_f;
    };
    union
    {
        __IO uint32_t SEL60;
        stc_intc_sel_field_t SEL60_f;
    };
    union
    {
        __IO uint32_t SEL61;
        stc_intc_sel_field_t SEL61_f;
    };
    union
    {
        __IO uint32_t SEL62;
        stc_intc_sel_field_t SEL62_f;
    };
    union
    {
        __IO uint32_t SEL63;
        stc_intc_sel_field_t SEL63_f;
    };
    union
    {
        __IO uint32_t SEL64;
        stc_intc_sel_field_t SEL64_f;
    };
    union
    {
        __IO uint32_t SEL65;
        stc_intc_sel_field_t SEL65_f;
    };
    union
    {
        __IO uint32_t SEL66;
        stc_intc_sel_field_t SEL66_f;
    };
    union
    {
        __IO uint32_t SEL67;
        stc_intc_sel_field_t SEL67_f;
    };
    union
    {
        __IO uint32_t SEL68;
        stc_intc_sel_field_t SEL68_f;
    };
    union
    {
        __IO uint32_t SEL69;
        stc_intc_sel_field_t SEL69_f;
    };
    union
    {
        __IO uint32_t SEL70;
        stc_intc_sel_field_t SEL70_f;
    };
    union
    {
        __IO uint32_t SEL71;
        stc_intc_sel_field_t SEL71_f;
    };
    union
    {
        __IO uint32_t SEL72;
        stc_intc_sel_field_t SEL72_f;
    };
    union
    {
        __IO uint32_t SEL73;
        stc_intc_sel_field_t SEL73_f;
    };
    union
    {
        __IO uint32_t SEL74;
        stc_intc_sel_field_t SEL74_f;
    };
    union
    {
        __IO uint32_t SEL75;
        stc_intc_sel_field_t SEL75_f;
    };
    union
    {
        __IO uint32_t SEL76;
        stc_intc_sel_field_t SEL76_f;
    };
    union
    {
        __IO uint32_t SEL77;
        stc_intc_sel_field_t SEL77_f;
    };
    union
    {
        __IO uint32_t SEL78;
        stc_intc_sel_field_t SEL78_f;
    };
    union
    {
        __IO uint32_t SEL79;
        stc_intc_sel_field_t SEL79_f;
    };
    union
    {
        __IO uint32_t SEL80;
        stc_intc_sel_field_t SEL80_f;
    };
    union
    {
        __IO uint32_t SEL81;
        stc_intc_sel_field_t SEL81_f;
    };
    union
    {
        __IO uint32_t SEL82;
        stc_intc_sel_field_t SEL82_f;
    };
    union
    {
        __IO uint32_t SEL83;
        stc_intc_sel_field_t SEL83_f;
    };
    union
    {
        __IO uint32_t SEL84;
        stc_intc_sel_field_t SEL84_f;
    };
    union
    {
        __IO uint32_t SEL85;
        stc_intc_sel_field_t SEL85_f;
    };
    union
    {
        __IO uint32_t SEL86;
        stc_intc_sel_field_t SEL86_f;
    };
    union
    {
        __IO uint32_t SEL87;
        stc_intc_sel_field_t SEL87_f;
    };
    union
    {
        __IO uint32_t SEL88;
        stc_intc_sel_field_t SEL88_f;
    };
    union
    {
        __IO uint32_t SEL89;
        stc_intc_sel_field_t SEL89_f;
    };
    union
    {
        __IO uint32_t SEL90;
        stc_intc_sel_field_t SEL90_f;
    };
    union
    {
        __IO uint32_t SEL91;
        stc_intc_sel_field_t SEL91_f;
    };
    union
    {
        __IO uint32_t SEL92;
        stc_intc_sel_field_t SEL92_f;
    };
    union
    {
        __IO uint32_t SEL93;
        stc_intc_sel_field_t SEL93_f;
    };
    union
    {
        __IO uint32_t SEL94;
        stc_intc_sel_field_t SEL94_f;
    };
    union
    {
        __IO uint32_t SEL95;
        stc_intc_sel_field_t SEL95_f;
    };
    union
    {
        __IO uint32_t SEL96;
        stc_intc_sel_field_t SEL96_f;
    };
    union
    {
        __IO uint32_t SEL97;
        stc_intc_sel_field_t SEL97_f;
    };
    union
    {
        __IO uint32_t SEL98;
        stc_intc_sel_field_t SEL98_f;
    };
    union
    {
        __IO uint32_t SEL99;
        stc_intc_sel_field_t SEL99_f;
    };
    union
    {
        __IO uint32_t SEL100;
        stc_intc_sel_field_t SEL100_f;
    };
    union
    {
        __IO uint32_t SEL101;
        stc_intc_sel_field_t SEL101_f;
    };
    union
    {
        __IO uint32_t SEL102;
        stc_intc_sel_field_t SEL102_f;
    };
    union
    {
        __IO uint32_t SEL103;
        stc_intc_sel_field_t SEL103_f;
    };
    union
    {
        __IO uint32_t SEL104;
        stc_intc_sel_field_t SEL104_f;
    };
    union
    {
        __IO uint32_t SEL105;
        stc_intc_sel_field_t SEL105_f;
    };
    union
    {
        __IO uint32_t SEL106;
        stc_intc_sel_field_t SEL106_f;
    };
    union
    {
        __IO uint32_t SEL107;
        stc_intc_sel_field_t SEL107_f;
    };
    union
    {
        __IO uint32_t SEL108;
        stc_intc_sel_field_t SEL108_f;
    };
    union
    {
        __IO uint32_t SEL109;
        stc_intc_sel_field_t SEL109_f;
    };
    union
    {
        __IO uint32_t SEL110;
        stc_intc_sel_field_t SEL110_f;
    };
    union
    {
        __IO uint32_t SEL111;
        stc_intc_sel_field_t SEL111_f;
    };
    union
    {
        __IO uint32_t SEL112;
        stc_intc_sel_field_t SEL112_f;
    };
    union
    {
        __IO uint32_t SEL113;
        stc_intc_sel_field_t SEL113_f;
    };
    union
    {
        __IO uint32_t SEL114;
        stc_intc_sel_field_t SEL114_f;
    };
    union
    {
        __IO uint32_t SEL115;
        stc_intc_sel_field_t SEL115_f;
    };
    union
    {
        __IO uint32_t SEL116;
        stc_intc_sel_field_t SEL116_f;
    };
    union
    {
        __IO uint32_t SEL117;
        stc_intc_sel_field_t SEL117_f;
    };
    union
    {
        __IO uint32_t SEL118;
        stc_intc_sel_field_t SEL118_f;
    };
    union
    {
        __IO uint32_t SEL119;
        stc_intc_sel_field_t SEL119_f;
    };
    union
    {
        __IO uint32_t SEL120;
        stc_intc_sel_field_t SEL120_f;
    };
    union
    {
        __IO uint32_t SEL121;
        stc_intc_sel_field_t SEL121_f;
    };
    union
    {
        __IO uint32_t SEL122;
        stc_intc_sel_field_t SEL122_f;
    };
    union
    {
        __IO uint32_t SEL123;
        stc_intc_sel_field_t SEL123_f;
    };
    union
    {
        __IO uint32_t SEL124;
        stc_intc_sel_field_t SEL124_f;
    };
    union
    {
        __IO uint32_t SEL125;
        stc_intc_sel_field_t SEL125_f;
    };
    union
    {
        __IO uint32_t SEL126;
        stc_intc_sel_field_t SEL126_f;
    };
    union
    {
        __IO uint32_t SEL127;
        stc_intc_sel_field_t SEL127_f;
    };
    union
    {
        __IO uint32_t VSSEL128;
        stc_intc_vssel_field_t VSSEL128_f;
    };
    union
    {
        __IO uint32_t VSSEL129;
        stc_intc_vssel_field_t VSSEL129_f;
    };
    union
    {
        __IO uint32_t VSSEL130;
        stc_intc_vssel_field_t VSSEL130_f;
    };
    union
    {
        __IO uint32_t VSSEL131;
        stc_intc_vssel_field_t VSSEL131_f;
    };
    union
    {
        __IO uint32_t VSSEL132;
        stc_intc_vssel_field_t VSSEL132_f;
    };
    union
    {
        __IO uint32_t VSSEL133;
        stc_intc_vssel_field_t VSSEL133_f;
    };
    union
    {
        __IO uint32_t VSSEL134;
        stc_intc_vssel_field_t VSSEL134_f;
    };
    union
    {
        __IO uint32_t VSSEL135;
        stc_intc_vssel_field_t VSSEL135_f;
    };
    union
    {
        __IO uint32_t VSSEL136;
        stc_intc_vssel_field_t VSSEL136_f;
    };
    union
    {
        __IO uint32_t VSSEL137;
        stc_intc_vssel_field_t VSSEL137_f;
    };
    union
    {
        __IO uint32_t VSSEL138;
        stc_intc_vssel_field_t VSSEL138_f;
    };
    union
    {
        __IO uint32_t VSSEL139;
        stc_intc_vssel_field_t VSSEL139_f;
    };
    union
    {
        __IO uint32_t VSSEL140;
        stc_intc_vssel_field_t VSSEL140_f;
    };
    union
    {
        __IO uint32_t VSSEL141;
        stc_intc_vssel_field_t VSSEL141_f;
    };
    union
    {
        __IO uint32_t VSSEL142;
        stc_intc_vssel_field_t VSSEL142_f;
    };
    union
    {
        __IO uint32_t VSSEL143;
        stc_intc_vssel_field_t VSSEL143_f;
    };
    union
    {
        __IO uint32_t SWIER;
        stc_intc_swier_field_t SWIER_f;
    };
    union
    {
        __IO uint32_t EVTER;
        stc_intc_evter_field_t EVTER_f;
    };
    union
    {
        __IO uint32_t IER;
        stc_intc_ier_field_t IER_f;
    };
} M4_INTC_TypeDef;

/**
 * @brief KEYSCAN
 */
typedef struct
{
    union
    {
        __IO uint32_t SCR;
        stc_keyscan_scr_field_t SCR_f;
    };
    union
    {
        __IO uint32_t SER;
        stc_keyscan_ser_field_t SER_f;
    };
    union
    {
        __IO uint32_t SSR;
        stc_keyscan_ssr_field_t SSR_f;
    };
} M4_KEYSCAN_TypeDef;

/**
 * @brief MPU
 */
typedef struct
{
    union
    {
        __IO uint32_t RGD0;
        stc_mpu_rgd_field_t RGD0_f;
    };
    union
    {
        __IO uint32_t RGD1;
        stc_mpu_rgd_field_t RGD1_f;
    };
    union
    {
        __IO uint32_t RGD2;
        stc_mpu_rgd_field_t RGD2_f;
    };
    union
    {
        __IO uint32_t RGD3;
        stc_mpu_rgd_field_t RGD3_f;
    };
    union
    {
        __IO uint32_t RGD4;
        stc_mpu_rgd_field_t RGD4_f;
    };
    union
    {
        __IO uint32_t RGD5;
        stc_mpu_rgd_field_t RGD5_f;
    };
    union
    {
        __IO uint32_t RGD6;
        stc_mpu_rgd_field_t RGD6_f;
    };
    union
    {
        __IO uint32_t RGD7;
        stc_mpu_rgd_field_t RGD7_f;
    };
    union
    {
        __IO uint32_t RGD8;
        stc_mpu_rgd_field_t RGD8_f;
    };
    union
    {
        __IO uint32_t RGD9;
        stc_mpu_rgd_field_t RGD9_f;
    };
    union
    {
        __IO uint32_t RGD10;
        stc_mpu_rgd_field_t RGD10_f;
    };
    union
    {
        __IO uint32_t RGD11;
        stc_mpu_rgd_field_t RGD11_f;
    };
    union
    {
        __IO uint32_t RGD12;
        stc_mpu_rgd_field_t RGD12_f;
    };
    union
    {
        __IO uint32_t RGD13;
        stc_mpu_rgd_field_t RGD13_f;
    };
    union
    {
        __IO uint32_t RGD14;
        stc_mpu_rgd_field_t RGD14_f;
    };
    union
    {
        __IO uint32_t RGD15;
        stc_mpu_rgd_field_t RGD15_f;
    };
    union
    {
        __IO uint32_t RGCR0;
        stc_mpu_rgcr0_field_t RGCR0_f;
    };
    union
    {
        __IO uint32_t RGCR1;
        stc_mpu_rgcr1_field_t RGCR1_f;
    };
    union
    {
        __IO uint32_t RGCR2;
        stc_mpu_rgcr2_field_t RGCR2_f;
    };
    union
    {
        __IO uint32_t RGCR3;
        stc_mpu_rgcr3_field_t RGCR3_f;
    };
    union
    {
        __IO uint32_t RGCR4;
        stc_mpu_rgcr4_field_t RGCR4_f;
    };
    union
    {
        __IO uint32_t RGCR5;
        stc_mpu_rgcr5_field_t RGCR5_f;
    };
    union
    {
        __IO uint32_t RGCR6;
        stc_mpu_rgcr6_field_t RGCR6_f;
    };
    union
    {
        __IO uint32_t RGCR7;
        stc_mpu_rgcr7_field_t RGCR7_f;
    };
    union
    {
        __IO uint32_t RGCR8;
        stc_mpu_rgcr8_field_t RGCR8_f;
    };
    union
    {
        __IO uint32_t RGCR9;
        stc_mpu_rgcr9_field_t RGCR9_f;
    };
    union
    {
        __IO uint32_t RGCR10;
        stc_mpu_rgcr10_field_t RGCR10_f;
    };
    union
    {
        __IO uint32_t RGCR11;
        stc_mpu_rgcr11_field_t RGCR11_f;
    };
    union
    {
        __IO uint32_t RGCR12;
        stc_mpu_rgcr12_field_t RGCR12_f;
    };
    union
    {
        __IO uint32_t RGCR13;
        stc_mpu_rgcr13_field_t RGCR13_f;
    };
    union
    {
        __IO uint32_t RGCR14;
        stc_mpu_rgcr14_field_t RGCR14_f;
    };
    union
    {
        __IO uint32_t RGCR15;
        stc_mpu_rgcr15_field_t RGCR15_f;
    };
    union
    {
        __IO uint32_t CR;
        stc_mpu_cr_field_t CR_f;
    };
    union
    {
        __IO uint32_t SR;
        stc_mpu_sr_field_t SR_f;
    };
    union
    {
        __IO uint32_t ECLR;
        stc_mpu_eclr_field_t ECLR_f;
    };
    union
    {
        __IO uint32_t WP;
        stc_mpu_wp_field_t WP_f;
    };
} M4_MPU_TypeDef;

/**
 * @brief MSTP
 */
typedef struct
{
    union
    {
        __IO uint32_t FCG0;
        stc_mstp_fcg0_field_t FCG0_f;
    };
    union
    {
        __IO uint32_t FCG1;
        stc_mstp_fcg1_field_t FCG1_f;
    };
    union
    {
        __IO uint32_t FCG2;
        stc_mstp_fcg2_field_t FCG2_f;
    };
    union
    {
        __IO uint32_t FCG3;
        stc_mstp_fcg3_field_t FCG3_f;
    };
    union
    {
        __IO uint32_t FCG0PC;
        stc_mstp_fcg0pc_field_t FCG0PC_f;
    };
} M4_MSTP_TypeDef;

/**
 * @brief OTS
 */
typedef struct
{
    union
    {
        __IO uint16_t CTL;
        stc_ots_ctl_field_t CTL_f;
    };
    __IO uint16_t DR1;
    __IO uint16_t DR2;
    __IO uint16_t ECR;
    union
    {
        __IO uint32_t LPR;
        stc_ots_lpr_field_t LPR_f;
    };
} M4_OTS_TypeDef;

/**
 * @brief PERIC
 */
typedef struct
{
    union
    {
        __IO uint32_t USBFS_SYCTLREG;
        stc_peric_usbfs_syctlreg_field_t USBFS_SYCTLREG_f;
    };
    union
    {
        __IO uint32_t SDIOC_SYCTLREG;
        stc_peric_sdioc_syctlreg_field_t SDIOC_SYCTLREG_f;
    };
} M4_PERIC_TypeDef;

/**
 * @brief PORT
 */
typedef struct
{
    union
    {
        __IO uint16_t PIDRA;
        stc_port_pidr_field_t PIDRA_f;
    };
    uint8_t RESERVED0[2];
    union
    {
        __IO uint16_t PODRA;
        stc_port_podr_field_t PODRA_f;
    };
    union
    {
        __IO uint16_t POERA;
        stc_port_poer_field_t POERA_f;
    };
    union
    {
        __IO uint16_t POSRA;
        stc_port_posr_field_t POSRA_f;
    };
    union
    {
        __IO uint16_t PORRA;
        stc_port_porr_field_t PORRA_f;
    };
    union
    {
        __IO uint16_t POTRA;
        stc_port_potr_field_t POTRA_f;
    };
    uint8_t RESERVED1[2];
    union
    {
        __IO uint16_t PIDRB;
        stc_port_pidr_field_t PIDRB_f;
    };
    uint8_t RESERVED2[2];
    union
    {
        __IO uint16_t PODRB;
        stc_port_podr_field_t PODRB_f;
    };
    union
    {
        __IO uint16_t POERB;
        stc_port_poer_field_t POERB_f;
    };
    union
    {
        __IO uint16_t POSRB;
        stc_port_posr_field_t POSRB_f;
    };
    union
    {
        __IO uint16_t PORRB;
        stc_port_porr_field_t PORRB_f;
    };
    union
    {
        __IO uint16_t POTRB;
        stc_port_potr_field_t POTRB_f;
    };
    uint8_t RESERVED3[2];
    union
    {
        __IO uint16_t PIDRC;
        stc_port_pidr_field_t PIDRC_f;
    };
    uint8_t RESERVED4[2];
    union
    {
        __IO uint16_t PODRC;
        stc_port_podr_field_t PODRC_f;
    };
    union
    {
        __IO uint16_t POERC;
        stc_port_poer_field_t POERC_f;
    };
    union
    {
        __IO uint16_t POSRC;
        stc_port_posr_field_t POSRC_f;
    };
    union
    {
        __IO uint16_t PORRC;
        stc_port_porr_field_t PORRC_f;
    };
    union
    {
        __IO uint16_t POTRC;
        stc_port_potr_field_t POTRC_f;
    };
    uint8_t RESERVED5[2];
    union
    {
        __IO uint16_t PIDRD;
        stc_port_pidr_field_t PIDRD_f;
    };
    uint8_t RESERVED6[2];
    union
    {
        __IO uint16_t PODRD;
        stc_port_podr_field_t PODRD_f;
    };
    union
    {
        __IO uint16_t POERD;
        stc_port_poer_field_t POERD_f;
    };
    union
    {
        __IO uint16_t POSRD;
        stc_port_posr_field_t POSRD_f;
    };
    union
    {
        __IO uint16_t PORRD;
        stc_port_porr_field_t PORRD_f;
    };
    union
    {
        __IO uint16_t POTRD;
        stc_port_potr_field_t POTRD_f;
    };
    uint8_t RESERVED7[2];
    union
    {
        __IO uint16_t PIDRE;
        stc_port_pidr_field_t PIDRE_f;
    };
    uint8_t RESERVED8[2];
    union
    {
        __IO uint16_t PODRE;
        stc_port_podr_field_t PODRE_f;
    };
    union
    {
        __IO uint16_t POERE;
        stc_port_poer_field_t POERE_f;
    };
    union
    {
        __IO uint16_t POSRE;
        stc_port_posr_field_t POSRE_f;
    };
    union
    {
        __IO uint16_t PORRE;
        stc_port_porr_field_t PORRE_f;
    };
    union
    {
        __IO uint16_t POTRE;
        stc_port_potr_field_t POTRE_f;
    };
    uint8_t RESERVED9[2];
    union
    {
        __IO uint16_t PIDRH;
        stc_port_pidrh_field_t PIDRH_f;
    };
    uint8_t RESERVED10[2];
    union
    {
        __IO uint16_t PODRH;
        stc_port_podrh_field_t PODRH_f;
    };
    union
    {
        __IO uint16_t POERH;
        stc_port_poerh_field_t POERH_f;
    };
    union
    {
        __IO uint16_t POSRH;
        stc_port_posrh_field_t POSRH_f;
    };
    union
    {
        __IO uint16_t PORRH;
        stc_port_porrh_field_t PORRH_f;
    };
    union
    {
        __IO uint16_t POTRH;
        stc_port_potrh_field_t POTRH_f;
    };
    uint8_t RESERVED11[918];
    union
    {
        __IO uint16_t PSPCR;
        stc_port_pspcr_field_t PSPCR_f;
    };
    uint8_t RESERVED12[2];
    union
    {
        __IO uint16_t PCCR;
        stc_port_pccr_field_t PCCR_f;
    };
    union
    {
        __IO uint16_t PINAER;
        stc_port_pinaer_field_t PINAER_f;
    };
    union
    {
        __IO uint16_t PWPR;
        stc_port_pwpr_field_t PWPR_f;
    };
    uint8_t RESERVED13[2];
    union
    {
        __IO uint16_t PCRA0;
        stc_port_pcr_field_t PCRA0_f;
    };
    union
    {
        __IO uint16_t PFSRA0;
        stc_port_pfsr_field_t PFSRA0_f;
    };
    union
    {
        __IO uint16_t PCRA1;
        stc_port_pcr_field_t PCRA1_f;
    };
    union
    {
        __IO uint16_t PFSRA1;
        stc_port_pfsr_field_t PFSRA1_f;
    };
    union
    {
        __IO uint16_t PCRA2;
        stc_port_pcr_field_t PCRA2_f;
    };
    union
    {
        __IO uint16_t PFSRA2;
        stc_port_pfsr_field_t PFSRA2_f;
    };
    union
    {
        __IO uint16_t PCRA3;
        stc_port_pcr_field_t PCRA3_f;
    };
    union
    {
        __IO uint16_t PFSRA3;
        stc_port_pfsr_field_t PFSRA3_f;
    };
    union
    {
        __IO uint16_t PCRA4;
        stc_port_pcr_field_t PCRA4_f;
    };
    union
    {
        __IO uint16_t PFSRA4;
        stc_port_pfsr_field_t PFSRA4_f;
    };
    union
    {
        __IO uint16_t PCRA5;
        stc_port_pcr_field_t PCRA5_f;
    };
    union
    {
        __IO uint16_t PFSRA5;
        stc_port_pfsr_field_t PFSRA5_f;
    };
    union
    {
        __IO uint16_t PCRA6;
        stc_port_pcr_field_t PCRA6_f;
    };
    union
    {
        __IO uint16_t PFSRA6;
        stc_port_pfsr_field_t PFSRA6_f;
    };
    union
    {
        __IO uint16_t PCRA7;
        stc_port_pcr_field_t PCRA7_f;
    };
    union
    {
        __IO uint16_t PFSRA7;
        stc_port_pfsr_field_t PFSRA7_f;
    };
    union
    {
        __IO uint16_t PCRA8;
        stc_port_pcr_field_t PCRA8_f;
    };
    union
    {
        __IO uint16_t PFSRA8;
        stc_port_pfsr_field_t PFSRA8_f;
    };
    union
    {
        __IO uint16_t PCRA9;
        stc_port_pcr_field_t PCRA9_f;
    };
    union
    {
        __IO uint16_t PFSRA9;
        stc_port_pfsr_field_t PFSRA9_f;
    };
    union
    {
        __IO uint16_t PCRA10;
        stc_port_pcr_field_t PCRA10_f;
    };
    union
    {
        __IO uint16_t PFSRA10;
        stc_port_pfsr_field_t PFSRA10_f;
    };
    union
    {
        __IO uint16_t PCRA11;
        stc_port_pcr_field_t PCRA11_f;
    };
    union
    {
        __IO uint16_t PFSRA11;
        stc_port_pfsr_field_t PFSRA11_f;
    };
    union
    {
        __IO uint16_t PCRA12;
        stc_port_pcr_field_t PCRA12_f;
    };
    union
    {
        __IO uint16_t PFSRA12;
        stc_port_pfsr_field_t PFSRA12_f;
    };
    union
    {
        __IO uint16_t PCRA13;
        stc_port_pcr_field_t PCRA13_f;
    };
    union
    {
        __IO uint16_t PFSRA13;
        stc_port_pfsr_field_t PFSRA13_f;
    };
    union
    {
        __IO uint16_t PCRA14;
        stc_port_pcr_field_t PCRA14_f;
    };
    union
    {
        __IO uint16_t PFSRA14;
        stc_port_pfsr_field_t PFSRA14_f;
    };
    union
    {
        __IO uint16_t PCRA15;
        stc_port_pcr_field_t PCRA15_f;
    };
    union
    {
        __IO uint16_t PFSRA15;
        stc_port_pfsr_field_t PFSRA15_f;
    };
    union
    {
        __IO uint16_t PCRB0;
        stc_port_pcr_field_t PCRB0_f;
    };
    union
    {
        __IO uint16_t PFSRB0;
        stc_port_pfsr_field_t PFSRB0_f;
    };
    union
    {
        __IO uint16_t PCRB1;
        stc_port_pcr_field_t PCRB1_f;
    };
    union
    {
        __IO uint16_t PFSRB1;
        stc_port_pfsr_field_t PFSRB1_f;
    };
    union
    {
        __IO uint16_t PCRB2;
        stc_port_pcr_field_t PCRB2_f;
    };
    union
    {
        __IO uint16_t PFSRB2;
        stc_port_pfsr_field_t PFSRB2_f;
    };
    union
    {
        __IO uint16_t PCRB3;
        stc_port_pcr_field_t PCRB3_f;
    };
    union
    {
        __IO uint16_t PFSRB3;
        stc_port_pfsr_field_t PFSRB3_f;
    };
    union
    {
        __IO uint16_t PCRB4;
        stc_port_pcr_field_t PCRB4_f;
    };
    union
    {
        __IO uint16_t PFSRB4;
        stc_port_pfsr_field_t PFSRB4_f;
    };
    union
    {
        __IO uint16_t PCRB5;
        stc_port_pcr_field_t PCRB5_f;
    };
    union
    {
        __IO uint16_t PFSRB5;
        stc_port_pfsr_field_t PFSRB5_f;
    };
    union
    {
        __IO uint16_t PCRB6;
        stc_port_pcr_field_t PCRB6_f;
    };
    union
    {
        __IO uint16_t PFSRB6;
        stc_port_pfsr_field_t PFSRB6_f;
    };
    union
    {
        __IO uint16_t PCRB7;
        stc_port_pcr_field_t PCRB7_f;
    };
    union
    {
        __IO uint16_t PFSRB7;
        stc_port_pfsr_field_t PFSRB7_f;
    };
    union
    {
        __IO uint16_t PCRB8;
        stc_port_pcr_field_t PCRB8_f;
    };
    union
    {
        __IO uint16_t PFSRB8;
        stc_port_pfsr_field_t PFSRB8_f;
    };
    union
    {
        __IO uint16_t PCRB9;
        stc_port_pcr_field_t PCRB9_f;
    };
    union
    {
        __IO uint16_t PFSRB9;
        stc_port_pfsr_field_t PFSRB9_f;
    };
    union
    {
        __IO uint16_t PCRB10;
        stc_port_pcr_field_t PCRB10_f;
    };
    union
    {
        __IO uint16_t PFSRB10;
        stc_port_pfsr_field_t PFSRB10_f;
    };
    union
    {
        __IO uint16_t PCRB11;
        stc_port_pcr_field_t PCRB11_f;
    };
    union
    {
        __IO uint16_t PFSRB11;
        stc_port_pfsr_field_t PFSRB11_f;
    };
    union
    {
        __IO uint16_t PCRB12;
        stc_port_pcr_field_t PCRB12_f;
    };
    union
    {
        __IO uint16_t PFSRB12;
        stc_port_pfsr_field_t PFSRB12_f;
    };
    union
    {
        __IO uint16_t PCRB13;
        stc_port_pcr_field_t PCRB13_f;
    };
    union
    {
        __IO uint16_t PFSRB13;
        stc_port_pfsr_field_t PFSRB13_f;
    };
    union
    {
        __IO uint16_t PCRB14;
        stc_port_pcr_field_t PCRB14_f;
    };
    union
    {
        __IO uint16_t PFSRB14;
        stc_port_pfsr_field_t PFSRB14_f;
    };
    union
    {
        __IO uint16_t PCRB15;
        stc_port_pcr_field_t PCRB15_f;
    };
    union
    {
        __IO uint16_t PFSRB15;
        stc_port_pfsr_field_t PFSRB15_f;
    };
    union
    {
        __IO uint16_t PCRC0;
        stc_port_pcr_field_t PCRC0_f;
    };
    union
    {
        __IO uint16_t PFSRC0;
        stc_port_pfsr_field_t PFSRC0_f;
    };
    union
    {
        __IO uint16_t PCRC1;
        stc_port_pcr_field_t PCRC1_f;
    };
    union
    {
        __IO uint16_t PFSRC1;
        stc_port_pfsr_field_t PFSRC1_f;
    };
    union
    {
        __IO uint16_t PCRC2;
        stc_port_pcr_field_t PCRC2_f;
    };
    union
    {
        __IO uint16_t PFSRC2;
        stc_port_pfsr_field_t PFSRC2_f;
    };
    union
    {
        __IO uint16_t PCRC3;
        stc_port_pcr_field_t PCRC3_f;
    };
    union
    {
        __IO uint16_t PFSRC3;
        stc_port_pfsr_field_t PFSRC3_f;
    };
    union
    {
        __IO uint16_t PCRC4;
        stc_port_pcr_field_t PCRC4_f;
    };
    union
    {
        __IO uint16_t PFSRC4;
        stc_port_pfsr_field_t PFSRC4_f;
    };
    union
    {
        __IO uint16_t PCRC5;
        stc_port_pcr_field_t PCRC5_f;
    };
    union
    {
        __IO uint16_t PFSRC5;
        stc_port_pfsr_field_t PFSRC5_f;
    };
    union
    {
        __IO uint16_t PCRC6;
        stc_port_pcr_field_t PCRC6_f;
    };
    union
    {
        __IO uint16_t PFSRC6;
        stc_port_pfsr_field_t PFSRC6_f;
    };
    union
    {
        __IO uint16_t PCRC7;
        stc_port_pcr_field_t PCRC7_f;
    };
    union
    {
        __IO uint16_t PFSRC7;
        stc_port_pfsr_field_t PFSRC7_f;
    };
    union
    {
        __IO uint16_t PCRC8;
        stc_port_pcr_field_t PCRC8_f;
    };
    union
    {
        __IO uint16_t PFSRC8;
        stc_port_pfsr_field_t PFSRC8_f;
    };
    union
    {
        __IO uint16_t PCRC9;
        stc_port_pcr_field_t PCRC9_f;
    };
    union
    {
        __IO uint16_t PFSRC9;
        stc_port_pfsr_field_t PFSRC9_f;
    };
    union
    {
        __IO uint16_t PCRC10;
        stc_port_pcr_field_t PCRC10_f;
    };
    union
    {
        __IO uint16_t PFSRC10;
        stc_port_pfsr_field_t PFSRC10_f;
    };
    union
    {
        __IO uint16_t PCRC11;
        stc_port_pcr_field_t PCRC11_f;
    };
    union
    {
        __IO uint16_t PFSRC11;
        stc_port_pfsr_field_t PFSRC11_f;
    };
    union
    {
        __IO uint16_t PCRC12;
        stc_port_pcr_field_t PCRC12_f;
    };
    union
    {
        __IO uint16_t PFSRC12;
        stc_port_pfsr_field_t PFSRC12_f;
    };
    union
    {
        __IO uint16_t PCRC13;
        stc_port_pcr_field_t PCRC13_f;
    };
    union
    {
        __IO uint16_t PFSRC13;
        stc_port_pfsr_field_t PFSRC13_f;
    };
    union
    {
        __IO uint16_t PCRC14;
        stc_port_pcr_field_t PCRC14_f;
    };
    union
    {
        __IO uint16_t PFSRC14;
        stc_port_pfsr_field_t PFSRC14_f;
    };
    union
    {
        __IO uint16_t PCRC15;
        stc_port_pcr_field_t PCRC15_f;
    };
    union
    {
        __IO uint16_t PFSRC15;
        stc_port_pfsr_field_t PFSRC15_f;
    };
    union
    {
        __IO uint16_t PCRD0;
        stc_port_pcr_field_t PCRD0_f;
    };
    union
    {
        __IO uint16_t PFSRD0;
        stc_port_pfsr_field_t PFSRD0_f;
    };
    union
    {
        __IO uint16_t PCRD1;
        stc_port_pcr_field_t PCRD1_f;
    };
    union
    {
        __IO uint16_t PFSRD1;
        stc_port_pfsr_field_t PFSRD1_f;
    };
    union
    {
        __IO uint16_t PCRD2;
        stc_port_pcr_field_t PCRD2_f;
    };
    union
    {
        __IO uint16_t PFSRD2;
        stc_port_pfsr_field_t PFSRD2_f;
    };
    union
    {
        __IO uint16_t PCRD3;
        stc_port_pcr_field_t PCRD3_f;
    };
    union
    {
        __IO uint16_t PFSRD3;
        stc_port_pfsr_field_t PFSRD3_f;
    };
    union
    {
        __IO uint16_t PCRD4;
        stc_port_pcr_field_t PCRD4_f;
    };
    union
    {
        __IO uint16_t PFSRD4;
        stc_port_pfsr_field_t PFSRD4_f;
    };
    union
    {
        __IO uint16_t PCRD5;
        stc_port_pcr_field_t PCRD5_f;
    };
    union
    {
        __IO uint16_t PFSRD5;
        stc_port_pfsr_field_t PFSRD5_f;
    };
    union
    {
        __IO uint16_t PCRD6;
        stc_port_pcr_field_t PCRD6_f;
    };
    union
    {
        __IO uint16_t PFSRD6;
        stc_port_pfsr_field_t PFSRD6_f;
    };
    union
    {
        __IO uint16_t PCRD7;
        stc_port_pcr_field_t PCRD7_f;
    };
    union
    {
        __IO uint16_t PFSRD7;
        stc_port_pfsr_field_t PFSRD7_f;
    };
    union
    {
        __IO uint16_t PCRD8;
        stc_port_pcr_field_t PCRD8_f;
    };
    union
    {
        __IO uint16_t PFSRD8;
        stc_port_pfsr_field_t PFSRD8_f;
    };
    union
    {
        __IO uint16_t PCRD9;
        stc_port_pcr_field_t PCRD9_f;
    };
    union
    {
        __IO uint16_t PFSRD9;
        stc_port_pfsr_field_t PFSRD9_f;
    };
    union
    {
        __IO uint16_t PCRD10;
        stc_port_pcr_field_t PCRD10_f;
    };
    union
    {
        __IO uint16_t PFSRD10;
        stc_port_pfsr_field_t PFSRD10_f;
    };
    union
    {
        __IO uint16_t PCRD11;
        stc_port_pcr_field_t PCRD11_f;
    };
    union
    {
        __IO uint16_t PFSRD11;
        stc_port_pfsr_field_t PFSRD11_f;
    };
    union
    {
        __IO uint16_t PCRD12;
        stc_port_pcr_field_t PCRD12_f;
    };
    union
    {
        __IO uint16_t PFSRD12;
        stc_port_pfsr_field_t PFSRD12_f;
    };
    union
    {
        __IO uint16_t PCRD13;
        stc_port_pcr_field_t PCRD13_f;
    };
    union
    {
        __IO uint16_t PFSRD13;
        stc_port_pfsr_field_t PFSRD13_f;
    };
    union
    {
        __IO uint16_t PCRD14;
        stc_port_pcr_field_t PCRD14_f;
    };
    union
    {
        __IO uint16_t PFSRD14;
        stc_port_pfsr_field_t PFSRD14_f;
    };
    union
    {
        __IO uint16_t PCRD15;
        stc_port_pcr_field_t PCRD15_f;
    };
    union
    {
        __IO uint16_t PFSRD15;
        stc_port_pfsr_field_t PFSRD15_f;
    };
    union
    {
        __IO uint16_t PCRE0;
        stc_port_pcr_field_t PCRE0_f;
    };
    union
    {
        __IO uint16_t PFSRE0;
        stc_port_pfsr_field_t PFSRE0_f;
    };
    union
    {
        __IO uint16_t PCRE1;
        stc_port_pcr_field_t PCRE1_f;
    };
    union
    {
        __IO uint16_t PFSRE1;
        stc_port_pfsr_field_t PFSRE1_f;
    };
    union
    {
        __IO uint16_t PCRE2;
        stc_port_pcr_field_t PCRE2_f;
    };
    union
    {
        __IO uint16_t PFSRE2;
        stc_port_pfsr_field_t PFSRE2_f;
    };
    union
    {
        __IO uint16_t PCRE3;
        stc_port_pcr_field_t PCRE3_f;
    };
    union
    {
        __IO uint16_t PFSRE3;
        stc_port_pfsr_field_t PFSRE3_f;
    };
    union
    {
        __IO uint16_t PCRE4;
        stc_port_pcr_field_t PCRE4_f;
    };
    union
    {
        __IO uint16_t PFSRE4;
        stc_port_pfsr_field_t PFSRE4_f;
    };
    union
    {
        __IO uint16_t PCRE5;
        stc_port_pcr_field_t PCRE5_f;
    };
    union
    {
        __IO uint16_t PFSRE5;
        stc_port_pfsr_field_t PFSRE5_f;
    };
    union
    {
        __IO uint16_t PCRE6;
        stc_port_pcr_field_t PCRE6_f;
    };
    union
    {
        __IO uint16_t PFSRE6;
        stc_port_pfsr_field_t PFSRE6_f;
    };
    union
    {
        __IO uint16_t PCRE7;
        stc_port_pcr_field_t PCRE7_f;
    };
    union
    {
        __IO uint16_t PFSRE7;
        stc_port_pfsr_field_t PFSRE7_f;
    };
    union
    {
        __IO uint16_t PCRE8;
        stc_port_pcr_field_t PCRE8_f;
    };
    union
    {
        __IO uint16_t PFSRE8;
        stc_port_pfsr_field_t PFSRE8_f;
    };
    union
    {
        __IO uint16_t PCRE9;
        stc_port_pcr_field_t PCRE9_f;
    };
    union
    {
        __IO uint16_t PFSRE9;
        stc_port_pfsr_field_t PFSRE9_f;
    };
    union
    {
        __IO uint16_t PCRE10;
        stc_port_pcr_field_t PCRE10_f;
    };
    union
    {
        __IO uint16_t PFSRE10;
        stc_port_pfsr_field_t PFSRE10_f;
    };
    union
    {
        __IO uint16_t PCRE11;
        stc_port_pcr_field_t PCRE11_f;
    };
    union
    {
        __IO uint16_t PFSRE11;
        stc_port_pfsr_field_t PFSRE11_f;
    };
    union
    {
        __IO uint16_t PCRE12;
        stc_port_pcr_field_t PCRE12_f;
    };
    union
    {
        __IO uint16_t PFSRE12;
        stc_port_pfsr_field_t PFSRE12_f;
    };
    union
    {
        __IO uint16_t PCRE13;
        stc_port_pcr_field_t PCRE13_f;
    };
    union
    {
        __IO uint16_t PFSRE13;
        stc_port_pfsr_field_t PFSRE13_f;
    };
    union
    {
        __IO uint16_t PCRE14;
        stc_port_pcr_field_t PCRE14_f;
    };
    union
    {
        __IO uint16_t PFSRE14;
        stc_port_pfsr_field_t PFSRE14_f;
    };
    union
    {
        __IO uint16_t PCRE15;
        stc_port_pcr_field_t PCRE15_f;
    };
    union
    {
        __IO uint16_t PFSRE15;
        stc_port_pfsr_field_t PFSRE15_f;
    };
    union
    {
        __IO uint16_t PCRH0;
        stc_port_pcr_field_t PCRH0_f;
    };
    union
    {
        __IO uint16_t PFSRH0;
        stc_port_pfsr_field_t PFSRH0_f;
    };
    union
    {
        __IO uint16_t PCRH1;
        stc_port_pcr_field_t PCRH1_f;
    };
    union
    {
        __IO uint16_t PFSRH1;
        stc_port_pfsr_field_t PFSRH1_f;
    };
    union
    {
        __IO uint16_t PCRH2;
        stc_port_pcr_field_t PCRH2_f;
    };
    union
    {
        __IO uint16_t PFSRH2;
        stc_port_pfsr_field_t PFSRH2_f;
    };
} M4_PORT_TypeDef;

/**
 * @brief QSPI
 */
typedef struct
{
    union
    {
        __IO uint32_t CR;
        stc_qspi_cr_field_t CR_f;
    };
    union
    {
        __IO uint32_t CSCR;
        stc_qspi_cscr_field_t CSCR_f;
    };
    union
    {
        __IO uint32_t FCR;
        stc_qspi_fcr_field_t FCR_f;
    };
    union
    {
        __IO uint32_t SR;
        stc_qspi_sr_field_t SR_f;
    };
    union
    {
        __IO uint32_t DCOM;
        stc_qspi_dcom_field_t DCOM_f;
    };
    union
    {
        __IO uint32_t CCMD;
        stc_qspi_ccmd_field_t CCMD_f;
    };
    union
    {
        __IO uint32_t XCMD;
        stc_qspi_xcmd_field_t XCMD_f;
    };
    uint8_t RESERVED0[8];
    union
    {
        __IO uint32_t SR2;
        stc_qspi_sr2_field_t SR2_f;
    };
    uint8_t RESERVED1[2012];
    union
    {
        __IO uint32_t EXAR;
        stc_qspi_exar_field_t EXAR_f;
    };
} M4_QSPI_TypeDef;

/**
 * @brief RTC
 */
typedef struct
{
    union
    {
        __IO uint8_t CR0;
        stc_rtc_cr0_field_t CR0_f;
    };
    uint8_t RESERVED0[3];
    union
    {
        __IO uint8_t CR1;
        stc_rtc_cr1_field_t CR1_f;
    };
    uint8_t RESERVED1[3];
    union
    {
        __IO uint8_t CR2;
        stc_rtc_cr2_field_t CR2_f;
    };
    uint8_t RESERVED2[3];
    union
    {
        __IO uint8_t CR3;
        stc_rtc_cr3_field_t CR3_f;
    };
    uint8_t RESERVED3[3];
    union
    {
        __IO uint8_t SEC;
        stc_rtc_sec_field_t SEC_f;
    };
    uint8_t RESERVED4[3];
    union
    {
        __IO uint8_t MIN;
        stc_rtc_min_field_t MIN_f;
    };
    uint8_t RESERVED5[3];
    union
    {
        __IO uint8_t HOUR;
        stc_rtc_hour_field_t HOUR_f;
    };
    uint8_t RESERVED6[3];
    union
    {
        __IO uint8_t WEEK;
        stc_rtc_week_field_t WEEK_f;
    };
    uint8_t RESERVED7[3];
    union
    {
        __IO uint8_t DAY;
        stc_rtc_day_field_t DAY_f;
    };
    uint8_t RESERVED8[3];
    union
    {
        __IO uint8_t MON;
        stc_rtc_mon_field_t MON_f;
    };
    uint8_t RESERVED9[3];
    union
    {
        __IO uint8_t YEAR;
        stc_rtc_year_field_t YEAR_f;
    };
    uint8_t RESERVED10[3];
    union
    {
        __IO uint8_t ALMMIN;
        stc_rtc_almmin_field_t ALMMIN_f;
    };
    uint8_t RESERVED11[3];
    union
    {
        __IO uint8_t ALMHOUR;
        stc_rtc_almhour_field_t ALMHOUR_f;
    };
    uint8_t RESERVED12[3];
    union
    {
        __IO uint8_t ALMWEEK;
        stc_rtc_almweek_field_t ALMWEEK_f;
    };
    uint8_t RESERVED13[3];
    union
    {
        __IO uint8_t ERRCRH;
        stc_rtc_errcrh_field_t ERRCRH_f;
    };
    uint8_t RESERVED14[3];
    union
    {
        __IO uint8_t ERRCRL;
        stc_rtc_errcrl_field_t ERRCRL_f;
    };
} M4_RTC_TypeDef;

/**
 * @brief SDIOC
 */
typedef struct
{
    uint8_t RESERVED0[4];
    union
    {
        __IO uint16_t BLKSIZE;
        stc_sdioc_blksize_field_t BLKSIZE_f;
    };
    __IO uint16_t BLKCNT;
    __IO uint16_t ARG0;
    __IO uint16_t ARG1;
    union
    {
        __IO uint16_t TRANSMODE;
        stc_sdioc_transmode_field_t TRANSMODE_f;
    };
    union
    {
        __IO uint16_t CMD;
        stc_sdioc_cmd_field_t CMD_f;
    };
    __IO uint16_t RESP0;
    __IO uint16_t RESP1;
    __IO uint16_t RESP2;
    __IO uint16_t RESP3;
    __IO uint16_t RESP4;
    __IO uint16_t RESP5;
    __IO uint16_t RESP6;
    __IO uint16_t RESP7;
    __IO uint16_t BUF0;
    __IO uint16_t BUF1;
    union
    {
        __IO uint32_t PSTAT;
        stc_sdioc_pstat_field_t PSTAT_f;
    };
    union
    {
        __IO uint8_t HOSTCON;
        stc_sdioc_hostcon_field_t HOSTCON_f;
    };
    union
    {
        __IO uint8_t PWRCON;
        stc_sdioc_pwrcon_field_t PWRCON_f;
    };
    union
    {
        __IO uint8_t BLKGPCON;
        stc_sdioc_blkgpcon_field_t BLKGPCON_f;
    };
    uint8_t RESERVED1[1];
    union
    {
        __IO uint16_t CLKCON;
        stc_sdioc_clkcon_field_t CLKCON_f;
    };
    union
    {
        __IO uint8_t TOUTCON;
        stc_sdioc_toutcon_field_t TOUTCON_f;
    };
    union
    {
        __IO uint8_t SFTRST;
        stc_sdioc_sftrst_field_t SFTRST_f;
    };
    union
    {
        __IO uint16_t NORINTST;
        stc_sdioc_norintst_field_t NORINTST_f;
    };
    union
    {
        __IO uint16_t ERRINTST;
        stc_sdioc_errintst_field_t ERRINTST_f;
    };
    union
    {
        __IO uint16_t NORINTSTEN;
        stc_sdioc_norintsten_field_t NORINTSTEN_f;
    };
    union
    {
        __IO uint16_t ERRINTSTEN;
        stc_sdioc_errintsten_field_t ERRINTSTEN_f;
    };
    union
    {
        __IO uint16_t NORINTSGEN;
        stc_sdioc_norintsgen_field_t NORINTSGEN_f;
    };
    union
    {
        __IO uint16_t ERRINTSGEN;
        stc_sdioc_errintsgen_field_t ERRINTSGEN_f;
    };
    union
    {
        __IO uint16_t ATCERRST;
        stc_sdioc_atcerrst_field_t ATCERRST_f;
    };
    uint8_t RESERVED2[18];
    union
    {
        __IO uint16_t FEA;
        stc_sdioc_fea_field_t FEA_f;
    };
    union
    {
        __IO uint16_t FEE;
        stc_sdioc_fee_field_t FEE_f;
    };
} M4_SDIOC_TypeDef;

/**
 * @brief SPI
 */
typedef struct
{
    __IO uint32_t DR;
    union
    {
        __IO uint32_t CR1;
        stc_spi_cr1_field_t CR1_f;
    };
    uint8_t RESERVED0[4];
    union
    {
        __IO uint32_t CFG1;
        stc_spi_cfg1_field_t CFG1_f;
    };
    uint8_t RESERVED1[4];
    union
    {
        __IO uint32_t SR;
        stc_spi_sr_field_t SR_f;
    };
    union
    {
        __IO uint32_t CFG2;
        stc_spi_cfg2_field_t CFG2_f;
    };
} M4_SPI_TypeDef;

/**
 * @brief SRAMC
 */
typedef struct
{
    union
    {
        __IO uint32_t WTCR;
        stc_sramc_wtcr_field_t WTCR_f;
    };
    union
    {
        __IO uint32_t WTPR;
        stc_sramc_wtpr_field_t WTPR_f;
    };
    union
    {
        __IO uint32_t CKCR;
        stc_sramc_ckcr_field_t CKCR_f;
    };
    union
    {
        __IO uint32_t CKPR;
        stc_sramc_ckpr_field_t CKPR_f;
    };
    union
    {
        __IO uint32_t CKSR;
        stc_sramc_cksr_field_t CKSR_f;
    };
} M4_SRAMC_TypeDef;

/**
 * @brief SWDT
 */
typedef struct
{
    uint8_t RESERVED0[4];
    union
    {
        __IO uint32_t SR;
        stc_swdt_sr_field_t SR_f;
    };
    union
    {
        __IO uint32_t RR;
        stc_swdt_rr_field_t RR_f;
    };
} M4_SWDT_TypeDef;

/**
 * @brief SYSREG
 */
typedef struct
{
    uint8_t RESERVED0[12];
    union
    {
        __IO uint16_t PWR_STPMCR;
        stc_sysreg_pwr_stpmcr_field_t PWR_STPMCR_f;
    };
    uint8_t RESERVED1[2];
    union
    {
        __IO uint16_t CMU_PERICKSEL;
        stc_sysreg_cmu_pericksel_field_t CMU_PERICKSEL_f;
    };
    union
    {
        __IO uint16_t CMU_I2SCKSEL;
        stc_sysreg_cmu_i2scksel_field_t CMU_I2SCKSEL_f;
    };
    union
    {
        __IO uint32_t PWR_RAMPC0;
        stc_sysreg_pwr_rampc0_field_t PWR_RAMPC0_f;
    };
    __IO uint16_t PWR_RAMOPM;
    uint8_t RESERVED2[2];
    union
    {
        __IO uint32_t MPU_IPPR;
        stc_sysreg_mpu_ippr_field_t MPU_IPPR_f;
    };
    union
    {
        __IO uint32_t CMU_SCFGR;
        stc_sysreg_cmu_scfgr_field_t CMU_SCFGR_f;
    };
    union
    {
        __IO uint8_t CMU_UFSCKCFGR;
        stc_sysreg_cmu_ufsckcfgr_field_t CMU_UFSCKCFGR_f;
    };
    uint8_t RESERVED3[1];
    union
    {
        __IO uint8_t CMU_CKSWR;
        stc_sysreg_cmu_ckswr_field_t CMU_CKSWR_f;
    };
    uint8_t RESERVED4[3];
    union
    {
        __IO uint8_t CMU_PLLCR;
        stc_sysreg_cmu_pllcr_field_t CMU_PLLCR_f;
    };
    uint8_t RESERVED5[3];
    union
    {
        __IO uint8_t CMU_UPLLCR;
        stc_sysreg_cmu_upllcr_field_t CMU_UPLLCR_f;
    };
    uint8_t RESERVED6[3];
    union
    {
        __IO uint8_t CMU_XTALCR;
        stc_sysreg_cmu_xtalcr_field_t CMU_XTALCR_f;
    };
    uint8_t RESERVED7[3];
    union
    {
        __IO uint8_t CMU_HRCCR;
        stc_sysreg_cmu_hrccr_field_t CMU_HRCCR_f;
    };
    uint8_t RESERVED8[1];
    union
    {
        __IO uint8_t CMU_MRCCR;
        stc_sysreg_cmu_mrccr_field_t CMU_MRCCR_f;
    };
    uint8_t RESERVED9[3];
    union
    {
        __IO uint8_t CMU_OSCSTBSR;
        stc_sysreg_cmu_oscstbsr_field_t CMU_OSCSTBSR_f;
    };
    union
    {
        __IO uint8_t CMU_MCO1CFGR;
        stc_sysreg_cmu_mco1cfgr_field_t CMU_MCO1CFGR_f;
    };
    union
    {
        __IO uint8_t CMU_MCO2CFGR;
        stc_sysreg_cmu_mco2cfgr_field_t CMU_MCO2CFGR_f;
    };
    union
    {
        __IO uint8_t CMU_TPIUCKCFGR;
        stc_sysreg_cmu_tpiuckcfgr_field_t CMU_TPIUCKCFGR_f;
    };
    union
    {
        __IO uint8_t CMU_XTALSTDCR;
        stc_sysreg_cmu_xtalstdcr_field_t CMU_XTALSTDCR_f;
    };
    union
    {
        __IO uint8_t CMU_XTALSTDSR;
        stc_sysreg_cmu_xtalstdsr_field_t CMU_XTALSTDSR_f;
    };
    uint8_t RESERVED10[31];
    __IO uint8_t CMU_MRCTRM;
    __IO uint8_t CMU_HRCTRM;
    uint8_t RESERVED11[63];
    union
    {
        __IO uint8_t CMU_XTALSTBCR;
        stc_sysreg_cmu_xtalstbcr_field_t CMU_XTALSTBCR_f;
    };
    uint8_t RESERVED12[29];
    union
    {
        __IO uint16_t RMU_RSTF0;
        stc_sysreg_rmu_rstf0_field_t RMU_RSTF0_f;
    };
    uint8_t RESERVED13[30];
    union
    {
        __IO uint8_t PWR_PVDICR;
        stc_sysreg_pwr_pvdicr_field_t PWR_PVDICR_f;
    };
    union
    {
        __IO uint8_t PWR_PVDDSR;
        stc_sysreg_pwr_pvddsr_field_t PWR_PVDDSR_f;
    };
    uint8_t RESERVED14[30];
    union
    {
        __IO uint32_t CMU_PLLCFGR;
        stc_sysreg_cmu_pllcfgr_field_t CMU_PLLCFGR_f;
    };
    union
    {
        __IO uint32_t CMU_UPLLCFGR;
        stc_sysreg_cmu_upllcfgr_field_t CMU_UPLLCFGR_f;
    };
    uint8_t RESERVED15[758];
    union
    {
        __IO uint16_t PWR_FPRC;
        stc_sysreg_pwr_fprc_field_t PWR_FPRC_f;
    };
    union
    {
        __IO uint8_t PWR_PWRC0;
        stc_sysreg_pwr_pwrc0_field_t PWR_PWRC0_f;
    };
    union
    {
        __IO uint8_t PWR_PWRC1;
        stc_sysreg_pwr_pwrc1_field_t PWR_PWRC1_f;
    };
    union
    {
        __IO uint8_t PWR_PWRC2;
        stc_sysreg_pwr_pwrc2_field_t PWR_PWRC2_f;
    };
    union
    {
        __IO uint8_t PWR_PWRC3;
        stc_sysreg_pwr_pwrc3_field_t PWR_PWRC3_f;
    };
    union
    {
        __IO uint8_t PWR_PDWKE0;
        stc_sysreg_pwr_pdwke0_field_t PWR_PDWKE0_f;
    };
    union
    {
        __IO uint8_t PWR_PDWKE1;
        stc_sysreg_pwr_pdwke1_field_t PWR_PDWKE1_f;
    };
    union
    {
        __IO uint8_t PWR_PDWKE2;
        stc_sysreg_pwr_pdwke2_field_t PWR_PDWKE2_f;
    };
    union
    {
        __IO uint8_t PWR_PDWKES;
        stc_sysreg_pwr_pdwkes_field_t PWR_PDWKES_f;
    };
    union
    {
        __IO uint8_t PWR_PDWKF0;
        stc_sysreg_pwr_pdwkf0_field_t PWR_PDWKF0_f;
    };
    union
    {
        __IO uint8_t PWR_PDWKF1;
        stc_sysreg_pwr_pdwkf1_field_t PWR_PDWKF1_f;
    };
    union
    {
        __IO uint8_t PWR_PWCMR;
        stc_sysreg_pwr_pwcmr_field_t PWR_PWCMR_f;
    };
    uint8_t RESERVED16[4];
    __IO uint8_t PWR_MDSWCR;
    union
    {
        __IO uint8_t CMU_XTALCFGR;
        stc_sysreg_cmu_xtalcfgr_field_t CMU_XTALCFGR_f;
    };
    uint8_t RESERVED17[1];
    union
    {
        __IO uint8_t PWR_PVDCR0;
        stc_sysreg_pwr_pvdcr0_field_t PWR_PVDCR0_f;
    };
    union
    {
        __IO uint8_t PWR_PVDCR1;
        stc_sysreg_pwr_pvdcr1_field_t PWR_PVDCR1_f;
    };
    union
    {
        __IO uint8_t PWR_PVDFCR;
        stc_sysreg_pwr_pvdfcr_field_t PWR_PVDFCR_f;
    };
    union
    {
        __IO uint8_t PWR_PVDLCR;
        stc_sysreg_pwr_pvdlcr_field_t PWR_PVDLCR_f;
    };
    uint8_t RESERVED18[10];
    union
    {
        __IO uint8_t CMU_XTAL32CR;
        stc_sysreg_cmu_xtal32cr_field_t CMU_XTAL32CR_f;
    };
    union
    {
        __IO uint8_t CMU_XTAL32CFGR;
        stc_sysreg_cmu_xtal32cfgr_field_t CMU_XTAL32CFGR_f;
    };
    uint8_t RESERVED19[3];
    union
    {
        __IO uint8_t CMU_XTAL32NFR;
        stc_sysreg_cmu_xtal32nfr_field_t CMU_XTAL32NFR_f;
    };
    uint8_t RESERVED20[1];
    union
    {
        __IO uint8_t CMU_LRCCR;
        stc_sysreg_cmu_lrccr_field_t CMU_LRCCR_f;
    };
    uint8_t RESERVED21[1];
    __IO uint8_t CMU_LRCTRM;
    uint8_t RESERVED22[1];
    union
    {
        __IO uint8_t PWR_XTAL32CS;
        stc_sysreg_pwr_xtal32cs_field_t PWR_XTAL32CS_f;
    };
} M4_SYSREG_TypeDef;

/**
 * @brief TMR0
 */
typedef struct
{
    union
    {
        __IO uint32_t CNTAR;
        stc_tmr0_cntar_field_t CNTAR_f;
    };
    union
    {
        __IO uint32_t CNTBR;
        stc_tmr0_cntbr_field_t CNTBR_f;
    };
    union
    {
        __IO uint32_t CMPAR;
        stc_tmr0_cmpar_field_t CMPAR_f;
    };
    union
    {
        __IO uint32_t CMPBR;
        stc_tmr0_cmpbr_field_t CMPBR_f;
    };
    union
    {
        __IO uint32_t BCONR;
        stc_tmr0_bconr_field_t BCONR_f;
    };
    union
    {
        __IO uint32_t STFLR;
        stc_tmr0_stflr_field_t STFLR_f;
    };
} M4_TMR0_TypeDef;

/**
 * @brief TMR4
 */
typedef struct
{
    uint8_t RESERVED0[2];
    __IO uint16_t OCCRUH;
    uint8_t RESERVED1[2];
    __IO uint16_t OCCRUL;
    uint8_t RESERVED2[2];
    __IO uint16_t OCCRVH;
    uint8_t RESERVED3[2];
    __IO uint16_t OCCRVL;
    uint8_t RESERVED4[2];
    __IO uint16_t OCCRWH;
    uint8_t RESERVED5[2];
    __IO uint16_t OCCRWL;
    union
    {
        __IO uint16_t OCSRU;
        stc_tmr4_ocsr_field_t OCSRU_f;
    };
    union
    {
        __IO uint16_t OCERU;
        stc_tmr4_ocer_field_t OCERU_f;
    };
    union
    {
        __IO uint16_t OCSRV;
        stc_tmr4_ocsr_field_t OCSRV_f;
    };
    union
    {
        __IO uint16_t OCERV;
        stc_tmr4_ocer_field_t OCERV_f;
    };
    union
    {
        __IO uint16_t OCSRW;
        stc_tmr4_ocsr_field_t OCSRW_f;
    };
    union
    {
        __IO uint16_t OCERW;
        stc_tmr4_ocer_field_t OCERW_f;
    };
    union
    {
        __IO uint16_t OCMRHUH;
        stc_tmr4_ocmrh_field_t OCMRHUH_f;
    };
    uint8_t RESERVED6[2];
    union
    {
        __IO uint32_t OCMRLUL;
        stc_tmr4_ocmrl_field_t OCMRLUL_f;
    };
    union
    {
        __IO uint16_t OCMRHVH;
        stc_tmr4_ocmrh_field_t OCMRHVH_f;
    };
    uint8_t RESERVED7[2];
    union
    {
        __IO uint32_t OCMRLVL;
        stc_tmr4_ocmrl_field_t OCMRLVL_f;
    };
    union
    {
        __IO uint16_t OCMRHWH;
        stc_tmr4_ocmrh_field_t OCMRHWH_f;
    };
    uint8_t RESERVED8[2];
    union
    {
        __IO uint32_t OCMRLWL;
        stc_tmr4_ocmrl_field_t OCMRLWL_f;
    };
    uint8_t RESERVED9[6];
    __IO uint16_t CPSR;
    uint8_t RESERVED10[2];
    __IO uint16_t CNTR;
    union
    {
        __IO uint16_t CCSR;
        stc_tmr4_ccsr_field_t CCSR_f;
    };
    union
    {
        __IO uint16_t CVPR;
        stc_tmr4_cvpr_field_t CVPR_f;
    };
    uint8_t RESERVED11[54];
    __IO uint16_t PFSRU;
    __IO uint16_t PDARU;
    __IO uint16_t PDBRU;
    uint8_t RESERVED12[2];
    __IO uint16_t PFSRV;
    __IO uint16_t PDARV;
    __IO uint16_t PDBRV;
    uint8_t RESERVED13[2];
    __IO uint16_t PFSRW;
    __IO uint16_t PDARW;
    __IO uint16_t PDBRW;
    union
    {
        __IO uint16_t POCRU;
        stc_tmr4_pocr_field_t POCRU_f;
    };
    uint8_t RESERVED14[2];
    union
    {
        __IO uint16_t POCRV;
        stc_tmr4_pocr_field_t POCRV_f;
    };
    uint8_t RESERVED15[2];
    union
    {
        __IO uint16_t POCRW;
        stc_tmr4_pocr_field_t POCRW_f;
    };
    uint8_t RESERVED16[2];
    union
    {
        __IO uint16_t RCSR;
        stc_tmr4_rcsr_field_t RCSR_f;
    };
    uint8_t RESERVED17[12];
    __IO uint16_t SCCRUH;
    uint8_t RESERVED18[2];
    __IO uint16_t SCCRUL;
    uint8_t RESERVED19[2];
    __IO uint16_t SCCRVH;
    uint8_t RESERVED20[2];
    __IO uint16_t SCCRVL;
    uint8_t RESERVED21[2];
    __IO uint16_t SCCRWH;
    uint8_t RESERVED22[2];
    __IO uint16_t SCCRWL;
    union
    {
        __IO uint16_t SCSRUH;
        stc_tmr4_scsr_field_t SCSRUH_f;
    };
    union
    {
        __IO uint16_t SCMRUH;
        stc_tmr4_scmr_field_t SCMRUH_f;
    };
    union
    {
        __IO uint16_t SCSRUL;
        stc_tmr4_scsr_field_t SCSRUL_f;
    };
    union
    {
        __IO uint16_t SCMRUL;
        stc_tmr4_scmr_field_t SCMRUL_f;
    };
    union
    {
        __IO uint16_t SCSRVH;
        stc_tmr4_scsr_field_t SCSRVH_f;
    };
    union
    {
        __IO uint16_t SCMRVH;
        stc_tmr4_scmr_field_t SCMRVH_f;
    };
    union
    {
        __IO uint16_t SCSRVL;
        stc_tmr4_scsr_field_t SCSRVL_f;
    };
    union
    {
        __IO uint16_t SCMRVL;
        stc_tmr4_scmr_field_t SCMRVL_f;
    };
    union
    {
        __IO uint16_t SCSRWH;
        stc_tmr4_scsr_field_t SCSRWH_f;
    };
    union
    {
        __IO uint16_t SCMRWH;
        stc_tmr4_scmr_field_t SCMRWH_f;
    };
    union
    {
        __IO uint16_t SCSRWL;
        stc_tmr4_scsr_field_t SCSRWL_f;
    };
    union
    {
        __IO uint16_t SCMRWL;
        stc_tmr4_scmr_field_t SCMRWL_f;
    };
    uint8_t RESERVED23[16];
    union
    {
        __IO uint16_t ECSR;
        stc_tmr4_ecsr_field_t ECSR_f;
    };
} M4_TMR4_TypeDef;

/**
 * @brief TMR4_CR
 */
typedef struct
{
    union
    {
        __IO uint16_t ECER1;
        stc_tmr4_cr_ecer1_field_t ECER1_f;
    };
    uint8_t RESERVED0[2];
    union
    {
        __IO uint16_t ECER2;
        stc_tmr4_cr_ecer2_field_t ECER2_f;
    };
    uint8_t RESERVED1[2];
    union
    {
        __IO uint16_t ECER3;
        stc_tmr4_cr_ecer3_field_t ECER3_f;
    };
} M4_TMR4_CR_TypeDef;

/**
 * @brief TMR6
 */
typedef struct
{
    union
    {
        __IO uint32_t CNTER;
        stc_tmr6_cnter_field_t CNTER_f;
    };
    union
    {
        __IO uint32_t PERAR;
        stc_tmr6_perar_field_t PERAR_f;
    };
    union
    {
        __IO uint32_t PERBR;
        stc_tmr6_perbr_field_t PERBR_f;
    };
    union
    {
        __IO uint32_t PERCR;
        stc_tmr6_percr_field_t PERCR_f;
    };
    union
    {
        __IO uint32_t GCMAR;
        stc_tmr6_gcmar_field_t GCMAR_f;
    };
    union
    {
        __IO uint32_t GCMBR;
        stc_tmr6_gcmbr_field_t GCMBR_f;
    };
    union
    {
        __IO uint32_t GCMCR;
        stc_tmr6_gcmcr_field_t GCMCR_f;
    };
    union
    {
        __IO uint32_t GCMDR;
        stc_tmr6_gcmdr_field_t GCMDR_f;
    };
    union
    {
        __IO uint32_t GCMER;
        stc_tmr6_gcmer_field_t GCMER_f;
    };
    union
    {
        __IO uint32_t GCMFR;
        stc_tmr6_gcmfr_field_t GCMFR_f;
    };
    union
    {
        __IO uint32_t SCMAR;
        stc_tmr6_scmar_field_t SCMAR_f;
    };
    union
    {
        __IO uint32_t SCMBR;
        stc_tmr6_scmbr_field_t SCMBR_f;
    };
    union
    {
        __IO uint32_t SCMCR;
        stc_tmr6_scmcr_field_t SCMCR_f;
    };
    union
    {
        __IO uint32_t SCMDR;
        stc_tmr6_scmdr_field_t SCMDR_f;
    };
    union
    {
        __IO uint32_t SCMER;
        stc_tmr6_scmer_field_t SCMER_f;
    };
    union
    {
        __IO uint32_t SCMFR;
        stc_tmr6_scmfr_field_t SCMFR_f;
    };
    union
    {
        __IO uint32_t DTUAR;
        stc_tmr6_dtuar_field_t DTUAR_f;
    };
    union
    {
        __IO uint32_t DTDAR;
        stc_tmr6_dtdar_field_t DTDAR_f;
    };
    union
    {
        __IO uint32_t DTUBR;
        stc_tmr6_dtubr_field_t DTUBR_f;
    };
    union
    {
        __IO uint32_t DTDBR;
        stc_tmr6_dtdbr_field_t DTDBR_f;
    };
    union
    {
        __IO uint32_t GCONR;
        stc_tmr6_gconr_field_t GCONR_f;
    };
    union
    {
        __IO uint32_t ICONR;
        stc_tmr6_iconr_field_t ICONR_f;
    };
    union
    {
        __IO uint32_t PCONR;
        stc_tmr6_pconr_field_t PCONR_f;
    };
    union
    {
        __IO uint32_t BCONR;
        stc_tmr6_bconr_field_t BCONR_f;
    };
    union
    {
        __IO uint32_t DCONR;
        stc_tmr6_dconr_field_t DCONR_f;
    };
    uint8_t RESERVED0[4];
    union
    {
        __IO uint32_t FCONR;
        stc_tmr6_fconr_field_t FCONR_f;
    };
    union
    {
        __IO uint32_t VPERR;
        stc_tmr6_vperr_field_t VPERR_f;
    };
    union
    {
        __IO uint32_t STFLR;
        stc_tmr6_stflr_field_t STFLR_f;
    };
    union
    {
        __IO uint32_t HSTAR;
        stc_tmr6_hstar_field_t HSTAR_f;
    };
    union
    {
        __IO uint32_t HSTPR;
        stc_tmr6_hstpr_field_t HSTPR_f;
    };
    union
    {
        __IO uint32_t HCLRR;
        stc_tmr6_hclrr_field_t HCLRR_f;
    };
    union
    {
        __IO uint32_t HCPAR;
        stc_tmr6_hcpar_field_t HCPAR_f;
    };
    union
    {
        __IO uint32_t HCPBR;
        stc_tmr6_hcpbr_field_t HCPBR_f;
    };
    union
    {
        __IO uint32_t HCUPR;
        stc_tmr6_hcupr_field_t HCUPR_f;
    };
    union
    {
        __IO uint32_t HCDOR;
        stc_tmr6_hcdor_field_t HCDOR_f;
    };
} M4_TMR6_TypeDef;

/**
 * @brief TMR6_CR
 */
typedef struct
{
    uint8_t RESERVED0[1012];
    union
    {
        __IO uint32_t SSTAR;
        stc_tmr6_cr_sstar_field_t SSTAR_f;
    };
    union
    {
        __IO uint32_t SSTPR;
        stc_tmr6_cr_sstpr_field_t SSTPR_f;
    };
    union
    {
        __IO uint32_t SCLRR;
        stc_tmr6_cr_sclrr_field_t SCLRR_f;
    };
} M4_TMR6_CR_TypeDef;

/**
 * @brief TMRA
 */
typedef struct
{
    union
    {
        __IO uint16_t CNTER;
        stc_tmra_cnter_field_t CNTER_f;
    };
    uint8_t RESERVED0[2];
    union
    {
        __IO uint16_t PERAR;
        stc_tmra_perar_field_t PERAR_f;
    };
    uint8_t RESERVED1[58];
    union
    {
        __IO uint16_t CMPAR1;
        stc_tmra_cmpar_field_t CMPAR1_f;
    };
    uint8_t RESERVED2[2];
    union
    {
        __IO uint16_t CMPAR2;
        stc_tmra_cmpar_field_t CMPAR2_f;
    };
    uint8_t RESERVED3[2];
    union
    {
        __IO uint16_t CMPAR3;
        stc_tmra_cmpar_field_t CMPAR3_f;
    };
    uint8_t RESERVED4[2];
    union
    {
        __IO uint16_t CMPAR4;
        stc_tmra_cmpar_field_t CMPAR4_f;
    };
    uint8_t RESERVED5[2];
    union
    {
        __IO uint16_t CMPAR5;
        stc_tmra_cmpar_field_t CMPAR5_f;
    };
    uint8_t RESERVED6[2];
    union
    {
        __IO uint16_t CMPAR6;
        stc_tmra_cmpar_field_t CMPAR6_f;
    };
    uint8_t RESERVED7[2];
    union
    {
        __IO uint16_t CMPAR7;
        stc_tmra_cmpar_field_t CMPAR7_f;
    };
    uint8_t RESERVED8[2];
    union
    {
        __IO uint16_t CMPAR8;
        stc_tmra_cmpar_field_t CMPAR8_f;
    };
    uint8_t RESERVED9[34];
    union
    {
        __IO uint16_t BCSTR;
        stc_tmra_bcstr_field_t BCSTR_f;
    };
    uint8_t RESERVED10[2];
    union
    {
        __IO uint16_t HCONR;
        stc_tmra_hconr_field_t HCONR_f;
    };
    uint8_t RESERVED11[2];
    union
    {
        __IO uint16_t HCUPR;
        stc_tmra_hcupr_field_t HCUPR_f;
    };
    uint8_t RESERVED12[2];
    union
    {
        __IO uint16_t HCDOR;
        stc_tmra_hcdor_field_t HCDOR_f;
    };
    uint8_t RESERVED13[2];
    union
    {
        __IO uint16_t ICONR;
        stc_tmra_iconr_field_t ICONR_f;
    };
    uint8_t RESERVED14[2];
    union
    {
        __IO uint16_t ECONR;
        stc_tmra_econr_field_t ECONR_f;
    };
    uint8_t RESERVED15[2];
    union
    {
        __IO uint16_t FCONR;
        stc_tmra_fconr_field_t FCONR_f;
    };
    uint8_t RESERVED16[2];
    union
    {
        __IO uint16_t STFLR;
        stc_tmra_stflr_field_t STFLR_f;
    };
    uint8_t RESERVED17[34];
    union
    {
        __IO uint16_t BCONR1;
        stc_tmra_bconr_field_t BCONR1_f;
    };
    uint8_t RESERVED18[6];
    union
    {
        __IO uint16_t BCONR2;
        stc_tmra_bconr_field_t BCONR2_f;
    };
    uint8_t RESERVED19[6];
    union
    {
        __IO uint16_t BCONR3;
        stc_tmra_bconr_field_t BCONR3_f;
    };
    uint8_t RESERVED20[6];
    union
    {
        __IO uint16_t BCONR4;
        stc_tmra_bconr_field_t BCONR4_f;
    };
    uint8_t RESERVED21[38];
    union
    {
        __IO uint16_t CCONR1;
        stc_tmra_cconr_field_t CCONR1_f;
    };
    uint8_t RESERVED22[2];
    union
    {
        __IO uint16_t CCONR2;
        stc_tmra_cconr_field_t CCONR2_f;
    };
    uint8_t RESERVED23[2];
    union
    {
        __IO uint16_t CCONR3;
        stc_tmra_cconr_field_t CCONR3_f;
    };
    uint8_t RESERVED24[2];
    union
    {
        __IO uint16_t CCONR4;
        stc_tmra_cconr_field_t CCONR4_f;
    };
    uint8_t RESERVED25[2];
    union
    {
        __IO uint16_t CCONR5;
        stc_tmra_cconr_field_t CCONR5_f;
    };
    uint8_t RESERVED26[2];
    union
    {
        __IO uint16_t CCONR6;
        stc_tmra_cconr_field_t CCONR6_f;
    };
    uint8_t RESERVED27[2];
    union
    {
        __IO uint16_t CCONR7;
        stc_tmra_cconr_field_t CCONR7_f;
    };
    uint8_t RESERVED28[2];
    union
    {
        __IO uint16_t CCONR8;
        stc_tmra_cconr_field_t CCONR8_f;
    };
    uint8_t RESERVED29[34];
    union
    {
        __IO uint16_t PCONR1;
        stc_tmra_pconr_field_t PCONR1_f;
    };
    uint8_t RESERVED30[2];
    union
    {
        __IO uint16_t PCONR2;
        stc_tmra_pconr_field_t PCONR2_f;
    };
    uint8_t RESERVED31[2];
    union
    {
        __IO uint16_t PCONR3;
        stc_tmra_pconr_field_t PCONR3_f;
    };
    uint8_t RESERVED32[2];
    union
    {
        __IO uint16_t PCONR4;
        stc_tmra_pconr_field_t PCONR4_f;
    };
    uint8_t RESERVED33[2];
    union
    {
        __IO uint16_t PCONR5;
        stc_tmra_pconr_field_t PCONR5_f;
    };
    uint8_t RESERVED34[2];
    union
    {
        __IO uint16_t PCONR6;
        stc_tmra_pconr_field_t PCONR6_f;
    };
    uint8_t RESERVED35[2];
    union
    {
        __IO uint16_t PCONR7;
        stc_tmra_pconr_field_t PCONR7_f;
    };
    uint8_t RESERVED36[2];
    union
    {
        __IO uint16_t PCONR8;
        stc_tmra_pconr_field_t PCONR8_f;
    };
} M4_TMRA_TypeDef;

/**
 * @brief TRNG
 */
typedef struct
{
    union
    {
        __IO uint32_t CR;
        stc_trng_cr_field_t CR_f;
    };
    union
    {
        __IO uint32_t MR;
        stc_trng_mr_field_t MR_f;
    };
    uint8_t RESERVED0[4];
    __IO uint32_t DR0;
    __IO uint32_t DR1;
} M4_TRNG_TypeDef;

/**
 * @brief USART
 */
typedef struct
{
    union
    {
        __IO uint32_t SR;
        stc_usart_sr_field_t SR_f;
    };
    union
    {
        __IO uint32_t DR;
        stc_usart_dr_field_t DR_f;
    };
    union
    {
        __IO uint32_t BRR;
        stc_usart_brr_field_t BRR_f;
    };
    union
    {
        __IO uint32_t CR1;
        stc_usart_cr1_field_t CR1_f;
    };
    union
    {
        __IO uint32_t CR2;
        stc_usart_cr2_field_t CR2_f;
    };
    union
    {
        __IO uint32_t CR3;
        stc_usart_cr3_field_t CR3_f;
    };
    union
    {
        __IO uint32_t PR;
        stc_usart_pr_field_t PR_f;
    };
} M4_USART_TypeDef;

/**
 * @brief USBFS
 */
typedef struct
{
    union
    {
        __IO uint32_t GVBUSCFG;
        stc_usbfs_gvbuscfg_field_t GVBUSCFG_f;
    };
    uint8_t RESERVED0[4];
    union
    {
        __IO uint32_t GAHBCFG;
        stc_usbfs_gahbcfg_field_t GAHBCFG_f;
    };
    union
    {
        __IO uint32_t GUSBCFG;
        stc_usbfs_gusbcfg_field_t GUSBCFG_f;
    };
    union
    {
        __IO uint32_t GRSTCTL;
        stc_usbfs_grstctl_field_t GRSTCTL_f;
    };
    union
    {
        __IO uint32_t GINTSTS;
        stc_usbfs_gintsts_field_t GINTSTS_f;
    };
    union
    {
        __IO uint32_t GINTMSK;
        stc_usbfs_gintmsk_field_t GINTMSK_f;
    };
    union
    {
        __IO uint32_t GRXSTSR;
        stc_usbfs_grxstsr_field_t GRXSTSR_f;
    };
    union
    {
        __IO uint32_t GRXSTSP;
        stc_usbfs_grxstsp_field_t GRXSTSP_f;
    };
    union
    {
        __IO uint32_t GRXFSIZ;
        stc_usbfs_grxfsiz_field_t GRXFSIZ_f;
    };
    union
    {
        __IO uint32_t HNPTXFSIZ;
        stc_usbfs_hnptxfsiz_field_t HNPTXFSIZ_f;
    };
    union
    {
        __IO uint32_t HNPTXSTS;
        stc_usbfs_hnptxsts_field_t HNPTXSTS_f;
    };
    uint8_t RESERVED1[12];
    __IO uint32_t CID;
    uint8_t RESERVED2[192];
    union
    {
        __IO uint32_t HPTXFSIZ;
        stc_usbfs_hptxfsiz_field_t HPTXFSIZ_f;
    };
    union
    {
        __IO uint32_t DIEPTXF1;
        stc_usbfs_dieptxf_field_t DIEPTXF1_f;
    };
    union
    {
        __IO uint32_t DIEPTXF2;
        stc_usbfs_dieptxf_field_t DIEPTXF2_f;
    };
    union
    {
        __IO uint32_t DIEPTXF3;
        stc_usbfs_dieptxf_field_t DIEPTXF3_f;
    };
    union
    {
        __IO uint32_t DIEPTXF4;
        stc_usbfs_dieptxf_field_t DIEPTXF4_f;
    };
    union
    {
        __IO uint32_t DIEPTXF5;
        stc_usbfs_dieptxf_field_t DIEPTXF5_f;
    };
    uint8_t RESERVED3[744];
    union
    {
        __IO uint32_t HCFG;
        stc_usbfs_hcfg_field_t HCFG_f;
    };
    union
    {
        __IO uint32_t HFIR;
        stc_usbfs_hfir_field_t HFIR_f;
    };
    union
    {
        __IO uint32_t HFNUM;
        stc_usbfs_hfnum_field_t HFNUM_f;
    };
    uint8_t RESERVED4[4];
    union
    {
        __IO uint32_t HPTXSTS;
        stc_usbfs_hptxsts_field_t HPTXSTS_f;
    };
    union
    {
        __IO uint32_t HAINT;
        stc_usbfs_haint_field_t HAINT_f;
    };
    union
    {
        __IO uint32_t HAINTMSK;
        stc_usbfs_haintmsk_field_t HAINTMSK_f;
    };
    uint8_t RESERVED5[36];
    union
    {
        __IO uint32_t HPRT;
        stc_usbfs_hprt_field_t HPRT_f;
    };
    uint8_t RESERVED6[188];
    union
    {
        __IO uint32_t HCCHAR0;
        stc_usbfs_hcchar_field_t HCCHAR0_f;
    };
    uint8_t RESERVED7[4];
    union
    {
        __IO uint32_t HCINT0;
        stc_usbfs_hcint_field_t HCINT0_f;
    };
    union
    {
        __IO uint32_t HCINTMSK0;
        stc_usbfs_hcintmsk_field_t HCINTMSK0_f;
    };
    union
    {
        __IO uint32_t HCTSIZ0;
        stc_usbfs_hctsiz_field_t HCTSIZ0_f;
    };
    __IO uint32_t HCDMA0;
    uint8_t RESERVED8[8];
    union
    {
        __IO uint32_t HCCHAR1;
        stc_usbfs_hcchar_field_t HCCHAR1_f;
    };
    uint8_t RESERVED9[4];
    union
    {
        __IO uint32_t HCINT1;
        stc_usbfs_hcint_field_t HCINT1_f;
    };
    union
    {
        __IO uint32_t HCINTMSK1;
        stc_usbfs_hcintmsk_field_t HCINTMSK1_f;
    };
    union
    {
        __IO uint32_t HCTSIZ1;
        stc_usbfs_hctsiz_field_t HCTSIZ1_f;
    };
    __IO uint32_t HCDMA1;
    uint8_t RESERVED10[8];
    union
    {
        __IO uint32_t HCCHAR2;
        stc_usbfs_hcchar_field_t HCCHAR2_f;
    };
    uint8_t RESERVED11[4];
    union
    {
        __IO uint32_t HCINT2;
        stc_usbfs_hcint_field_t HCINT2_f;
    };
    union
    {
        __IO uint32_t HCINTMSK2;
        stc_usbfs_hcintmsk_field_t HCINTMSK2_f;
    };
    union
    {
        __IO uint32_t HCTSIZ2;
        stc_usbfs_hctsiz_field_t HCTSIZ2_f;
    };
    __IO uint32_t HCDMA2;
    uint8_t RESERVED12[8];
    union
    {
        __IO uint32_t HCCHAR3;
        stc_usbfs_hcchar_field_t HCCHAR3_f;
    };
    uint8_t RESERVED13[4];
    union
    {
        __IO uint32_t HCINT3;
        stc_usbfs_hcint_field_t HCINT3_f;
    };
    union
    {
        __IO uint32_t HCINTMSK3;
        stc_usbfs_hcintmsk_field_t HCINTMSK3_f;
    };
    union
    {
        __IO uint32_t HCTSIZ3;
        stc_usbfs_hctsiz_field_t HCTSIZ3_f;
    };
    __IO uint32_t HCDMA3;
    uint8_t RESERVED14[8];
    union
    {
        __IO uint32_t HCCHAR4;
        stc_usbfs_hcchar_field_t HCCHAR4_f;
    };
    uint8_t RESERVED15[4];
    union
    {
        __IO uint32_t HCINT4;
        stc_usbfs_hcint_field_t HCINT4_f;
    };
    union
    {
        __IO uint32_t HCINTMSK4;
        stc_usbfs_hcintmsk_field_t HCINTMSK4_f;
    };
    union
    {
        __IO uint32_t HCTSIZ4;
        stc_usbfs_hctsiz_field_t HCTSIZ4_f;
    };
    __IO uint32_t HCDMA4;
    uint8_t RESERVED16[8];
    union
    {
        __IO uint32_t HCCHAR5;
        stc_usbfs_hcchar_field_t HCCHAR5_f;
    };
    uint8_t RESERVED17[4];
    union
    {
        __IO uint32_t HCINT5;
        stc_usbfs_hcint_field_t HCINT5_f;
    };
    union
    {
        __IO uint32_t HCINTMSK5;
        stc_usbfs_hcintmsk_field_t HCINTMSK5_f;
    };
    union
    {
        __IO uint32_t HCTSIZ5;
        stc_usbfs_hctsiz_field_t HCTSIZ5_f;
    };
    __IO uint32_t HCDMA5;
    uint8_t RESERVED18[8];
    union
    {
        __IO uint32_t HCCHAR6;
        stc_usbfs_hcchar_field_t HCCHAR6_f;
    };
    uint8_t RESERVED19[4];
    union
    {
        __IO uint32_t HCINT6;
        stc_usbfs_hcint_field_t HCINT6_f;
    };
    union
    {
        __IO uint32_t HCINTMSK6;
        stc_usbfs_hcintmsk_field_t HCINTMSK6_f;
    };
    union
    {
        __IO uint32_t HCTSIZ6;
        stc_usbfs_hctsiz_field_t HCTSIZ6_f;
    };
    __IO uint32_t HCDMA6;
    uint8_t RESERVED20[8];
    union
    {
        __IO uint32_t HCCHAR7;
        stc_usbfs_hcchar_field_t HCCHAR7_f;
    };
    uint8_t RESERVED21[4];
    union
    {
        __IO uint32_t HCINT7;
        stc_usbfs_hcint_field_t HCINT7_f;
    };
    union
    {
        __IO uint32_t HCINTMSK7;
        stc_usbfs_hcintmsk_field_t HCINTMSK7_f;
    };
    union
    {
        __IO uint32_t HCTSIZ7;
        stc_usbfs_hctsiz_field_t HCTSIZ7_f;
    };
    __IO uint32_t HCDMA7;
    uint8_t RESERVED22[8];
    union
    {
        __IO uint32_t HCCHAR8;
        stc_usbfs_hcchar_field_t HCCHAR8_f;
    };
    uint8_t RESERVED23[4];
    union
    {
        __IO uint32_t HCINT8;
        stc_usbfs_hcint_field_t HCINT8_f;
    };
    union
    {
        __IO uint32_t HCINTMSK8;
        stc_usbfs_hcintmsk_field_t HCINTMSK8_f;
    };
    union
    {
        __IO uint32_t HCTSIZ8;
        stc_usbfs_hctsiz_field_t HCTSIZ8_f;
    };
    __IO uint32_t HCDMA8;
    uint8_t RESERVED24[8];
    union
    {
        __IO uint32_t HCCHAR9;
        stc_usbfs_hcchar_field_t HCCHAR9_f;
    };
    uint8_t RESERVED25[4];
    union
    {
        __IO uint32_t HCINT9;
        stc_usbfs_hcint_field_t HCINT9_f;
    };
    union
    {
        __IO uint32_t HCINTMSK9;
        stc_usbfs_hcintmsk_field_t HCINTMSK9_f;
    };
    union
    {
        __IO uint32_t HCTSIZ9;
        stc_usbfs_hctsiz_field_t HCTSIZ9_f;
    };
    __IO uint32_t HCDMA9;
    uint8_t RESERVED26[8];
    union
    {
        __IO uint32_t HCCHAR10;
        stc_usbfs_hcchar_field_t HCCHAR10_f;
    };
    uint8_t RESERVED27[4];
    union
    {
        __IO uint32_t HCINT10;
        stc_usbfs_hcint_field_t HCINT10_f;
    };
    union
    {
        __IO uint32_t HCINTMSK10;
        stc_usbfs_hcintmsk_field_t HCINTMSK10_f;
    };
    union
    {
        __IO uint32_t HCTSIZ10;
        stc_usbfs_hctsiz_field_t HCTSIZ10_f;
    };
    __IO uint32_t HCDMA10;
    uint8_t RESERVED28[8];
    union
    {
        __IO uint32_t HCCHAR11;
        stc_usbfs_hcchar_field_t HCCHAR11_f;
    };
    uint8_t RESERVED29[4];
    union
    {
        __IO uint32_t HCINT11;
        stc_usbfs_hcint_field_t HCINT11_f;
    };
    union
    {
        __IO uint32_t HCINTMSK11;
        stc_usbfs_hcintmsk_field_t HCINTMSK11_f;
    };
    union
    {
        __IO uint32_t HCTSIZ11;
        stc_usbfs_hctsiz_field_t HCTSIZ11_f;
    };
    __IO uint32_t HCDMA11;
    uint8_t RESERVED30[392];
    union
    {
        __IO uint32_t DCFG;
        stc_usbfs_dcfg_field_t DCFG_f;
    };
    union
    {
        __IO uint32_t DCTL;
        stc_usbfs_dctl_field_t DCTL_f;
    };
    union
    {
        __IO uint32_t DSTS;
        stc_usbfs_dsts_field_t DSTS_f;
    };
    uint8_t RESERVED31[4];
    union
    {
        __IO uint32_t DIEPMSK;
        stc_usbfs_diepmsk_field_t DIEPMSK_f;
    };
    union
    {
        __IO uint32_t DOEPMSK;
        stc_usbfs_doepmsk_field_t DOEPMSK_f;
    };
    union
    {
        __IO uint32_t DAINT;
        stc_usbfs_daint_field_t DAINT_f;
    };
    union
    {
        __IO uint32_t DAINTMSK;
        stc_usbfs_daintmsk_field_t DAINTMSK_f;
    };
    uint8_t RESERVED32[20];
    union
    {
        __IO uint32_t DIEPEMPMSK;
        stc_usbfs_diepempmsk_field_t DIEPEMPMSK_f;
    };
    uint8_t RESERVED33[200];
    union
    {
        __IO uint32_t DIEPCTL0;
        stc_usbfs_diepctl0_field_t DIEPCTL0_f;
    };
    uint8_t RESERVED34[4];
    union
    {
        __IO uint32_t DIEPINT0;
        stc_usbfs_diepint0_field_t DIEPINT0_f;
    };
    uint8_t RESERVED35[4];
    union
    {
        __IO uint32_t DIEPTSIZ0;
        stc_usbfs_dieptsiz0_field_t DIEPTSIZ0_f;
    };
    __IO uint32_t DIEPDMA0;
    union
    {
        __IO uint32_t DTXFSTS0;
        stc_usbfs_dtxfsts0_field_t DTXFSTS0_f;
    };
    uint8_t RESERVED36[4];
    union
    {
        __IO uint32_t DIEPCTL1;
        stc_usbfs_diepctl_field_t DIEPCTL1_f;
    };
    uint8_t RESERVED37[4];
    union
    {
        __IO uint32_t DIEPINT1;
        stc_usbfs_diepint_field_t DIEPINT1_f;
    };
    uint8_t RESERVED38[4];
    union
    {
        __IO uint32_t DIEPTSIZ1;
        stc_usbfs_dieptsiz_field_t DIEPTSIZ1_f;
    };
    __IO uint32_t DIEPDMA1;
    union
    {
        __IO uint32_t DTXFSTS1;
        stc_usbfs_dtxfsts_field_t DTXFSTS1_f;
    };
    uint8_t RESERVED39[4];
    union
    {
        __IO uint32_t DIEPCTL2;
        stc_usbfs_diepctl_field_t DIEPCTL2_f;
    };
    uint8_t RESERVED40[4];
    union
    {
        __IO uint32_t DIEPINT2;
        stc_usbfs_diepint_field_t DIEPINT2_f;
    };
    uint8_t RESERVED41[4];
    union
    {
        __IO uint32_t DIEPTSIZ2;
        stc_usbfs_dieptsiz_field_t DIEPTSIZ2_f;
    };
    __IO uint32_t DIEPDMA2;
    union
    {
        __IO uint32_t DTXFSTS2;
        stc_usbfs_dtxfsts_field_t DTXFSTS2_f;
    };
    uint8_t RESERVED42[4];
    union
    {
        __IO uint32_t DIEPCTL3;
        stc_usbfs_diepctl_field_t DIEPCTL3_f;
    };
    uint8_t RESERVED43[4];
    union
    {
        __IO uint32_t DIEPINT3;
        stc_usbfs_diepint_field_t DIEPINT3_f;
    };
    uint8_t RESERVED44[4];
    union
    {
        __IO uint32_t DIEPTSIZ3;
        stc_usbfs_dieptsiz_field_t DIEPTSIZ3_f;
    };
    __IO uint32_t DIEPDMA3;
    union
    {
        __IO uint32_t DTXFSTS3;
        stc_usbfs_dtxfsts_field_t DTXFSTS3_f;
    };
    uint8_t RESERVED45[4];
    union
    {
        __IO uint32_t DIEPCTL4;
        stc_usbfs_diepctl_field_t DIEPCTL4_f;
    };
    uint8_t RESERVED46[4];
    union
    {
        __IO uint32_t DIEPINT4;
        stc_usbfs_diepint_field_t DIEPINT4_f;
    };
    uint8_t RESERVED47[4];
    union
    {
        __IO uint32_t DIEPTSIZ4;
        stc_usbfs_dieptsiz_field_t DIEPTSIZ4_f;
    };
    __IO uint32_t DIEPDMA4;
    union
    {
        __IO uint32_t DTXFSTS4;
        stc_usbfs_dtxfsts_field_t DTXFSTS4_f;
    };
    uint8_t RESERVED48[4];
    union
    {
        __IO uint32_t DIEPCTL5;
        stc_usbfs_diepctl_field_t DIEPCTL5_f;
    };
    uint8_t RESERVED49[4];
    union
    {
        __IO uint32_t DIEPINT5;
        stc_usbfs_diepint_field_t DIEPINT5_f;
    };
    uint8_t RESERVED50[4];
    union
    {
        __IO uint32_t DIEPTSIZ5;
        stc_usbfs_dieptsiz_field_t DIEPTSIZ5_f;
    };
    __IO uint32_t DIEPDMA5;
    union
    {
        __IO uint32_t DTXFSTS5;
        stc_usbfs_dtxfsts_field_t DTXFSTS5_f;
    };
    uint8_t RESERVED51[324];
    union
    {
        __IO uint32_t DOEPCTL0;
        stc_usbfs_doepctl0_field_t DOEPCTL0_f;
    };
    uint8_t RESERVED52[4];
    union
    {
        __IO uint32_t DOEPINT0;
        stc_usbfs_doepint_field_t DOEPINT0_f;
    };
    uint8_t RESERVED53[4];
    union
    {
        __IO uint32_t DOEPTSIZ0;
        stc_usbfs_doeptsiz0_field_t DOEPTSIZ0_f;
    };
    __IO uint32_t DOEPDMA0;
    uint8_t RESERVED54[8];
    union
    {
        __IO uint32_t DOEPCTL1;
        stc_usbfs_doepctl_field_t DOEPCTL1_f;
    };
    uint8_t RESERVED55[4];
    union
    {
        __IO uint32_t DOEPINT1;
        stc_usbfs_doepint_field_t DOEPINT1_f;
    };
    uint8_t RESERVED56[4];
    union
    {
        __IO uint32_t DOEPTSIZ1;
        stc_usbfs_doeptsiz_field_t DOEPTSIZ1_f;
    };
    __IO uint32_t DOEPDMA1;
    uint8_t RESERVED57[8];
    union
    {
        __IO uint32_t DOEPCTL2;
        stc_usbfs_doepctl_field_t DOEPCTL2_f;
    };
    uint8_t RESERVED58[4];
    union
    {
        __IO uint32_t DOEPINT2;
        stc_usbfs_doepint_field_t DOEPINT2_f;
    };
    uint8_t RESERVED59[4];
    union
    {
        __IO uint32_t DOEPTSIZ2;
        stc_usbfs_doeptsiz_field_t DOEPTSIZ2_f;
    };
    __IO uint32_t DOEPDMA2;
    uint8_t RESERVED60[8];
    union
    {
        __IO uint32_t DOEPCTL3;
        stc_usbfs_doepctl_field_t DOEPCTL3_f;
    };
    uint8_t RESERVED61[4];
    union
    {
        __IO uint32_t DOEPINT3;
        stc_usbfs_doepint_field_t DOEPINT3_f;
    };
    uint8_t RESERVED62[4];
    union
    {
        __IO uint32_t DOEPTSIZ3;
        stc_usbfs_doeptsiz_field_t DOEPTSIZ3_f;
    };
    __IO uint32_t DOEPDMA3;
    uint8_t RESERVED63[8];
    union
    {
        __IO uint32_t DOEPCTL4;
        stc_usbfs_doepctl_field_t DOEPCTL4_f;
    };
    uint8_t RESERVED64[4];
    union
    {
        __IO uint32_t DOEPINT4;
        stc_usbfs_doepint_field_t DOEPINT4_f;
    };
    uint8_t RESERVED65[4];
    union
    {
        __IO uint32_t DOEPTSIZ4;
        stc_usbfs_doeptsiz_field_t DOEPTSIZ4_f;
    };
    __IO uint32_t DOEPDMA4;
    uint8_t RESERVED66[8];
    union
    {
        __IO uint32_t DOEPCTL5;
        stc_usbfs_doepctl_field_t DOEPCTL5_f;
    };
    uint8_t RESERVED67[4];
    union
    {
        __IO uint32_t DOEPINT5;
        stc_usbfs_doepint_field_t DOEPINT5_f;
    };
    uint8_t RESERVED68[4];
    union
    {
        __IO uint32_t DOEPTSIZ5;
        stc_usbfs_doeptsiz_field_t DOEPTSIZ5_f;
    };
    __IO uint32_t DOEPDMA5;
    uint8_t RESERVED69[584];
    union
    {
        __IO uint32_t PCGCCTL;
        stc_usbfs_pcgcctl_field_t PCGCCTL_f;
    };
} M4_USBFS_TypeDef;

/**
 * @brief WDT
 */
typedef struct
{
    union
    {
        __IO uint32_t CR;
        stc_wdt_cr_field_t CR_f;
    };
    union
    {
        __IO uint32_t SR;
        stc_wdt_sr_field_t SR_f;
    };
    union
    {
        __IO uint32_t RR;
        stc_wdt_rr_field_t RR_f;
    };
} M4_WDT_TypeDef;

/**
 * @brief WKTM
 */
typedef struct
{
    union
    {
        __IO uint16_t CR;
        stc_wktm_cr_field_t CR_f;
    };
} M4_WKTM_TypeDef;



/******************************************************************************/
/*           Device Specific Peripheral declaration & memory map              */
/******************************************************************************/

#define M4_ADC1                              ((M4_ADC_TypeDef *)0x40040000UL)
#define M4_ADC2                              ((M4_ADC_TypeDef *)0x40040400UL)
#define M4_AES                               ((M4_AES_TypeDef *)0x40008000UL)
#define M4_AOS                               ((M4_AOS_TypeDef *)0x40010800UL)
#define M4_CAN                               ((M4_CAN_TypeDef *)0x40070400UL)
#define M4_CMP1                              ((M4_CMP_TypeDef *)0x4004A000UL)
#define M4_CMP2                              ((M4_CMP_TypeDef *)0x4004A010UL)
#define M4_CMP3                              ((M4_CMP_TypeDef *)0x4004A020UL)
#define M4_CMP_CR                            ((M4_CMP_CR_TypeDef *)0x4004A000UL)
#define M4_CRC                               ((M4_CRC_TypeDef *)0x40008C00UL)
#define M4_DBGC                              ((M4_DBGC_TypeDef *)0xE0042000UL)
#define M4_DCU1                              ((M4_DCU_TypeDef *)0x40052000UL)
#define M4_DCU2                              ((M4_DCU_TypeDef *)0x40052400UL)
#define M4_DCU3                              ((M4_DCU_TypeDef *)0x40052800UL)
#define M4_DCU4                              ((M4_DCU_TypeDef *)0x40052C00UL)
#define M4_DMA1                              ((M4_DMA_TypeDef *)0x40053000UL)
#define M4_DMA2                              ((M4_DMA_TypeDef *)0x40053400UL)
#define M4_EFM                               ((M4_EFM_TypeDef *)0x40010400UL)
#define M4_EMB1                              ((M4_EMB_TypeDef *)0x40017C00UL)
#define M4_EMB2                              ((M4_EMB_TypeDef *)0x40017C20UL)
#define M4_EMB3                              ((M4_EMB_TypeDef *)0x40017C40UL)
#define M4_EMB4                              ((M4_EMB_TypeDef *)0x40017C60UL)
#define M4_FCM                               ((M4_FCM_TypeDef *)0x40048400UL)
#define M4_HASH                              ((M4_HASH_TypeDef *)0x40008400UL)
#define M4_I2C1                              ((M4_I2C_TypeDef *)0x4004E000UL)
#define M4_I2C2                              ((M4_I2C_TypeDef *)0x4004E400UL)
#define M4_I2C3                              ((M4_I2C_TypeDef *)0x4004E800UL)
#define M4_I2S1                              ((M4_I2S_TypeDef *)0x4001E000UL)
#define M4_I2S2                              ((M4_I2S_TypeDef *)0x4001E400UL)
#define M4_I2S3                              ((M4_I2S_TypeDef *)0x40022000UL)
#define M4_I2S4                              ((M4_I2S_TypeDef *)0x40022400UL)
#define M4_ICG                               ((M4_ICG_TypeDef *)0x00000400UL)
#define M4_INTC                              ((M4_INTC_TypeDef *)0x40051000UL)
#define M4_KEYSCAN                           ((M4_KEYSCAN_TypeDef *)0x40050C00UL)
#define M4_MPU                               ((M4_MPU_TypeDef *)0x40050000UL)
#define M4_MSTP                              ((M4_MSTP_TypeDef *)0x40048000UL)
#define M4_OTS                               ((M4_OTS_TypeDef *)0x4004A400UL)
#define M4_PERIC                             ((M4_PERIC_TypeDef *)0x40055400UL)
#define M4_PORT                              ((M4_PORT_TypeDef *)0x40053800UL)
#define M4_QSPI                              ((M4_QSPI_TypeDef *)0x9C000000UL)
#define M4_RTC                               ((M4_RTC_TypeDef *)0x4004C000UL)
#define M4_SDIOC1                            ((M4_SDIOC_TypeDef *)0x4006FC00UL)
#define M4_SDIOC2                            ((M4_SDIOC_TypeDef *)0x40070000UL)
#define M4_SPI1                              ((M4_SPI_TypeDef *)0x4001C000UL)
#define M4_SPI2                              ((M4_SPI_TypeDef *)0x4001C400UL)
#define M4_SPI3                              ((M4_SPI_TypeDef *)0x40020000UL)
#define M4_SPI4                              ((M4_SPI_TypeDef *)0x40020400UL)
#define M4_SRAMC                             ((M4_SRAMC_TypeDef *)0x40050800UL)
#define M4_SWDT                              ((M4_SWDT_TypeDef *)0x40049400UL)
#define M4_SYSREG                            ((M4_SYSREG_TypeDef *)0x40054000UL)
#define M4_TMR01                             ((M4_TMR0_TypeDef *)0x40024000UL)
#define M4_TMR02                             ((M4_TMR0_TypeDef *)0x40024400UL)
#define M4_TMR41                             ((M4_TMR4_TypeDef *)0x40017000UL)
#define M4_TMR42                             ((M4_TMR4_TypeDef *)0x40024800UL)
#define M4_TMR43                             ((M4_TMR4_TypeDef *)0x40024C00UL)
#define M4_TMR4_CR                           ((M4_TMR4_CR_TypeDef *)0x40055408UL)
#define M4_TMR61                             ((M4_TMR6_TypeDef *)0x40018000UL)
#define M4_TMR62                             ((M4_TMR6_TypeDef *)0x40018400UL)
#define M4_TMR63                             ((M4_TMR6_TypeDef *)0x40018800UL)
#define M4_TMR6_CR                           ((M4_TMR6_CR_TypeDef *)0x40018000UL)
#define M4_TMRA1                             ((M4_TMRA_TypeDef *)0x40015000UL)
#define M4_TMRA2                             ((M4_TMRA_TypeDef *)0x40015400UL)
#define M4_TMRA3                             ((M4_TMRA_TypeDef *)0x40015800UL)
#define M4_TMRA4                             ((M4_TMRA_TypeDef *)0x40015C00UL)
#define M4_TMRA5                             ((M4_TMRA_TypeDef *)0x40016000UL)
#define M4_TMRA6                             ((M4_TMRA_TypeDef *)0x40016400UL)
#define M4_TRNG                              ((M4_TRNG_TypeDef *)0x40041000UL)
#define M4_USART1                            ((M4_USART_TypeDef *)0x4001D000UL)
#define M4_USART2                            ((M4_USART_TypeDef *)0x4001D400UL)
#define M4_USART3                            ((M4_USART_TypeDef *)0x40021000UL)
#define M4_USART4                            ((M4_USART_TypeDef *)0x40021400UL)
#define M4_USBFS                             ((M4_USBFS_TypeDef *)0x400C0000UL)
#define M4_WDT                               ((M4_WDT_TypeDef *)0x40049000UL)
#define M4_WKTM                              ((M4_WKTM_TypeDef *)0x4004C400UL)


/******************************************************************************/
/*      Device Specific Peripheral bit_band declaration & memory map          */
/******************************************************************************/

#define bM4_ADC1_STR_STRT                         (*((volatile unsigned int*)(0x42800000UL)))
#define bM4_ADC1_CR0_MS0                          (*((volatile unsigned int*)(0x42800040UL)))
#define bM4_ADC1_CR0_MS1                          (*((volatile unsigned int*)(0x42800044UL)))
#define bM4_ADC1_CR0_ACCSEL0                      (*((volatile unsigned int*)(0x42800050UL)))
#define bM4_ADC1_CR0_ACCSEL1                      (*((volatile unsigned int*)(0x42800054UL)))
#define bM4_ADC1_CR0_CLREN                        (*((volatile unsigned int*)(0x42800058UL)))
#define bM4_ADC1_CR0_DFMT                         (*((volatile unsigned int*)(0x4280005CUL)))
#define bM4_ADC1_CR0_AVCNT0                       (*((volatile unsigned int*)(0x42800060UL)))
#define bM4_ADC1_CR0_AVCNT1                       (*((volatile unsigned int*)(0x42800064UL)))
#define bM4_ADC1_CR0_AVCNT2                       (*((volatile unsigned int*)(0x42800068UL)))
#define bM4_ADC1_CR1_RSCHSEL                      (*((volatile unsigned int*)(0x42800088UL)))
#define bM4_ADC1_TRGSR_TRGSELA0                   (*((volatile unsigned int*)(0x42800140UL)))
#define bM4_ADC1_TRGSR_TRGSELA1                   (*((volatile unsigned int*)(0x42800144UL)))
#define bM4_ADC1_TRGSR_TRGSELA2                   (*((volatile unsigned int*)(0x42800148UL)))
#define bM4_ADC1_TRGSR_TRGENA                     (*((volatile unsigned int*)(0x4280015CUL)))
#define bM4_ADC1_TRGSR_TRGSELB0                   (*((volatile unsigned int*)(0x42800160UL)))
#define bM4_ADC1_TRGSR_TRGSELB1                   (*((volatile unsigned int*)(0x42800164UL)))
#define bM4_ADC1_TRGSR_TRGSELB2                   (*((volatile unsigned int*)(0x42800168UL)))
#define bM4_ADC1_TRGSR_TRGENB                     (*((volatile unsigned int*)(0x4280017CUL)))
#define bM4_ADC1_CHSELRA1_CHSELA16                (*((volatile unsigned int*)(0x428001C0UL)))
#define bM4_ADC1_CHSELRB1_CHSELB16                (*((volatile unsigned int*)(0x42800240UL)))
#define bM4_ADC1_AVCHSELR1_AVCHSEL16              (*((volatile unsigned int*)(0x428002C0UL)))
#define bM4_ADC1_CHMUXR0_CH00MUX0                 (*((volatile unsigned int*)(0x42800700UL)))
#define bM4_ADC1_CHMUXR0_CH00MUX1                 (*((volatile unsigned int*)(0x42800704UL)))
#define bM4_ADC1_CHMUXR0_CH00MUX2                 (*((volatile unsigned int*)(0x42800708UL)))
#define bM4_ADC1_CHMUXR0_CH00MUX3                 (*((volatile unsigned int*)(0x4280070CUL)))
#define bM4_ADC1_CHMUXR0_CH01MUX0                 (*((volatile unsigned int*)(0x42800710UL)))
#define bM4_ADC1_CHMUXR0_CH01MUX1                 (*((volatile unsigned int*)(0x42800714UL)))
#define bM4_ADC1_CHMUXR0_CH01MUX2                 (*((volatile unsigned int*)(0x42800718UL)))
#define bM4_ADC1_CHMUXR0_CH01MUX3                 (*((volatile unsigned int*)(0x4280071CUL)))
#define bM4_ADC1_CHMUXR0_CH02MUX0                 (*((volatile unsigned int*)(0x42800720UL)))
#define bM4_ADC1_CHMUXR0_CH02MUX1                 (*((volatile unsigned int*)(0x42800724UL)))
#define bM4_ADC1_CHMUXR0_CH02MUX2                 (*((volatile unsigned int*)(0x42800728UL)))
#define bM4_ADC1_CHMUXR0_CH02MUX3                 (*((volatile unsigned int*)(0x4280072CUL)))
#define bM4_ADC1_CHMUXR0_CH03MUX0                 (*((volatile unsigned int*)(0x42800730UL)))
#define bM4_ADC1_CHMUXR0_CH03MUX1                 (*((volatile unsigned int*)(0x42800734UL)))
#define bM4_ADC1_CHMUXR0_CH03MUX2                 (*((volatile unsigned int*)(0x42800738UL)))
#define bM4_ADC1_CHMUXR0_CH03MUX3                 (*((volatile unsigned int*)(0x4280073CUL)))
#define bM4_ADC1_CHMUXR1_CH04MUX0                 (*((volatile unsigned int*)(0x42800740UL)))
#define bM4_ADC1_CHMUXR1_CH04MUX1                 (*((volatile unsigned int*)(0x42800744UL)))
#define bM4_ADC1_CHMUXR1_CH04MUX2                 (*((volatile unsigned int*)(0x42800748UL)))
#define bM4_ADC1_CHMUXR1_CH04MUX3                 (*((volatile unsigned int*)(0x4280074CUL)))
#define bM4_ADC1_CHMUXR1_CH05MUX0                 (*((volatile unsigned int*)(0x42800750UL)))
#define bM4_ADC1_CHMUXR1_CH05MUX1                 (*((volatile unsigned int*)(0x42800754UL)))
#define bM4_ADC1_CHMUXR1_CH05MUX2                 (*((volatile unsigned int*)(0x42800758UL)))
#define bM4_ADC1_CHMUXR1_CH05MUX3                 (*((volatile unsigned int*)(0x4280075CUL)))
#define bM4_ADC1_CHMUXR1_CH06MUX0                 (*((volatile unsigned int*)(0x42800760UL)))
#define bM4_ADC1_CHMUXR1_CH06MUX1                 (*((volatile unsigned int*)(0x42800764UL)))
#define bM4_ADC1_CHMUXR1_CH06MUX2                 (*((volatile unsigned int*)(0x42800768UL)))
#define bM4_ADC1_CHMUXR1_CH06MUX3                 (*((volatile unsigned int*)(0x4280076CUL)))
#define bM4_ADC1_CHMUXR1_CH07MUX0                 (*((volatile unsigned int*)(0x42800770UL)))
#define bM4_ADC1_CHMUXR1_CH07MUX1                 (*((volatile unsigned int*)(0x42800774UL)))
#define bM4_ADC1_CHMUXR1_CH07MUX2                 (*((volatile unsigned int*)(0x42800778UL)))
#define bM4_ADC1_CHMUXR1_CH07MUX3                 (*((volatile unsigned int*)(0x4280077CUL)))
#define bM4_ADC1_CHMUXR2_CH08MUX0                 (*((volatile unsigned int*)(0x42800780UL)))
#define bM4_ADC1_CHMUXR2_CH08MUX1                 (*((volatile unsigned int*)(0x42800784UL)))
#define bM4_ADC1_CHMUXR2_CH08MUX2                 (*((volatile unsigned int*)(0x42800788UL)))
#define bM4_ADC1_CHMUXR2_CH08MUX3                 (*((volatile unsigned int*)(0x4280078CUL)))
#define bM4_ADC1_CHMUXR2_CH09MUX0                 (*((volatile unsigned int*)(0x42800790UL)))
#define bM4_ADC1_CHMUXR2_CH09MUX1                 (*((volatile unsigned int*)(0x42800794UL)))
#define bM4_ADC1_CHMUXR2_CH09MUX2                 (*((volatile unsigned int*)(0x42800798UL)))
#define bM4_ADC1_CHMUXR2_CH09MUX3                 (*((volatile unsigned int*)(0x4280079CUL)))
#define bM4_ADC1_CHMUXR2_CH10MUX0                 (*((volatile unsigned int*)(0x428007A0UL)))
#define bM4_ADC1_CHMUXR2_CH10MUX1                 (*((volatile unsigned int*)(0x428007A4UL)))
#define bM4_ADC1_CHMUXR2_CH10MUX2                 (*((volatile unsigned int*)(0x428007A8UL)))
#define bM4_ADC1_CHMUXR2_CH10MUX3                 (*((volatile unsigned int*)(0x428007ACUL)))
#define bM4_ADC1_CHMUXR2_CH11MUX0                 (*((volatile unsigned int*)(0x428007B0UL)))
#define bM4_ADC1_CHMUXR2_CH11MUX1                 (*((volatile unsigned int*)(0x428007B4UL)))
#define bM4_ADC1_CHMUXR2_CH11MUX2                 (*((volatile unsigned int*)(0x428007B8UL)))
#define bM4_ADC1_CHMUXR2_CH11MUX3                 (*((volatile unsigned int*)(0x428007BCUL)))
#define bM4_ADC1_CHMUXR3_CH12MUX0                 (*((volatile unsigned int*)(0x428007C0UL)))
#define bM4_ADC1_CHMUXR3_CH12MUX1                 (*((volatile unsigned int*)(0x428007C4UL)))
#define bM4_ADC1_CHMUXR3_CH12MUX2                 (*((volatile unsigned int*)(0x428007C8UL)))
#define bM4_ADC1_CHMUXR3_CH12MUX3                 (*((volatile unsigned int*)(0x428007CCUL)))
#define bM4_ADC1_CHMUXR3_CH13MUX0                 (*((volatile unsigned int*)(0x428007D0UL)))
#define bM4_ADC1_CHMUXR3_CH13MUX1                 (*((volatile unsigned int*)(0x428007D4UL)))
#define bM4_ADC1_CHMUXR3_CH13MUX2                 (*((volatile unsigned int*)(0x428007D8UL)))
#define bM4_ADC1_CHMUXR3_CH13MUX3                 (*((volatile unsigned int*)(0x428007DCUL)))
#define bM4_ADC1_CHMUXR3_CH14MUX0                 (*((volatile unsigned int*)(0x428007E0UL)))
#define bM4_ADC1_CHMUXR3_CH14MUX1                 (*((volatile unsigned int*)(0x428007E4UL)))
#define bM4_ADC1_CHMUXR3_CH14MUX2                 (*((volatile unsigned int*)(0x428007E8UL)))
#define bM4_ADC1_CHMUXR3_CH14MUX3                 (*((volatile unsigned int*)(0x428007ECUL)))
#define bM4_ADC1_CHMUXR3_CH15MUX0                 (*((volatile unsigned int*)(0x428007F0UL)))
#define bM4_ADC1_CHMUXR3_CH15MUX1                 (*((volatile unsigned int*)(0x428007F4UL)))
#define bM4_ADC1_CHMUXR3_CH15MUX2                 (*((volatile unsigned int*)(0x428007F8UL)))
#define bM4_ADC1_CHMUXR3_CH15MUX3                 (*((volatile unsigned int*)(0x428007FCUL)))
#define bM4_ADC1_ISR_EOCAF                        (*((volatile unsigned int*)(0x428008C0UL)))
#define bM4_ADC1_ISR_EOCBF                        (*((volatile unsigned int*)(0x428008C4UL)))
#define bM4_ADC1_ICR_EOCAIEN                      (*((volatile unsigned int*)(0x428008E0UL)))
#define bM4_ADC1_ICR_EOCBIEN                      (*((volatile unsigned int*)(0x428008E4UL)))
#define bM4_ADC1_SYNCCR_SYNCEN                    (*((volatile unsigned int*)(0x42800980UL)))
#define bM4_ADC1_SYNCCR_SYNCMD0                   (*((volatile unsigned int*)(0x42800990UL)))
#define bM4_ADC1_SYNCCR_SYNCMD1                   (*((volatile unsigned int*)(0x42800994UL)))
#define bM4_ADC1_SYNCCR_SYNCMD2                   (*((volatile unsigned int*)(0x42800998UL)))
#define bM4_ADC1_SYNCCR_SYNCDLY0                  (*((volatile unsigned int*)(0x428009A0UL)))
#define bM4_ADC1_SYNCCR_SYNCDLY1                  (*((volatile unsigned int*)(0x428009A4UL)))
#define bM4_ADC1_SYNCCR_SYNCDLY2                  (*((volatile unsigned int*)(0x428009A8UL)))
#define bM4_ADC1_SYNCCR_SYNCDLY3                  (*((volatile unsigned int*)(0x428009ACUL)))
#define bM4_ADC1_SYNCCR_SYNCDLY4                  (*((volatile unsigned int*)(0x428009B0UL)))
#define bM4_ADC1_SYNCCR_SYNCDLY5                  (*((volatile unsigned int*)(0x428009B4UL)))
#define bM4_ADC1_SYNCCR_SYNCDLY6                  (*((volatile unsigned int*)(0x428009B8UL)))
#define bM4_ADC1_SYNCCR_SYNCDLY7                  (*((volatile unsigned int*)(0x428009BCUL)))
#define bM4_ADC1_AWDCR_AWDEN                      (*((volatile unsigned int*)(0x42801400UL)))
#define bM4_ADC1_AWDCR_AWDMD                      (*((volatile unsigned int*)(0x42801410UL)))
#define bM4_ADC1_AWDCR_AWDSS0                     (*((volatile unsigned int*)(0x42801418UL)))
#define bM4_ADC1_AWDCR_AWDSS1                     (*((volatile unsigned int*)(0x4280141CUL)))
#define bM4_ADC1_AWDCR_AWDIEN                     (*((volatile unsigned int*)(0x42801420UL)))
#define bM4_ADC1_AWDCHSR1_AWDCH16                 (*((volatile unsigned int*)(0x428015C0UL)))
#define bM4_ADC1_AWDSR1_AWDF16                    (*((volatile unsigned int*)(0x42801640UL)))
#define bM4_ADC1_PGACR_PGACTL0                    (*((volatile unsigned int*)(0x42801800UL)))
#define bM4_ADC1_PGACR_PGACTL1                    (*((volatile unsigned int*)(0x42801804UL)))
#define bM4_ADC1_PGACR_PGACTL2                    (*((volatile unsigned int*)(0x42801808UL)))
#define bM4_ADC1_PGACR_PGACTL3                    (*((volatile unsigned int*)(0x4280180CUL)))
#define bM4_ADC1_PGAGSR_GAIN0                     (*((volatile unsigned int*)(0x42801840UL)))
#define bM4_ADC1_PGAGSR_GAIN1                     (*((volatile unsigned int*)(0x42801844UL)))
#define bM4_ADC1_PGAGSR_GAIN2                     (*((volatile unsigned int*)(0x42801848UL)))
#define bM4_ADC1_PGAGSR_GAIN3                     (*((volatile unsigned int*)(0x4280184CUL)))
#define bM4_ADC1_PGAINSR0_PGAINSEL0               (*((volatile unsigned int*)(0x42801980UL)))
#define bM4_ADC1_PGAINSR0_PGAINSEL1               (*((volatile unsigned int*)(0x42801984UL)))
#define bM4_ADC1_PGAINSR0_PGAINSEL2               (*((volatile unsigned int*)(0x42801988UL)))
#define bM4_ADC1_PGAINSR0_PGAINSEL3               (*((volatile unsigned int*)(0x4280198CUL)))
#define bM4_ADC1_PGAINSR0_PGAINSEL4               (*((volatile unsigned int*)(0x42801990UL)))
#define bM4_ADC1_PGAINSR0_PGAINSEL5               (*((volatile unsigned int*)(0x42801994UL)))
#define bM4_ADC1_PGAINSR0_PGAINSEL6               (*((volatile unsigned int*)(0x42801998UL)))
#define bM4_ADC1_PGAINSR0_PGAINSEL7               (*((volatile unsigned int*)(0x4280199CUL)))
#define bM4_ADC1_PGAINSR0_PGAINSEL8               (*((volatile unsigned int*)(0x428019A0UL)))
#define bM4_ADC1_PGAINSR1_PGAVSSEN                (*((volatile unsigned int*)(0x428019C0UL)))
#define bM4_ADC2_STR_STRT                         (*((volatile unsigned int*)(0x42808000UL)))
#define bM4_ADC2_CR0_MS0                          (*((volatile unsigned int*)(0x42808040UL)))
#define bM4_ADC2_CR0_MS1                          (*((volatile unsigned int*)(0x42808044UL)))
#define bM4_ADC2_CR0_ACCSEL0                      (*((volatile unsigned int*)(0x42808050UL)))
#define bM4_ADC2_CR0_ACCSEL1                      (*((volatile unsigned int*)(0x42808054UL)))
#define bM4_ADC2_CR0_CLREN                        (*((volatile unsigned int*)(0x42808058UL)))
#define bM4_ADC2_CR0_DFMT                         (*((volatile unsigned int*)(0x4280805CUL)))
#define bM4_ADC2_CR0_AVCNT0                       (*((volatile unsigned int*)(0x42808060UL)))
#define bM4_ADC2_CR0_AVCNT1                       (*((volatile unsigned int*)(0x42808064UL)))
#define bM4_ADC2_CR0_AVCNT2                       (*((volatile unsigned int*)(0x42808068UL)))
#define bM4_ADC2_CR1_RSCHSEL                      (*((volatile unsigned int*)(0x42808088UL)))
#define bM4_ADC2_TRGSR_TRGSELA0                   (*((volatile unsigned int*)(0x42808140UL)))
#define bM4_ADC2_TRGSR_TRGSELA1                   (*((volatile unsigned int*)(0x42808144UL)))
#define bM4_ADC2_TRGSR_TRGSELA2                   (*((volatile unsigned int*)(0x42808148UL)))
#define bM4_ADC2_TRGSR_TRGENA                     (*((volatile unsigned int*)(0x4280815CUL)))
#define bM4_ADC2_TRGSR_TRGSELB0                   (*((volatile unsigned int*)(0x42808160UL)))
#define bM4_ADC2_TRGSR_TRGSELB1                   (*((volatile unsigned int*)(0x42808164UL)))
#define bM4_ADC2_TRGSR_TRGSELB2                   (*((volatile unsigned int*)(0x42808168UL)))
#define bM4_ADC2_TRGSR_TRGENB                     (*((volatile unsigned int*)(0x4280817CUL)))
#define bM4_ADC2_CHSELRA1_CHSELA16                (*((volatile unsigned int*)(0x428081C0UL)))
#define bM4_ADC2_CHSELRB1_CHSELB16                (*((volatile unsigned int*)(0x42808240UL)))
#define bM4_ADC2_AVCHSELR1_AVCHSEL16              (*((volatile unsigned int*)(0x428082C0UL)))
#define bM4_ADC2_CHMUXR0_CH00MUX0                 (*((volatile unsigned int*)(0x42808700UL)))
#define bM4_ADC2_CHMUXR0_CH00MUX1                 (*((volatile unsigned int*)(0x42808704UL)))
#define bM4_ADC2_CHMUXR0_CH00MUX2                 (*((volatile unsigned int*)(0x42808708UL)))
#define bM4_ADC2_CHMUXR0_CH00MUX3                 (*((volatile unsigned int*)(0x4280870CUL)))
#define bM4_ADC2_CHMUXR0_CH01MUX0                 (*((volatile unsigned int*)(0x42808710UL)))
#define bM4_ADC2_CHMUXR0_CH01MUX1                 (*((volatile unsigned int*)(0x42808714UL)))
#define bM4_ADC2_CHMUXR0_CH01MUX2                 (*((volatile unsigned int*)(0x42808718UL)))
#define bM4_ADC2_CHMUXR0_CH01MUX3                 (*((volatile unsigned int*)(0x4280871CUL)))
#define bM4_ADC2_CHMUXR0_CH02MUX0                 (*((volatile unsigned int*)(0x42808720UL)))
#define bM4_ADC2_CHMUXR0_CH02MUX1                 (*((volatile unsigned int*)(0x42808724UL)))
#define bM4_ADC2_CHMUXR0_CH02MUX2                 (*((volatile unsigned int*)(0x42808728UL)))
#define bM4_ADC2_CHMUXR0_CH02MUX3                 (*((volatile unsigned int*)(0x4280872CUL)))
#define bM4_ADC2_CHMUXR0_CH03MUX0                 (*((volatile unsigned int*)(0x42808730UL)))
#define bM4_ADC2_CHMUXR0_CH03MUX1                 (*((volatile unsigned int*)(0x42808734UL)))
#define bM4_ADC2_CHMUXR0_CH03MUX2                 (*((volatile unsigned int*)(0x42808738UL)))
#define bM4_ADC2_CHMUXR0_CH03MUX3                 (*((volatile unsigned int*)(0x4280873CUL)))
#define bM4_ADC2_CHMUXR1_CH04MUX0                 (*((volatile unsigned int*)(0x42808740UL)))
#define bM4_ADC2_CHMUXR1_CH04MUX1                 (*((volatile unsigned int*)(0x42808744UL)))
#define bM4_ADC2_CHMUXR1_CH04MUX2                 (*((volatile unsigned int*)(0x42808748UL)))
#define bM4_ADC2_CHMUXR1_CH04MUX3                 (*((volatile unsigned int*)(0x4280874CUL)))
#define bM4_ADC2_CHMUXR1_CH05MUX0                 (*((volatile unsigned int*)(0x42808750UL)))
#define bM4_ADC2_CHMUXR1_CH05MUX1                 (*((volatile unsigned int*)(0x42808754UL)))
#define bM4_ADC2_CHMUXR1_CH05MUX2                 (*((volatile unsigned int*)(0x42808758UL)))
#define bM4_ADC2_CHMUXR1_CH05MUX3                 (*((volatile unsigned int*)(0x4280875CUL)))
#define bM4_ADC2_CHMUXR1_CH06MUX0                 (*((volatile unsigned int*)(0x42808760UL)))
#define bM4_ADC2_CHMUXR1_CH06MUX1                 (*((volatile unsigned int*)(0x42808764UL)))
#define bM4_ADC2_CHMUXR1_CH06MUX2                 (*((volatile unsigned int*)(0x42808768UL)))
#define bM4_ADC2_CHMUXR1_CH06MUX3                 (*((volatile unsigned int*)(0x4280876CUL)))
#define bM4_ADC2_CHMUXR1_CH07MUX0                 (*((volatile unsigned int*)(0x42808770UL)))
#define bM4_ADC2_CHMUXR1_CH07MUX1                 (*((volatile unsigned int*)(0x42808774UL)))
#define bM4_ADC2_CHMUXR1_CH07MUX2                 (*((volatile unsigned int*)(0x42808778UL)))
#define bM4_ADC2_CHMUXR1_CH07MUX3                 (*((volatile unsigned int*)(0x4280877CUL)))
#define bM4_ADC2_CHMUXR2_CH08MUX0                 (*((volatile unsigned int*)(0x42808780UL)))
#define bM4_ADC2_CHMUXR2_CH08MUX1                 (*((volatile unsigned int*)(0x42808784UL)))
#define bM4_ADC2_CHMUXR2_CH08MUX2                 (*((volatile unsigned int*)(0x42808788UL)))
#define bM4_ADC2_CHMUXR2_CH08MUX3                 (*((volatile unsigned int*)(0x4280878CUL)))
#define bM4_ADC2_CHMUXR2_CH09MUX0                 (*((volatile unsigned int*)(0x42808790UL)))
#define bM4_ADC2_CHMUXR2_CH09MUX1                 (*((volatile unsigned int*)(0x42808794UL)))
#define bM4_ADC2_CHMUXR2_CH09MUX2                 (*((volatile unsigned int*)(0x42808798UL)))
#define bM4_ADC2_CHMUXR2_CH09MUX3                 (*((volatile unsigned int*)(0x4280879CUL)))
#define bM4_ADC2_CHMUXR2_CH10MUX0                 (*((volatile unsigned int*)(0x428087A0UL)))
#define bM4_ADC2_CHMUXR2_CH10MUX1                 (*((volatile unsigned int*)(0x428087A4UL)))
#define bM4_ADC2_CHMUXR2_CH10MUX2                 (*((volatile unsigned int*)(0x428087A8UL)))
#define bM4_ADC2_CHMUXR2_CH10MUX3                 (*((volatile unsigned int*)(0x428087ACUL)))
#define bM4_ADC2_CHMUXR2_CH11MUX0                 (*((volatile unsigned int*)(0x428087B0UL)))
#define bM4_ADC2_CHMUXR2_CH11MUX1                 (*((volatile unsigned int*)(0x428087B4UL)))
#define bM4_ADC2_CHMUXR2_CH11MUX2                 (*((volatile unsigned int*)(0x428087B8UL)))
#define bM4_ADC2_CHMUXR2_CH11MUX3                 (*((volatile unsigned int*)(0x428087BCUL)))
#define bM4_ADC2_CHMUXR3_CH12MUX0                 (*((volatile unsigned int*)(0x428087C0UL)))
#define bM4_ADC2_CHMUXR3_CH12MUX1                 (*((volatile unsigned int*)(0x428087C4UL)))
#define bM4_ADC2_CHMUXR3_CH12MUX2                 (*((volatile unsigned int*)(0x428087C8UL)))
#define bM4_ADC2_CHMUXR3_CH12MUX3                 (*((volatile unsigned int*)(0x428087CCUL)))
#define bM4_ADC2_CHMUXR3_CH13MUX0                 (*((volatile unsigned int*)(0x428087D0UL)))
#define bM4_ADC2_CHMUXR3_CH13MUX1                 (*((volatile unsigned int*)(0x428087D4UL)))
#define bM4_ADC2_CHMUXR3_CH13MUX2                 (*((volatile unsigned int*)(0x428087D8UL)))
#define bM4_ADC2_CHMUXR3_CH13MUX3                 (*((volatile unsigned int*)(0x428087DCUL)))
#define bM4_ADC2_CHMUXR3_CH14MUX0                 (*((volatile unsigned int*)(0x428087E0UL)))
#define bM4_ADC2_CHMUXR3_CH14MUX1                 (*((volatile unsigned int*)(0x428087E4UL)))
#define bM4_ADC2_CHMUXR3_CH14MUX2                 (*((volatile unsigned int*)(0x428087E8UL)))
#define bM4_ADC2_CHMUXR3_CH14MUX3                 (*((volatile unsigned int*)(0x428087ECUL)))
#define bM4_ADC2_CHMUXR3_CH15MUX0                 (*((volatile unsigned int*)(0x428087F0UL)))
#define bM4_ADC2_CHMUXR3_CH15MUX1                 (*((volatile unsigned int*)(0x428087F4UL)))
#define bM4_ADC2_CHMUXR3_CH15MUX2                 (*((volatile unsigned int*)(0x428087F8UL)))
#define bM4_ADC2_CHMUXR3_CH15MUX3                 (*((volatile unsigned int*)(0x428087FCUL)))
#define bM4_ADC2_ISR_EOCAF                        (*((volatile unsigned int*)(0x428088C0UL)))
#define bM4_ADC2_ISR_EOCBF                        (*((volatile unsigned int*)(0x428088C4UL)))
#define bM4_ADC2_ICR_EOCAIEN                      (*((volatile unsigned int*)(0x428088E0UL)))
#define bM4_ADC2_ICR_EOCBIEN                      (*((volatile unsigned int*)(0x428088E4UL)))
#define bM4_ADC2_SYNCCR_SYNCEN                    (*((volatile unsigned int*)(0x42808980UL)))
#define bM4_ADC2_SYNCCR_SYNCMD0                   (*((volatile unsigned int*)(0x42808990UL)))
#define bM4_ADC2_SYNCCR_SYNCMD1                   (*((volatile unsigned int*)(0x42808994UL)))
#define bM4_ADC2_SYNCCR_SYNCMD2                   (*((volatile unsigned int*)(0x42808998UL)))
#define bM4_ADC2_SYNCCR_SYNCDLY0                  (*((volatile unsigned int*)(0x428089A0UL)))
#define bM4_ADC2_SYNCCR_SYNCDLY1                  (*((volatile unsigned int*)(0x428089A4UL)))
#define bM4_ADC2_SYNCCR_SYNCDLY2                  (*((volatile unsigned int*)(0x428089A8UL)))
#define bM4_ADC2_SYNCCR_SYNCDLY3                  (*((volatile unsigned int*)(0x428089ACUL)))
#define bM4_ADC2_SYNCCR_SYNCDLY4                  (*((volatile unsigned int*)(0x428089B0UL)))
#define bM4_ADC2_SYNCCR_SYNCDLY5                  (*((volatile unsigned int*)(0x428089B4UL)))
#define bM4_ADC2_SYNCCR_SYNCDLY6                  (*((volatile unsigned int*)(0x428089B8UL)))
#define bM4_ADC2_SYNCCR_SYNCDLY7                  (*((volatile unsigned int*)(0x428089BCUL)))
#define bM4_ADC2_AWDCR_AWDEN                      (*((volatile unsigned int*)(0x42809400UL)))
#define bM4_ADC2_AWDCR_AWDMD                      (*((volatile unsigned int*)(0x42809410UL)))
#define bM4_ADC2_AWDCR_AWDSS0                     (*((volatile unsigned int*)(0x42809418UL)))
#define bM4_ADC2_AWDCR_AWDSS1                     (*((volatile unsigned int*)(0x4280941CUL)))
#define bM4_ADC2_AWDCR_AWDIEN                     (*((volatile unsigned int*)(0x42809420UL)))
#define bM4_ADC2_AWDCHSR1_AWDCH16                 (*((volatile unsigned int*)(0x428095C0UL)))
#define bM4_ADC2_AWDSR1_AWDF16                    (*((volatile unsigned int*)(0x42809640UL)))
#define bM4_ADC2_PGACR_PGACTL0                    (*((volatile unsigned int*)(0x42809800UL)))
#define bM4_ADC2_PGACR_PGACTL1                    (*((volatile unsigned int*)(0x42809804UL)))
#define bM4_ADC2_PGACR_PGACTL2                    (*((volatile unsigned int*)(0x42809808UL)))
#define bM4_ADC2_PGACR_PGACTL3                    (*((volatile unsigned int*)(0x4280980CUL)))
#define bM4_ADC2_PGAGSR_GAIN0                     (*((volatile unsigned int*)(0x42809840UL)))
#define bM4_ADC2_PGAGSR_GAIN1                     (*((volatile unsigned int*)(0x42809844UL)))
#define bM4_ADC2_PGAGSR_GAIN2                     (*((volatile unsigned int*)(0x42809848UL)))
#define bM4_ADC2_PGAGSR_GAIN3                     (*((volatile unsigned int*)(0x4280984CUL)))
#define bM4_ADC2_PGAINSR0_PGAINSEL0               (*((volatile unsigned int*)(0x42809980UL)))
#define bM4_ADC2_PGAINSR0_PGAINSEL1               (*((volatile unsigned int*)(0x42809984UL)))
#define bM4_ADC2_PGAINSR0_PGAINSEL2               (*((volatile unsigned int*)(0x42809988UL)))
#define bM4_ADC2_PGAINSR0_PGAINSEL3               (*((volatile unsigned int*)(0x4280998CUL)))
#define bM4_ADC2_PGAINSR0_PGAINSEL4               (*((volatile unsigned int*)(0x42809990UL)))
#define bM4_ADC2_PGAINSR0_PGAINSEL5               (*((volatile unsigned int*)(0x42809994UL)))
#define bM4_ADC2_PGAINSR0_PGAINSEL6               (*((volatile unsigned int*)(0x42809998UL)))
#define bM4_ADC2_PGAINSR0_PGAINSEL7               (*((volatile unsigned int*)(0x4280999CUL)))
#define bM4_ADC2_PGAINSR0_PGAINSEL8               (*((volatile unsigned int*)(0x428099A0UL)))
#define bM4_ADC2_PGAINSR1_PGAVSSEN                (*((volatile unsigned int*)(0x428099C0UL)))
#define bM4_AES_CR_START                          (*((volatile unsigned int*)(0x42100000UL)))
#define bM4_AES_CR_MODE                           (*((volatile unsigned int*)(0x42100004UL)))
#define bM4_AOS_INT_SFTTRG_STRG                   (*((volatile unsigned int*)(0x42210000UL)))
#define bM4_AOS_DCU1_TRGSEL_TRGSEL0               (*((volatile unsigned int*)(0x42210080UL)))
#define bM4_AOS_DCU1_TRGSEL_TRGSEL1               (*((volatile unsigned int*)(0x42210084UL)))
#define bM4_AOS_DCU1_TRGSEL_TRGSEL2               (*((volatile unsigned int*)(0x42210088UL)))
#define bM4_AOS_DCU1_TRGSEL_TRGSEL3               (*((volatile unsigned int*)(0x4221008CUL)))
#define bM4_AOS_DCU1_TRGSEL_TRGSEL4               (*((volatile unsigned int*)(0x42210090UL)))
#define bM4_AOS_DCU1_TRGSEL_TRGSEL5               (*((volatile unsigned int*)(0x42210094UL)))
#define bM4_AOS_DCU1_TRGSEL_TRGSEL6               (*((volatile unsigned int*)(0x42210098UL)))
#define bM4_AOS_DCU1_TRGSEL_TRGSEL7               (*((volatile unsigned int*)(0x4221009CUL)))
#define bM4_AOS_DCU1_TRGSEL_TRGSEL8               (*((volatile unsigned int*)(0x422100A0UL)))
#define bM4_AOS_DCU1_TRGSEL_COMTRG_EN0            (*((volatile unsigned int*)(0x422100F8UL)))
#define bM4_AOS_DCU1_TRGSEL_COMTRG_EN1            (*((volatile unsigned int*)(0x422100FCUL)))
#define bM4_AOS_DCU2_TRGSEL_TRGSEL0               (*((volatile unsigned int*)(0x42210100UL)))
#define bM4_AOS_DCU2_TRGSEL_TRGSEL1               (*((volatile unsigned int*)(0x42210104UL)))
#define bM4_AOS_DCU2_TRGSEL_TRGSEL2               (*((volatile unsigned int*)(0x42210108UL)))
#define bM4_AOS_DCU2_TRGSEL_TRGSEL3               (*((volatile unsigned int*)(0x4221010CUL)))
#define bM4_AOS_DCU2_TRGSEL_TRGSEL4               (*((volatile unsigned int*)(0x42210110UL)))
#define bM4_AOS_DCU2_TRGSEL_TRGSEL5               (*((volatile unsigned int*)(0x42210114UL)))
#define bM4_AOS_DCU2_TRGSEL_TRGSEL6               (*((volatile unsigned int*)(0x42210118UL)))
#define bM4_AOS_DCU2_TRGSEL_TRGSEL7               (*((volatile unsigned int*)(0x4221011CUL)))
#define bM4_AOS_DCU2_TRGSEL_TRGSEL8               (*((volatile unsigned int*)(0x42210120UL)))
#define bM4_AOS_DCU2_TRGSEL_COMTRG_EN0            (*((volatile unsigned int*)(0x42210178UL)))
#define bM4_AOS_DCU2_TRGSEL_COMTRG_EN1            (*((volatile unsigned int*)(0x4221017CUL)))
#define bM4_AOS_DCU3_TRGSEL_TRGSEL0               (*((volatile unsigned int*)(0x42210180UL)))
#define bM4_AOS_DCU3_TRGSEL_TRGSEL1               (*((volatile unsigned int*)(0x42210184UL)))
#define bM4_AOS_DCU3_TRGSEL_TRGSEL2               (*((volatile unsigned int*)(0x42210188UL)))
#define bM4_AOS_DCU3_TRGSEL_TRGSEL3               (*((volatile unsigned int*)(0x4221018CUL)))
#define bM4_AOS_DCU3_TRGSEL_TRGSEL4               (*((volatile unsigned int*)(0x42210190UL)))
#define bM4_AOS_DCU3_TRGSEL_TRGSEL5               (*((volatile unsigned int*)(0x42210194UL)))
#define bM4_AOS_DCU3_TRGSEL_TRGSEL6               (*((volatile unsigned int*)(0x42210198UL)))
#define bM4_AOS_DCU3_TRGSEL_TRGSEL7               (*((volatile unsigned int*)(0x4221019CUL)))
#define bM4_AOS_DCU3_TRGSEL_TRGSEL8               (*((volatile unsigned int*)(0x422101A0UL)))
#define bM4_AOS_DCU3_TRGSEL_COMTRG_EN0            (*((volatile unsigned int*)(0x422101F8UL)))
#define bM4_AOS_DCU3_TRGSEL_COMTRG_EN1            (*((volatile unsigned int*)(0x422101FCUL)))
#define bM4_AOS_DCU4_TRGSEL_TRGSEL0               (*((volatile unsigned int*)(0x42210200UL)))
#define bM4_AOS_DCU4_TRGSEL_TRGSEL1               (*((volatile unsigned int*)(0x42210204UL)))
#define bM4_AOS_DCU4_TRGSEL_TRGSEL2               (*((volatile unsigned int*)(0x42210208UL)))
#define bM4_AOS_DCU4_TRGSEL_TRGSEL3               (*((volatile unsigned int*)(0x4221020CUL)))
#define bM4_AOS_DCU4_TRGSEL_TRGSEL4               (*((volatile unsigned int*)(0x42210210UL)))
#define bM4_AOS_DCU4_TRGSEL_TRGSEL5               (*((volatile unsigned int*)(0x42210214UL)))
#define bM4_AOS_DCU4_TRGSEL_TRGSEL6               (*((volatile unsigned int*)(0x42210218UL)))
#define bM4_AOS_DCU4_TRGSEL_TRGSEL7               (*((volatile unsigned int*)(0x4221021CUL)))
#define bM4_AOS_DCU4_TRGSEL_TRGSEL8               (*((volatile unsigned int*)(0x42210220UL)))
#define bM4_AOS_DCU4_TRGSEL_COMTRG_EN0            (*((volatile unsigned int*)(0x42210278UL)))
#define bM4_AOS_DCU4_TRGSEL_COMTRG_EN1            (*((volatile unsigned int*)(0x4221027CUL)))
#define bM4_AOS_DMA1_TRGSEL0_TRGSEL0              (*((volatile unsigned int*)(0x42210280UL)))
#define bM4_AOS_DMA1_TRGSEL0_TRGSEL1              (*((volatile unsigned int*)(0x42210284UL)))
#define bM4_AOS_DMA1_TRGSEL0_TRGSEL2              (*((volatile unsigned int*)(0x42210288UL)))
#define bM4_AOS_DMA1_TRGSEL0_TRGSEL3              (*((volatile unsigned int*)(0x4221028CUL)))
#define bM4_AOS_DMA1_TRGSEL0_TRGSEL4              (*((volatile unsigned int*)(0x42210290UL)))
#define bM4_AOS_DMA1_TRGSEL0_TRGSEL5              (*((volatile unsigned int*)(0x42210294UL)))
#define bM4_AOS_DMA1_TRGSEL0_TRGSEL6              (*((volatile unsigned int*)(0x42210298UL)))
#define bM4_AOS_DMA1_TRGSEL0_TRGSEL7              (*((volatile unsigned int*)(0x4221029CUL)))
#define bM4_AOS_DMA1_TRGSEL0_TRGSEL8              (*((volatile unsigned int*)(0x422102A0UL)))
#define bM4_AOS_DMA1_TRGSEL0_COMTRG_EN0           (*((volatile unsigned int*)(0x422102F8UL)))
#define bM4_AOS_DMA1_TRGSEL0_COMTRG_EN1           (*((volatile unsigned int*)(0x422102FCUL)))
#define bM4_AOS_DMA1_TRGSEL1_TRGSEL0              (*((volatile unsigned int*)(0x42210300UL)))
#define bM4_AOS_DMA1_TRGSEL1_TRGSEL1              (*((volatile unsigned int*)(0x42210304UL)))
#define bM4_AOS_DMA1_TRGSEL1_TRGSEL2              (*((volatile unsigned int*)(0x42210308UL)))
#define bM4_AOS_DMA1_TRGSEL1_TRGSEL3              (*((volatile unsigned int*)(0x4221030CUL)))
#define bM4_AOS_DMA1_TRGSEL1_TRGSEL4              (*((volatile unsigned int*)(0x42210310UL)))
#define bM4_AOS_DMA1_TRGSEL1_TRGSEL5              (*((volatile unsigned int*)(0x42210314UL)))
#define bM4_AOS_DMA1_TRGSEL1_TRGSEL6              (*((volatile unsigned int*)(0x42210318UL)))
#define bM4_AOS_DMA1_TRGSEL1_TRGSEL7              (*((volatile unsigned int*)(0x4221031CUL)))
#define bM4_AOS_DMA1_TRGSEL1_TRGSEL8              (*((volatile unsigned int*)(0x42210320UL)))
#define bM4_AOS_DMA1_TRGSEL1_COMTRG_EN0           (*((volatile unsigned int*)(0x42210378UL)))
#define bM4_AOS_DMA1_TRGSEL1_COMTRG_EN1           (*((volatile unsigned int*)(0x4221037CUL)))
#define bM4_AOS_DMA1_TRGSEL2_TRGSEL0              (*((volatile unsigned int*)(0x42210380UL)))
#define bM4_AOS_DMA1_TRGSEL2_TRGSEL1              (*((volatile unsigned int*)(0x42210384UL)))
#define bM4_AOS_DMA1_TRGSEL2_TRGSEL2              (*((volatile unsigned int*)(0x42210388UL)))
#define bM4_AOS_DMA1_TRGSEL2_TRGSEL3              (*((volatile unsigned int*)(0x4221038CUL)))
#define bM4_AOS_DMA1_TRGSEL2_TRGSEL4              (*((volatile unsigned int*)(0x42210390UL)))
#define bM4_AOS_DMA1_TRGSEL2_TRGSEL5              (*((volatile unsigned int*)(0x42210394UL)))
#define bM4_AOS_DMA1_TRGSEL2_TRGSEL6              (*((volatile unsigned int*)(0x42210398UL)))
#define bM4_AOS_DMA1_TRGSEL2_TRGSEL7              (*((volatile unsigned int*)(0x4221039CUL)))
#define bM4_AOS_DMA1_TRGSEL2_TRGSEL8              (*((volatile unsigned int*)(0x422103A0UL)))
#define bM4_AOS_DMA1_TRGSEL2_COMTRG_EN0           (*((volatile unsigned int*)(0x422103F8UL)))
#define bM4_AOS_DMA1_TRGSEL2_COMTRG_EN1           (*((volatile unsigned int*)(0x422103FCUL)))
#define bM4_AOS_DMA1_TRGSEL3_TRGSEL0              (*((volatile unsigned int*)(0x42210400UL)))
#define bM4_AOS_DMA1_TRGSEL3_TRGSEL1              (*((volatile unsigned int*)(0x42210404UL)))
#define bM4_AOS_DMA1_TRGSEL3_TRGSEL2              (*((volatile unsigned int*)(0x42210408UL)))
#define bM4_AOS_DMA1_TRGSEL3_TRGSEL3              (*((volatile unsigned int*)(0x4221040CUL)))
#define bM4_AOS_DMA1_TRGSEL3_TRGSEL4              (*((volatile unsigned int*)(0x42210410UL)))
#define bM4_AOS_DMA1_TRGSEL3_TRGSEL5              (*((volatile unsigned int*)(0x42210414UL)))
#define bM4_AOS_DMA1_TRGSEL3_TRGSEL6              (*((volatile unsigned int*)(0x42210418UL)))
#define bM4_AOS_DMA1_TRGSEL3_TRGSEL7              (*((volatile unsigned int*)(0x4221041CUL)))
#define bM4_AOS_DMA1_TRGSEL3_TRGSEL8              (*((volatile unsigned int*)(0x42210420UL)))
#define bM4_AOS_DMA1_TRGSEL3_COMTRG_EN0           (*((volatile unsigned int*)(0x42210478UL)))
#define bM4_AOS_DMA1_TRGSEL3_COMTRG_EN1           (*((volatile unsigned int*)(0x4221047CUL)))
#define bM4_AOS_DMA2_TRGSEL0_TRGSEL0              (*((volatile unsigned int*)(0x42210480UL)))
#define bM4_AOS_DMA2_TRGSEL0_TRGSEL1              (*((volatile unsigned int*)(0x42210484UL)))
#define bM4_AOS_DMA2_TRGSEL0_TRGSEL2              (*((volatile unsigned int*)(0x42210488UL)))
#define bM4_AOS_DMA2_TRGSEL0_TRGSEL3              (*((volatile unsigned int*)(0x4221048CUL)))
#define bM4_AOS_DMA2_TRGSEL0_TRGSEL4              (*((volatile unsigned int*)(0x42210490UL)))
#define bM4_AOS_DMA2_TRGSEL0_TRGSEL5              (*((volatile unsigned int*)(0x42210494UL)))
#define bM4_AOS_DMA2_TRGSEL0_TRGSEL6              (*((volatile unsigned int*)(0x42210498UL)))
#define bM4_AOS_DMA2_TRGSEL0_TRGSEL7              (*((volatile unsigned int*)(0x4221049CUL)))
#define bM4_AOS_DMA2_TRGSEL0_TRGSEL8              (*((volatile unsigned int*)(0x422104A0UL)))
#define bM4_AOS_DMA2_TRGSEL0_COMTRG_EN0           (*((volatile unsigned int*)(0x422104F8UL)))
#define bM4_AOS_DMA2_TRGSEL0_COMTRG_EN1           (*((volatile unsigned int*)(0x422104FCUL)))
#define bM4_AOS_DMA2_TRGSEL1_TRGSEL0              (*((volatile unsigned int*)(0x42210500UL)))
#define bM4_AOS_DMA2_TRGSEL1_TRGSEL1              (*((volatile unsigned int*)(0x42210504UL)))
#define bM4_AOS_DMA2_TRGSEL1_TRGSEL2              (*((volatile unsigned int*)(0x42210508UL)))
#define bM4_AOS_DMA2_TRGSEL1_TRGSEL3              (*((volatile unsigned int*)(0x4221050CUL)))
#define bM4_AOS_DMA2_TRGSEL1_TRGSEL4              (*((volatile unsigned int*)(0x42210510UL)))
#define bM4_AOS_DMA2_TRGSEL1_TRGSEL5              (*((volatile unsigned int*)(0x42210514UL)))
#define bM4_AOS_DMA2_TRGSEL1_TRGSEL6              (*((volatile unsigned int*)(0x42210518UL)))
#define bM4_AOS_DMA2_TRGSEL1_TRGSEL7              (*((volatile unsigned int*)(0x4221051CUL)))
#define bM4_AOS_DMA2_TRGSEL1_TRGSEL8              (*((volatile unsigned int*)(0x42210520UL)))
#define bM4_AOS_DMA2_TRGSEL1_COMTRG_EN0           (*((volatile unsigned int*)(0x42210578UL)))
#define bM4_AOS_DMA2_TRGSEL1_COMTRG_EN1           (*((volatile unsigned int*)(0x4221057CUL)))
#define bM4_AOS_DMA2_TRGSEL2_TRGSEL0              (*((volatile unsigned int*)(0x42210580UL)))
#define bM4_AOS_DMA2_TRGSEL2_TRGSEL1              (*((volatile unsigned int*)(0x42210584UL)))
#define bM4_AOS_DMA2_TRGSEL2_TRGSEL2              (*((volatile unsigned int*)(0x42210588UL)))
#define bM4_AOS_DMA2_TRGSEL2_TRGSEL3              (*((volatile unsigned int*)(0x4221058CUL)))
#define bM4_AOS_DMA2_TRGSEL2_TRGSEL4              (*((volatile unsigned int*)(0x42210590UL)))
#define bM4_AOS_DMA2_TRGSEL2_TRGSEL5              (*((volatile unsigned int*)(0x42210594UL)))
#define bM4_AOS_DMA2_TRGSEL2_TRGSEL6              (*((volatile unsigned int*)(0x42210598UL)))
#define bM4_AOS_DMA2_TRGSEL2_TRGSEL7              (*((volatile unsigned int*)(0x4221059CUL)))
#define bM4_AOS_DMA2_TRGSEL2_TRGSEL8              (*((volatile unsigned int*)(0x422105A0UL)))
#define bM4_AOS_DMA2_TRGSEL2_COMTRG_EN0           (*((volatile unsigned int*)(0x422105F8UL)))
#define bM4_AOS_DMA2_TRGSEL2_COMTRG_EN1           (*((volatile unsigned int*)(0x422105FCUL)))
#define bM4_AOS_DMA2_TRGSEL3_TRGSEL0              (*((volatile unsigned int*)(0x42210600UL)))
#define bM4_AOS_DMA2_TRGSEL3_TRGSEL1              (*((volatile unsigned int*)(0x42210604UL)))
#define bM4_AOS_DMA2_TRGSEL3_TRGSEL2              (*((volatile unsigned int*)(0x42210608UL)))
#define bM4_AOS_DMA2_TRGSEL3_TRGSEL3              (*((volatile unsigned int*)(0x4221060CUL)))
#define bM4_AOS_DMA2_TRGSEL3_TRGSEL4              (*((volatile unsigned int*)(0x42210610UL)))
#define bM4_AOS_DMA2_TRGSEL3_TRGSEL5              (*((volatile unsigned int*)(0x42210614UL)))
#define bM4_AOS_DMA2_TRGSEL3_TRGSEL6              (*((volatile unsigned int*)(0x42210618UL)))
#define bM4_AOS_DMA2_TRGSEL3_TRGSEL7              (*((volatile unsigned int*)(0x4221061CUL)))
#define bM4_AOS_DMA2_TRGSEL3_TRGSEL8              (*((volatile unsigned int*)(0x42210620UL)))
#define bM4_AOS_DMA2_TRGSEL3_COMTRG_EN0           (*((volatile unsigned int*)(0x42210678UL)))
#define bM4_AOS_DMA2_TRGSEL3_COMTRG_EN1           (*((volatile unsigned int*)(0x4221067CUL)))
#define bM4_AOS_DMA_TRGSELRC_TRGSEL0              (*((volatile unsigned int*)(0x42210680UL)))
#define bM4_AOS_DMA_TRGSELRC_TRGSEL1              (*((volatile unsigned int*)(0x42210684UL)))
#define bM4_AOS_DMA_TRGSELRC_TRGSEL2              (*((volatile unsigned int*)(0x42210688UL)))
#define bM4_AOS_DMA_TRGSELRC_TRGSEL3              (*((volatile unsigned int*)(0x4221068CUL)))
#define bM4_AOS_DMA_TRGSELRC_TRGSEL4              (*((volatile unsigned int*)(0x42210690UL)))
#define bM4_AOS_DMA_TRGSELRC_TRGSEL5              (*((volatile unsigned int*)(0x42210694UL)))
#define bM4_AOS_DMA_TRGSELRC_TRGSEL6              (*((volatile unsigned int*)(0x42210698UL)))
#define bM4_AOS_DMA_TRGSELRC_TRGSEL7              (*((volatile unsigned int*)(0x4221069CUL)))
#define bM4_AOS_DMA_TRGSELRC_TRGSEL8              (*((volatile unsigned int*)(0x422106A0UL)))
#define bM4_AOS_DMA_TRGSELRC_COMTRG_EN0           (*((volatile unsigned int*)(0x422106F8UL)))
#define bM4_AOS_DMA_TRGSELRC_COMTRG_EN1           (*((volatile unsigned int*)(0x422106FCUL)))
#define bM4_AOS_TMR6_HTSSR0_TRGSEL0               (*((volatile unsigned int*)(0x42210700UL)))
#define bM4_AOS_TMR6_HTSSR0_TRGSEL1               (*((volatile unsigned int*)(0x42210704UL)))
#define bM4_AOS_TMR6_HTSSR0_TRGSEL2               (*((volatile unsigned int*)(0x42210708UL)))
#define bM4_AOS_TMR6_HTSSR0_TRGSEL3               (*((volatile unsigned int*)(0x4221070CUL)))
#define bM4_AOS_TMR6_HTSSR0_TRGSEL4               (*((volatile unsigned int*)(0x42210710UL)))
#define bM4_AOS_TMR6_HTSSR0_TRGSEL5               (*((volatile unsigned int*)(0x42210714UL)))
#define bM4_AOS_TMR6_HTSSR0_TRGSEL6               (*((volatile unsigned int*)(0x42210718UL)))
#define bM4_AOS_TMR6_HTSSR0_TRGSEL7               (*((volatile unsigned int*)(0x4221071CUL)))
#define bM4_AOS_TMR6_HTSSR0_TRGSEL8               (*((volatile unsigned int*)(0x42210720UL)))
#define bM4_AOS_TMR6_HTSSR0_COMTRG_EN0            (*((volatile unsigned int*)(0x42210778UL)))
#define bM4_AOS_TMR6_HTSSR0_COMTRG_EN1            (*((volatile unsigned int*)(0x4221077CUL)))
#define bM4_AOS_TMR6_HTSSR1_TRGSEL0               (*((volatile unsigned int*)(0x42210780UL)))
#define bM4_AOS_TMR6_HTSSR1_TRGSEL1               (*((volatile unsigned int*)(0x42210784UL)))
#define bM4_AOS_TMR6_HTSSR1_TRGSEL2               (*((volatile unsigned int*)(0x42210788UL)))
#define bM4_AOS_TMR6_HTSSR1_TRGSEL3               (*((volatile unsigned int*)(0x4221078CUL)))
#define bM4_AOS_TMR6_HTSSR1_TRGSEL4               (*((volatile unsigned int*)(0x42210790UL)))
#define bM4_AOS_TMR6_HTSSR1_TRGSEL5               (*((volatile unsigned int*)(0x42210794UL)))
#define bM4_AOS_TMR6_HTSSR1_TRGSEL6               (*((volatile unsigned int*)(0x42210798UL)))
#define bM4_AOS_TMR6_HTSSR1_TRGSEL7               (*((volatile unsigned int*)(0x4221079CUL)))
#define bM4_AOS_TMR6_HTSSR1_TRGSEL8               (*((volatile unsigned int*)(0x422107A0UL)))
#define bM4_AOS_TMR6_HTSSR1_COMTRG_EN0            (*((volatile unsigned int*)(0x422107F8UL)))
#define bM4_AOS_TMR6_HTSSR1_COMTRG_EN1            (*((volatile unsigned int*)(0x422107FCUL)))
#define bM4_AOS_TMR0_HTSSR_TRGSEL0                (*((volatile unsigned int*)(0x42210800UL)))
#define bM4_AOS_TMR0_HTSSR_TRGSEL1                (*((volatile unsigned int*)(0x42210804UL)))
#define bM4_AOS_TMR0_HTSSR_TRGSEL2                (*((volatile unsigned int*)(0x42210808UL)))
#define bM4_AOS_TMR0_HTSSR_TRGSEL3                (*((volatile unsigned int*)(0x4221080CUL)))
#define bM4_AOS_TMR0_HTSSR_TRGSEL4                (*((volatile unsigned int*)(0x42210810UL)))
#define bM4_AOS_TMR0_HTSSR_TRGSEL5                (*((volatile unsigned int*)(0x42210814UL)))
#define bM4_AOS_TMR0_HTSSR_TRGSEL6                (*((volatile unsigned int*)(0x42210818UL)))
#define bM4_AOS_TMR0_HTSSR_TRGSEL7                (*((volatile unsigned int*)(0x4221081CUL)))
#define bM4_AOS_TMR0_HTSSR_TRGSEL8                (*((volatile unsigned int*)(0x42210820UL)))
#define bM4_AOS_TMR0_HTSSR_COMTRG_EN0             (*((volatile unsigned int*)(0x42210878UL)))
#define bM4_AOS_TMR0_HTSSR_COMTRG_EN1             (*((volatile unsigned int*)(0x4221087CUL)))
#define bM4_AOS_PEVNTTRGSR12_TRGSEL0              (*((volatile unsigned int*)(0x42210880UL)))
#define bM4_AOS_PEVNTTRGSR12_TRGSEL1              (*((volatile unsigned int*)(0x42210884UL)))
#define bM4_AOS_PEVNTTRGSR12_TRGSEL2              (*((volatile unsigned int*)(0x42210888UL)))
#define bM4_AOS_PEVNTTRGSR12_TRGSEL3              (*((volatile unsigned int*)(0x4221088CUL)))
#define bM4_AOS_PEVNTTRGSR12_TRGSEL4              (*((volatile unsigned int*)(0x42210890UL)))
#define bM4_AOS_PEVNTTRGSR12_TRGSEL5              (*((volatile unsigned int*)(0x42210894UL)))
#define bM4_AOS_PEVNTTRGSR12_TRGSEL6              (*((volatile unsigned int*)(0x42210898UL)))
#define bM4_AOS_PEVNTTRGSR12_TRGSEL7              (*((volatile unsigned int*)(0x4221089CUL)))
#define bM4_AOS_PEVNTTRGSR12_TRGSEL8              (*((volatile unsigned int*)(0x422108A0UL)))
#define bM4_AOS_PEVNTTRGSR12_COMTRG_EN0           (*((volatile unsigned int*)(0x422108F8UL)))
#define bM4_AOS_PEVNTTRGSR12_COMTRG_EN1           (*((volatile unsigned int*)(0x422108FCUL)))
#define bM4_AOS_PEVNTTRGSR34_TRGSEL0              (*((volatile unsigned int*)(0x42210900UL)))
#define bM4_AOS_PEVNTTRGSR34_TRGSEL1              (*((volatile unsigned int*)(0x42210904UL)))
#define bM4_AOS_PEVNTTRGSR34_TRGSEL2              (*((volatile unsigned int*)(0x42210908UL)))
#define bM4_AOS_PEVNTTRGSR34_TRGSEL3              (*((volatile unsigned int*)(0x4221090CUL)))
#define bM4_AOS_PEVNTTRGSR34_TRGSEL4              (*((volatile unsigned int*)(0x42210910UL)))
#define bM4_AOS_PEVNTTRGSR34_TRGSEL5              (*((volatile unsigned int*)(0x42210914UL)))
#define bM4_AOS_PEVNTTRGSR34_TRGSEL6              (*((volatile unsigned int*)(0x42210918UL)))
#define bM4_AOS_PEVNTTRGSR34_TRGSEL7              (*((volatile unsigned int*)(0x4221091CUL)))
#define bM4_AOS_PEVNTTRGSR34_TRGSEL8              (*((volatile unsigned int*)(0x42210920UL)))
#define bM4_AOS_PEVNTTRGSR34_COMTRG_EN0           (*((volatile unsigned int*)(0x42210978UL)))
#define bM4_AOS_PEVNTTRGSR34_COMTRG_EN1           (*((volatile unsigned int*)(0x4221097CUL)))
#define bM4_AOS_TMRA_HTSSR0_TRGSEL0               (*((volatile unsigned int*)(0x42210980UL)))
#define bM4_AOS_TMRA_HTSSR0_TRGSEL1               (*((volatile unsigned int*)(0x42210984UL)))
#define bM4_AOS_TMRA_HTSSR0_TRGSEL2               (*((volatile unsigned int*)(0x42210988UL)))
#define bM4_AOS_TMRA_HTSSR0_TRGSEL3               (*((volatile unsigned int*)(0x4221098CUL)))
#define bM4_AOS_TMRA_HTSSR0_TRGSEL4               (*((volatile unsigned int*)(0x42210990UL)))
#define bM4_AOS_TMRA_HTSSR0_TRGSEL5               (*((volatile unsigned int*)(0x42210994UL)))
#define bM4_AOS_TMRA_HTSSR0_TRGSEL6               (*((volatile unsigned int*)(0x42210998UL)))
#define bM4_AOS_TMRA_HTSSR0_TRGSEL7               (*((volatile unsigned int*)(0x4221099CUL)))
#define bM4_AOS_TMRA_HTSSR0_TRGSEL8               (*((volatile unsigned int*)(0x422109A0UL)))
#define bM4_AOS_TMRA_HTSSR0_COMTRG_EN0            (*((volatile unsigned int*)(0x422109F8UL)))
#define bM4_AOS_TMRA_HTSSR0_COMTRG_EN1            (*((volatile unsigned int*)(0x422109FCUL)))
#define bM4_AOS_TMRA_HTSSR1_TRGSEL0               (*((volatile unsigned int*)(0x42210A00UL)))
#define bM4_AOS_TMRA_HTSSR1_TRGSEL1               (*((volatile unsigned int*)(0x42210A04UL)))
#define bM4_AOS_TMRA_HTSSR1_TRGSEL2               (*((volatile unsigned int*)(0x42210A08UL)))
#define bM4_AOS_TMRA_HTSSR1_TRGSEL3               (*((volatile unsigned int*)(0x42210A0CUL)))
#define bM4_AOS_TMRA_HTSSR1_TRGSEL4               (*((volatile unsigned int*)(0x42210A10UL)))
#define bM4_AOS_TMRA_HTSSR1_TRGSEL5               (*((volatile unsigned int*)(0x42210A14UL)))
#define bM4_AOS_TMRA_HTSSR1_TRGSEL6               (*((volatile unsigned int*)(0x42210A18UL)))
#define bM4_AOS_TMRA_HTSSR1_TRGSEL7               (*((volatile unsigned int*)(0x42210A1CUL)))
#define bM4_AOS_TMRA_HTSSR1_TRGSEL8               (*((volatile unsigned int*)(0x42210A20UL)))
#define bM4_AOS_TMRA_HTSSR1_COMTRG_EN0            (*((volatile unsigned int*)(0x42210A78UL)))
#define bM4_AOS_TMRA_HTSSR1_COMTRG_EN1            (*((volatile unsigned int*)(0x42210A7CUL)))
#define bM4_AOS_OTS_TRG_TRGSEL0                   (*((volatile unsigned int*)(0x42210A80UL)))
#define bM4_AOS_OTS_TRG_TRGSEL1                   (*((volatile unsigned int*)(0x42210A84UL)))
#define bM4_AOS_OTS_TRG_TRGSEL2                   (*((volatile unsigned int*)(0x42210A88UL)))
#define bM4_AOS_OTS_TRG_TRGSEL3                   (*((volatile unsigned int*)(0x42210A8CUL)))
#define bM4_AOS_OTS_TRG_TRGSEL4                   (*((volatile unsigned int*)(0x42210A90UL)))
#define bM4_AOS_OTS_TRG_TRGSEL5                   (*((volatile unsigned int*)(0x42210A94UL)))
#define bM4_AOS_OTS_TRG_TRGSEL6                   (*((volatile unsigned int*)(0x42210A98UL)))
#define bM4_AOS_OTS_TRG_TRGSEL7                   (*((volatile unsigned int*)(0x42210A9CUL)))
#define bM4_AOS_OTS_TRG_TRGSEL8                   (*((volatile unsigned int*)(0x42210AA0UL)))
#define bM4_AOS_OTS_TRG_COMTRG_EN0                (*((volatile unsigned int*)(0x42210AF8UL)))
#define bM4_AOS_OTS_TRG_COMTRG_EN1                (*((volatile unsigned int*)(0x42210AFCUL)))
#define bM4_AOS_ADC1_ITRGSELR0_TRGSEL0            (*((volatile unsigned int*)(0x42210B00UL)))
#define bM4_AOS_ADC1_ITRGSELR0_TRGSEL1            (*((volatile unsigned int*)(0x42210B04UL)))
#define bM4_AOS_ADC1_ITRGSELR0_TRGSEL2            (*((volatile unsigned int*)(0x42210B08UL)))
#define bM4_AOS_ADC1_ITRGSELR0_TRGSEL3            (*((volatile unsigned int*)(0x42210B0CUL)))
#define bM4_AOS_ADC1_ITRGSELR0_TRGSEL4            (*((volatile unsigned int*)(0x42210B10UL)))
#define bM4_AOS_ADC1_ITRGSELR0_TRGSEL5            (*((volatile unsigned int*)(0x42210B14UL)))
#define bM4_AOS_ADC1_ITRGSELR0_TRGSEL6            (*((volatile unsigned int*)(0x42210B18UL)))
#define bM4_AOS_ADC1_ITRGSELR0_TRGSEL7            (*((volatile unsigned int*)(0x42210B1CUL)))
#define bM4_AOS_ADC1_ITRGSELR0_TRGSEL8            (*((volatile unsigned int*)(0x42210B20UL)))
#define bM4_AOS_ADC1_ITRGSELR0_COMTRG_EN0         (*((volatile unsigned int*)(0x42210B78UL)))
#define bM4_AOS_ADC1_ITRGSELR0_COMTRG_EN1         (*((volatile unsigned int*)(0x42210B7CUL)))
#define bM4_AOS_ADC1_ITRGSELR1_TRGSEL0            (*((volatile unsigned int*)(0x42210B80UL)))
#define bM4_AOS_ADC1_ITRGSELR1_TRGSEL1            (*((volatile unsigned int*)(0x42210B84UL)))
#define bM4_AOS_ADC1_ITRGSELR1_TRGSEL2            (*((volatile unsigned int*)(0x42210B88UL)))
#define bM4_AOS_ADC1_ITRGSELR1_TRGSEL3            (*((volatile unsigned int*)(0x42210B8CUL)))
#define bM4_AOS_ADC1_ITRGSELR1_TRGSEL4            (*((volatile unsigned int*)(0x42210B90UL)))
#define bM4_AOS_ADC1_ITRGSELR1_TRGSEL5            (*((volatile unsigned int*)(0x42210B94UL)))
#define bM4_AOS_ADC1_ITRGSELR1_TRGSEL6            (*((volatile unsigned int*)(0x42210B98UL)))
#define bM4_AOS_ADC1_ITRGSELR1_TRGSEL7            (*((volatile unsigned int*)(0x42210B9CUL)))
#define bM4_AOS_ADC1_ITRGSELR1_TRGSEL8            (*((volatile unsigned int*)(0x42210BA0UL)))
#define bM4_AOS_ADC1_ITRGSELR1_COMTRG_EN0         (*((volatile unsigned int*)(0x42210BF8UL)))
#define bM4_AOS_ADC1_ITRGSELR1_COMTRG_EN1         (*((volatile unsigned int*)(0x42210BFCUL)))
#define bM4_AOS_ADC2_ITRGSELR0_TRGSEL0            (*((volatile unsigned int*)(0x42210C00UL)))
#define bM4_AOS_ADC2_ITRGSELR0_TRGSEL1            (*((volatile unsigned int*)(0x42210C04UL)))
#define bM4_AOS_ADC2_ITRGSELR0_TRGSEL2            (*((volatile unsigned int*)(0x42210C08UL)))
#define bM4_AOS_ADC2_ITRGSELR0_TRGSEL3            (*((volatile unsigned int*)(0x42210C0CUL)))
#define bM4_AOS_ADC2_ITRGSELR0_TRGSEL4            (*((volatile unsigned int*)(0x42210C10UL)))
#define bM4_AOS_ADC2_ITRGSELR0_TRGSEL5            (*((volatile unsigned int*)(0x42210C14UL)))
#define bM4_AOS_ADC2_ITRGSELR0_TRGSEL6            (*((volatile unsigned int*)(0x42210C18UL)))
#define bM4_AOS_ADC2_ITRGSELR0_TRGSEL7            (*((volatile unsigned int*)(0x42210C1CUL)))
#define bM4_AOS_ADC2_ITRGSELR0_TRGSEL8            (*((volatile unsigned int*)(0x42210C20UL)))
#define bM4_AOS_ADC2_ITRGSELR0_COMTRG_EN0         (*((volatile unsigned int*)(0x42210C78UL)))
#define bM4_AOS_ADC2_ITRGSELR0_COMTRG_EN1         (*((volatile unsigned int*)(0x42210C7CUL)))
#define bM4_AOS_ADC2_ITRGSELR1_TRGSEL0            (*((volatile unsigned int*)(0x42210C80UL)))
#define bM4_AOS_ADC2_ITRGSELR1_TRGSEL1            (*((volatile unsigned int*)(0x42210C84UL)))
#define bM4_AOS_ADC2_ITRGSELR1_TRGSEL2            (*((volatile unsigned int*)(0x42210C88UL)))
#define bM4_AOS_ADC2_ITRGSELR1_TRGSEL3            (*((volatile unsigned int*)(0x42210C8CUL)))
#define bM4_AOS_ADC2_ITRGSELR1_TRGSEL4            (*((volatile unsigned int*)(0x42210C90UL)))
#define bM4_AOS_ADC2_ITRGSELR1_TRGSEL5            (*((volatile unsigned int*)(0x42210C94UL)))
#define bM4_AOS_ADC2_ITRGSELR1_TRGSEL6            (*((volatile unsigned int*)(0x42210C98UL)))
#define bM4_AOS_ADC2_ITRGSELR1_TRGSEL7            (*((volatile unsigned int*)(0x42210C9CUL)))
#define bM4_AOS_ADC2_ITRGSELR1_TRGSEL8            (*((volatile unsigned int*)(0x42210CA0UL)))
#define bM4_AOS_ADC2_ITRGSELR1_COMTRG_EN0         (*((volatile unsigned int*)(0x42210CF8UL)))
#define bM4_AOS_ADC2_ITRGSELR1_COMTRG_EN1         (*((volatile unsigned int*)(0x42210CFCUL)))
#define bM4_AOS_COMTRG1_TRGSEL0                   (*((volatile unsigned int*)(0x42210D00UL)))
#define bM4_AOS_COMTRG1_TRGSEL1                   (*((volatile unsigned int*)(0x42210D04UL)))
#define bM4_AOS_COMTRG1_TRGSEL2                   (*((volatile unsigned int*)(0x42210D08UL)))
#define bM4_AOS_COMTRG1_TRGSEL3                   (*((volatile unsigned int*)(0x42210D0CUL)))
#define bM4_AOS_COMTRG1_TRGSEL4                   (*((volatile unsigned int*)(0x42210D10UL)))
#define bM4_AOS_COMTRG1_TRGSEL5                   (*((volatile unsigned int*)(0x42210D14UL)))
#define bM4_AOS_COMTRG1_TRGSEL6                   (*((volatile unsigned int*)(0x42210D18UL)))
#define bM4_AOS_COMTRG1_TRGSEL7                   (*((volatile unsigned int*)(0x42210D1CUL)))
#define bM4_AOS_COMTRG1_TRGSEL8                   (*((volatile unsigned int*)(0x42210D20UL)))
#define bM4_AOS_COMTRG2_TRGSEL0                   (*((volatile unsigned int*)(0x42210D80UL)))
#define bM4_AOS_COMTRG2_TRGSEL1                   (*((volatile unsigned int*)(0x42210D84UL)))
#define bM4_AOS_COMTRG2_TRGSEL2                   (*((volatile unsigned int*)(0x42210D88UL)))
#define bM4_AOS_COMTRG2_TRGSEL3                   (*((volatile unsigned int*)(0x42210D8CUL)))
#define bM4_AOS_COMTRG2_TRGSEL4                   (*((volatile unsigned int*)(0x42210D90UL)))
#define bM4_AOS_COMTRG2_TRGSEL5                   (*((volatile unsigned int*)(0x42210D94UL)))
#define bM4_AOS_COMTRG2_TRGSEL6                   (*((volatile unsigned int*)(0x42210D98UL)))
#define bM4_AOS_COMTRG2_TRGSEL7                   (*((volatile unsigned int*)(0x42210D9CUL)))
#define bM4_AOS_COMTRG2_TRGSEL8                   (*((volatile unsigned int*)(0x42210DA0UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR00                 (*((volatile unsigned int*)(0x42212000UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR01                 (*((volatile unsigned int*)(0x42212004UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR02                 (*((volatile unsigned int*)(0x42212008UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR03                 (*((volatile unsigned int*)(0x4221200CUL)))
#define bM4_AOS_PEVNTDIRR1_PDIR04                 (*((volatile unsigned int*)(0x42212010UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR05                 (*((volatile unsigned int*)(0x42212014UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR06                 (*((volatile unsigned int*)(0x42212018UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR07                 (*((volatile unsigned int*)(0x4221201CUL)))
#define bM4_AOS_PEVNTDIRR1_PDIR08                 (*((volatile unsigned int*)(0x42212020UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR09                 (*((volatile unsigned int*)(0x42212024UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR10                 (*((volatile unsigned int*)(0x42212028UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR11                 (*((volatile unsigned int*)(0x4221202CUL)))
#define bM4_AOS_PEVNTDIRR1_PDIR12                 (*((volatile unsigned int*)(0x42212030UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR13                 (*((volatile unsigned int*)(0x42212034UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR14                 (*((volatile unsigned int*)(0x42212038UL)))
#define bM4_AOS_PEVNTDIRR1_PDIR15                 (*((volatile unsigned int*)(0x4221203CUL)))
#define bM4_AOS_PEVNTIDR1_PIN00                   (*((volatile unsigned int*)(0x42212080UL)))
#define bM4_AOS_PEVNTIDR1_PIN01                   (*((volatile unsigned int*)(0x42212084UL)))
#define bM4_AOS_PEVNTIDR1_PIN02                   (*((volatile unsigned int*)(0x42212088UL)))
#define bM4_AOS_PEVNTIDR1_PIN03                   (*((volatile unsigned int*)(0x4221208CUL)))
#define bM4_AOS_PEVNTIDR1_PIN04                   (*((volatile unsigned int*)(0x42212090UL)))
#define bM4_AOS_PEVNTIDR1_PIN05                   (*((volatile unsigned int*)(0x42212094UL)))
#define bM4_AOS_PEVNTIDR1_PIN06                   (*((volatile unsigned int*)(0x42212098UL)))
#define bM4_AOS_PEVNTIDR1_PIN07                   (*((volatile unsigned int*)(0x4221209CUL)))
#define bM4_AOS_PEVNTIDR1_PIN08                   (*((volatile unsigned int*)(0x422120A0UL)))
#define bM4_AOS_PEVNTIDR1_PIN09                   (*((volatile unsigned int*)(0x422120A4UL)))
#define bM4_AOS_PEVNTIDR1_PIN10                   (*((volatile unsigned int*)(0x422120A8UL)))
#define bM4_AOS_PEVNTIDR1_PIN11                   (*((volatile unsigned int*)(0x422120ACUL)))
#define bM4_AOS_PEVNTIDR1_PIN12                   (*((volatile unsigned int*)(0x422120B0UL)))
#define bM4_AOS_PEVNTIDR1_PIN13                   (*((volatile unsigned int*)(0x422120B4UL)))
#define bM4_AOS_PEVNTIDR1_PIN14                   (*((volatile unsigned int*)(0x422120B8UL)))
#define bM4_AOS_PEVNTIDR1_PIN15                   (*((volatile unsigned int*)(0x422120BCUL)))
#define bM4_AOS_PEVNTODR1_POUT00                  (*((volatile unsigned int*)(0x42212100UL)))
#define bM4_AOS_PEVNTODR1_POUT01                  (*((volatile unsigned int*)(0x42212104UL)))
#define bM4_AOS_PEVNTODR1_POUT02                  (*((volatile unsigned int*)(0x42212108UL)))
#define bM4_AOS_PEVNTODR1_POUT03                  (*((volatile unsigned int*)(0x4221210CUL)))
#define bM4_AOS_PEVNTODR1_POUT04                  (*((volatile unsigned int*)(0x42212110UL)))
#define bM4_AOS_PEVNTODR1_POUT05                  (*((volatile unsigned int*)(0x42212114UL)))
#define bM4_AOS_PEVNTODR1_POUT06                  (*((volatile unsigned int*)(0x42212118UL)))
#define bM4_AOS_PEVNTODR1_POUT07                  (*((volatile unsigned int*)(0x4221211CUL)))
#define bM4_AOS_PEVNTODR1_POUT08                  (*((volatile unsigned int*)(0x42212120UL)))
#define bM4_AOS_PEVNTODR1_POUT09                  (*((volatile unsigned int*)(0x42212124UL)))
#define bM4_AOS_PEVNTODR1_POUT10                  (*((volatile unsigned int*)(0x42212128UL)))
#define bM4_AOS_PEVNTODR1_POUT11                  (*((volatile unsigned int*)(0x4221212CUL)))
#define bM4_AOS_PEVNTODR1_POUT12                  (*((volatile unsigned int*)(0x42212130UL)))
#define bM4_AOS_PEVNTODR1_POUT13                  (*((volatile unsigned int*)(0x42212134UL)))
#define bM4_AOS_PEVNTODR1_POUT14                  (*((volatile unsigned int*)(0x42212138UL)))
#define bM4_AOS_PEVNTODR1_POUT15                  (*((volatile unsigned int*)(0x4221213CUL)))
#define bM4_AOS_PEVNTORR1_POR00                   (*((volatile unsigned int*)(0x42212180UL)))
#define bM4_AOS_PEVNTORR1_POR01                   (*((volatile unsigned int*)(0x42212184UL)))
#define bM4_AOS_PEVNTORR1_POR02                   (*((volatile unsigned int*)(0x42212188UL)))
#define bM4_AOS_PEVNTORR1_POR03                   (*((volatile unsigned int*)(0x4221218CUL)))
#define bM4_AOS_PEVNTORR1_POR04                   (*((volatile unsigned int*)(0x42212190UL)))
#define bM4_AOS_PEVNTORR1_POR05                   (*((volatile unsigned int*)(0x42212194UL)))
#define bM4_AOS_PEVNTORR1_POR06                   (*((volatile unsigned int*)(0x42212198UL)))
#define bM4_AOS_PEVNTORR1_POR07                   (*((volatile unsigned int*)(0x4221219CUL)))
#define bM4_AOS_PEVNTORR1_POR08                   (*((volatile unsigned int*)(0x422121A0UL)))
#define bM4_AOS_PEVNTORR1_POR09                   (*((volatile unsigned int*)(0x422121A4UL)))
#define bM4_AOS_PEVNTORR1_POR10                   (*((volatile unsigned int*)(0x422121A8UL)))
#define bM4_AOS_PEVNTORR1_POR11                   (*((volatile unsigned int*)(0x422121ACUL)))
#define bM4_AOS_PEVNTORR1_POR12                   (*((volatile unsigned int*)(0x422121B0UL)))
#define bM4_AOS_PEVNTORR1_POR13                   (*((volatile unsigned int*)(0x422121B4UL)))
#define bM4_AOS_PEVNTORR1_POR14                   (*((volatile unsigned int*)(0x422121B8UL)))
#define bM4_AOS_PEVNTORR1_POR15                   (*((volatile unsigned int*)(0x422121BCUL)))
#define bM4_AOS_PEVNTOSR1_POS00                   (*((volatile unsigned int*)(0x42212200UL)))
#define bM4_AOS_PEVNTOSR1_POS01                   (*((volatile unsigned int*)(0x42212204UL)))
#define bM4_AOS_PEVNTOSR1_POS02                   (*((volatile unsigned int*)(0x42212208UL)))
#define bM4_AOS_PEVNTOSR1_POS03                   (*((volatile unsigned int*)(0x4221220CUL)))
#define bM4_AOS_PEVNTOSR1_POS04                   (*((volatile unsigned int*)(0x42212210UL)))
#define bM4_AOS_PEVNTOSR1_POS05                   (*((volatile unsigned int*)(0x42212214UL)))
#define bM4_AOS_PEVNTOSR1_POS06                   (*((volatile unsigned int*)(0x42212218UL)))
#define bM4_AOS_PEVNTOSR1_POS07                   (*((volatile unsigned int*)(0x4221221CUL)))
#define bM4_AOS_PEVNTOSR1_POS08                   (*((volatile unsigned int*)(0x42212220UL)))
#define bM4_AOS_PEVNTOSR1_POS09                   (*((volatile unsigned int*)(0x42212224UL)))
#define bM4_AOS_PEVNTOSR1_POS10                   (*((volatile unsigned int*)(0x42212228UL)))
#define bM4_AOS_PEVNTOSR1_POS11                   (*((volatile unsigned int*)(0x4221222CUL)))
#define bM4_AOS_PEVNTOSR1_POS12                   (*((volatile unsigned int*)(0x42212230UL)))
#define bM4_AOS_PEVNTOSR1_POS13                   (*((volatile unsigned int*)(0x42212234UL)))
#define bM4_AOS_PEVNTOSR1_POS14                   (*((volatile unsigned int*)(0x42212238UL)))
#define bM4_AOS_PEVNTOSR1_POS15                   (*((volatile unsigned int*)(0x4221223CUL)))
#define bM4_AOS_PEVNTRISR1_RIS00                  (*((volatile unsigned int*)(0x42212280UL)))
#define bM4_AOS_PEVNTRISR1_RIS01                  (*((volatile unsigned int*)(0x42212284UL)))
#define bM4_AOS_PEVNTRISR1_RIS02                  (*((volatile unsigned int*)(0x42212288UL)))
#define bM4_AOS_PEVNTRISR1_RIS03                  (*((volatile unsigned int*)(0x4221228CUL)))
#define bM4_AOS_PEVNTRISR1_RIS04                  (*((volatile unsigned int*)(0x42212290UL)))
#define bM4_AOS_PEVNTRISR1_RIS05                  (*((volatile unsigned int*)(0x42212294UL)))
#define bM4_AOS_PEVNTRISR1_RIS06                  (*((volatile unsigned int*)(0x42212298UL)))
#define bM4_AOS_PEVNTRISR1_RIS07                  (*((volatile unsigned int*)(0x4221229CUL)))
#define bM4_AOS_PEVNTRISR1_RIS08                  (*((volatile unsigned int*)(0x422122A0UL)))
#define bM4_AOS_PEVNTRISR1_RIS09                  (*((volatile unsigned int*)(0x422122A4UL)))
#define bM4_AOS_PEVNTRISR1_RIS10                  (*((volatile unsigned int*)(0x422122A8UL)))
#define bM4_AOS_PEVNTRISR1_RIS11                  (*((volatile unsigned int*)(0x422122ACUL)))
#define bM4_AOS_PEVNTRISR1_RIS12                  (*((volatile unsigned int*)(0x422122B0UL)))
#define bM4_AOS_PEVNTRISR1_RIS13                  (*((volatile unsigned int*)(0x422122B4UL)))
#define bM4_AOS_PEVNTRISR1_RIS14                  (*((volatile unsigned int*)(0x422122B8UL)))
#define bM4_AOS_PEVNTRISR1_RIS15                  (*((volatile unsigned int*)(0x422122BCUL)))
#define bM4_AOS_PEVNTFAL1_FAL00                   (*((volatile unsigned int*)(0x42212300UL)))
#define bM4_AOS_PEVNTFAL1_FAL01                   (*((volatile unsigned int*)(0x42212304UL)))
#define bM4_AOS_PEVNTFAL1_FAL02                   (*((volatile unsigned int*)(0x42212308UL)))
#define bM4_AOS_PEVNTFAL1_FAL03                   (*((volatile unsigned int*)(0x4221230CUL)))
#define bM4_AOS_PEVNTFAL1_FAL04                   (*((volatile unsigned int*)(0x42212310UL)))
#define bM4_AOS_PEVNTFAL1_FAL05                   (*((volatile unsigned int*)(0x42212314UL)))
#define bM4_AOS_PEVNTFAL1_FAL06                   (*((volatile unsigned int*)(0x42212318UL)))
#define bM4_AOS_PEVNTFAL1_FAL07                   (*((volatile unsigned int*)(0x4221231CUL)))
#define bM4_AOS_PEVNTFAL1_FAL08                   (*((volatile unsigned int*)(0x42212320UL)))
#define bM4_AOS_PEVNTFAL1_FAL09                   (*((volatile unsigned int*)(0x42212324UL)))
#define bM4_AOS_PEVNTFAL1_FAL10                   (*((volatile unsigned int*)(0x42212328UL)))
#define bM4_AOS_PEVNTFAL1_FAL11                   (*((volatile unsigned int*)(0x4221232CUL)))
#define bM4_AOS_PEVNTFAL1_FAL12                   (*((volatile unsigned int*)(0x42212330UL)))
#define bM4_AOS_PEVNTFAL1_FAL13                   (*((volatile unsigned int*)(0x42212334UL)))
#define bM4_AOS_PEVNTFAL1_FAL14                   (*((volatile unsigned int*)(0x42212338UL)))
#define bM4_AOS_PEVNTFAL1_FAL15                   (*((volatile unsigned int*)(0x4221233CUL)))
#define bM4_AOS_PEVNTDIRR2_PDIR00                 (*((volatile unsigned int*)(0x42212380UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR01                 (*((volatile unsigned int*)(0x42212384UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR02                 (*((volatile unsigned int*)(0x42212388UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR03                 (*((volatile unsigned int*)(0x4221238CUL)))
#define bM4_AOS_PEVNTDIRR2_PDIR04                 (*((volatile unsigned int*)(0x42212390UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR05                 (*((volatile unsigned int*)(0x42212394UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR06                 (*((volatile unsigned int*)(0x42212398UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR07                 (*((volatile unsigned int*)(0x4221239CUL)))
#define bM4_AOS_PEVNTDIRR2_PDIR08                 (*((volatile unsigned int*)(0x422123A0UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR09                 (*((volatile unsigned int*)(0x422123A4UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR10                 (*((volatile unsigned int*)(0x422123A8UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR11                 (*((volatile unsigned int*)(0x422123ACUL)))
#define bM4_AOS_PEVNTDIRR2_PDIR12                 (*((volatile unsigned int*)(0x422123B0UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR13                 (*((volatile unsigned int*)(0x422123B4UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR14                 (*((volatile unsigned int*)(0x422123B8UL)))
#define bM4_AOS_PEVNTDIRR2_PDIR15                 (*((volatile unsigned int*)(0x422123BCUL)))
#define bM4_AOS_PEVNTIDR2_PIN00                   (*((volatile unsigned int*)(0x42212400UL)))
#define bM4_AOS_PEVNTIDR2_PIN01                   (*((volatile unsigned int*)(0x42212404UL)))
#define bM4_AOS_PEVNTIDR2_PIN02                   (*((volatile unsigned int*)(0x42212408UL)))
#define bM4_AOS_PEVNTIDR2_PIN03                   (*((volatile unsigned int*)(0x4221240CUL)))
#define bM4_AOS_PEVNTIDR2_PIN04                   (*((volatile unsigned int*)(0x42212410UL)))
#define bM4_AOS_PEVNTIDR2_PIN05                   (*((volatile unsigned int*)(0x42212414UL)))
#define bM4_AOS_PEVNTIDR2_PIN06                   (*((volatile unsigned int*)(0x42212418UL)))
#define bM4_AOS_PEVNTIDR2_PIN07                   (*((volatile unsigned int*)(0x4221241CUL)))
#define bM4_AOS_PEVNTIDR2_PIN08                   (*((volatile unsigned int*)(0x42212420UL)))
#define bM4_AOS_PEVNTIDR2_PIN09                   (*((volatile unsigned int*)(0x42212424UL)))
#define bM4_AOS_PEVNTIDR2_PIN10                   (*((volatile unsigned int*)(0x42212428UL)))
#define bM4_AOS_PEVNTIDR2_PIN11                   (*((volatile unsigned int*)(0x4221242CUL)))
#define bM4_AOS_PEVNTIDR2_PIN12                   (*((volatile unsigned int*)(0x42212430UL)))
#define bM4_AOS_PEVNTIDR2_PIN13                   (*((volatile unsigned int*)(0x42212434UL)))
#define bM4_AOS_PEVNTIDR2_PIN14                   (*((volatile unsigned int*)(0x42212438UL)))
#define bM4_AOS_PEVNTIDR2_PIN15                   (*((volatile unsigned int*)(0x4221243CUL)))
#define bM4_AOS_PEVNTODR2_POUT00                  (*((volatile unsigned int*)(0x42212480UL)))
#define bM4_AOS_PEVNTODR2_POUT01                  (*((volatile unsigned int*)(0x42212484UL)))
#define bM4_AOS_PEVNTODR2_POUT02                  (*((volatile unsigned int*)(0x42212488UL)))
#define bM4_AOS_PEVNTODR2_POUT03                  (*((volatile unsigned int*)(0x4221248CUL)))
#define bM4_AOS_PEVNTODR2_POUT04                  (*((volatile unsigned int*)(0x42212490UL)))
#define bM4_AOS_PEVNTODR2_POUT05                  (*((volatile unsigned int*)(0x42212494UL)))
#define bM4_AOS_PEVNTODR2_POUT06                  (*((volatile unsigned int*)(0x42212498UL)))
#define bM4_AOS_PEVNTODR2_POUT07                  (*((volatile unsigned int*)(0x4221249CUL)))
#define bM4_AOS_PEVNTODR2_POUT08                  (*((volatile unsigned int*)(0x422124A0UL)))
#define bM4_AOS_PEVNTODR2_POUT09                  (*((volatile unsigned int*)(0x422124A4UL)))
#define bM4_AOS_PEVNTODR2_POUT10                  (*((volatile unsigned int*)(0x422124A8UL)))
#define bM4_AOS_PEVNTODR2_POUT11                  (*((volatile unsigned int*)(0x422124ACUL)))
#define bM4_AOS_PEVNTODR2_POUT12                  (*((volatile unsigned int*)(0x422124B0UL)))
#define bM4_AOS_PEVNTODR2_POUT13                  (*((volatile unsigned int*)(0x422124B4UL)))
#define bM4_AOS_PEVNTODR2_POUT14                  (*((volatile unsigned int*)(0x422124B8UL)))
#define bM4_AOS_PEVNTODR2_POUT15                  (*((volatile unsigned int*)(0x422124BCUL)))
#define bM4_AOS_PEVNTORR2_POR00                   (*((volatile unsigned int*)(0x42212500UL)))
#define bM4_AOS_PEVNTORR2_POR01                   (*((volatile unsigned int*)(0x42212504UL)))
#define bM4_AOS_PEVNTORR2_POR02                   (*((volatile unsigned int*)(0x42212508UL)))
#define bM4_AOS_PEVNTORR2_POR03                   (*((volatile unsigned int*)(0x4221250CUL)))
#define bM4_AOS_PEVNTORR2_POR04                   (*((volatile unsigned int*)(0x42212510UL)))
#define bM4_AOS_PEVNTORR2_POR05                   (*((volatile unsigned int*)(0x42212514UL)))
#define bM4_AOS_PEVNTORR2_POR06                   (*((volatile unsigned int*)(0x42212518UL)))
#define bM4_AOS_PEVNTORR2_POR07                   (*((volatile unsigned int*)(0x4221251CUL)))
#define bM4_AOS_PEVNTORR2_POR08                   (*((volatile unsigned int*)(0x42212520UL)))
#define bM4_AOS_PEVNTORR2_POR09                   (*((volatile unsigned int*)(0x42212524UL)))
#define bM4_AOS_PEVNTORR2_POR10                   (*((volatile unsigned int*)(0x42212528UL)))
#define bM4_AOS_PEVNTORR2_POR11                   (*((volatile unsigned int*)(0x4221252CUL)))
#define bM4_AOS_PEVNTORR2_POR12                   (*((volatile unsigned int*)(0x42212530UL)))
#define bM4_AOS_PEVNTORR2_POR13                   (*((volatile unsigned int*)(0x42212534UL)))
#define bM4_AOS_PEVNTORR2_POR14                   (*((volatile unsigned int*)(0x42212538UL)))
#define bM4_AOS_PEVNTORR2_POR15                   (*((volatile unsigned int*)(0x4221253CUL)))
#define bM4_AOS_PEVNTOSR2_POS00                   (*((volatile unsigned int*)(0x42212580UL)))
#define bM4_AOS_PEVNTOSR2_POS01                   (*((volatile unsigned int*)(0x42212584UL)))
#define bM4_AOS_PEVNTOSR2_POS02                   (*((volatile unsigned int*)(0x42212588UL)))
#define bM4_AOS_PEVNTOSR2_POS03                   (*((volatile unsigned int*)(0x4221258CUL)))
#define bM4_AOS_PEVNTOSR2_POS04                   (*((volatile unsigned int*)(0x42212590UL)))
#define bM4_AOS_PEVNTOSR2_POS05                   (*((volatile unsigned int*)(0x42212594UL)))
#define bM4_AOS_PEVNTOSR2_POS06                   (*((volatile unsigned int*)(0x42212598UL)))
#define bM4_AOS_PEVNTOSR2_POS07                   (*((volatile unsigned int*)(0x4221259CUL)))
#define bM4_AOS_PEVNTOSR2_POS08                   (*((volatile unsigned int*)(0x422125A0UL)))
#define bM4_AOS_PEVNTOSR2_POS09                   (*((volatile unsigned int*)(0x422125A4UL)))
#define bM4_AOS_PEVNTOSR2_POS10                   (*((volatile unsigned int*)(0x422125A8UL)))
#define bM4_AOS_PEVNTOSR2_POS11                   (*((volatile unsigned int*)(0x422125ACUL)))
#define bM4_AOS_PEVNTOSR2_POS12                   (*((volatile unsigned int*)(0x422125B0UL)))
#define bM4_AOS_PEVNTOSR2_POS13                   (*((volatile unsigned int*)(0x422125B4UL)))
#define bM4_AOS_PEVNTOSR2_POS14                   (*((volatile unsigned int*)(0x422125B8UL)))
#define bM4_AOS_PEVNTOSR2_POS15                   (*((volatile unsigned int*)(0x422125BCUL)))
#define bM4_AOS_PEVNTRISR2_RIS00                  (*((volatile unsigned int*)(0x42212600UL)))
#define bM4_AOS_PEVNTRISR2_RIS01                  (*((volatile unsigned int*)(0x42212604UL)))
#define bM4_AOS_PEVNTRISR2_RIS02                  (*((volatile unsigned int*)(0x42212608UL)))
#define bM4_AOS_PEVNTRISR2_RIS03                  (*((volatile unsigned int*)(0x4221260CUL)))
#define bM4_AOS_PEVNTRISR2_RIS04                  (*((volatile unsigned int*)(0x42212610UL)))
#define bM4_AOS_PEVNTRISR2_RIS05                  (*((volatile unsigned int*)(0x42212614UL)))
#define bM4_AOS_PEVNTRISR2_RIS06                  (*((volatile unsigned int*)(0x42212618UL)))
#define bM4_AOS_PEVNTRISR2_RIS07                  (*((volatile unsigned int*)(0x4221261CUL)))
#define bM4_AOS_PEVNTRISR2_RIS08                  (*((volatile unsigned int*)(0x42212620UL)))
#define bM4_AOS_PEVNTRISR2_RIS09                  (*((volatile unsigned int*)(0x42212624UL)))
#define bM4_AOS_PEVNTRISR2_RIS10                  (*((volatile unsigned int*)(0x42212628UL)))
#define bM4_AOS_PEVNTRISR2_RIS11                  (*((volatile unsigned int*)(0x4221262CUL)))
#define bM4_AOS_PEVNTRISR2_RIS12                  (*((volatile unsigned int*)(0x42212630UL)))
#define bM4_AOS_PEVNTRISR2_RIS13                  (*((volatile unsigned int*)(0x42212634UL)))
#define bM4_AOS_PEVNTRISR2_RIS14                  (*((volatile unsigned int*)(0x42212638UL)))
#define bM4_AOS_PEVNTRISR2_RIS15                  (*((volatile unsigned int*)(0x4221263CUL)))
#define bM4_AOS_PEVNTFAL2_FAL00                   (*((volatile unsigned int*)(0x42212680UL)))
#define bM4_AOS_PEVNTFAL2_FAL01                   (*((volatile unsigned int*)(0x42212684UL)))
#define bM4_AOS_PEVNTFAL2_FAL02                   (*((volatile unsigned int*)(0x42212688UL)))
#define bM4_AOS_PEVNTFAL2_FAL03                   (*((volatile unsigned int*)(0x4221268CUL)))
#define bM4_AOS_PEVNTFAL2_FAL04                   (*((volatile unsigned int*)(0x42212690UL)))
#define bM4_AOS_PEVNTFAL2_FAL05                   (*((volatile unsigned int*)(0x42212694UL)))
#define bM4_AOS_PEVNTFAL2_FAL06                   (*((volatile unsigned int*)(0x42212698UL)))
#define bM4_AOS_PEVNTFAL2_FAL07                   (*((volatile unsigned int*)(0x4221269CUL)))
#define bM4_AOS_PEVNTFAL2_FAL08                   (*((volatile unsigned int*)(0x422126A0UL)))
#define bM4_AOS_PEVNTFAL2_FAL09                   (*((volatile unsigned int*)(0x422126A4UL)))
#define bM4_AOS_PEVNTFAL2_FAL10                   (*((volatile unsigned int*)(0x422126A8UL)))
#define bM4_AOS_PEVNTFAL2_FAL11                   (*((volatile unsigned int*)(0x422126ACUL)))
#define bM4_AOS_PEVNTFAL2_FAL12                   (*((volatile unsigned int*)(0x422126B0UL)))
#define bM4_AOS_PEVNTFAL2_FAL13                   (*((volatile unsigned int*)(0x422126B4UL)))
#define bM4_AOS_PEVNTFAL2_FAL14                   (*((volatile unsigned int*)(0x422126B8UL)))
#define bM4_AOS_PEVNTFAL2_FAL15                   (*((volatile unsigned int*)(0x422126BCUL)))
#define bM4_AOS_PEVNTDIRR3_PDIR00                 (*((volatile unsigned int*)(0x42212700UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR01                 (*((volatile unsigned int*)(0x42212704UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR02                 (*((volatile unsigned int*)(0x42212708UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR03                 (*((volatile unsigned int*)(0x4221270CUL)))
#define bM4_AOS_PEVNTDIRR3_PDIR04                 (*((volatile unsigned int*)(0x42212710UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR05                 (*((volatile unsigned int*)(0x42212714UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR06                 (*((volatile unsigned int*)(0x42212718UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR07                 (*((volatile unsigned int*)(0x4221271CUL)))
#define bM4_AOS_PEVNTDIRR3_PDIR08                 (*((volatile unsigned int*)(0x42212720UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR09                 (*((volatile unsigned int*)(0x42212724UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR10                 (*((volatile unsigned int*)(0x42212728UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR11                 (*((volatile unsigned int*)(0x4221272CUL)))
#define bM4_AOS_PEVNTDIRR3_PDIR12                 (*((volatile unsigned int*)(0x42212730UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR13                 (*((volatile unsigned int*)(0x42212734UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR14                 (*((volatile unsigned int*)(0x42212738UL)))
#define bM4_AOS_PEVNTDIRR3_PDIR15                 (*((volatile unsigned int*)(0x4221273CUL)))
#define bM4_AOS_PEVNTIDR3_PIN00                   (*((volatile unsigned int*)(0x42212780UL)))
#define bM4_AOS_PEVNTIDR3_PIN01                   (*((volatile unsigned int*)(0x42212784UL)))
#define bM4_AOS_PEVNTIDR3_PIN02                   (*((volatile unsigned int*)(0x42212788UL)))
#define bM4_AOS_PEVNTIDR3_PIN03                   (*((volatile unsigned int*)(0x4221278CUL)))
#define bM4_AOS_PEVNTIDR3_PIN04                   (*((volatile unsigned int*)(0x42212790UL)))
#define bM4_AOS_PEVNTIDR3_PIN05                   (*((volatile unsigned int*)(0x42212794UL)))
#define bM4_AOS_PEVNTIDR3_PIN06                   (*((volatile unsigned int*)(0x42212798UL)))
#define bM4_AOS_PEVNTIDR3_PIN07                   (*((volatile unsigned int*)(0x4221279CUL)))
#define bM4_AOS_PEVNTIDR3_PIN08                   (*((volatile unsigned int*)(0x422127A0UL)))
#define bM4_AOS_PEVNTIDR3_PIN09                   (*((volatile unsigned int*)(0x422127A4UL)))
#define bM4_AOS_PEVNTIDR3_PIN10                   (*((volatile unsigned int*)(0x422127A8UL)))
#define bM4_AOS_PEVNTIDR3_PIN11                   (*((volatile unsigned int*)(0x422127ACUL)))
#define bM4_AOS_PEVNTIDR3_PIN12                   (*((volatile unsigned int*)(0x422127B0UL)))
#define bM4_AOS_PEVNTIDR3_PIN13                   (*((volatile unsigned int*)(0x422127B4UL)))
#define bM4_AOS_PEVNTIDR3_PIN14                   (*((volatile unsigned int*)(0x422127B8UL)))
#define bM4_AOS_PEVNTIDR3_PIN15                   (*((volatile unsigned int*)(0x422127BCUL)))
#define bM4_AOS_PEVNTODR3_POUT00                  (*((volatile unsigned int*)(0x42212800UL)))
#define bM4_AOS_PEVNTODR3_POUT01                  (*((volatile unsigned int*)(0x42212804UL)))
#define bM4_AOS_PEVNTODR3_POUT02                  (*((volatile unsigned int*)(0x42212808UL)))
#define bM4_AOS_PEVNTODR3_POUT03                  (*((volatile unsigned int*)(0x4221280CUL)))
#define bM4_AOS_PEVNTODR3_POUT04                  (*((volatile unsigned int*)(0x42212810UL)))
#define bM4_AOS_PEVNTODR3_POUT05                  (*((volatile unsigned int*)(0x42212814UL)))
#define bM4_AOS_PEVNTODR3_POUT06                  (*((volatile unsigned int*)(0x42212818UL)))
#define bM4_AOS_PEVNTODR3_POUT07                  (*((volatile unsigned int*)(0x4221281CUL)))
#define bM4_AOS_PEVNTODR3_POUT08                  (*((volatile unsigned int*)(0x42212820UL)))
#define bM4_AOS_PEVNTODR3_POUT09                  (*((volatile unsigned int*)(0x42212824UL)))
#define bM4_AOS_PEVNTODR3_POUT10                  (*((volatile unsigned int*)(0x42212828UL)))
#define bM4_AOS_PEVNTODR3_POUT11                  (*((volatile unsigned int*)(0x4221282CUL)))
#define bM4_AOS_PEVNTODR3_POUT12                  (*((volatile unsigned int*)(0x42212830UL)))
#define bM4_AOS_PEVNTODR3_POUT13                  (*((volatile unsigned int*)(0x42212834UL)))
#define bM4_AOS_PEVNTODR3_POUT14                  (*((volatile unsigned int*)(0x42212838UL)))
#define bM4_AOS_PEVNTODR3_POUT15                  (*((volatile unsigned int*)(0x4221283CUL)))
#define bM4_AOS_PEVNTORR3_POR00                   (*((volatile unsigned int*)(0x42212880UL)))
#define bM4_AOS_PEVNTORR3_POR01                   (*((volatile unsigned int*)(0x42212884UL)))
#define bM4_AOS_PEVNTORR3_POR02                   (*((volatile unsigned int*)(0x42212888UL)))
#define bM4_AOS_PEVNTORR3_POR03                   (*((volatile unsigned int*)(0x4221288CUL)))
#define bM4_AOS_PEVNTORR3_POR04                   (*((volatile unsigned int*)(0x42212890UL)))
#define bM4_AOS_PEVNTORR3_POR05                   (*((volatile unsigned int*)(0x42212894UL)))
#define bM4_AOS_PEVNTORR3_POR06                   (*((volatile unsigned int*)(0x42212898UL)))
#define bM4_AOS_PEVNTORR3_POR07                   (*((volatile unsigned int*)(0x4221289CUL)))
#define bM4_AOS_PEVNTORR3_POR08                   (*((volatile unsigned int*)(0x422128A0UL)))
#define bM4_AOS_PEVNTORR3_POR09                   (*((volatile unsigned int*)(0x422128A4UL)))
#define bM4_AOS_PEVNTORR3_POR10                   (*((volatile unsigned int*)(0x422128A8UL)))
#define bM4_AOS_PEVNTORR3_POR11                   (*((volatile unsigned int*)(0x422128ACUL)))
#define bM4_AOS_PEVNTORR3_POR12                   (*((volatile unsigned int*)(0x422128B0UL)))
#define bM4_AOS_PEVNTORR3_POR13                   (*((volatile unsigned int*)(0x422128B4UL)))
#define bM4_AOS_PEVNTORR3_POR14                   (*((volatile unsigned int*)(0x422128B8UL)))
#define bM4_AOS_PEVNTORR3_POR15                   (*((volatile unsigned int*)(0x422128BCUL)))
#define bM4_AOS_PEVNTOSR3_POS00                   (*((volatile unsigned int*)(0x42212900UL)))
#define bM4_AOS_PEVNTOSR3_POS01                   (*((volatile unsigned int*)(0x42212904UL)))
#define bM4_AOS_PEVNTOSR3_POS02                   (*((volatile unsigned int*)(0x42212908UL)))
#define bM4_AOS_PEVNTOSR3_POS03                   (*((volatile unsigned int*)(0x4221290CUL)))
#define bM4_AOS_PEVNTOSR3_POS04                   (*((volatile unsigned int*)(0x42212910UL)))
#define bM4_AOS_PEVNTOSR3_POS05                   (*((volatile unsigned int*)(0x42212914UL)))
#define bM4_AOS_PEVNTOSR3_POS06                   (*((volatile unsigned int*)(0x42212918UL)))
#define bM4_AOS_PEVNTOSR3_POS07                   (*((volatile unsigned int*)(0x4221291CUL)))
#define bM4_AOS_PEVNTOSR3_POS08                   (*((volatile unsigned int*)(0x42212920UL)))
#define bM4_AOS_PEVNTOSR3_POS09                   (*((volatile unsigned int*)(0x42212924UL)))
#define bM4_AOS_PEVNTOSR3_POS10                   (*((volatile unsigned int*)(0x42212928UL)))
#define bM4_AOS_PEVNTOSR3_POS11                   (*((volatile unsigned int*)(0x4221292CUL)))
#define bM4_AOS_PEVNTOSR3_POS12                   (*((volatile unsigned int*)(0x42212930UL)))
#define bM4_AOS_PEVNTOSR3_POS13                   (*((volatile unsigned int*)(0x42212934UL)))
#define bM4_AOS_PEVNTOSR3_POS14                   (*((volatile unsigned int*)(0x42212938UL)))
#define bM4_AOS_PEVNTOSR3_POS15                   (*((volatile unsigned int*)(0x4221293CUL)))
#define bM4_AOS_PEVNTRISR3_RIS00                  (*((volatile unsigned int*)(0x42212980UL)))
#define bM4_AOS_PEVNTRISR3_RIS01                  (*((volatile unsigned int*)(0x42212984UL)))
#define bM4_AOS_PEVNTRISR3_RIS02                  (*((volatile unsigned int*)(0x42212988UL)))
#define bM4_AOS_PEVNTRISR3_RIS03                  (*((volatile unsigned int*)(0x4221298CUL)))
#define bM4_AOS_PEVNTRISR3_RIS04                  (*((volatile unsigned int*)(0x42212990UL)))
#define bM4_AOS_PEVNTRISR3_RIS05                  (*((volatile unsigned int*)(0x42212994UL)))
#define bM4_AOS_PEVNTRISR3_RIS06                  (*((volatile unsigned int*)(0x42212998UL)))
#define bM4_AOS_PEVNTRISR3_RIS07                  (*((volatile unsigned int*)(0x4221299CUL)))
#define bM4_AOS_PEVNTRISR3_RIS08                  (*((volatile unsigned int*)(0x422129A0UL)))
#define bM4_AOS_PEVNTRISR3_RIS09                  (*((volatile unsigned int*)(0x422129A4UL)))
#define bM4_AOS_PEVNTRISR3_RIS10                  (*((volatile unsigned int*)(0x422129A8UL)))
#define bM4_AOS_PEVNTRISR3_RIS11                  (*((volatile unsigned int*)(0x422129ACUL)))
#define bM4_AOS_PEVNTRISR3_RIS12                  (*((volatile unsigned int*)(0x422129B0UL)))
#define bM4_AOS_PEVNTRISR3_RIS13                  (*((volatile unsigned int*)(0x422129B4UL)))
#define bM4_AOS_PEVNTRISR3_RIS14                  (*((volatile unsigned int*)(0x422129B8UL)))
#define bM4_AOS_PEVNTRISR3_RIS15                  (*((volatile unsigned int*)(0x422129BCUL)))
#define bM4_AOS_PEVNTFAL3_FAL00                   (*((volatile unsigned int*)(0x42212A00UL)))
#define bM4_AOS_PEVNTFAL3_FAL01                   (*((volatile unsigned int*)(0x42212A04UL)))
#define bM4_AOS_PEVNTFAL3_FAL02                   (*((volatile unsigned int*)(0x42212A08UL)))
#define bM4_AOS_PEVNTFAL3_FAL03                   (*((volatile unsigned int*)(0x42212A0CUL)))
#define bM4_AOS_PEVNTFAL3_FAL04                   (*((volatile unsigned int*)(0x42212A10UL)))
#define bM4_AOS_PEVNTFAL3_FAL05                   (*((volatile unsigned int*)(0x42212A14UL)))
#define bM4_AOS_PEVNTFAL3_FAL06                   (*((volatile unsigned int*)(0x42212A18UL)))
#define bM4_AOS_PEVNTFAL3_FAL07                   (*((volatile unsigned int*)(0x42212A1CUL)))
#define bM4_AOS_PEVNTFAL3_FAL08                   (*((volatile unsigned int*)(0x42212A20UL)))
#define bM4_AOS_PEVNTFAL3_FAL09                   (*((volatile unsigned int*)(0x42212A24UL)))
#define bM4_AOS_PEVNTFAL3_FAL10                   (*((volatile unsigned int*)(0x42212A28UL)))
#define bM4_AOS_PEVNTFAL3_FAL11                   (*((volatile unsigned int*)(0x42212A2CUL)))
#define bM4_AOS_PEVNTFAL3_FAL12                   (*((volatile unsigned int*)(0x42212A30UL)))
#define bM4_AOS_PEVNTFAL3_FAL13                   (*((volatile unsigned int*)(0x42212A34UL)))
#define bM4_AOS_PEVNTFAL3_FAL14                   (*((volatile unsigned int*)(0x42212A38UL)))
#define bM4_AOS_PEVNTFAL3_FAL15                   (*((volatile unsigned int*)(0x42212A3CUL)))
#define bM4_AOS_PEVNTDIRR4_PDIR00                 (*((volatile unsigned int*)(0x42212A80UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR01                 (*((volatile unsigned int*)(0x42212A84UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR02                 (*((volatile unsigned int*)(0x42212A88UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR03                 (*((volatile unsigned int*)(0x42212A8CUL)))
#define bM4_AOS_PEVNTDIRR4_PDIR04                 (*((volatile unsigned int*)(0x42212A90UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR05                 (*((volatile unsigned int*)(0x42212A94UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR06                 (*((volatile unsigned int*)(0x42212A98UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR07                 (*((volatile unsigned int*)(0x42212A9CUL)))
#define bM4_AOS_PEVNTDIRR4_PDIR08                 (*((volatile unsigned int*)(0x42212AA0UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR09                 (*((volatile unsigned int*)(0x42212AA4UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR10                 (*((volatile unsigned int*)(0x42212AA8UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR11                 (*((volatile unsigned int*)(0x42212AACUL)))
#define bM4_AOS_PEVNTDIRR4_PDIR12                 (*((volatile unsigned int*)(0x42212AB0UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR13                 (*((volatile unsigned int*)(0x42212AB4UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR14                 (*((volatile unsigned int*)(0x42212AB8UL)))
#define bM4_AOS_PEVNTDIRR4_PDIR15                 (*((volatile unsigned int*)(0x42212ABCUL)))
#define bM4_AOS_PEVNTIDR4_PIN00                   (*((volatile unsigned int*)(0x42212B00UL)))
#define bM4_AOS_PEVNTIDR4_PIN01                   (*((volatile unsigned int*)(0x42212B04UL)))
#define bM4_AOS_PEVNTIDR4_PIN02                   (*((volatile unsigned int*)(0x42212B08UL)))
#define bM4_AOS_PEVNTIDR4_PIN03                   (*((volatile unsigned int*)(0x42212B0CUL)))
#define bM4_AOS_PEVNTIDR4_PIN04                   (*((volatile unsigned int*)(0x42212B10UL)))
#define bM4_AOS_PEVNTIDR4_PIN05                   (*((volatile unsigned int*)(0x42212B14UL)))
#define bM4_AOS_PEVNTIDR4_PIN06                   (*((volatile unsigned int*)(0x42212B18UL)))
#define bM4_AOS_PEVNTIDR4_PIN07                   (*((volatile unsigned int*)(0x42212B1CUL)))
#define bM4_AOS_PEVNTIDR4_PIN08                   (*((volatile unsigned int*)(0x42212B20UL)))
#define bM4_AOS_PEVNTIDR4_PIN09                   (*((volatile unsigned int*)(0x42212B24UL)))
#define bM4_AOS_PEVNTIDR4_PIN10                   (*((volatile unsigned int*)(0x42212B28UL)))
#define bM4_AOS_PEVNTIDR4_PIN11                   (*((volatile unsigned int*)(0x42212B2CUL)))
#define bM4_AOS_PEVNTIDR4_PIN12                   (*((volatile unsigned int*)(0x42212B30UL)))
#define bM4_AOS_PEVNTIDR4_PIN13                   (*((volatile unsigned int*)(0x42212B34UL)))
#define bM4_AOS_PEVNTIDR4_PIN14                   (*((volatile unsigned int*)(0x42212B38UL)))
#define bM4_AOS_PEVNTIDR4_PIN15                   (*((volatile unsigned int*)(0x42212B3CUL)))
#define bM4_AOS_PEVNTODR4_POUT00                  (*((volatile unsigned int*)(0x42212B80UL)))
#define bM4_AOS_PEVNTODR4_POUT01                  (*((volatile unsigned int*)(0x42212B84UL)))
#define bM4_AOS_PEVNTODR4_POUT02                  (*((volatile unsigned int*)(0x42212B88UL)))
#define bM4_AOS_PEVNTODR4_POUT03                  (*((volatile unsigned int*)(0x42212B8CUL)))
#define bM4_AOS_PEVNTODR4_POUT04                  (*((volatile unsigned int*)(0x42212B90UL)))
#define bM4_AOS_PEVNTODR4_POUT05                  (*((volatile unsigned int*)(0x42212B94UL)))
#define bM4_AOS_PEVNTODR4_POUT06                  (*((volatile unsigned int*)(0x42212B98UL)))
#define bM4_AOS_PEVNTODR4_POUT07                  (*((volatile unsigned int*)(0x42212B9CUL)))
#define bM4_AOS_PEVNTODR4_POUT08                  (*((volatile unsigned int*)(0x42212BA0UL)))
#define bM4_AOS_PEVNTODR4_POUT09                  (*((volatile unsigned int*)(0x42212BA4UL)))
#define bM4_AOS_PEVNTODR4_POUT10                  (*((volatile unsigned int*)(0x42212BA8UL)))
#define bM4_AOS_PEVNTODR4_POUT11                  (*((volatile unsigned int*)(0x42212BACUL)))
#define bM4_AOS_PEVNTODR4_POUT12                  (*((volatile unsigned int*)(0x42212BB0UL)))
#define bM4_AOS_PEVNTODR4_POUT13                  (*((volatile unsigned int*)(0x42212BB4UL)))
#define bM4_AOS_PEVNTODR4_POUT14                  (*((volatile unsigned int*)(0x42212BB8UL)))
#define bM4_AOS_PEVNTODR4_POUT15                  (*((volatile unsigned int*)(0x42212BBCUL)))
#define bM4_AOS_PEVNTORR4_POR00                   (*((volatile unsigned int*)(0x42212C00UL)))
#define bM4_AOS_PEVNTORR4_POR01                   (*((volatile unsigned int*)(0x42212C04UL)))
#define bM4_AOS_PEVNTORR4_POR02                   (*((volatile unsigned int*)(0x42212C08UL)))
#define bM4_AOS_PEVNTORR4_POR03                   (*((volatile unsigned int*)(0x42212C0CUL)))
#define bM4_AOS_PEVNTORR4_POR04                   (*((volatile unsigned int*)(0x42212C10UL)))
#define bM4_AOS_PEVNTORR4_POR05                   (*((volatile unsigned int*)(0x42212C14UL)))
#define bM4_AOS_PEVNTORR4_POR06                   (*((volatile unsigned int*)(0x42212C18UL)))
#define bM4_AOS_PEVNTORR4_POR07                   (*((volatile unsigned int*)(0x42212C1CUL)))
#define bM4_AOS_PEVNTORR4_POR08                   (*((volatile unsigned int*)(0x42212C20UL)))
#define bM4_AOS_PEVNTORR4_POR09                   (*((volatile unsigned int*)(0x42212C24UL)))
#define bM4_AOS_PEVNTORR4_POR10                   (*((volatile unsigned int*)(0x42212C28UL)))
#define bM4_AOS_PEVNTORR4_POR11                   (*((volatile unsigned int*)(0x42212C2CUL)))
#define bM4_AOS_PEVNTORR4_POR12                   (*((volatile unsigned int*)(0x42212C30UL)))
#define bM4_AOS_PEVNTORR4_POR13                   (*((volatile unsigned int*)(0x42212C34UL)))
#define bM4_AOS_PEVNTORR4_POR14                   (*((volatile unsigned int*)(0x42212C38UL)))
#define bM4_AOS_PEVNTORR4_POR15                   (*((volatile unsigned int*)(0x42212C3CUL)))
#define bM4_AOS_PEVNTOSR4_POS00                   (*((volatile unsigned int*)(0x42212C80UL)))
#define bM4_AOS_PEVNTOSR4_POS01                   (*((volatile unsigned int*)(0x42212C84UL)))
#define bM4_AOS_PEVNTOSR4_POS02                   (*((volatile unsigned int*)(0x42212C88UL)))
#define bM4_AOS_PEVNTOSR4_POS03                   (*((volatile unsigned int*)(0x42212C8CUL)))
#define bM4_AOS_PEVNTOSR4_POS04                   (*((volatile unsigned int*)(0x42212C90UL)))
#define bM4_AOS_PEVNTOSR4_POS05                   (*((volatile unsigned int*)(0x42212C94UL)))
#define bM4_AOS_PEVNTOSR4_POS06                   (*((volatile unsigned int*)(0x42212C98UL)))
#define bM4_AOS_PEVNTOSR4_POS07                   (*((volatile unsigned int*)(0x42212C9CUL)))
#define bM4_AOS_PEVNTOSR4_POS08                   (*((volatile unsigned int*)(0x42212CA0UL)))
#define bM4_AOS_PEVNTOSR4_POS09                   (*((volatile unsigned int*)(0x42212CA4UL)))
#define bM4_AOS_PEVNTOSR4_POS10                   (*((volatile unsigned int*)(0x42212CA8UL)))
#define bM4_AOS_PEVNTOSR4_POS11                   (*((volatile unsigned int*)(0x42212CACUL)))
#define bM4_AOS_PEVNTOSR4_POS12                   (*((volatile unsigned int*)(0x42212CB0UL)))
#define bM4_AOS_PEVNTOSR4_POS13                   (*((volatile unsigned int*)(0x42212CB4UL)))
#define bM4_AOS_PEVNTOSR4_POS14                   (*((volatile unsigned int*)(0x42212CB8UL)))
#define bM4_AOS_PEVNTOSR4_POS15                   (*((volatile unsigned int*)(0x42212CBCUL)))
#define bM4_AOS_PEVNTRISR4_RIS00                  (*((volatile unsigned int*)(0x42212D00UL)))
#define bM4_AOS_PEVNTRISR4_RIS01                  (*((volatile unsigned int*)(0x42212D04UL)))
#define bM4_AOS_PEVNTRISR4_RIS02                  (*((volatile unsigned int*)(0x42212D08UL)))
#define bM4_AOS_PEVNTRISR4_RIS03                  (*((volatile unsigned int*)(0x42212D0CUL)))
#define bM4_AOS_PEVNTRISR4_RIS04                  (*((volatile unsigned int*)(0x42212D10UL)))
#define bM4_AOS_PEVNTRISR4_RIS05                  (*((volatile unsigned int*)(0x42212D14UL)))
#define bM4_AOS_PEVNTRISR4_RIS06                  (*((volatile unsigned int*)(0x42212D18UL)))
#define bM4_AOS_PEVNTRISR4_RIS07                  (*((volatile unsigned int*)(0x42212D1CUL)))
#define bM4_AOS_PEVNTRISR4_RIS08                  (*((volatile unsigned int*)(0x42212D20UL)))
#define bM4_AOS_PEVNTRISR4_RIS09                  (*((volatile unsigned int*)(0x42212D24UL)))
#define bM4_AOS_PEVNTRISR4_RIS10                  (*((volatile unsigned int*)(0x42212D28UL)))
#define bM4_AOS_PEVNTRISR4_RIS11                  (*((volatile unsigned int*)(0x42212D2CUL)))
#define bM4_AOS_PEVNTRISR4_RIS12                  (*((volatile unsigned int*)(0x42212D30UL)))
#define bM4_AOS_PEVNTRISR4_RIS13                  (*((volatile unsigned int*)(0x42212D34UL)))
#define bM4_AOS_PEVNTRISR4_RIS14                  (*((volatile unsigned int*)(0x42212D38UL)))
#define bM4_AOS_PEVNTRISR4_RIS15                  (*((volatile unsigned int*)(0x42212D3CUL)))
#define bM4_AOS_PEVNTFAL4_FAL00                   (*((volatile unsigned int*)(0x42212D80UL)))
#define bM4_AOS_PEVNTFAL4_FAL01                   (*((volatile unsigned int*)(0x42212D84UL)))
#define bM4_AOS_PEVNTFAL4_FAL02                   (*((volatile unsigned int*)(0x42212D88UL)))
#define bM4_AOS_PEVNTFAL4_FAL03                   (*((volatile unsigned int*)(0x42212D8CUL)))
#define bM4_AOS_PEVNTFAL4_FAL04                   (*((volatile unsigned int*)(0x42212D90UL)))
#define bM4_AOS_PEVNTFAL4_FAL05                   (*((volatile unsigned int*)(0x42212D94UL)))
#define bM4_AOS_PEVNTFAL4_FAL06                   (*((volatile unsigned int*)(0x42212D98UL)))
#define bM4_AOS_PEVNTFAL4_FAL07                   (*((volatile unsigned int*)(0x42212D9CUL)))
#define bM4_AOS_PEVNTFAL4_FAL08                   (*((volatile unsigned int*)(0x42212DA0UL)))
#define bM4_AOS_PEVNTFAL4_FAL09                   (*((volatile unsigned int*)(0x42212DA4UL)))
#define bM4_AOS_PEVNTFAL4_FAL10                   (*((volatile unsigned int*)(0x42212DA8UL)))
#define bM4_AOS_PEVNTFAL4_FAL11                   (*((volatile unsigned int*)(0x42212DACUL)))
#define bM4_AOS_PEVNTFAL4_FAL12                   (*((volatile unsigned int*)(0x42212DB0UL)))
#define bM4_AOS_PEVNTFAL4_FAL13                   (*((volatile unsigned int*)(0x42212DB4UL)))
#define bM4_AOS_PEVNTFAL4_FAL14                   (*((volatile unsigned int*)(0x42212DB8UL)))
#define bM4_AOS_PEVNTFAL4_FAL15                   (*((volatile unsigned int*)(0x42212DBCUL)))
#define bM4_AOS_PEVNTNFCR_NFEN1                   (*((volatile unsigned int*)(0x42212E00UL)))
#define bM4_AOS_PEVNTNFCR_DIVS10                  (*((volatile unsigned int*)(0x42212E04UL)))
#define bM4_AOS_PEVNTNFCR_DIVS11                  (*((volatile unsigned int*)(0x42212E08UL)))
#define bM4_AOS_PEVNTNFCR_NFEN2                   (*((volatile unsigned int*)(0x42212E20UL)))
#define bM4_AOS_PEVNTNFCR_DIVS20                  (*((volatile unsigned int*)(0x42212E24UL)))
#define bM4_AOS_PEVNTNFCR_DIVS21                  (*((volatile unsigned int*)(0x42212E28UL)))
#define bM4_AOS_PEVNTNFCR_NFEN3                   (*((volatile unsigned int*)(0x42212E40UL)))
#define bM4_AOS_PEVNTNFCR_DIVS30                  (*((volatile unsigned int*)(0x42212E44UL)))
#define bM4_AOS_PEVNTNFCR_DIVS31                  (*((volatile unsigned int*)(0x42212E48UL)))
#define bM4_AOS_PEVNTNFCR_NFEN4                   (*((volatile unsigned int*)(0x42212E60UL)))
#define bM4_AOS_PEVNTNFCR_DIVS40                  (*((volatile unsigned int*)(0x42212E64UL)))
#define bM4_AOS_PEVNTNFCR_DIVS41                  (*((volatile unsigned int*)(0x42212E68UL)))
#define bM4_CAN_CFG_STAT_BUSOFF                   (*((volatile unsigned int*)(0x42E09400UL)))
#define bM4_CAN_CFG_STAT_TACTIVE                  (*((volatile unsigned int*)(0x42E09404UL)))
#define bM4_CAN_CFG_STAT_RACTIVE                  (*((volatile unsigned int*)(0x42E09408UL)))
#define bM4_CAN_CFG_STAT_TSSS                     (*((volatile unsigned int*)(0x42E0940CUL)))
#define bM4_CAN_CFG_STAT_TPSS                     (*((volatile unsigned int*)(0x42E09410UL)))
#define bM4_CAN_CFG_STAT_LBMI                     (*((volatile unsigned int*)(0x42E09414UL)))
#define bM4_CAN_CFG_STAT_LBME                     (*((volatile unsigned int*)(0x42E09418UL)))
#define bM4_CAN_CFG_STAT_RESET                    (*((volatile unsigned int*)(0x42E0941CUL)))
#define bM4_CAN_TCMD_TSA                          (*((volatile unsigned int*)(0x42E09420UL)))
#define bM4_CAN_TCMD_TSALL                        (*((volatile unsigned int*)(0x42E09424UL)))
#define bM4_CAN_TCMD_TSONE                        (*((volatile unsigned int*)(0x42E09428UL)))
#define bM4_CAN_TCMD_TPA                          (*((volatile unsigned int*)(0x42E0942CUL)))
#define bM4_CAN_TCMD_TPE                          (*((volatile unsigned int*)(0x42E09430UL)))
#define bM4_CAN_TCMD_LOM                          (*((volatile unsigned int*)(0x42E09438UL)))
#define bM4_CAN_TCMD_TBSEL                        (*((volatile unsigned int*)(0x42E0943CUL)))
#define bM4_CAN_TCTRL_TSSTAT0                     (*((volatile unsigned int*)(0x42E09440UL)))
#define bM4_CAN_TCTRL_TSSTAT1                     (*((volatile unsigned int*)(0x42E09444UL)))
#define bM4_CAN_TCTRL_TTTBM                       (*((volatile unsigned int*)(0x42E09450UL)))
#define bM4_CAN_TCTRL_TSMODE                      (*((volatile unsigned int*)(0x42E09454UL)))
#define bM4_CAN_TCTRL_TSNEXT                      (*((volatile unsigned int*)(0x42E09458UL)))
#define bM4_CAN_RCTRL_RSTAT0                      (*((volatile unsigned int*)(0x42E09460UL)))
#define bM4_CAN_RCTRL_RSTAT1                      (*((volatile unsigned int*)(0x42E09464UL)))
#define bM4_CAN_RCTRL_RBALL                       (*((volatile unsigned int*)(0x42E0946CUL)))
#define bM4_CAN_RCTRL_RREL                        (*((volatile unsigned int*)(0x42E09470UL)))
#define bM4_CAN_RCTRL_ROV                         (*((volatile unsigned int*)(0x42E09474UL)))
#define bM4_CAN_RCTRL_ROM                         (*((volatile unsigned int*)(0x42E09478UL)))
#define bM4_CAN_RCTRL_SACK                        (*((volatile unsigned int*)(0x42E0947CUL)))
#define bM4_CAN_RTIE_TSFF                         (*((volatile unsigned int*)(0x42E09480UL)))
#define bM4_CAN_RTIE_EIE                          (*((volatile unsigned int*)(0x42E09484UL)))
#define bM4_CAN_RTIE_TSIE                         (*((volatile unsigned int*)(0x42E09488UL)))
#define bM4_CAN_RTIE_TPIE                         (*((volatile unsigned int*)(0x42E0948CUL)))
#define bM4_CAN_RTIE_RAFIE                        (*((volatile unsigned int*)(0x42E09490UL)))
#define bM4_CAN_RTIE_RFIE                         (*((volatile unsigned int*)(0x42E09494UL)))
#define bM4_CAN_RTIE_ROIE                         (*((volatile unsigned int*)(0x42E09498UL)))
#define bM4_CAN_RTIE_RIE                          (*((volatile unsigned int*)(0x42E0949CUL)))
#define bM4_CAN_RTIF_AIF                          (*((volatile unsigned int*)(0x42E094A0UL)))
#define bM4_CAN_RTIF_EIF                          (*((volatile unsigned int*)(0x42E094A4UL)))
#define bM4_CAN_RTIF_TSIF                         (*((volatile unsigned int*)(0x42E094A8UL)))
#define bM4_CAN_RTIF_TPIF                         (*((volatile unsigned int*)(0x42E094ACUL)))
#define bM4_CAN_RTIF_RAFIF                        (*((volatile unsigned int*)(0x42E094B0UL)))
#define bM4_CAN_RTIF_RFIF                         (*((volatile unsigned int*)(0x42E094B4UL)))
#define bM4_CAN_RTIF_ROIF                         (*((volatile unsigned int*)(0x42E094B8UL)))
#define bM4_CAN_RTIF_RIF                          (*((volatile unsigned int*)(0x42E094BCUL)))
#define bM4_CAN_ERRINT_BEIF                       (*((volatile unsigned int*)(0x42E094C0UL)))
#define bM4_CAN_ERRINT_BEIE                       (*((volatile unsigned int*)(0x42E094C4UL)))
#define bM4_CAN_ERRINT_ALIF                       (*((volatile unsigned int*)(0x42E094C8UL)))
#define bM4_CAN_ERRINT_ALIE                       (*((volatile unsigned int*)(0x42E094CCUL)))
#define bM4_CAN_ERRINT_EPIF                       (*((volatile unsigned int*)(0x42E094D0UL)))
#define bM4_CAN_ERRINT_EPIE                       (*((volatile unsigned int*)(0x42E094D4UL)))
#define bM4_CAN_ERRINT_EPASS                      (*((volatile unsigned int*)(0x42E094D8UL)))
#define bM4_CAN_ERRINT_EWARN                      (*((volatile unsigned int*)(0x42E094DCUL)))
#define bM4_CAN_LIMIT_EWL0                        (*((volatile unsigned int*)(0x42E094E0UL)))
#define bM4_CAN_LIMIT_EWL1                        (*((volatile unsigned int*)(0x42E094E4UL)))
#define bM4_CAN_LIMIT_EWL2                        (*((volatile unsigned int*)(0x42E094E8UL)))
#define bM4_CAN_LIMIT_EWL3                        (*((volatile unsigned int*)(0x42E094ECUL)))
#define bM4_CAN_LIMIT_AFWL0                       (*((volatile unsigned int*)(0x42E094F0UL)))
#define bM4_CAN_LIMIT_AFWL1                       (*((volatile unsigned int*)(0x42E094F4UL)))
#define bM4_CAN_LIMIT_AFWL2                       (*((volatile unsigned int*)(0x42E094F8UL)))
#define bM4_CAN_LIMIT_AFWL3                       (*((volatile unsigned int*)(0x42E094FCUL)))
#define bM4_CAN_BT_SEG_10                         (*((volatile unsigned int*)(0x42E09500UL)))
#define bM4_CAN_BT_SEG_11                         (*((volatile unsigned int*)(0x42E09504UL)))
#define bM4_CAN_BT_SEG_12                         (*((volatile unsigned int*)(0x42E09508UL)))
#define bM4_CAN_BT_SEG_13                         (*((volatile unsigned int*)(0x42E0950CUL)))
#define bM4_CAN_BT_SEG_14                         (*((volatile unsigned int*)(0x42E09510UL)))
#define bM4_CAN_BT_SEG_15                         (*((volatile unsigned int*)(0x42E09514UL)))
#define bM4_CAN_BT_SEG_16                         (*((volatile unsigned int*)(0x42E09518UL)))
#define bM4_CAN_BT_SEG_17                         (*((volatile unsigned int*)(0x42E0951CUL)))
#define bM4_CAN_BT_SEG_20                         (*((volatile unsigned int*)(0x42E09520UL)))
#define bM4_CAN_BT_SEG_21                         (*((volatile unsigned int*)(0x42E09524UL)))
#define bM4_CAN_BT_SEG_22                         (*((volatile unsigned int*)(0x42E09528UL)))
#define bM4_CAN_BT_SEG_23                         (*((volatile unsigned int*)(0x42E0952CUL)))
#define bM4_CAN_BT_SEG_24                         (*((volatile unsigned int*)(0x42E09530UL)))
#define bM4_CAN_BT_SEG_25                         (*((volatile unsigned int*)(0x42E09534UL)))
#define bM4_CAN_BT_SEG_26                         (*((volatile unsigned int*)(0x42E09538UL)))
#define bM4_CAN_BT_SJW0                           (*((volatile unsigned int*)(0x42E09540UL)))
#define bM4_CAN_BT_SJW1                           (*((volatile unsigned int*)(0x42E09544UL)))
#define bM4_CAN_BT_SJW2                           (*((volatile unsigned int*)(0x42E09548UL)))
#define bM4_CAN_BT_SJW3                           (*((volatile unsigned int*)(0x42E0954CUL)))
#define bM4_CAN_BT_SJW4                           (*((volatile unsigned int*)(0x42E09550UL)))
#define bM4_CAN_BT_SJW5                           (*((volatile unsigned int*)(0x42E09554UL)))
#define bM4_CAN_BT_SJW6                           (*((volatile unsigned int*)(0x42E09558UL)))
#define bM4_CAN_BT_PRESC0                         (*((volatile unsigned int*)(0x42E09560UL)))
#define bM4_CAN_BT_PRESC1                         (*((volatile unsigned int*)(0x42E09564UL)))
#define bM4_CAN_BT_PRESC2                         (*((volatile unsigned int*)(0x42E09568UL)))
#define bM4_CAN_BT_PRESC3                         (*((volatile unsigned int*)(0x42E0956CUL)))
#define bM4_CAN_BT_PRESC4                         (*((volatile unsigned int*)(0x42E09570UL)))
#define bM4_CAN_BT_PRESC5                         (*((volatile unsigned int*)(0x42E09574UL)))
#define bM4_CAN_BT_PRESC6                         (*((volatile unsigned int*)(0x42E09578UL)))
#define bM4_CAN_BT_PRESC7                         (*((volatile unsigned int*)(0x42E0957CUL)))
#define bM4_CAN_EALCAP_ALC0                       (*((volatile unsigned int*)(0x42E09600UL)))
#define bM4_CAN_EALCAP_ALC1                       (*((volatile unsigned int*)(0x42E09604UL)))
#define bM4_CAN_EALCAP_ALC2                       (*((volatile unsigned int*)(0x42E09608UL)))
#define bM4_CAN_EALCAP_ALC3                       (*((volatile unsigned int*)(0x42E0960CUL)))
#define bM4_CAN_EALCAP_ALC4                       (*((volatile unsigned int*)(0x42E09610UL)))
#define bM4_CAN_EALCAP_KOER0                      (*((volatile unsigned int*)(0x42E09614UL)))
#define bM4_CAN_EALCAP_KOER1                      (*((volatile unsigned int*)(0x42E09618UL)))
#define bM4_CAN_EALCAP_KOER2                      (*((volatile unsigned int*)(0x42E0961CUL)))
#define bM4_CAN_ACFCTRL_ACFADR0                   (*((volatile unsigned int*)(0x42E09680UL)))
#define bM4_CAN_ACFCTRL_ACFADR1                   (*((volatile unsigned int*)(0x42E09684UL)))
#define bM4_CAN_ACFCTRL_ACFADR2                   (*((volatile unsigned int*)(0x42E09688UL)))
#define bM4_CAN_ACFCTRL_ACFADR3                   (*((volatile unsigned int*)(0x42E0968CUL)))
#define bM4_CAN_ACFCTRL_SELMASK                   (*((volatile unsigned int*)(0x42E09694UL)))
#define bM4_CAN_ACFEN_AE_1                        (*((volatile unsigned int*)(0x42E096C0UL)))
#define bM4_CAN_ACFEN_AE_2                        (*((volatile unsigned int*)(0x42E096C4UL)))
#define bM4_CAN_ACFEN_AE_3                        (*((volatile unsigned int*)(0x42E096C8UL)))
#define bM4_CAN_ACFEN_AE_4                        (*((volatile unsigned int*)(0x42E096CCUL)))
#define bM4_CAN_ACFEN_AE_5                        (*((volatile unsigned int*)(0x42E096D0UL)))
#define bM4_CAN_ACFEN_AE_6                        (*((volatile unsigned int*)(0x42E096D4UL)))
#define bM4_CAN_ACFEN_AE_7                        (*((volatile unsigned int*)(0x42E096D8UL)))
#define bM4_CAN_ACFEN_AE_8                        (*((volatile unsigned int*)(0x42E096DCUL)))
#define bM4_CAN_ACF_ACODEORAMASK0                 (*((volatile unsigned int*)(0x42E09700UL)))
#define bM4_CAN_ACF_ACODEORAMASK1                 (*((volatile unsigned int*)(0x42E09704UL)))
#define bM4_CAN_ACF_ACODEORAMASK2                 (*((volatile unsigned int*)(0x42E09708UL)))
#define bM4_CAN_ACF_ACODEORAMASK3                 (*((volatile unsigned int*)(0x42E0970CUL)))
#define bM4_CAN_ACF_ACODEORAMASK4                 (*((volatile unsigned int*)(0x42E09710UL)))
#define bM4_CAN_ACF_ACODEORAMASK5                 (*((volatile unsigned int*)(0x42E09714UL)))
#define bM4_CAN_ACF_ACODEORAMASK6                 (*((volatile unsigned int*)(0x42E09718UL)))
#define bM4_CAN_ACF_ACODEORAMASK7                 (*((volatile unsigned int*)(0x42E0971CUL)))
#define bM4_CAN_ACF_ACODEORAMASK8                 (*((volatile unsigned int*)(0x42E09720UL)))
#define bM4_CAN_ACF_ACODEORAMASK9                 (*((volatile unsigned int*)(0x42E09724UL)))
#define bM4_CAN_ACF_ACODEORAMASK10                (*((volatile unsigned int*)(0x42E09728UL)))
#define bM4_CAN_ACF_ACODEORAMASK11                (*((volatile unsigned int*)(0x42E0972CUL)))
#define bM4_CAN_ACF_ACODEORAMASK12                (*((volatile unsigned int*)(0x42E09730UL)))
#define bM4_CAN_ACF_ACODEORAMASK13                (*((volatile unsigned int*)(0x42E09734UL)))
#define bM4_CAN_ACF_ACODEORAMASK14                (*((volatile unsigned int*)(0x42E09738UL)))
#define bM4_CAN_ACF_ACODEORAMASK15                (*((volatile unsigned int*)(0x42E0973CUL)))
#define bM4_CAN_ACF_ACODEORAMASK16                (*((volatile unsigned int*)(0x42E09740UL)))
#define bM4_CAN_ACF_ACODEORAMASK17                (*((volatile unsigned int*)(0x42E09744UL)))
#define bM4_CAN_ACF_ACODEORAMASK18                (*((volatile unsigned int*)(0x42E09748UL)))
#define bM4_CAN_ACF_ACODEORAMASK19                (*((volatile unsigned int*)(0x42E0974CUL)))
#define bM4_CAN_ACF_ACODEORAMASK20                (*((volatile unsigned int*)(0x42E09750UL)))
#define bM4_CAN_ACF_ACODEORAMASK21                (*((volatile unsigned int*)(0x42E09754UL)))
#define bM4_CAN_ACF_ACODEORAMASK22                (*((volatile unsigned int*)(0x42E09758UL)))
#define bM4_CAN_ACF_ACODEORAMASK23                (*((volatile unsigned int*)(0x42E0975CUL)))
#define bM4_CAN_ACF_ACODEORAMASK24                (*((volatile unsigned int*)(0x42E09760UL)))
#define bM4_CAN_ACF_ACODEORAMASK25                (*((volatile unsigned int*)(0x42E09764UL)))
#define bM4_CAN_ACF_ACODEORAMASK26                (*((volatile unsigned int*)(0x42E09768UL)))
#define bM4_CAN_ACF_ACODEORAMASK27                (*((volatile unsigned int*)(0x42E0976CUL)))
#define bM4_CAN_ACF_ACODEORAMASK28                (*((volatile unsigned int*)(0x42E09770UL)))
#define bM4_CAN_ACF_AIDE                          (*((volatile unsigned int*)(0x42E09774UL)))
#define bM4_CAN_ACF_AIDEE                         (*((volatile unsigned int*)(0x42E09778UL)))
#define bM4_CAN_TBSLOT_TBPTR0                     (*((volatile unsigned int*)(0x42E097C0UL)))
#define bM4_CAN_TBSLOT_TBPTR1                     (*((volatile unsigned int*)(0x42E097C4UL)))
#define bM4_CAN_TBSLOT_TBPTR2                     (*((volatile unsigned int*)(0x42E097C8UL)))
#define bM4_CAN_TBSLOT_TBPTR3                     (*((volatile unsigned int*)(0x42E097CCUL)))
#define bM4_CAN_TBSLOT_TBPTR4                     (*((volatile unsigned int*)(0x42E097D0UL)))
#define bM4_CAN_TBSLOT_TBPTR5                     (*((volatile unsigned int*)(0x42E097D4UL)))
#define bM4_CAN_TBSLOT_TBF                        (*((volatile unsigned int*)(0x42E097D8UL)))
#define bM4_CAN_TBSLOT_TBE                        (*((volatile unsigned int*)(0x42E097DCUL)))
#define bM4_CAN_TTCFG_TTEN                        (*((volatile unsigned int*)(0x42E097E0UL)))
#define bM4_CAN_TTCFG_T_PRESC0                    (*((volatile unsigned int*)(0x42E097E4UL)))
#define bM4_CAN_TTCFG_T_PRESC1                    (*((volatile unsigned int*)(0x42E097E8UL)))
#define bM4_CAN_TTCFG_TTIF                        (*((volatile unsigned int*)(0x42E097ECUL)))
#define bM4_CAN_TTCFG_TTIE                        (*((volatile unsigned int*)(0x42E097F0UL)))
#define bM4_CAN_TTCFG_TEIF                        (*((volatile unsigned int*)(0x42E097F4UL)))
#define bM4_CAN_TTCFG_WTIF                        (*((volatile unsigned int*)(0x42E097F8UL)))
#define bM4_CAN_TTCFG_WTIE                        (*((volatile unsigned int*)(0x42E097FCUL)))
#define bM4_CAN_REF_MSG_REF_ID0                   (*((volatile unsigned int*)(0x42E09800UL)))
#define bM4_CAN_REF_MSG_REF_ID1                   (*((volatile unsigned int*)(0x42E09804UL)))
#define bM4_CAN_REF_MSG_REF_ID2                   (*((volatile unsigned int*)(0x42E09808UL)))
#define bM4_CAN_REF_MSG_REF_ID3                   (*((volatile unsigned int*)(0x42E0980CUL)))
#define bM4_CAN_REF_MSG_REF_ID4                   (*((volatile unsigned int*)(0x42E09810UL)))
#define bM4_CAN_REF_MSG_REF_ID5                   (*((volatile unsigned int*)(0x42E09814UL)))
#define bM4_CAN_REF_MSG_REF_ID6                   (*((volatile unsigned int*)(0x42E09818UL)))
#define bM4_CAN_REF_MSG_REF_ID7                   (*((volatile unsigned int*)(0x42E0981CUL)))
#define bM4_CAN_REF_MSG_REF_ID8                   (*((volatile unsigned int*)(0x42E09820UL)))
#define bM4_CAN_REF_MSG_REF_ID9                   (*((volatile unsigned int*)(0x42E09824UL)))
#define bM4_CAN_REF_MSG_REF_ID10                  (*((volatile unsigned int*)(0x42E09828UL)))
#define bM4_CAN_REF_MSG_REF_ID11                  (*((volatile unsigned int*)(0x42E0982CUL)))
#define bM4_CAN_REF_MSG_REF_ID12                  (*((volatile unsigned int*)(0x42E09830UL)))
#define bM4_CAN_REF_MSG_REF_ID13                  (*((volatile unsigned int*)(0x42E09834UL)))
#define bM4_CAN_REF_MSG_REF_ID14                  (*((volatile unsigned int*)(0x42E09838UL)))
#define bM4_CAN_REF_MSG_REF_ID15                  (*((volatile unsigned int*)(0x42E0983CUL)))
#define bM4_CAN_REF_MSG_REF_ID16                  (*((volatile unsigned int*)(0x42E09840UL)))
#define bM4_CAN_REF_MSG_REF_ID17                  (*((volatile unsigned int*)(0x42E09844UL)))
#define bM4_CAN_REF_MSG_REF_ID18                  (*((volatile unsigned int*)(0x42E09848UL)))
#define bM4_CAN_REF_MSG_REF_ID19                  (*((volatile unsigned int*)(0x42E0984CUL)))
#define bM4_CAN_REF_MSG_REF_ID20                  (*((volatile unsigned int*)(0x42E09850UL)))
#define bM4_CAN_REF_MSG_REF_ID21                  (*((volatile unsigned int*)(0x42E09854UL)))
#define bM4_CAN_REF_MSG_REF_ID22                  (*((volatile unsigned int*)(0x42E09858UL)))
#define bM4_CAN_REF_MSG_REF_ID23                  (*((volatile unsigned int*)(0x42E0985CUL)))
#define bM4_CAN_REF_MSG_REF_ID24                  (*((volatile unsigned int*)(0x42E09860UL)))
#define bM4_CAN_REF_MSG_REF_ID25                  (*((volatile unsigned int*)(0x42E09864UL)))
#define bM4_CAN_REF_MSG_REF_ID26                  (*((volatile unsigned int*)(0x42E09868UL)))
#define bM4_CAN_REF_MSG_REF_ID27                  (*((volatile unsigned int*)(0x42E0986CUL)))
#define bM4_CAN_REF_MSG_REF_ID28                  (*((volatile unsigned int*)(0x42E09870UL)))
#define bM4_CAN_REF_MSG_REF_IDE                   (*((volatile unsigned int*)(0x42E0987CUL)))
#define bM4_CAN_TRG_CFG_TTPTR0                    (*((volatile unsigned int*)(0x42E09880UL)))
#define bM4_CAN_TRG_CFG_TTPTR1                    (*((volatile unsigned int*)(0x42E09884UL)))
#define bM4_CAN_TRG_CFG_TTPTR2                    (*((volatile unsigned int*)(0x42E09888UL)))
#define bM4_CAN_TRG_CFG_TTPTR3                    (*((volatile unsigned int*)(0x42E0988CUL)))
#define bM4_CAN_TRG_CFG_TTPTR4                    (*((volatile unsigned int*)(0x42E09890UL)))
#define bM4_CAN_TRG_CFG_TTPTR5                    (*((volatile unsigned int*)(0x42E09894UL)))
#define bM4_CAN_TRG_CFG_TTYPE0                    (*((volatile unsigned int*)(0x42E098A0UL)))
#define bM4_CAN_TRG_CFG_TTYPE1                    (*((volatile unsigned int*)(0x42E098A4UL)))
#define bM4_CAN_TRG_CFG_TTYPE2                    (*((volatile unsigned int*)(0x42E098A8UL)))
#define bM4_CAN_TRG_CFG_TEW0                      (*((volatile unsigned int*)(0x42E098B0UL)))
#define bM4_CAN_TRG_CFG_TEW1                      (*((volatile unsigned int*)(0x42E098B4UL)))
#define bM4_CAN_TRG_CFG_TEW2                      (*((volatile unsigned int*)(0x42E098B8UL)))
#define bM4_CAN_TRG_CFG_TEW3                      (*((volatile unsigned int*)(0x42E098BCUL)))
#define bM4_CMP1_CTRL_FLTSL0                      (*((volatile unsigned int*)(0x42940000UL)))
#define bM4_CMP1_CTRL_FLTSL1                      (*((volatile unsigned int*)(0x42940004UL)))
#define bM4_CMP1_CTRL_FLTSL2                      (*((volatile unsigned int*)(0x42940008UL)))
#define bM4_CMP1_CTRL_EDGSL0                      (*((volatile unsigned int*)(0x42940014UL)))
#define bM4_CMP1_CTRL_EDGSL1                      (*((volatile unsigned int*)(0x42940018UL)))
#define bM4_CMP1_CTRL_IEN                         (*((volatile unsigned int*)(0x4294001CUL)))
#define bM4_CMP1_CTRL_CVSEN                       (*((volatile unsigned int*)(0x42940020UL)))
#define bM4_CMP1_CTRL_OUTEN                       (*((volatile unsigned int*)(0x42940030UL)))
#define bM4_CMP1_CTRL_INV                         (*((volatile unsigned int*)(0x42940034UL)))
#define bM4_CMP1_CTRL_CMPOE                       (*((volatile unsigned int*)(0x42940038UL)))
#define bM4_CMP1_CTRL_CMPON                       (*((volatile unsigned int*)(0x4294003CUL)))
#define bM4_CMP1_VLTSEL_RVSL0                     (*((volatile unsigned int*)(0x42940040UL)))
#define bM4_CMP1_VLTSEL_RVSL1                     (*((volatile unsigned int*)(0x42940044UL)))
#define bM4_CMP1_VLTSEL_RVSL2                     (*((volatile unsigned int*)(0x42940048UL)))
#define bM4_CMP1_VLTSEL_RVSL3                     (*((volatile unsigned int*)(0x4294004CUL)))
#define bM4_CMP1_VLTSEL_CVSL0                     (*((volatile unsigned int*)(0x42940060UL)))
#define bM4_CMP1_VLTSEL_CVSL1                     (*((volatile unsigned int*)(0x42940064UL)))
#define bM4_CMP1_VLTSEL_CVSL2                     (*((volatile unsigned int*)(0x42940068UL)))
#define bM4_CMP1_VLTSEL_CVSL3                     (*((volatile unsigned int*)(0x4294006CUL)))
#define bM4_CMP1_VLTSEL_C4SL0                     (*((volatile unsigned int*)(0x42940070UL)))
#define bM4_CMP1_VLTSEL_C4SL1                     (*((volatile unsigned int*)(0x42940074UL)))
#define bM4_CMP1_VLTSEL_C4SL2                     (*((volatile unsigned int*)(0x42940078UL)))
#define bM4_CMP1_OUTMON_OMON                      (*((volatile unsigned int*)(0x42940080UL)))
#define bM4_CMP1_OUTMON_CVST0                     (*((volatile unsigned int*)(0x429400A0UL)))
#define bM4_CMP1_OUTMON_CVST1                     (*((volatile unsigned int*)(0x429400A4UL)))
#define bM4_CMP1_OUTMON_CVST2                     (*((volatile unsigned int*)(0x429400A8UL)))
#define bM4_CMP1_OUTMON_CVST3                     (*((volatile unsigned int*)(0x429400ACUL)))
#define bM4_CMP1_CVSSTB_STB0                      (*((volatile unsigned int*)(0x429400C0UL)))
#define bM4_CMP1_CVSSTB_STB1                      (*((volatile unsigned int*)(0x429400C4UL)))
#define bM4_CMP1_CVSSTB_STB2                      (*((volatile unsigned int*)(0x429400C8UL)))
#define bM4_CMP1_CVSSTB_STB3                      (*((volatile unsigned int*)(0x429400CCUL)))
#define bM4_CMP1_CVSPRD_PRD0                      (*((volatile unsigned int*)(0x42940100UL)))
#define bM4_CMP1_CVSPRD_PRD1                      (*((volatile unsigned int*)(0x42940104UL)))
#define bM4_CMP1_CVSPRD_PRD2                      (*((volatile unsigned int*)(0x42940108UL)))
#define bM4_CMP1_CVSPRD_PRD3                      (*((volatile unsigned int*)(0x4294010CUL)))
#define bM4_CMP1_CVSPRD_PRD4                      (*((volatile unsigned int*)(0x42940110UL)))
#define bM4_CMP1_CVSPRD_PRD5                      (*((volatile unsigned int*)(0x42940114UL)))
#define bM4_CMP1_CVSPRD_PRD6                      (*((volatile unsigned int*)(0x42940118UL)))
#define bM4_CMP1_CVSPRD_PRD7                      (*((volatile unsigned int*)(0x4294011CUL)))
#define bM4_CMP2_CTRL_FLTSL0                      (*((volatile unsigned int*)(0x42940200UL)))
#define bM4_CMP2_CTRL_FLTSL1                      (*((volatile unsigned int*)(0x42940204UL)))
#define bM4_CMP2_CTRL_FLTSL2                      (*((volatile unsigned int*)(0x42940208UL)))
#define bM4_CMP2_CTRL_EDGSL0                      (*((volatile unsigned int*)(0x42940214UL)))
#define bM4_CMP2_CTRL_EDGSL1                      (*((volatile unsigned int*)(0x42940218UL)))
#define bM4_CMP2_CTRL_IEN                         (*((volatile unsigned int*)(0x4294021CUL)))
#define bM4_CMP2_CTRL_CVSEN                       (*((volatile unsigned int*)(0x42940220UL)))
#define bM4_CMP2_CTRL_OUTEN                       (*((volatile unsigned int*)(0x42940230UL)))
#define bM4_CMP2_CTRL_INV                         (*((volatile unsigned int*)(0x42940234UL)))
#define bM4_CMP2_CTRL_CMPOE                       (*((volatile unsigned int*)(0x42940238UL)))
#define bM4_CMP2_CTRL_CMPON                       (*((volatile unsigned int*)(0x4294023CUL)))
#define bM4_CMP2_VLTSEL_RVSL0                     (*((volatile unsigned int*)(0x42940240UL)))
#define bM4_CMP2_VLTSEL_RVSL1                     (*((volatile unsigned int*)(0x42940244UL)))
#define bM4_CMP2_VLTSEL_RVSL2                     (*((volatile unsigned int*)(0x42940248UL)))
#define bM4_CMP2_VLTSEL_RVSL3                     (*((volatile unsigned int*)(0x4294024CUL)))
#define bM4_CMP2_VLTSEL_CVSL0                     (*((volatile unsigned int*)(0x42940260UL)))
#define bM4_CMP2_VLTSEL_CVSL1                     (*((volatile unsigned int*)(0x42940264UL)))
#define bM4_CMP2_VLTSEL_CVSL2                     (*((volatile unsigned int*)(0x42940268UL)))
#define bM4_CMP2_VLTSEL_CVSL3                     (*((volatile unsigned int*)(0x4294026CUL)))
#define bM4_CMP2_VLTSEL_C4SL0                     (*((volatile unsigned int*)(0x42940270UL)))
#define bM4_CMP2_VLTSEL_C4SL1                     (*((volatile unsigned int*)(0x42940274UL)))
#define bM4_CMP2_VLTSEL_C4SL2                     (*((volatile unsigned int*)(0x42940278UL)))
#define bM4_CMP2_OUTMON_OMON                      (*((volatile unsigned int*)(0x42940280UL)))
#define bM4_CMP2_OUTMON_CVST0                     (*((volatile unsigned int*)(0x429402A0UL)))
#define bM4_CMP2_OUTMON_CVST1                     (*((volatile unsigned int*)(0x429402A4UL)))
#define bM4_CMP2_OUTMON_CVST2                     (*((volatile unsigned int*)(0x429402A8UL)))
#define bM4_CMP2_OUTMON_CVST3                     (*((volatile unsigned int*)(0x429402ACUL)))
#define bM4_CMP2_CVSSTB_STB0                      (*((volatile unsigned int*)(0x429402C0UL)))
#define bM4_CMP2_CVSSTB_STB1                      (*((volatile unsigned int*)(0x429402C4UL)))
#define bM4_CMP2_CVSSTB_STB2                      (*((volatile unsigned int*)(0x429402C8UL)))
#define bM4_CMP2_CVSSTB_STB3                      (*((volatile unsigned int*)(0x429402CCUL)))
#define bM4_CMP2_CVSPRD_PRD0                      (*((volatile unsigned int*)(0x42940300UL)))
#define bM4_CMP2_CVSPRD_PRD1                      (*((volatile unsigned int*)(0x42940304UL)))
#define bM4_CMP2_CVSPRD_PRD2                      (*((volatile unsigned int*)(0x42940308UL)))
#define bM4_CMP2_CVSPRD_PRD3                      (*((volatile unsigned int*)(0x4294030CUL)))
#define bM4_CMP2_CVSPRD_PRD4                      (*((volatile unsigned int*)(0x42940310UL)))
#define bM4_CMP2_CVSPRD_PRD5                      (*((volatile unsigned int*)(0x42940314UL)))
#define bM4_CMP2_CVSPRD_PRD6                      (*((volatile unsigned int*)(0x42940318UL)))
#define bM4_CMP2_CVSPRD_PRD7                      (*((volatile unsigned int*)(0x4294031CUL)))
#define bM4_CMP3_CTRL_FLTSL0                      (*((volatile unsigned int*)(0x42940400UL)))
#define bM4_CMP3_CTRL_FLTSL1                      (*((volatile unsigned int*)(0x42940404UL)))
#define bM4_CMP3_CTRL_FLTSL2                      (*((volatile unsigned int*)(0x42940408UL)))
#define bM4_CMP3_CTRL_EDGSL0                      (*((volatile unsigned int*)(0x42940414UL)))
#define bM4_CMP3_CTRL_EDGSL1                      (*((volatile unsigned int*)(0x42940418UL)))
#define bM4_CMP3_CTRL_IEN                         (*((volatile unsigned int*)(0x4294041CUL)))
#define bM4_CMP3_CTRL_CVSEN                       (*((volatile unsigned int*)(0x42940420UL)))
#define bM4_CMP3_CTRL_OUTEN                       (*((volatile unsigned int*)(0x42940430UL)))
#define bM4_CMP3_CTRL_INV                         (*((volatile unsigned int*)(0x42940434UL)))
#define bM4_CMP3_CTRL_CMPOE                       (*((volatile unsigned int*)(0x42940438UL)))
#define bM4_CMP3_CTRL_CMPON                       (*((volatile unsigned int*)(0x4294043CUL)))
#define bM4_CMP3_VLTSEL_RVSL0                     (*((volatile unsigned int*)(0x42940440UL)))
#define bM4_CMP3_VLTSEL_RVSL1                     (*((volatile unsigned int*)(0x42940444UL)))
#define bM4_CMP3_VLTSEL_RVSL2                     (*((volatile unsigned int*)(0x42940448UL)))
#define bM4_CMP3_VLTSEL_RVSL3                     (*((volatile unsigned int*)(0x4294044CUL)))
#define bM4_CMP3_VLTSEL_CVSL0                     (*((volatile unsigned int*)(0x42940460UL)))
#define bM4_CMP3_VLTSEL_CVSL1                     (*((volatile unsigned int*)(0x42940464UL)))
#define bM4_CMP3_VLTSEL_CVSL2                     (*((volatile unsigned int*)(0x42940468UL)))
#define bM4_CMP3_VLTSEL_CVSL3                     (*((volatile unsigned int*)(0x4294046CUL)))
#define bM4_CMP3_VLTSEL_C4SL0                     (*((volatile unsigned int*)(0x42940470UL)))
#define bM4_CMP3_VLTSEL_C4SL1                     (*((volatile unsigned int*)(0x42940474UL)))
#define bM4_CMP3_VLTSEL_C4SL2                     (*((volatile unsigned int*)(0x42940478UL)))
#define bM4_CMP3_OUTMON_OMON                      (*((volatile unsigned int*)(0x42940480UL)))
#define bM4_CMP3_OUTMON_CVST0                     (*((volatile unsigned int*)(0x429404A0UL)))
#define bM4_CMP3_OUTMON_CVST1                     (*((volatile unsigned int*)(0x429404A4UL)))
#define bM4_CMP3_OUTMON_CVST2                     (*((volatile unsigned int*)(0x429404A8UL)))
#define bM4_CMP3_OUTMON_CVST3                     (*((volatile unsigned int*)(0x429404ACUL)))
#define bM4_CMP3_CVSSTB_STB0                      (*((volatile unsigned int*)(0x429404C0UL)))
#define bM4_CMP3_CVSSTB_STB1                      (*((volatile unsigned int*)(0x429404C4UL)))
#define bM4_CMP3_CVSSTB_STB2                      (*((volatile unsigned int*)(0x429404C8UL)))
#define bM4_CMP3_CVSSTB_STB3                      (*((volatile unsigned int*)(0x429404CCUL)))
#define bM4_CMP3_CVSPRD_PRD0                      (*((volatile unsigned int*)(0x42940500UL)))
#define bM4_CMP3_CVSPRD_PRD1                      (*((volatile unsigned int*)(0x42940504UL)))
#define bM4_CMP3_CVSPRD_PRD2                      (*((volatile unsigned int*)(0x42940508UL)))
#define bM4_CMP3_CVSPRD_PRD3                      (*((volatile unsigned int*)(0x4294050CUL)))
#define bM4_CMP3_CVSPRD_PRD4                      (*((volatile unsigned int*)(0x42940510UL)))
#define bM4_CMP3_CVSPRD_PRD5                      (*((volatile unsigned int*)(0x42940514UL)))
#define bM4_CMP3_CVSPRD_PRD6                      (*((volatile unsigned int*)(0x42940518UL)))
#define bM4_CMP3_CVSPRD_PRD7                      (*((volatile unsigned int*)(0x4294051CUL)))
#define bM4_CMP_CR_DADR1_DATA0                    (*((volatile unsigned int*)(0x42942000UL)))
#define bM4_CMP_CR_DADR1_DATA1                    (*((volatile unsigned int*)(0x42942004UL)))
#define bM4_CMP_CR_DADR1_DATA2                    (*((volatile unsigned int*)(0x42942008UL)))
#define bM4_CMP_CR_DADR1_DATA3                    (*((volatile unsigned int*)(0x4294200CUL)))
#define bM4_CMP_CR_DADR1_DATA4                    (*((volatile unsigned int*)(0x42942010UL)))
#define bM4_CMP_CR_DADR1_DATA5                    (*((volatile unsigned int*)(0x42942014UL)))
#define bM4_CMP_CR_DADR1_DATA6                    (*((volatile unsigned int*)(0x42942018UL)))
#define bM4_CMP_CR_DADR1_DATA7                    (*((volatile unsigned int*)(0x4294201CUL)))
#define bM4_CMP_CR_DADR2_DATA0                    (*((volatile unsigned int*)(0x42942040UL)))
#define bM4_CMP_CR_DADR2_DATA1                    (*((volatile unsigned int*)(0x42942044UL)))
#define bM4_CMP_CR_DADR2_DATA2                    (*((volatile unsigned int*)(0x42942048UL)))
#define bM4_CMP_CR_DADR2_DATA3                    (*((volatile unsigned int*)(0x4294204CUL)))
#define bM4_CMP_CR_DADR2_DATA4                    (*((volatile unsigned int*)(0x42942050UL)))
#define bM4_CMP_CR_DADR2_DATA5                    (*((volatile unsigned int*)(0x42942054UL)))
#define bM4_CMP_CR_DADR2_DATA6                    (*((volatile unsigned int*)(0x42942058UL)))
#define bM4_CMP_CR_DADR2_DATA7                    (*((volatile unsigned int*)(0x4294205CUL)))
#define bM4_CMP_CR_DACR_DA1EN                     (*((volatile unsigned int*)(0x42942100UL)))
#define bM4_CMP_CR_DACR_DA2EN                     (*((volatile unsigned int*)(0x42942104UL)))
#define bM4_CMP_CR_RVADC_DA1SW                    (*((volatile unsigned int*)(0x42942180UL)))
#define bM4_CMP_CR_RVADC_DA2SW                    (*((volatile unsigned int*)(0x42942184UL)))
#define bM4_CMP_CR_RVADC_VREFSW                   (*((volatile unsigned int*)(0x42942190UL)))
#define bM4_CMP_CR_RVADC_WPRT0                    (*((volatile unsigned int*)(0x429421A0UL)))
#define bM4_CMP_CR_RVADC_WPRT1                    (*((volatile unsigned int*)(0x429421A4UL)))
#define bM4_CMP_CR_RVADC_WPRT2                    (*((volatile unsigned int*)(0x429421A8UL)))
#define bM4_CMP_CR_RVADC_WPRT3                    (*((volatile unsigned int*)(0x429421ACUL)))
#define bM4_CMP_CR_RVADC_WPRT4                    (*((volatile unsigned int*)(0x429421B0UL)))
#define bM4_CMP_CR_RVADC_WPRT5                    (*((volatile unsigned int*)(0x429421B4UL)))
#define bM4_CMP_CR_RVADC_WPRT6                    (*((volatile unsigned int*)(0x429421B8UL)))
#define bM4_CMP_CR_RVADC_WPRT7                    (*((volatile unsigned int*)(0x429421BCUL)))
#define bM4_CRC_CR_CRC_SEL                        (*((volatile unsigned int*)(0x42118004UL)))
#define bM4_CRC_CR_REFIN                          (*((volatile unsigned int*)(0x42118008UL)))
#define bM4_CRC_CR_REFOUT                         (*((volatile unsigned int*)(0x4211800CUL)))
#define bM4_CRC_CR_XOROUT                         (*((volatile unsigned int*)(0x42118010UL)))
#define bM4_CRC_RESLT_CRC_REG0                    (*((volatile unsigned int*)(0x42118080UL)))
#define bM4_CRC_RESLT_CRC_REG1                    (*((volatile unsigned int*)(0x42118084UL)))
#define bM4_CRC_RESLT_CRC_REG2                    (*((volatile unsigned int*)(0x42118088UL)))
#define bM4_CRC_RESLT_CRC_REG3                    (*((volatile unsigned int*)(0x4211808CUL)))
#define bM4_CRC_RESLT_CRC_REG4                    (*((volatile unsigned int*)(0x42118090UL)))
#define bM4_CRC_RESLT_CRC_REG5                    (*((volatile unsigned int*)(0x42118094UL)))
#define bM4_CRC_RESLT_CRC_REG6                    (*((volatile unsigned int*)(0x42118098UL)))
#define bM4_CRC_RESLT_CRC_REG7                    (*((volatile unsigned int*)(0x4211809CUL)))
#define bM4_CRC_RESLT_CRC_REG8                    (*((volatile unsigned int*)(0x421180A0UL)))
#define bM4_CRC_RESLT_CRC_REG9                    (*((volatile unsigned int*)(0x421180A4UL)))
#define bM4_CRC_RESLT_CRC_REG10                   (*((volatile unsigned int*)(0x421180A8UL)))
#define bM4_CRC_RESLT_CRC_REG11                   (*((volatile unsigned int*)(0x421180ACUL)))
#define bM4_CRC_RESLT_CRC_REG12                   (*((volatile unsigned int*)(0x421180B0UL)))
#define bM4_CRC_RESLT_CRC_REG13                   (*((volatile unsigned int*)(0x421180B4UL)))
#define bM4_CRC_RESLT_CRC_REG14                   (*((volatile unsigned int*)(0x421180B8UL)))
#define bM4_CRC_RESLT_CRC_REG15                   (*((volatile unsigned int*)(0x421180BCUL)))
#define bM4_CRC_RESLT_CRCFLAG_16                  (*((volatile unsigned int*)(0x421180C0UL)))
#define bM4_CRC_FLG_FLAG                          (*((volatile unsigned int*)(0x42118180UL)))
#define bM4_DCU1_CTL_MODE0                        (*((volatile unsigned int*)(0x42A40000UL)))
#define bM4_DCU1_CTL_MODE1                        (*((volatile unsigned int*)(0x42A40004UL)))
#define bM4_DCU1_CTL_MODE2                        (*((volatile unsigned int*)(0x42A40008UL)))
#define bM4_DCU1_CTL_DATASIZE0                    (*((volatile unsigned int*)(0x42A4000CUL)))
#define bM4_DCU1_CTL_DATASIZE1                    (*((volatile unsigned int*)(0x42A40010UL)))
#define bM4_DCU1_CTL_COMP_TRG                     (*((volatile unsigned int*)(0x42A40020UL)))
#define bM4_DCU1_CTL_INTEN                        (*((volatile unsigned int*)(0x42A4007CUL)))
#define bM4_DCU1_FLAG_FLAG_OP                     (*((volatile unsigned int*)(0x42A40080UL)))
#define bM4_DCU1_FLAG_FLAG_LS2                    (*((volatile unsigned int*)(0x42A40084UL)))
#define bM4_DCU1_FLAG_FLAG_EQ2                    (*((volatile unsigned int*)(0x42A40088UL)))
#define bM4_DCU1_FLAG_FLAG_GT2                    (*((volatile unsigned int*)(0x42A4008CUL)))
#define bM4_DCU1_FLAG_FLAG_LS1                    (*((volatile unsigned int*)(0x42A40090UL)))
#define bM4_DCU1_FLAG_FLAG_EQ1                    (*((volatile unsigned int*)(0x42A40094UL)))
#define bM4_DCU1_FLAG_FLAG_GT1                    (*((volatile unsigned int*)(0x42A40098UL)))
#define bM4_DCU1_FLAGCLR_CLR_OP                   (*((volatile unsigned int*)(0x42A40280UL)))
#define bM4_DCU1_FLAGCLR_CLR_LS2                  (*((volatile unsigned int*)(0x42A40284UL)))
#define bM4_DCU1_FLAGCLR_CLR_EQ2                  (*((volatile unsigned int*)(0x42A40288UL)))
#define bM4_DCU1_FLAGCLR_CLR_GT2                  (*((volatile unsigned int*)(0x42A4028CUL)))
#define bM4_DCU1_FLAGCLR_CLR_LS1                  (*((volatile unsigned int*)(0x42A40290UL)))
#define bM4_DCU1_FLAGCLR_CLR_EQ1                  (*((volatile unsigned int*)(0x42A40294UL)))
#define bM4_DCU1_FLAGCLR_CLR_GT1                  (*((volatile unsigned int*)(0x42A40298UL)))
#define bM4_DCU1_INTSEL_INT_OP                    (*((volatile unsigned int*)(0x42A40300UL)))
#define bM4_DCU1_INTSEL_INT_LS2                   (*((volatile unsigned int*)(0x42A40304UL)))
#define bM4_DCU1_INTSEL_INT_EQ2                   (*((volatile unsigned int*)(0x42A40308UL)))
#define bM4_DCU1_INTSEL_INT_GT2                   (*((volatile unsigned int*)(0x42A4030CUL)))
#define bM4_DCU1_INTSEL_INT_LS1                   (*((volatile unsigned int*)(0x42A40310UL)))
#define bM4_DCU1_INTSEL_INT_EQ1                   (*((volatile unsigned int*)(0x42A40314UL)))
#define bM4_DCU1_INTSEL_INT_GT1                   (*((volatile unsigned int*)(0x42A40318UL)))
#define bM4_DCU1_INTSEL_INT_WIN0                  (*((volatile unsigned int*)(0x42A4031CUL)))
#define bM4_DCU1_INTSEL_INT_WIN1                  (*((volatile unsigned int*)(0x42A40320UL)))
#define bM4_DCU2_CTL_MODE0                        (*((volatile unsigned int*)(0x42A48000UL)))
#define bM4_DCU2_CTL_MODE1                        (*((volatile unsigned int*)(0x42A48004UL)))
#define bM4_DCU2_CTL_MODE2                        (*((volatile unsigned int*)(0x42A48008UL)))
#define bM4_DCU2_CTL_DATASIZE0                    (*((volatile unsigned int*)(0x42A4800CUL)))
#define bM4_DCU2_CTL_DATASIZE1                    (*((volatile unsigned int*)(0x42A48010UL)))
#define bM4_DCU2_CTL_COMP_TRG                     (*((volatile unsigned int*)(0x42A48020UL)))
#define bM4_DCU2_CTL_INTEN                        (*((volatile unsigned int*)(0x42A4807CUL)))
#define bM4_DCU2_FLAG_FLAG_OP                     (*((volatile unsigned int*)(0x42A48080UL)))
#define bM4_DCU2_FLAG_FLAG_LS2                    (*((volatile unsigned int*)(0x42A48084UL)))
#define bM4_DCU2_FLAG_FLAG_EQ2                    (*((volatile unsigned int*)(0x42A48088UL)))
#define bM4_DCU2_FLAG_FLAG_GT2                    (*((volatile unsigned int*)(0x42A4808CUL)))
#define bM4_DCU2_FLAG_FLAG_LS1                    (*((volatile unsigned int*)(0x42A48090UL)))
#define bM4_DCU2_FLAG_FLAG_EQ1                    (*((volatile unsigned int*)(0x42A48094UL)))
#define bM4_DCU2_FLAG_FLAG_GT1                    (*((volatile unsigned int*)(0x42A48098UL)))
#define bM4_DCU2_FLAGCLR_CLR_OP                   (*((volatile unsigned int*)(0x42A48280UL)))
#define bM4_DCU2_FLAGCLR_CLR_LS2                  (*((volatile unsigned int*)(0x42A48284UL)))
#define bM4_DCU2_FLAGCLR_CLR_EQ2                  (*((volatile unsigned int*)(0x42A48288UL)))
#define bM4_DCU2_FLAGCLR_CLR_GT2                  (*((volatile unsigned int*)(0x42A4828CUL)))
#define bM4_DCU2_FLAGCLR_CLR_LS1                  (*((volatile unsigned int*)(0x42A48290UL)))
#define bM4_DCU2_FLAGCLR_CLR_EQ1                  (*((volatile unsigned int*)(0x42A48294UL)))
#define bM4_DCU2_FLAGCLR_CLR_GT1                  (*((volatile unsigned int*)(0x42A48298UL)))
#define bM4_DCU2_INTSEL_INT_OP                    (*((volatile unsigned int*)(0x42A48300UL)))
#define bM4_DCU2_INTSEL_INT_LS2                   (*((volatile unsigned int*)(0x42A48304UL)))
#define bM4_DCU2_INTSEL_INT_EQ2                   (*((volatile unsigned int*)(0x42A48308UL)))
#define bM4_DCU2_INTSEL_INT_GT2                   (*((volatile unsigned int*)(0x42A4830CUL)))
#define bM4_DCU2_INTSEL_INT_LS1                   (*((volatile unsigned int*)(0x42A48310UL)))
#define bM4_DCU2_INTSEL_INT_EQ1                   (*((volatile unsigned int*)(0x42A48314UL)))
#define bM4_DCU2_INTSEL_INT_GT1                   (*((volatile unsigned int*)(0x42A48318UL)))
#define bM4_DCU2_INTSEL_INT_WIN0                  (*((volatile unsigned int*)(0x42A4831CUL)))
#define bM4_DCU2_INTSEL_INT_WIN1                  (*((volatile unsigned int*)(0x42A48320UL)))
#define bM4_DCU3_CTL_MODE0                        (*((volatile unsigned int*)(0x42A50000UL)))
#define bM4_DCU3_CTL_MODE1                        (*((volatile unsigned int*)(0x42A50004UL)))
#define bM4_DCU3_CTL_MODE2                        (*((volatile unsigned int*)(0x42A50008UL)))
#define bM4_DCU3_CTL_DATASIZE0                    (*((volatile unsigned int*)(0x42A5000CUL)))
#define bM4_DCU3_CTL_DATASIZE1                    (*((volatile unsigned int*)(0x42A50010UL)))
#define bM4_DCU3_CTL_COMP_TRG                     (*((volatile unsigned int*)(0x42A50020UL)))
#define bM4_DCU3_CTL_INTEN                        (*((volatile unsigned int*)(0x42A5007CUL)))
#define bM4_DCU3_FLAG_FLAG_OP                     (*((volatile unsigned int*)(0x42A50080UL)))
#define bM4_DCU3_FLAG_FLAG_LS2                    (*((volatile unsigned int*)(0x42A50084UL)))
#define bM4_DCU3_FLAG_FLAG_EQ2                    (*((volatile unsigned int*)(0x42A50088UL)))
#define bM4_DCU3_FLAG_FLAG_GT2                    (*((volatile unsigned int*)(0x42A5008CUL)))
#define bM4_DCU3_FLAG_FLAG_LS1                    (*((volatile unsigned int*)(0x42A50090UL)))
#define bM4_DCU3_FLAG_FLAG_EQ1                    (*((volatile unsigned int*)(0x42A50094UL)))
#define bM4_DCU3_FLAG_FLAG_GT1                    (*((volatile unsigned int*)(0x42A50098UL)))
#define bM4_DCU3_FLAGCLR_CLR_OP                   (*((volatile unsigned int*)(0x42A50280UL)))
#define bM4_DCU3_FLAGCLR_CLR_LS2                  (*((volatile unsigned int*)(0x42A50284UL)))
#define bM4_DCU3_FLAGCLR_CLR_EQ2                  (*((volatile unsigned int*)(0x42A50288UL)))
#define bM4_DCU3_FLAGCLR_CLR_GT2                  (*((volatile unsigned int*)(0x42A5028CUL)))
#define bM4_DCU3_FLAGCLR_CLR_LS1                  (*((volatile unsigned int*)(0x42A50290UL)))
#define bM4_DCU3_FLAGCLR_CLR_EQ1                  (*((volatile unsigned int*)(0x42A50294UL)))
#define bM4_DCU3_FLAGCLR_CLR_GT1                  (*((volatile unsigned int*)(0x42A50298UL)))
#define bM4_DCU3_INTSEL_INT_OP                    (*((volatile unsigned int*)(0x42A50300UL)))
#define bM4_DCU3_INTSEL_INT_LS2                   (*((volatile unsigned int*)(0x42A50304UL)))
#define bM4_DCU3_INTSEL_INT_EQ2                   (*((volatile unsigned int*)(0x42A50308UL)))
#define bM4_DCU3_INTSEL_INT_GT2                   (*((volatile unsigned int*)(0x42A5030CUL)))
#define bM4_DCU3_INTSEL_INT_LS1                   (*((volatile unsigned int*)(0x42A50310UL)))
#define bM4_DCU3_INTSEL_INT_EQ1                   (*((volatile unsigned int*)(0x42A50314UL)))
#define bM4_DCU3_INTSEL_INT_GT1                   (*((volatile unsigned int*)(0x42A50318UL)))
#define bM4_DCU3_INTSEL_INT_WIN0                  (*((volatile unsigned int*)(0x42A5031CUL)))
#define bM4_DCU3_INTSEL_INT_WIN1                  (*((volatile unsigned int*)(0x42A50320UL)))
#define bM4_DCU4_CTL_MODE0                        (*((volatile unsigned int*)(0x42A58000UL)))
#define bM4_DCU4_CTL_MODE1                        (*((volatile unsigned int*)(0x42A58004UL)))
#define bM4_DCU4_CTL_MODE2                        (*((volatile unsigned int*)(0x42A58008UL)))
#define bM4_DCU4_CTL_DATASIZE0                    (*((volatile unsigned int*)(0x42A5800CUL)))
#define bM4_DCU4_CTL_DATASIZE1                    (*((volatile unsigned int*)(0x42A58010UL)))
#define bM4_DCU4_CTL_COMP_TRG                     (*((volatile unsigned int*)(0x42A58020UL)))
#define bM4_DCU4_CTL_INTEN                        (*((volatile unsigned int*)(0x42A5807CUL)))
#define bM4_DCU4_FLAG_FLAG_OP                     (*((volatile unsigned int*)(0x42A58080UL)))
#define bM4_DCU4_FLAG_FLAG_LS2                    (*((volatile unsigned int*)(0x42A58084UL)))
#define bM4_DCU4_FLAG_FLAG_EQ2                    (*((volatile unsigned int*)(0x42A58088UL)))
#define bM4_DCU4_FLAG_FLAG_GT2                    (*((volatile unsigned int*)(0x42A5808CUL)))
#define bM4_DCU4_FLAG_FLAG_LS1                    (*((volatile unsigned int*)(0x42A58090UL)))
#define bM4_DCU4_FLAG_FLAG_EQ1                    (*((volatile unsigned int*)(0x42A58094UL)))
#define bM4_DCU4_FLAG_FLAG_GT1                    (*((volatile unsigned int*)(0x42A58098UL)))
#define bM4_DCU4_FLAGCLR_CLR_OP                   (*((volatile unsigned int*)(0x42A58280UL)))
#define bM4_DCU4_FLAGCLR_CLR_LS2                  (*((volatile unsigned int*)(0x42A58284UL)))
#define bM4_DCU4_FLAGCLR_CLR_EQ2                  (*((volatile unsigned int*)(0x42A58288UL)))
#define bM4_DCU4_FLAGCLR_CLR_GT2                  (*((volatile unsigned int*)(0x42A5828CUL)))
#define bM4_DCU4_FLAGCLR_CLR_LS1                  (*((volatile unsigned int*)(0x42A58290UL)))
#define bM4_DCU4_FLAGCLR_CLR_EQ1                  (*((volatile unsigned int*)(0x42A58294UL)))
#define bM4_DCU4_FLAGCLR_CLR_GT1                  (*((volatile unsigned int*)(0x42A58298UL)))
#define bM4_DCU4_INTSEL_INT_OP                    (*((volatile unsigned int*)(0x42A58300UL)))
#define bM4_DCU4_INTSEL_INT_LS2                   (*((volatile unsigned int*)(0x42A58304UL)))
#define bM4_DCU4_INTSEL_INT_EQ2                   (*((volatile unsigned int*)(0x42A58308UL)))
#define bM4_DCU4_INTSEL_INT_GT2                   (*((volatile unsigned int*)(0x42A5830CUL)))
#define bM4_DCU4_INTSEL_INT_LS1                   (*((volatile unsigned int*)(0x42A58310UL)))
#define bM4_DCU4_INTSEL_INT_EQ1                   (*((volatile unsigned int*)(0x42A58314UL)))
#define bM4_DCU4_INTSEL_INT_GT1                   (*((volatile unsigned int*)(0x42A58318UL)))
#define bM4_DCU4_INTSEL_INT_WIN0                  (*((volatile unsigned int*)(0x42A5831CUL)))
#define bM4_DCU4_INTSEL_INT_WIN1                  (*((volatile unsigned int*)(0x42A58320UL)))
#define bM4_DMA1_EN_EN                            (*((volatile unsigned int*)(0x42A60000UL)))
#define bM4_DMA1_INTSTAT0_TRNERR0                 (*((volatile unsigned int*)(0x42A60080UL)))
#define bM4_DMA1_INTSTAT0_TRNERR1                 (*((volatile unsigned int*)(0x42A60084UL)))
#define bM4_DMA1_INTSTAT0_TRNERR2                 (*((volatile unsigned int*)(0x42A60088UL)))
#define bM4_DMA1_INTSTAT0_TRNERR3                 (*((volatile unsigned int*)(0x42A6008CUL)))
#define bM4_DMA1_INTSTAT0_REQERR0                 (*((volatile unsigned int*)(0x42A600C0UL)))
#define bM4_DMA1_INTSTAT0_REQERR1                 (*((volatile unsigned int*)(0x42A600C4UL)))
#define bM4_DMA1_INTSTAT0_REQERR2                 (*((volatile unsigned int*)(0x42A600C8UL)))
#define bM4_DMA1_INTSTAT0_REQERR3                 (*((volatile unsigned int*)(0x42A600CCUL)))
#define bM4_DMA1_INTSTAT1_TC0                     (*((volatile unsigned int*)(0x42A60100UL)))
#define bM4_DMA1_INTSTAT1_TC1                     (*((volatile unsigned int*)(0x42A60104UL)))
#define bM4_DMA1_INTSTAT1_TC2                     (*((volatile unsigned int*)(0x42A60108UL)))
#define bM4_DMA1_INTSTAT1_TC3                     (*((volatile unsigned int*)(0x42A6010CUL)))
#define bM4_DMA1_INTSTAT1_BTC0                    (*((volatile unsigned int*)(0x42A60140UL)))
#define bM4_DMA1_INTSTAT1_BTC1                    (*((volatile unsigned int*)(0x42A60144UL)))
#define bM4_DMA1_INTSTAT1_BTC2                    (*((volatile unsigned int*)(0x42A60148UL)))
#define bM4_DMA1_INTSTAT1_BTC3                    (*((volatile unsigned int*)(0x42A6014CUL)))
#define bM4_DMA1_INTMASK0_MSKTRNERR0              (*((volatile unsigned int*)(0x42A60180UL)))
#define bM4_DMA1_INTMASK0_MSKTRNERR1              (*((volatile unsigned int*)(0x42A60184UL)))
#define bM4_DMA1_INTMASK0_MSKTRNERR2              (*((volatile unsigned int*)(0x42A60188UL)))
#define bM4_DMA1_INTMASK0_MSKTRNERR3              (*((volatile unsigned int*)(0x42A6018CUL)))
#define bM4_DMA1_INTMASK0_MSKREQERR0              (*((volatile unsigned int*)(0x42A601C0UL)))
#define bM4_DMA1_INTMASK0_MSKREQERR1              (*((volatile unsigned int*)(0x42A601C4UL)))
#define bM4_DMA1_INTMASK0_MSKREQERR2              (*((volatile unsigned int*)(0x42A601C8UL)))
#define bM4_DMA1_INTMASK0_MSKREQERR3              (*((volatile unsigned int*)(0x42A601CCUL)))
#define bM4_DMA1_INTMASK1_MSKTC0                  (*((volatile unsigned int*)(0x42A60200UL)))
#define bM4_DMA1_INTMASK1_MSKTC1                  (*((volatile unsigned int*)(0x42A60204UL)))
#define bM4_DMA1_INTMASK1_MSKTC2                  (*((volatile unsigned int*)(0x42A60208UL)))
#define bM4_DMA1_INTMASK1_MSKTC3                  (*((volatile unsigned int*)(0x42A6020CUL)))
#define bM4_DMA1_INTMASK1_MSKBTC0                 (*((volatile unsigned int*)(0x42A60240UL)))
#define bM4_DMA1_INTMASK1_MSKBTC1                 (*((volatile unsigned int*)(0x42A60244UL)))
#define bM4_DMA1_INTMASK1_MSKBTC2                 (*((volatile unsigned int*)(0x42A60248UL)))
#define bM4_DMA1_INTMASK1_MSKBTC3                 (*((volatile unsigned int*)(0x42A6024CUL)))
#define bM4_DMA1_INTCLR0_CLRTRNERR0               (*((volatile unsigned int*)(0x42A60280UL)))
#define bM4_DMA1_INTCLR0_CLRTRNERR1               (*((volatile unsigned int*)(0x42A60284UL)))
#define bM4_DMA1_INTCLR0_CLRTRNERR2               (*((volatile unsigned int*)(0x42A60288UL)))
#define bM4_DMA1_INTCLR0_CLRTRNERR3               (*((volatile unsigned int*)(0x42A6028CUL)))
#define bM4_DMA1_INTCLR0_CLRREQERR0               (*((volatile unsigned int*)(0x42A602C0UL)))
#define bM4_DMA1_INTCLR0_CLRREQERR1               (*((volatile unsigned int*)(0x42A602C4UL)))
#define bM4_DMA1_INTCLR0_CLRREQERR2               (*((volatile unsigned int*)(0x42A602C8UL)))
#define bM4_DMA1_INTCLR0_CLRREQERR3               (*((volatile unsigned int*)(0x42A602CCUL)))
#define bM4_DMA1_INTCLR1_CLRTC0                   (*((volatile unsigned int*)(0x42A60300UL)))
#define bM4_DMA1_INTCLR1_CLRTC1                   (*((volatile unsigned int*)(0x42A60304UL)))
#define bM4_DMA1_INTCLR1_CLRTC2                   (*((volatile unsigned int*)(0x42A60308UL)))
#define bM4_DMA1_INTCLR1_CLRTC3                   (*((volatile unsigned int*)(0x42A6030CUL)))
#define bM4_DMA1_INTCLR1_CLRBTC0                  (*((volatile unsigned int*)(0x42A60340UL)))
#define bM4_DMA1_INTCLR1_CLRBTC1                  (*((volatile unsigned int*)(0x42A60344UL)))
#define bM4_DMA1_INTCLR1_CLRBTC2                  (*((volatile unsigned int*)(0x42A60348UL)))
#define bM4_DMA1_INTCLR1_CLRBTC3                  (*((volatile unsigned int*)(0x42A6034CUL)))
#define bM4_DMA1_CHEN_CHEN0                       (*((volatile unsigned int*)(0x42A60380UL)))
#define bM4_DMA1_CHEN_CHEN1                       (*((volatile unsigned int*)(0x42A60384UL)))
#define bM4_DMA1_CHEN_CHEN2                       (*((volatile unsigned int*)(0x42A60388UL)))
#define bM4_DMA1_CHEN_CHEN3                       (*((volatile unsigned int*)(0x42A6038CUL)))
#define bM4_DMA1_REQSTAT_CHREQ0                   (*((volatile unsigned int*)(0x42A60400UL)))
#define bM4_DMA1_REQSTAT_CHREQ1                   (*((volatile unsigned int*)(0x42A60404UL)))
#define bM4_DMA1_REQSTAT_CHREQ2                   (*((volatile unsigned int*)(0x42A60408UL)))
#define bM4_DMA1_REQSTAT_CHREQ3                   (*((volatile unsigned int*)(0x42A6040CUL)))
#define bM4_DMA1_REQSTAT_RCFGREQ                  (*((volatile unsigned int*)(0x42A6043CUL)))
#define bM4_DMA1_CHSTAT_DMAACT                    (*((volatile unsigned int*)(0x42A60480UL)))
#define bM4_DMA1_CHSTAT_RCFGACT                   (*((volatile unsigned int*)(0x42A60484UL)))
#define bM4_DMA1_CHSTAT_CHACT0                    (*((volatile unsigned int*)(0x42A604C0UL)))
#define bM4_DMA1_CHSTAT_CHACT1                    (*((volatile unsigned int*)(0x42A604C4UL)))
#define bM4_DMA1_CHSTAT_CHACT2                    (*((volatile unsigned int*)(0x42A604C8UL)))
#define bM4_DMA1_CHSTAT_CHACT3                    (*((volatile unsigned int*)(0x42A604CCUL)))
#define bM4_DMA1_RCFGCTL_RCFGEN                   (*((volatile unsigned int*)(0x42A60580UL)))
#define bM4_DMA1_RCFGCTL_RCFGLLP                  (*((volatile unsigned int*)(0x42A60584UL)))
#define bM4_DMA1_RCFGCTL_RCFGCHS0                 (*((volatile unsigned int*)(0x42A605A0UL)))
#define bM4_DMA1_RCFGCTL_RCFGCHS1                 (*((volatile unsigned int*)(0x42A605A4UL)))
#define bM4_DMA1_RCFGCTL_RCFGCHS2                 (*((volatile unsigned int*)(0x42A605A8UL)))
#define bM4_DMA1_RCFGCTL_RCFGCHS3                 (*((volatile unsigned int*)(0x42A605ACUL)))
#define bM4_DMA1_RCFGCTL_SARMD0                   (*((volatile unsigned int*)(0x42A605C0UL)))
#define bM4_DMA1_RCFGCTL_SARMD1                   (*((volatile unsigned int*)(0x42A605C4UL)))
#define bM4_DMA1_RCFGCTL_DARMD0                   (*((volatile unsigned int*)(0x42A605C8UL)))
#define bM4_DMA1_RCFGCTL_DARMD1                   (*((volatile unsigned int*)(0x42A605CCUL)))
#define bM4_DMA1_RCFGCTL_CNTMD0                   (*((volatile unsigned int*)(0x42A605D0UL)))
#define bM4_DMA1_RCFGCTL_CNTMD1                   (*((volatile unsigned int*)(0x42A605D4UL)))
#define bM4_DMA1_DTCTL0_BLKSIZE0                  (*((volatile unsigned int*)(0x42A60900UL)))
#define bM4_DMA1_DTCTL0_BLKSIZE1                  (*((volatile unsigned int*)(0x42A60904UL)))
#define bM4_DMA1_DTCTL0_BLKSIZE2                  (*((volatile unsigned int*)(0x42A60908UL)))
#define bM4_DMA1_DTCTL0_BLKSIZE3                  (*((volatile unsigned int*)(0x42A6090CUL)))
#define bM4_DMA1_DTCTL0_BLKSIZE4                  (*((volatile unsigned int*)(0x42A60910UL)))
#define bM4_DMA1_DTCTL0_BLKSIZE5                  (*((volatile unsigned int*)(0x42A60914UL)))
#define bM4_DMA1_DTCTL0_BLKSIZE6                  (*((volatile unsigned int*)(0x42A60918UL)))
#define bM4_DMA1_DTCTL0_BLKSIZE7                  (*((volatile unsigned int*)(0x42A6091CUL)))
#define bM4_DMA1_DTCTL0_BLKSIZE8                  (*((volatile unsigned int*)(0x42A60920UL)))
#define bM4_DMA1_DTCTL0_BLKSIZE9                  (*((volatile unsigned int*)(0x42A60924UL)))
#define bM4_DMA1_DTCTL0_CNT0                      (*((volatile unsigned int*)(0x42A60940UL)))
#define bM4_DMA1_DTCTL0_CNT1                      (*((volatile unsigned int*)(0x42A60944UL)))
#define bM4_DMA1_DTCTL0_CNT2                      (*((volatile unsigned int*)(0x42A60948UL)))
#define bM4_DMA1_DTCTL0_CNT3                      (*((volatile unsigned int*)(0x42A6094CUL)))
#define bM4_DMA1_DTCTL0_CNT4                      (*((volatile unsigned int*)(0x42A60950UL)))
#define bM4_DMA1_DTCTL0_CNT5                      (*((volatile unsigned int*)(0x42A60954UL)))
#define bM4_DMA1_DTCTL0_CNT6                      (*((volatile unsigned int*)(0x42A60958UL)))
#define bM4_DMA1_DTCTL0_CNT7                      (*((volatile unsigned int*)(0x42A6095CUL)))
#define bM4_DMA1_DTCTL0_CNT8                      (*((volatile unsigned int*)(0x42A60960UL)))
#define bM4_DMA1_DTCTL0_CNT9                      (*((volatile unsigned int*)(0x42A60964UL)))
#define bM4_DMA1_DTCTL0_CNT10                     (*((volatile unsigned int*)(0x42A60968UL)))
#define bM4_DMA1_DTCTL0_CNT11                     (*((volatile unsigned int*)(0x42A6096CUL)))
#define bM4_DMA1_DTCTL0_CNT12                     (*((volatile unsigned int*)(0x42A60970UL)))
#define bM4_DMA1_DTCTL0_CNT13                     (*((volatile unsigned int*)(0x42A60974UL)))
#define bM4_DMA1_DTCTL0_CNT14                     (*((volatile unsigned int*)(0x42A60978UL)))
#define bM4_DMA1_DTCTL0_CNT15                     (*((volatile unsigned int*)(0x42A6097CUL)))
#define bM4_DMA1_RPT0_SRPT0                       (*((volatile unsigned int*)(0x42A60980UL)))
#define bM4_DMA1_RPT0_SRPT1                       (*((volatile unsigned int*)(0x42A60984UL)))
#define bM4_DMA1_RPT0_SRPT2                       (*((volatile unsigned int*)(0x42A60988UL)))
#define bM4_DMA1_RPT0_SRPT3                       (*((volatile unsigned int*)(0x42A6098CUL)))
#define bM4_DMA1_RPT0_SRPT4                       (*((volatile unsigned int*)(0x42A60990UL)))
#define bM4_DMA1_RPT0_SRPT5                       (*((volatile unsigned int*)(0x42A60994UL)))
#define bM4_DMA1_RPT0_SRPT6                       (*((volatile unsigned int*)(0x42A60998UL)))
#define bM4_DMA1_RPT0_SRPT7                       (*((volatile unsigned int*)(0x42A6099CUL)))
#define bM4_DMA1_RPT0_SRPT8                       (*((volatile unsigned int*)(0x42A609A0UL)))
#define bM4_DMA1_RPT0_SRPT9                       (*((volatile unsigned int*)(0x42A609A4UL)))
#define bM4_DMA1_RPT0_DRPT0                       (*((volatile unsigned int*)(0x42A609C0UL)))
#define bM4_DMA1_RPT0_DRPT1                       (*((volatile unsigned int*)(0x42A609C4UL)))
#define bM4_DMA1_RPT0_DRPT2                       (*((volatile unsigned int*)(0x42A609C8UL)))
#define bM4_DMA1_RPT0_DRPT3                       (*((volatile unsigned int*)(0x42A609CCUL)))
#define bM4_DMA1_RPT0_DRPT4                       (*((volatile unsigned int*)(0x42A609D0UL)))
#define bM4_DMA1_RPT0_DRPT5                       (*((volatile unsigned int*)(0x42A609D4UL)))
#define bM4_DMA1_RPT0_DRPT6                       (*((volatile unsigned int*)(0x42A609D8UL)))
#define bM4_DMA1_RPT0_DRPT7                       (*((volatile unsigned int*)(0x42A609DCUL)))
#define bM4_DMA1_RPT0_DRPT8                       (*((volatile unsigned int*)(0x42A609E0UL)))
#define bM4_DMA1_RPT0_DRPT9                       (*((volatile unsigned int*)(0x42A609E4UL)))
#define bM4_DMA1_RPTB0_SRPTB0                     (*((volatile unsigned int*)(0x42A60980UL)))
#define bM4_DMA1_RPTB0_SRPTB1                     (*((volatile unsigned int*)(0x42A60984UL)))
#define bM4_DMA1_RPTB0_SRPTB2                     (*((volatile unsigned int*)(0x42A60988UL)))
#define bM4_DMA1_RPTB0_SRPTB3                     (*((volatile unsigned int*)(0x42A6098CUL)))
#define bM4_DMA1_RPTB0_SRPTB4                     (*((volatile unsigned int*)(0x42A60990UL)))
#define bM4_DMA1_RPTB0_SRPTB5                     (*((volatile unsigned int*)(0x42A60994UL)))
#define bM4_DMA1_RPTB0_SRPTB6                     (*((volatile unsigned int*)(0x42A60998UL)))
#define bM4_DMA1_RPTB0_SRPTB7                     (*((volatile unsigned int*)(0x42A6099CUL)))
#define bM4_DMA1_RPTB0_SRPTB8                     (*((volatile unsigned int*)(0x42A609A0UL)))
#define bM4_DMA1_RPTB0_SRPTB9                     (*((volatile unsigned int*)(0x42A609A4UL)))
#define bM4_DMA1_RPTB0_DRPTB0                     (*((volatile unsigned int*)(0x42A609C0UL)))
#define bM4_DMA1_RPTB0_DRPTB1                     (*((volatile unsigned int*)(0x42A609C4UL)))
#define bM4_DMA1_RPTB0_DRPTB2                     (*((volatile unsigned int*)(0x42A609C8UL)))
#define bM4_DMA1_RPTB0_DRPTB3                     (*((volatile unsigned int*)(0x42A609CCUL)))
#define bM4_DMA1_RPTB0_DRPTB4                     (*((volatile unsigned int*)(0x42A609D0UL)))
#define bM4_DMA1_RPTB0_DRPTB5                     (*((volatile unsigned int*)(0x42A609D4UL)))
#define bM4_DMA1_RPTB0_DRPTB6                     (*((volatile unsigned int*)(0x42A609D8UL)))
#define bM4_DMA1_RPTB0_DRPTB7                     (*((volatile unsigned int*)(0x42A609DCUL)))
#define bM4_DMA1_RPTB0_DRPTB8                     (*((volatile unsigned int*)(0x42A609E0UL)))
#define bM4_DMA1_RPTB0_DRPTB9                     (*((volatile unsigned int*)(0x42A609E4UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET0               (*((volatile unsigned int*)(0x42A60A00UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET1               (*((volatile unsigned int*)(0x42A60A04UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET2               (*((volatile unsigned int*)(0x42A60A08UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET3               (*((volatile unsigned int*)(0x42A60A0CUL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET4               (*((volatile unsigned int*)(0x42A60A10UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET5               (*((volatile unsigned int*)(0x42A60A14UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET6               (*((volatile unsigned int*)(0x42A60A18UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET7               (*((volatile unsigned int*)(0x42A60A1CUL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET8               (*((volatile unsigned int*)(0x42A60A20UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET9               (*((volatile unsigned int*)(0x42A60A24UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET10              (*((volatile unsigned int*)(0x42A60A28UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET11              (*((volatile unsigned int*)(0x42A60A2CUL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET12              (*((volatile unsigned int*)(0x42A60A30UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET13              (*((volatile unsigned int*)(0x42A60A34UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET14              (*((volatile unsigned int*)(0x42A60A38UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET15              (*((volatile unsigned int*)(0x42A60A3CUL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET16              (*((volatile unsigned int*)(0x42A60A40UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET17              (*((volatile unsigned int*)(0x42A60A44UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET18              (*((volatile unsigned int*)(0x42A60A48UL)))
#define bM4_DMA1_SNSEQCTL0_SOFFSET19              (*((volatile unsigned int*)(0x42A60A4CUL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT0                (*((volatile unsigned int*)(0x42A60A50UL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT1                (*((volatile unsigned int*)(0x42A60A54UL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT2                (*((volatile unsigned int*)(0x42A60A58UL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT3                (*((volatile unsigned int*)(0x42A60A5CUL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT4                (*((volatile unsigned int*)(0x42A60A60UL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT5                (*((volatile unsigned int*)(0x42A60A64UL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT6                (*((volatile unsigned int*)(0x42A60A68UL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT7                (*((volatile unsigned int*)(0x42A60A6CUL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT8                (*((volatile unsigned int*)(0x42A60A70UL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT9                (*((volatile unsigned int*)(0x42A60A74UL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT10               (*((volatile unsigned int*)(0x42A60A78UL)))
#define bM4_DMA1_SNSEQCTL0_SNSCNT11               (*((volatile unsigned int*)(0x42A60A7CUL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST0              (*((volatile unsigned int*)(0x42A60A00UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST1              (*((volatile unsigned int*)(0x42A60A04UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST2              (*((volatile unsigned int*)(0x42A60A08UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST3              (*((volatile unsigned int*)(0x42A60A0CUL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST4              (*((volatile unsigned int*)(0x42A60A10UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST5              (*((volatile unsigned int*)(0x42A60A14UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST6              (*((volatile unsigned int*)(0x42A60A18UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST7              (*((volatile unsigned int*)(0x42A60A1CUL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST8              (*((volatile unsigned int*)(0x42A60A20UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST9              (*((volatile unsigned int*)(0x42A60A24UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST10             (*((volatile unsigned int*)(0x42A60A28UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST11             (*((volatile unsigned int*)(0x42A60A2CUL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST12             (*((volatile unsigned int*)(0x42A60A30UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST13             (*((volatile unsigned int*)(0x42A60A34UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST14             (*((volatile unsigned int*)(0x42A60A38UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST15             (*((volatile unsigned int*)(0x42A60A3CUL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST16             (*((volatile unsigned int*)(0x42A60A40UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST17             (*((volatile unsigned int*)(0x42A60A44UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST18             (*((volatile unsigned int*)(0x42A60A48UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSDIST19             (*((volatile unsigned int*)(0x42A60A4CUL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB0              (*((volatile unsigned int*)(0x42A60A50UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB1              (*((volatile unsigned int*)(0x42A60A54UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB2              (*((volatile unsigned int*)(0x42A60A58UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB3              (*((volatile unsigned int*)(0x42A60A5CUL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB4              (*((volatile unsigned int*)(0x42A60A60UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB5              (*((volatile unsigned int*)(0x42A60A64UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB6              (*((volatile unsigned int*)(0x42A60A68UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB7              (*((volatile unsigned int*)(0x42A60A6CUL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB8              (*((volatile unsigned int*)(0x42A60A70UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB9              (*((volatile unsigned int*)(0x42A60A74UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB10             (*((volatile unsigned int*)(0x42A60A78UL)))
#define bM4_DMA1_SNSEQCTLB0_SNSCNTB11             (*((volatile unsigned int*)(0x42A60A7CUL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET0               (*((volatile unsigned int*)(0x42A60A80UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET1               (*((volatile unsigned int*)(0x42A60A84UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET2               (*((volatile unsigned int*)(0x42A60A88UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET3               (*((volatile unsigned int*)(0x42A60A8CUL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET4               (*((volatile unsigned int*)(0x42A60A90UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET5               (*((volatile unsigned int*)(0x42A60A94UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET6               (*((volatile unsigned int*)(0x42A60A98UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET7               (*((volatile unsigned int*)(0x42A60A9CUL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET8               (*((volatile unsigned int*)(0x42A60AA0UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET9               (*((volatile unsigned int*)(0x42A60AA4UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET10              (*((volatile unsigned int*)(0x42A60AA8UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET11              (*((volatile unsigned int*)(0x42A60AACUL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET12              (*((volatile unsigned int*)(0x42A60AB0UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET13              (*((volatile unsigned int*)(0x42A60AB4UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET14              (*((volatile unsigned int*)(0x42A60AB8UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET15              (*((volatile unsigned int*)(0x42A60ABCUL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET16              (*((volatile unsigned int*)(0x42A60AC0UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET17              (*((volatile unsigned int*)(0x42A60AC4UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET18              (*((volatile unsigned int*)(0x42A60AC8UL)))
#define bM4_DMA1_DNSEQCTL0_DOFFSET19              (*((volatile unsigned int*)(0x42A60ACCUL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT0                (*((volatile unsigned int*)(0x42A60AD0UL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT1                (*((volatile unsigned int*)(0x42A60AD4UL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT2                (*((volatile unsigned int*)(0x42A60AD8UL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT3                (*((volatile unsigned int*)(0x42A60ADCUL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT4                (*((volatile unsigned int*)(0x42A60AE0UL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT5                (*((volatile unsigned int*)(0x42A60AE4UL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT6                (*((volatile unsigned int*)(0x42A60AE8UL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT7                (*((volatile unsigned int*)(0x42A60AECUL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT8                (*((volatile unsigned int*)(0x42A60AF0UL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT9                (*((volatile unsigned int*)(0x42A60AF4UL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT10               (*((volatile unsigned int*)(0x42A60AF8UL)))
#define bM4_DMA1_DNSEQCTL0_DNSCNT11               (*((volatile unsigned int*)(0x42A60AFCUL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST0              (*((volatile unsigned int*)(0x42A60A80UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST1              (*((volatile unsigned int*)(0x42A60A84UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST2              (*((volatile unsigned int*)(0x42A60A88UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST3              (*((volatile unsigned int*)(0x42A60A8CUL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST4              (*((volatile unsigned int*)(0x42A60A90UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST5              (*((volatile unsigned int*)(0x42A60A94UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST6              (*((volatile unsigned int*)(0x42A60A98UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST7              (*((volatile unsigned int*)(0x42A60A9CUL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST8              (*((volatile unsigned int*)(0x42A60AA0UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST9              (*((volatile unsigned int*)(0x42A60AA4UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST10             (*((volatile unsigned int*)(0x42A60AA8UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST11             (*((volatile unsigned int*)(0x42A60AACUL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST12             (*((volatile unsigned int*)(0x42A60AB0UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST13             (*((volatile unsigned int*)(0x42A60AB4UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST14             (*((volatile unsigned int*)(0x42A60AB8UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST15             (*((volatile unsigned int*)(0x42A60ABCUL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST16             (*((volatile unsigned int*)(0x42A60AC0UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST17             (*((volatile unsigned int*)(0x42A60AC4UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST18             (*((volatile unsigned int*)(0x42A60AC8UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSDIST19             (*((volatile unsigned int*)(0x42A60ACCUL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB0              (*((volatile unsigned int*)(0x42A60AD0UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB1              (*((volatile unsigned int*)(0x42A60AD4UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB2              (*((volatile unsigned int*)(0x42A60AD8UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB3              (*((volatile unsigned int*)(0x42A60ADCUL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB4              (*((volatile unsigned int*)(0x42A60AE0UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB5              (*((volatile unsigned int*)(0x42A60AE4UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB6              (*((volatile unsigned int*)(0x42A60AE8UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB7              (*((volatile unsigned int*)(0x42A60AECUL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB8              (*((volatile unsigned int*)(0x42A60AF0UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB9              (*((volatile unsigned int*)(0x42A60AF4UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB10             (*((volatile unsigned int*)(0x42A60AF8UL)))
#define bM4_DMA1_DNSEQCTLB0_DNSCNTB11             (*((volatile unsigned int*)(0x42A60AFCUL)))
#define bM4_DMA1_LLP0_LLP0                        (*((volatile unsigned int*)(0x42A60B08UL)))
#define bM4_DMA1_LLP0_LLP1                        (*((volatile unsigned int*)(0x42A60B0CUL)))
#define bM4_DMA1_LLP0_LLP2                        (*((volatile unsigned int*)(0x42A60B10UL)))
#define bM4_DMA1_LLP0_LLP3                        (*((volatile unsigned int*)(0x42A60B14UL)))
#define bM4_DMA1_LLP0_LLP4                        (*((volatile unsigned int*)(0x42A60B18UL)))
#define bM4_DMA1_LLP0_LLP5                        (*((volatile unsigned int*)(0x42A60B1CUL)))
#define bM4_DMA1_LLP0_LLP6                        (*((volatile unsigned int*)(0x42A60B20UL)))
#define bM4_DMA1_LLP0_LLP7                        (*((volatile unsigned int*)(0x42A60B24UL)))
#define bM4_DMA1_LLP0_LLP8                        (*((volatile unsigned int*)(0x42A60B28UL)))
#define bM4_DMA1_LLP0_LLP9                        (*((volatile unsigned int*)(0x42A60B2CUL)))
#define bM4_DMA1_LLP0_LLP10                       (*((volatile unsigned int*)(0x42A60B30UL)))
#define bM4_DMA1_LLP0_LLP11                       (*((volatile unsigned int*)(0x42A60B34UL)))
#define bM4_DMA1_LLP0_LLP12                       (*((volatile unsigned int*)(0x42A60B38UL)))
#define bM4_DMA1_LLP0_LLP13                       (*((volatile unsigned int*)(0x42A60B3CUL)))
#define bM4_DMA1_LLP0_LLP14                       (*((volatile unsigned int*)(0x42A60B40UL)))
#define bM4_DMA1_LLP0_LLP15                       (*((volatile unsigned int*)(0x42A60B44UL)))
#define bM4_DMA1_LLP0_LLP16                       (*((volatile unsigned int*)(0x42A60B48UL)))
#define bM4_DMA1_LLP0_LLP17                       (*((volatile unsigned int*)(0x42A60B4CUL)))
#define bM4_DMA1_LLP0_LLP18                       (*((volatile unsigned int*)(0x42A60B50UL)))
#define bM4_DMA1_LLP0_LLP19                       (*((volatile unsigned int*)(0x42A60B54UL)))
#define bM4_DMA1_LLP0_LLP20                       (*((volatile unsigned int*)(0x42A60B58UL)))
#define bM4_DMA1_LLP0_LLP21                       (*((volatile unsigned int*)(0x42A60B5CUL)))
#define bM4_DMA1_LLP0_LLP22                       (*((volatile unsigned int*)(0x42A60B60UL)))
#define bM4_DMA1_LLP0_LLP23                       (*((volatile unsigned int*)(0x42A60B64UL)))
#define bM4_DMA1_LLP0_LLP24                       (*((volatile unsigned int*)(0x42A60B68UL)))
#define bM4_DMA1_LLP0_LLP25                       (*((volatile unsigned int*)(0x42A60B6CUL)))
#define bM4_DMA1_LLP0_LLP26                       (*((volatile unsigned int*)(0x42A60B70UL)))
#define bM4_DMA1_LLP0_LLP27                       (*((volatile unsigned int*)(0x42A60B74UL)))
#define bM4_DMA1_LLP0_LLP28                       (*((volatile unsigned int*)(0x42A60B78UL)))
#define bM4_DMA1_LLP0_LLP29                       (*((volatile unsigned int*)(0x42A60B7CUL)))
#define bM4_DMA1_CHCTL0_SINC0                     (*((volatile unsigned int*)(0x42A60B80UL)))
#define bM4_DMA1_CHCTL0_SINC1                     (*((volatile unsigned int*)(0x42A60B84UL)))
#define bM4_DMA1_CHCTL0_DINC0                     (*((volatile unsigned int*)(0x42A60B88UL)))
#define bM4_DMA1_CHCTL0_DINC1                     (*((volatile unsigned int*)(0x42A60B8CUL)))
#define bM4_DMA1_CHCTL0_SRPTEN                    (*((volatile unsigned int*)(0x42A60B90UL)))
#define bM4_DMA1_CHCTL0_DRPTEN                    (*((volatile unsigned int*)(0x42A60B94UL)))
#define bM4_DMA1_CHCTL0_SNSEQEN                   (*((volatile unsigned int*)(0x42A60B98UL)))
#define bM4_DMA1_CHCTL0_DNSEQEN                   (*((volatile unsigned int*)(0x42A60B9CUL)))
#define bM4_DMA1_CHCTL0_HSIZE0                    (*((volatile unsigned int*)(0x42A60BA0UL)))
#define bM4_DMA1_CHCTL0_HSIZE1                    (*((volatile unsigned int*)(0x42A60BA4UL)))
#define bM4_DMA1_CHCTL0_LLPEN                     (*((volatile unsigned int*)(0x42A60BA8UL)))
#define bM4_DMA1_CHCTL0_LLPRUN                    (*((volatile unsigned int*)(0x42A60BACUL)))
#define bM4_DMA1_CHCTL0_IE                        (*((volatile unsigned int*)(0x42A60BB0UL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE0               (*((volatile unsigned int*)(0x42A60D00UL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE1               (*((volatile unsigned int*)(0x42A60D04UL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE2               (*((volatile unsigned int*)(0x42A60D08UL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE3               (*((volatile unsigned int*)(0x42A60D0CUL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE4               (*((volatile unsigned int*)(0x42A60D10UL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE5               (*((volatile unsigned int*)(0x42A60D14UL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE6               (*((volatile unsigned int*)(0x42A60D18UL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE7               (*((volatile unsigned int*)(0x42A60D1CUL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE8               (*((volatile unsigned int*)(0x42A60D20UL)))
#define bM4_DMA1_MONDTCTL0_BLKSIZE9               (*((volatile unsigned int*)(0x42A60D24UL)))
#define bM4_DMA1_MONDTCTL0_CNT0                   (*((volatile unsigned int*)(0x42A60D40UL)))
#define bM4_DMA1_MONDTCTL0_CNT1                   (*((volatile unsigned int*)(0x42A60D44UL)))
#define bM4_DMA1_MONDTCTL0_CNT2                   (*((volatile unsigned int*)(0x42A60D48UL)))
#define bM4_DMA1_MONDTCTL0_CNT3                   (*((volatile unsigned int*)(0x42A60D4CUL)))
#define bM4_DMA1_MONDTCTL0_CNT4                   (*((volatile unsigned int*)(0x42A60D50UL)))
#define bM4_DMA1_MONDTCTL0_CNT5                   (*((volatile unsigned int*)(0x42A60D54UL)))
#define bM4_DMA1_MONDTCTL0_CNT6                   (*((volatile unsigned int*)(0x42A60D58UL)))
#define bM4_DMA1_MONDTCTL0_CNT7                   (*((volatile unsigned int*)(0x42A60D5CUL)))
#define bM4_DMA1_MONDTCTL0_CNT8                   (*((volatile unsigned int*)(0x42A60D60UL)))
#define bM4_DMA1_MONDTCTL0_CNT9                   (*((volatile unsigned int*)(0x42A60D64UL)))
#define bM4_DMA1_MONDTCTL0_CNT10                  (*((volatile unsigned int*)(0x42A60D68UL)))
#define bM4_DMA1_MONDTCTL0_CNT11                  (*((volatile unsigned int*)(0x42A60D6CUL)))
#define bM4_DMA1_MONDTCTL0_CNT12                  (*((volatile unsigned int*)(0x42A60D70UL)))
#define bM4_DMA1_MONDTCTL0_CNT13                  (*((volatile unsigned int*)(0x42A60D74UL)))
#define bM4_DMA1_MONDTCTL0_CNT14                  (*((volatile unsigned int*)(0x42A60D78UL)))
#define bM4_DMA1_MONDTCTL0_CNT15                  (*((volatile unsigned int*)(0x42A60D7CUL)))
#define bM4_DMA1_MONRPT0_SRPT0                    (*((volatile unsigned int*)(0x42A60D80UL)))
#define bM4_DMA1_MONRPT0_SRPT1                    (*((volatile unsigned int*)(0x42A60D84UL)))
#define bM4_DMA1_MONRPT0_SRPT2                    (*((volatile unsigned int*)(0x42A60D88UL)))
#define bM4_DMA1_MONRPT0_SRPT3                    (*((volatile unsigned int*)(0x42A60D8CUL)))
#define bM4_DMA1_MONRPT0_SRPT4                    (*((volatile unsigned int*)(0x42A60D90UL)))
#define bM4_DMA1_MONRPT0_SRPT5                    (*((volatile unsigned int*)(0x42A60D94UL)))
#define bM4_DMA1_MONRPT0_SRPT6                    (*((volatile unsigned int*)(0x42A60D98UL)))
#define bM4_DMA1_MONRPT0_SRPT7                    (*((volatile unsigned int*)(0x42A60D9CUL)))
#define bM4_DMA1_MONRPT0_SRPT8                    (*((volatile unsigned int*)(0x42A60DA0UL)))
#define bM4_DMA1_MONRPT0_SRPT9                    (*((volatile unsigned int*)(0x42A60DA4UL)))
#define bM4_DMA1_MONRPT0_DRPT0                    (*((volatile unsigned int*)(0x42A60DC0UL)))
#define bM4_DMA1_MONRPT0_DRPT1                    (*((volatile unsigned int*)(0x42A60DC4UL)))
#define bM4_DMA1_MONRPT0_DRPT2                    (*((volatile unsigned int*)(0x42A60DC8UL)))
#define bM4_DMA1_MONRPT0_DRPT3                    (*((volatile unsigned int*)(0x42A60DCCUL)))
#define bM4_DMA1_MONRPT0_DRPT4                    (*((volatile unsigned int*)(0x42A60DD0UL)))
#define bM4_DMA1_MONRPT0_DRPT5                    (*((volatile unsigned int*)(0x42A60DD4UL)))
#define bM4_DMA1_MONRPT0_DRPT6                    (*((volatile unsigned int*)(0x42A60DD8UL)))
#define bM4_DMA1_MONRPT0_DRPT7                    (*((volatile unsigned int*)(0x42A60DDCUL)))
#define bM4_DMA1_MONRPT0_DRPT8                    (*((volatile unsigned int*)(0x42A60DE0UL)))
#define bM4_DMA1_MONRPT0_DRPT9                    (*((volatile unsigned int*)(0x42A60DE4UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET0            (*((volatile unsigned int*)(0x42A60E00UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET1            (*((volatile unsigned int*)(0x42A60E04UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET2            (*((volatile unsigned int*)(0x42A60E08UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET3            (*((volatile unsigned int*)(0x42A60E0CUL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET4            (*((volatile unsigned int*)(0x42A60E10UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET5            (*((volatile unsigned int*)(0x42A60E14UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET6            (*((volatile unsigned int*)(0x42A60E18UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET7            (*((volatile unsigned int*)(0x42A60E1CUL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET8            (*((volatile unsigned int*)(0x42A60E20UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET9            (*((volatile unsigned int*)(0x42A60E24UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET10           (*((volatile unsigned int*)(0x42A60E28UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET11           (*((volatile unsigned int*)(0x42A60E2CUL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET12           (*((volatile unsigned int*)(0x42A60E30UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET13           (*((volatile unsigned int*)(0x42A60E34UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET14           (*((volatile unsigned int*)(0x42A60E38UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET15           (*((volatile unsigned int*)(0x42A60E3CUL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET16           (*((volatile unsigned int*)(0x42A60E40UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET17           (*((volatile unsigned int*)(0x42A60E44UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET18           (*((volatile unsigned int*)(0x42A60E48UL)))
#define bM4_DMA1_MONSNSEQCTL0_SOFFSET19           (*((volatile unsigned int*)(0x42A60E4CUL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT0             (*((volatile unsigned int*)(0x42A60E50UL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT1             (*((volatile unsigned int*)(0x42A60E54UL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT2             (*((volatile unsigned int*)(0x42A60E58UL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT3             (*((volatile unsigned int*)(0x42A60E5CUL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT4             (*((volatile unsigned int*)(0x42A60E60UL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT5             (*((volatile unsigned int*)(0x42A60E64UL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT6             (*((volatile unsigned int*)(0x42A60E68UL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT7             (*((volatile unsigned int*)(0x42A60E6CUL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT8             (*((volatile unsigned int*)(0x42A60E70UL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT9             (*((volatile unsigned int*)(0x42A60E74UL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT10            (*((volatile unsigned int*)(0x42A60E78UL)))
#define bM4_DMA1_MONSNSEQCTL0_SNSCNT11            (*((volatile unsigned int*)(0x42A60E7CUL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET0            (*((volatile unsigned int*)(0x42A60E80UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET1            (*((volatile unsigned int*)(0x42A60E84UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET2            (*((volatile unsigned int*)(0x42A60E88UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET3            (*((volatile unsigned int*)(0x42A60E8CUL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET4            (*((volatile unsigned int*)(0x42A60E90UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET5            (*((volatile unsigned int*)(0x42A60E94UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET6            (*((volatile unsigned int*)(0x42A60E98UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET7            (*((volatile unsigned int*)(0x42A60E9CUL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET8            (*((volatile unsigned int*)(0x42A60EA0UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET9            (*((volatile unsigned int*)(0x42A60EA4UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET10           (*((volatile unsigned int*)(0x42A60EA8UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET11           (*((volatile unsigned int*)(0x42A60EACUL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET12           (*((volatile unsigned int*)(0x42A60EB0UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET13           (*((volatile unsigned int*)(0x42A60EB4UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET14           (*((volatile unsigned int*)(0x42A60EB8UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET15           (*((volatile unsigned int*)(0x42A60EBCUL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET16           (*((volatile unsigned int*)(0x42A60EC0UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET17           (*((volatile unsigned int*)(0x42A60EC4UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET18           (*((volatile unsigned int*)(0x42A60EC8UL)))
#define bM4_DMA1_MONDNSEQCTL0_DOFFSET19           (*((volatile unsigned int*)(0x42A60ECCUL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT0             (*((volatile unsigned int*)(0x42A60ED0UL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT1             (*((volatile unsigned int*)(0x42A60ED4UL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT2             (*((volatile unsigned int*)(0x42A60ED8UL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT3             (*((volatile unsigned int*)(0x42A60EDCUL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT4             (*((volatile unsigned int*)(0x42A60EE0UL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT5             (*((volatile unsigned int*)(0x42A60EE4UL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT6             (*((volatile unsigned int*)(0x42A60EE8UL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT7             (*((volatile unsigned int*)(0x42A60EECUL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT8             (*((volatile unsigned int*)(0x42A60EF0UL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT9             (*((volatile unsigned int*)(0x42A60EF4UL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT10            (*((volatile unsigned int*)(0x42A60EF8UL)))
#define bM4_DMA1_MONDNSEQCTL0_DNSCNT11            (*((volatile unsigned int*)(0x42A60EFCUL)))
#define bM4_DMA1_DTCTL1_BLKSIZE0                  (*((volatile unsigned int*)(0x42A61100UL)))
#define bM4_DMA1_DTCTL1_BLKSIZE1                  (*((volatile unsigned int*)(0x42A61104UL)))
#define bM4_DMA1_DTCTL1_BLKSIZE2                  (*((volatile unsigned int*)(0x42A61108UL)))
#define bM4_DMA1_DTCTL1_BLKSIZE3                  (*((volatile unsigned int*)(0x42A6110CUL)))
#define bM4_DMA1_DTCTL1_BLKSIZE4                  (*((volatile unsigned int*)(0x42A61110UL)))
#define bM4_DMA1_DTCTL1_BLKSIZE5                  (*((volatile unsigned int*)(0x42A61114UL)))
#define bM4_DMA1_DTCTL1_BLKSIZE6                  (*((volatile unsigned int*)(0x42A61118UL)))
#define bM4_DMA1_DTCTL1_BLKSIZE7                  (*((volatile unsigned int*)(0x42A6111CUL)))
#define bM4_DMA1_DTCTL1_BLKSIZE8                  (*((volatile unsigned int*)(0x42A61120UL)))
#define bM4_DMA1_DTCTL1_BLKSIZE9                  (*((volatile unsigned int*)(0x42A61124UL)))
#define bM4_DMA1_DTCTL1_CNT0                      (*((volatile unsigned int*)(0x42A61140UL)))
#define bM4_DMA1_DTCTL1_CNT1                      (*((volatile unsigned int*)(0x42A61144UL)))
#define bM4_DMA1_DTCTL1_CNT2                      (*((volatile unsigned int*)(0x42A61148UL)))
#define bM4_DMA1_DTCTL1_CNT3                      (*((volatile unsigned int*)(0x42A6114CUL)))
#define bM4_DMA1_DTCTL1_CNT4                      (*((volatile unsigned int*)(0x42A61150UL)))
#define bM4_DMA1_DTCTL1_CNT5                      (*((volatile unsigned int*)(0x42A61154UL)))
#define bM4_DMA1_DTCTL1_CNT6                      (*((volatile unsigned int*)(0x42A61158UL)))
#define bM4_DMA1_DTCTL1_CNT7                      (*((volatile unsigned int*)(0x42A6115CUL)))
#define bM4_DMA1_DTCTL1_CNT8                      (*((volatile unsigned int*)(0x42A61160UL)))
#define bM4_DMA1_DTCTL1_CNT9                      (*((volatile unsigned int*)(0x42A61164UL)))
#define bM4_DMA1_DTCTL1_CNT10                     (*((volatile unsigned int*)(0x42A61168UL)))
#define bM4_DMA1_DTCTL1_CNT11                     (*((volatile unsigned int*)(0x42A6116CUL)))
#define bM4_DMA1_DTCTL1_CNT12                     (*((volatile unsigned int*)(0x42A61170UL)))
#define bM4_DMA1_DTCTL1_CNT13                     (*((volatile unsigned int*)(0x42A61174UL)))
#define bM4_DMA1_DTCTL1_CNT14                     (*((volatile unsigned int*)(0x42A61178UL)))
#define bM4_DMA1_DTCTL1_CNT15                     (*((volatile unsigned int*)(0x42A6117CUL)))
#define bM4_DMA1_RPT1_SRPT0                       (*((volatile unsigned int*)(0x42A61180UL)))
#define bM4_DMA1_RPT1_SRPT1                       (*((volatile unsigned int*)(0x42A61184UL)))
#define bM4_DMA1_RPT1_SRPT2                       (*((volatile unsigned int*)(0x42A61188UL)))
#define bM4_DMA1_RPT1_SRPT3                       (*((volatile unsigned int*)(0x42A6118CUL)))
#define bM4_DMA1_RPT1_SRPT4                       (*((volatile unsigned int*)(0x42A61190UL)))
#define bM4_DMA1_RPT1_SRPT5                       (*((volatile unsigned int*)(0x42A61194UL)))
#define bM4_DMA1_RPT1_SRPT6                       (*((volatile unsigned int*)(0x42A61198UL)))
#define bM4_DMA1_RPT1_SRPT7                       (*((volatile unsigned int*)(0x42A6119CUL)))
#define bM4_DMA1_RPT1_SRPT8                       (*((volatile unsigned int*)(0x42A611A0UL)))
#define bM4_DMA1_RPT1_SRPT9                       (*((volatile unsigned int*)(0x42A611A4UL)))
#define bM4_DMA1_RPT1_DRPT0                       (*((volatile unsigned int*)(0x42A611C0UL)))
#define bM4_DMA1_RPT1_DRPT1                       (*((volatile unsigned int*)(0x42A611C4UL)))
#define bM4_DMA1_RPT1_DRPT2                       (*((volatile unsigned int*)(0x42A611C8UL)))
#define bM4_DMA1_RPT1_DRPT3                       (*((volatile unsigned int*)(0x42A611CCUL)))
#define bM4_DMA1_RPT1_DRPT4                       (*((volatile unsigned int*)(0x42A611D0UL)))
#define bM4_DMA1_RPT1_DRPT5                       (*((volatile unsigned int*)(0x42A611D4UL)))
#define bM4_DMA1_RPT1_DRPT6                       (*((volatile unsigned int*)(0x42A611D8UL)))
#define bM4_DMA1_RPT1_DRPT7                       (*((volatile unsigned int*)(0x42A611DCUL)))
#define bM4_DMA1_RPT1_DRPT8                       (*((volatile unsigned int*)(0x42A611E0UL)))
#define bM4_DMA1_RPT1_DRPT9                       (*((volatile unsigned int*)(0x42A611E4UL)))
#define bM4_DMA1_RPTB1_SRPTB0                     (*((volatile unsigned int*)(0x42A61180UL)))
#define bM4_DMA1_RPTB1_SRPTB1                     (*((volatile unsigned int*)(0x42A61184UL)))
#define bM4_DMA1_RPTB1_SRPTB2                     (*((volatile unsigned int*)(0x42A61188UL)))
#define bM4_DMA1_RPTB1_SRPTB3                     (*((volatile unsigned int*)(0x42A6118CUL)))
#define bM4_DMA1_RPTB1_SRPTB4                     (*((volatile unsigned int*)(0x42A61190UL)))
#define bM4_DMA1_RPTB1_SRPTB5                     (*((volatile unsigned int*)(0x42A61194UL)))
#define bM4_DMA1_RPTB1_SRPTB6                     (*((volatile unsigned int*)(0x42A61198UL)))
#define bM4_DMA1_RPTB1_SRPTB7                     (*((volatile unsigned int*)(0x42A6119CUL)))
#define bM4_DMA1_RPTB1_SRPTB8                     (*((volatile unsigned int*)(0x42A611A0UL)))
#define bM4_DMA1_RPTB1_SRPTB9                     (*((volatile unsigned int*)(0x42A611A4UL)))
#define bM4_DMA1_RPTB1_DRPTB0                     (*((volatile unsigned int*)(0x42A611C0UL)))
#define bM4_DMA1_RPTB1_DRPTB1                     (*((volatile unsigned int*)(0x42A611C4UL)))
#define bM4_DMA1_RPTB1_DRPTB2                     (*((volatile unsigned int*)(0x42A611C8UL)))
#define bM4_DMA1_RPTB1_DRPTB3                     (*((volatile unsigned int*)(0x42A611CCUL)))
#define bM4_DMA1_RPTB1_DRPTB4                     (*((volatile unsigned int*)(0x42A611D0UL)))
#define bM4_DMA1_RPTB1_DRPTB5                     (*((volatile unsigned int*)(0x42A611D4UL)))
#define bM4_DMA1_RPTB1_DRPTB6                     (*((volatile unsigned int*)(0x42A611D8UL)))
#define bM4_DMA1_RPTB1_DRPTB7                     (*((volatile unsigned int*)(0x42A611DCUL)))
#define bM4_DMA1_RPTB1_DRPTB8                     (*((volatile unsigned int*)(0x42A611E0UL)))
#define bM4_DMA1_RPTB1_DRPTB9                     (*((volatile unsigned int*)(0x42A611E4UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET0               (*((volatile unsigned int*)(0x42A61200UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET1               (*((volatile unsigned int*)(0x42A61204UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET2               (*((volatile unsigned int*)(0x42A61208UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET3               (*((volatile unsigned int*)(0x42A6120CUL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET4               (*((volatile unsigned int*)(0x42A61210UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET5               (*((volatile unsigned int*)(0x42A61214UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET6               (*((volatile unsigned int*)(0x42A61218UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET7               (*((volatile unsigned int*)(0x42A6121CUL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET8               (*((volatile unsigned int*)(0x42A61220UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET9               (*((volatile unsigned int*)(0x42A61224UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET10              (*((volatile unsigned int*)(0x42A61228UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET11              (*((volatile unsigned int*)(0x42A6122CUL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET12              (*((volatile unsigned int*)(0x42A61230UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET13              (*((volatile unsigned int*)(0x42A61234UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET14              (*((volatile unsigned int*)(0x42A61238UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET15              (*((volatile unsigned int*)(0x42A6123CUL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET16              (*((volatile unsigned int*)(0x42A61240UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET17              (*((volatile unsigned int*)(0x42A61244UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET18              (*((volatile unsigned int*)(0x42A61248UL)))
#define bM4_DMA1_SNSEQCTL1_SOFFSET19              (*((volatile unsigned int*)(0x42A6124CUL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT0                (*((volatile unsigned int*)(0x42A61250UL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT1                (*((volatile unsigned int*)(0x42A61254UL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT2                (*((volatile unsigned int*)(0x42A61258UL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT3                (*((volatile unsigned int*)(0x42A6125CUL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT4                (*((volatile unsigned int*)(0x42A61260UL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT5                (*((volatile unsigned int*)(0x42A61264UL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT6                (*((volatile unsigned int*)(0x42A61268UL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT7                (*((volatile unsigned int*)(0x42A6126CUL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT8                (*((volatile unsigned int*)(0x42A61270UL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT9                (*((volatile unsigned int*)(0x42A61274UL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT10               (*((volatile unsigned int*)(0x42A61278UL)))
#define bM4_DMA1_SNSEQCTL1_SNSCNT11               (*((volatile unsigned int*)(0x42A6127CUL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST0              (*((volatile unsigned int*)(0x42A61200UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST1              (*((volatile unsigned int*)(0x42A61204UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST2              (*((volatile unsigned int*)(0x42A61208UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST3              (*((volatile unsigned int*)(0x42A6120CUL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST4              (*((volatile unsigned int*)(0x42A61210UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST5              (*((volatile unsigned int*)(0x42A61214UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST6              (*((volatile unsigned int*)(0x42A61218UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST7              (*((volatile unsigned int*)(0x42A6121CUL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST8              (*((volatile unsigned int*)(0x42A61220UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST9              (*((volatile unsigned int*)(0x42A61224UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST10             (*((volatile unsigned int*)(0x42A61228UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST11             (*((volatile unsigned int*)(0x42A6122CUL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST12             (*((volatile unsigned int*)(0x42A61230UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST13             (*((volatile unsigned int*)(0x42A61234UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST14             (*((volatile unsigned int*)(0x42A61238UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST15             (*((volatile unsigned int*)(0x42A6123CUL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST16             (*((volatile unsigned int*)(0x42A61240UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST17             (*((volatile unsigned int*)(0x42A61244UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST18             (*((volatile unsigned int*)(0x42A61248UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSDIST19             (*((volatile unsigned int*)(0x42A6124CUL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB0              (*((volatile unsigned int*)(0x42A61250UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB1              (*((volatile unsigned int*)(0x42A61254UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB2              (*((volatile unsigned int*)(0x42A61258UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB3              (*((volatile unsigned int*)(0x42A6125CUL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB4              (*((volatile unsigned int*)(0x42A61260UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB5              (*((volatile unsigned int*)(0x42A61264UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB6              (*((volatile unsigned int*)(0x42A61268UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB7              (*((volatile unsigned int*)(0x42A6126CUL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB8              (*((volatile unsigned int*)(0x42A61270UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB9              (*((volatile unsigned int*)(0x42A61274UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB10             (*((volatile unsigned int*)(0x42A61278UL)))
#define bM4_DMA1_SNSEQCTLB1_SNSCNTB11             (*((volatile unsigned int*)(0x42A6127CUL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET0               (*((volatile unsigned int*)(0x42A61280UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET1               (*((volatile unsigned int*)(0x42A61284UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET2               (*((volatile unsigned int*)(0x42A61288UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET3               (*((volatile unsigned int*)(0x42A6128CUL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET4               (*((volatile unsigned int*)(0x42A61290UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET5               (*((volatile unsigned int*)(0x42A61294UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET6               (*((volatile unsigned int*)(0x42A61298UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET7               (*((volatile unsigned int*)(0x42A6129CUL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET8               (*((volatile unsigned int*)(0x42A612A0UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET9               (*((volatile unsigned int*)(0x42A612A4UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET10              (*((volatile unsigned int*)(0x42A612A8UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET11              (*((volatile unsigned int*)(0x42A612ACUL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET12              (*((volatile unsigned int*)(0x42A612B0UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET13              (*((volatile unsigned int*)(0x42A612B4UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET14              (*((volatile unsigned int*)(0x42A612B8UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET15              (*((volatile unsigned int*)(0x42A612BCUL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET16              (*((volatile unsigned int*)(0x42A612C0UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET17              (*((volatile unsigned int*)(0x42A612C4UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET18              (*((volatile unsigned int*)(0x42A612C8UL)))
#define bM4_DMA1_DNSEQCTL1_DOFFSET19              (*((volatile unsigned int*)(0x42A612CCUL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT0                (*((volatile unsigned int*)(0x42A612D0UL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT1                (*((volatile unsigned int*)(0x42A612D4UL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT2                (*((volatile unsigned int*)(0x42A612D8UL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT3                (*((volatile unsigned int*)(0x42A612DCUL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT4                (*((volatile unsigned int*)(0x42A612E0UL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT5                (*((volatile unsigned int*)(0x42A612E4UL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT6                (*((volatile unsigned int*)(0x42A612E8UL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT7                (*((volatile unsigned int*)(0x42A612ECUL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT8                (*((volatile unsigned int*)(0x42A612F0UL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT9                (*((volatile unsigned int*)(0x42A612F4UL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT10               (*((volatile unsigned int*)(0x42A612F8UL)))
#define bM4_DMA1_DNSEQCTL1_DNSCNT11               (*((volatile unsigned int*)(0x42A612FCUL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST0              (*((volatile unsigned int*)(0x42A61280UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST1              (*((volatile unsigned int*)(0x42A61284UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST2              (*((volatile unsigned int*)(0x42A61288UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST3              (*((volatile unsigned int*)(0x42A6128CUL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST4              (*((volatile unsigned int*)(0x42A61290UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST5              (*((volatile unsigned int*)(0x42A61294UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST6              (*((volatile unsigned int*)(0x42A61298UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST7              (*((volatile unsigned int*)(0x42A6129CUL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST8              (*((volatile unsigned int*)(0x42A612A0UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST9              (*((volatile unsigned int*)(0x42A612A4UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST10             (*((volatile unsigned int*)(0x42A612A8UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST11             (*((volatile unsigned int*)(0x42A612ACUL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST12             (*((volatile unsigned int*)(0x42A612B0UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST13             (*((volatile unsigned int*)(0x42A612B4UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST14             (*((volatile unsigned int*)(0x42A612B8UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST15             (*((volatile unsigned int*)(0x42A612BCUL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST16             (*((volatile unsigned int*)(0x42A612C0UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST17             (*((volatile unsigned int*)(0x42A612C4UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST18             (*((volatile unsigned int*)(0x42A612C8UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSDIST19             (*((volatile unsigned int*)(0x42A612CCUL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB0              (*((volatile unsigned int*)(0x42A612D0UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB1              (*((volatile unsigned int*)(0x42A612D4UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB2              (*((volatile unsigned int*)(0x42A612D8UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB3              (*((volatile unsigned int*)(0x42A612DCUL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB4              (*((volatile unsigned int*)(0x42A612E0UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB5              (*((volatile unsigned int*)(0x42A612E4UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB6              (*((volatile unsigned int*)(0x42A612E8UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB7              (*((volatile unsigned int*)(0x42A612ECUL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB8              (*((volatile unsigned int*)(0x42A612F0UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB9              (*((volatile unsigned int*)(0x42A612F4UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB10             (*((volatile unsigned int*)(0x42A612F8UL)))
#define bM4_DMA1_DNSEQCTLB1_DNSCNTB11             (*((volatile unsigned int*)(0x42A612FCUL)))
#define bM4_DMA1_LLP1_LLP0                        (*((volatile unsigned int*)(0x42A61308UL)))
#define bM4_DMA1_LLP1_LLP1                        (*((volatile unsigned int*)(0x42A6130CUL)))
#define bM4_DMA1_LLP1_LLP2                        (*((volatile unsigned int*)(0x42A61310UL)))
#define bM4_DMA1_LLP1_LLP3                        (*((volatile unsigned int*)(0x42A61314UL)))
#define bM4_DMA1_LLP1_LLP4                        (*((volatile unsigned int*)(0x42A61318UL)))
#define bM4_DMA1_LLP1_LLP5                        (*((volatile unsigned int*)(0x42A6131CUL)))
#define bM4_DMA1_LLP1_LLP6                        (*((volatile unsigned int*)(0x42A61320UL)))
#define bM4_DMA1_LLP1_LLP7                        (*((volatile unsigned int*)(0x42A61324UL)))
#define bM4_DMA1_LLP1_LLP8                        (*((volatile unsigned int*)(0x42A61328UL)))
#define bM4_DMA1_LLP1_LLP9                        (*((volatile unsigned int*)(0x42A6132CUL)))
#define bM4_DMA1_LLP1_LLP10                       (*((volatile unsigned int*)(0x42A61330UL)))
#define bM4_DMA1_LLP1_LLP11                       (*((volatile unsigned int*)(0x42A61334UL)))
#define bM4_DMA1_LLP1_LLP12                       (*((volatile unsigned int*)(0x42A61338UL)))
#define bM4_DMA1_LLP1_LLP13                       (*((volatile unsigned int*)(0x42A6133CUL)))
#define bM4_DMA1_LLP1_LLP14                       (*((volatile unsigned int*)(0x42A61340UL)))
#define bM4_DMA1_LLP1_LLP15                       (*((volatile unsigned int*)(0x42A61344UL)))
#define bM4_DMA1_LLP1_LLP16                       (*((volatile unsigned int*)(0x42A61348UL)))
#define bM4_DMA1_LLP1_LLP17                       (*((volatile unsigned int*)(0x42A6134CUL)))
#define bM4_DMA1_LLP1_LLP18                       (*((volatile unsigned int*)(0x42A61350UL)))
#define bM4_DMA1_LLP1_LLP19                       (*((volatile unsigned int*)(0x42A61354UL)))
#define bM4_DMA1_LLP1_LLP20                       (*((volatile unsigned int*)(0x42A61358UL)))
#define bM4_DMA1_LLP1_LLP21                       (*((volatile unsigned int*)(0x42A6135CUL)))
#define bM4_DMA1_LLP1_LLP22                       (*((volatile unsigned int*)(0x42A61360UL)))
#define bM4_DMA1_LLP1_LLP23                       (*((volatile unsigned int*)(0x42A61364UL)))
#define bM4_DMA1_LLP1_LLP24                       (*((volatile unsigned int*)(0x42A61368UL)))
#define bM4_DMA1_LLP1_LLP25                       (*((volatile unsigned int*)(0x42A6136CUL)))
#define bM4_DMA1_LLP1_LLP26                       (*((volatile unsigned int*)(0x42A61370UL)))
#define bM4_DMA1_LLP1_LLP27                       (*((volatile unsigned int*)(0x42A61374UL)))
#define bM4_DMA1_LLP1_LLP28                       (*((volatile unsigned int*)(0x42A61378UL)))
#define bM4_DMA1_LLP1_LLP29                       (*((volatile unsigned int*)(0x42A6137CUL)))
#define bM4_DMA1_CHCTL1_SINC0                     (*((volatile unsigned int*)(0x42A61380UL)))
#define bM4_DMA1_CHCTL1_SINC1                     (*((volatile unsigned int*)(0x42A61384UL)))
#define bM4_DMA1_CHCTL1_DINC0                     (*((volatile unsigned int*)(0x42A61388UL)))
#define bM4_DMA1_CHCTL1_DINC1                     (*((volatile unsigned int*)(0x42A6138CUL)))
#define bM4_DMA1_CHCTL1_SRPTEN                    (*((volatile unsigned int*)(0x42A61390UL)))
#define bM4_DMA1_CHCTL1_DRPTEN                    (*((volatile unsigned int*)(0x42A61394UL)))
#define bM4_DMA1_CHCTL1_SNSEQEN                   (*((volatile unsigned int*)(0x42A61398UL)))
#define bM4_DMA1_CHCTL1_DNSEQEN                   (*((volatile unsigned int*)(0x42A6139CUL)))
#define bM4_DMA1_CHCTL1_HSIZE0                    (*((volatile unsigned int*)(0x42A613A0UL)))
#define bM4_DMA1_CHCTL1_HSIZE1                    (*((volatile unsigned int*)(0x42A613A4UL)))
#define bM4_DMA1_CHCTL1_LLPEN                     (*((volatile unsigned int*)(0x42A613A8UL)))
#define bM4_DMA1_CHCTL1_LLPRUN                    (*((volatile unsigned int*)(0x42A613ACUL)))
#define bM4_DMA1_CHCTL1_IE                        (*((volatile unsigned int*)(0x42A613B0UL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE0               (*((volatile unsigned int*)(0x42A61500UL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE1               (*((volatile unsigned int*)(0x42A61504UL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE2               (*((volatile unsigned int*)(0x42A61508UL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE3               (*((volatile unsigned int*)(0x42A6150CUL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE4               (*((volatile unsigned int*)(0x42A61510UL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE5               (*((volatile unsigned int*)(0x42A61514UL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE6               (*((volatile unsigned int*)(0x42A61518UL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE7               (*((volatile unsigned int*)(0x42A6151CUL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE8               (*((volatile unsigned int*)(0x42A61520UL)))
#define bM4_DMA1_MONDTCTL1_BLKSIZE9               (*((volatile unsigned int*)(0x42A61524UL)))
#define bM4_DMA1_MONDTCTL1_CNT0                   (*((volatile unsigned int*)(0x42A61540UL)))
#define bM4_DMA1_MONDTCTL1_CNT1                   (*((volatile unsigned int*)(0x42A61544UL)))
#define bM4_DMA1_MONDTCTL1_CNT2                   (*((volatile unsigned int*)(0x42A61548UL)))
#define bM4_DMA1_MONDTCTL1_CNT3                   (*((volatile unsigned int*)(0x42A6154CUL)))
#define bM4_DMA1_MONDTCTL1_CNT4                   (*((volatile unsigned int*)(0x42A61550UL)))
#define bM4_DMA1_MONDTCTL1_CNT5                   (*((volatile unsigned int*)(0x42A61554UL)))
#define bM4_DMA1_MONDTCTL1_CNT6                   (*((volatile unsigned int*)(0x42A61558UL)))
#define bM4_DMA1_MONDTCTL1_CNT7                   (*((volatile unsigned int*)(0x42A6155CUL)))
#define bM4_DMA1_MONDTCTL1_CNT8                   (*((volatile unsigned int*)(0x42A61560UL)))
#define bM4_DMA1_MONDTCTL1_CNT9                   (*((volatile unsigned int*)(0x42A61564UL)))
#define bM4_DMA1_MONDTCTL1_CNT10                  (*((volatile unsigned int*)(0x42A61568UL)))
#define bM4_DMA1_MONDTCTL1_CNT11                  (*((volatile unsigned int*)(0x42A6156CUL)))
#define bM4_DMA1_MONDTCTL1_CNT12                  (*((volatile unsigned int*)(0x42A61570UL)))
#define bM4_DMA1_MONDTCTL1_CNT13                  (*((volatile unsigned int*)(0x42A61574UL)))
#define bM4_DMA1_MONDTCTL1_CNT14                  (*((volatile unsigned int*)(0x42A61578UL)))
#define bM4_DMA1_MONDTCTL1_CNT15                  (*((volatile unsigned int*)(0x42A6157CUL)))
#define bM4_DMA1_MONRPT1_SRPT0                    (*((volatile unsigned int*)(0x42A61580UL)))
#define bM4_DMA1_MONRPT1_SRPT1                    (*((volatile unsigned int*)(0x42A61584UL)))
#define bM4_DMA1_MONRPT1_SRPT2                    (*((volatile unsigned int*)(0x42A61588UL)))
#define bM4_DMA1_MONRPT1_SRPT3                    (*((volatile unsigned int*)(0x42A6158CUL)))
#define bM4_DMA1_MONRPT1_SRPT4                    (*((volatile unsigned int*)(0x42A61590UL)))
#define bM4_DMA1_MONRPT1_SRPT5                    (*((volatile unsigned int*)(0x42A61594UL)))
#define bM4_DMA1_MONRPT1_SRPT6                    (*((volatile unsigned int*)(0x42A61598UL)))
#define bM4_DMA1_MONRPT1_SRPT7                    (*((volatile unsigned int*)(0x42A6159CUL)))
#define bM4_DMA1_MONRPT1_SRPT8                    (*((volatile unsigned int*)(0x42A615A0UL)))
#define bM4_DMA1_MONRPT1_SRPT9                    (*((volatile unsigned int*)(0x42A615A4UL)))
#define bM4_DMA1_MONRPT1_DRPT0                    (*((volatile unsigned int*)(0x42A615C0UL)))
#define bM4_DMA1_MONRPT1_DRPT1                    (*((volatile unsigned int*)(0x42A615C4UL)))
#define bM4_DMA1_MONRPT1_DRPT2                    (*((volatile unsigned int*)(0x42A615C8UL)))
#define bM4_DMA1_MONRPT1_DRPT3                    (*((volatile unsigned int*)(0x42A615CCUL)))
#define bM4_DMA1_MONRPT1_DRPT4                    (*((volatile unsigned int*)(0x42A615D0UL)))
#define bM4_DMA1_MONRPT1_DRPT5                    (*((volatile unsigned int*)(0x42A615D4UL)))
#define bM4_DMA1_MONRPT1_DRPT6                    (*((volatile unsigned int*)(0x42A615D8UL)))
#define bM4_DMA1_MONRPT1_DRPT7                    (*((volatile unsigned int*)(0x42A615DCUL)))
#define bM4_DMA1_MONRPT1_DRPT8                    (*((volatile unsigned int*)(0x42A615E0UL)))
#define bM4_DMA1_MONRPT1_DRPT9                    (*((volatile unsigned int*)(0x42A615E4UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET0            (*((volatile unsigned int*)(0x42A61600UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET1            (*((volatile unsigned int*)(0x42A61604UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET2            (*((volatile unsigned int*)(0x42A61608UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET3            (*((volatile unsigned int*)(0x42A6160CUL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET4            (*((volatile unsigned int*)(0x42A61610UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET5            (*((volatile unsigned int*)(0x42A61614UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET6            (*((volatile unsigned int*)(0x42A61618UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET7            (*((volatile unsigned int*)(0x42A6161CUL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET8            (*((volatile unsigned int*)(0x42A61620UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET9            (*((volatile unsigned int*)(0x42A61624UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET10           (*((volatile unsigned int*)(0x42A61628UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET11           (*((volatile unsigned int*)(0x42A6162CUL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET12           (*((volatile unsigned int*)(0x42A61630UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET13           (*((volatile unsigned int*)(0x42A61634UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET14           (*((volatile unsigned int*)(0x42A61638UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET15           (*((volatile unsigned int*)(0x42A6163CUL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET16           (*((volatile unsigned int*)(0x42A61640UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET17           (*((volatile unsigned int*)(0x42A61644UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET18           (*((volatile unsigned int*)(0x42A61648UL)))
#define bM4_DMA1_MONSNSEQCTL1_SOFFSET19           (*((volatile unsigned int*)(0x42A6164CUL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT0             (*((volatile unsigned int*)(0x42A61650UL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT1             (*((volatile unsigned int*)(0x42A61654UL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT2             (*((volatile unsigned int*)(0x42A61658UL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT3             (*((volatile unsigned int*)(0x42A6165CUL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT4             (*((volatile unsigned int*)(0x42A61660UL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT5             (*((volatile unsigned int*)(0x42A61664UL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT6             (*((volatile unsigned int*)(0x42A61668UL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT7             (*((volatile unsigned int*)(0x42A6166CUL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT8             (*((volatile unsigned int*)(0x42A61670UL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT9             (*((volatile unsigned int*)(0x42A61674UL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT10            (*((volatile unsigned int*)(0x42A61678UL)))
#define bM4_DMA1_MONSNSEQCTL1_SNSCNT11            (*((volatile unsigned int*)(0x42A6167CUL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET0            (*((volatile unsigned int*)(0x42A61680UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET1            (*((volatile unsigned int*)(0x42A61684UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET2            (*((volatile unsigned int*)(0x42A61688UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET3            (*((volatile unsigned int*)(0x42A6168CUL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET4            (*((volatile unsigned int*)(0x42A61690UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET5            (*((volatile unsigned int*)(0x42A61694UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET6            (*((volatile unsigned int*)(0x42A61698UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET7            (*((volatile unsigned int*)(0x42A6169CUL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET8            (*((volatile unsigned int*)(0x42A616A0UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET9            (*((volatile unsigned int*)(0x42A616A4UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET10           (*((volatile unsigned int*)(0x42A616A8UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET11           (*((volatile unsigned int*)(0x42A616ACUL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET12           (*((volatile unsigned int*)(0x42A616B0UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET13           (*((volatile unsigned int*)(0x42A616B4UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET14           (*((volatile unsigned int*)(0x42A616B8UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET15           (*((volatile unsigned int*)(0x42A616BCUL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET16           (*((volatile unsigned int*)(0x42A616C0UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET17           (*((volatile unsigned int*)(0x42A616C4UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET18           (*((volatile unsigned int*)(0x42A616C8UL)))
#define bM4_DMA1_MONDNSEQCTL1_DOFFSET19           (*((volatile unsigned int*)(0x42A616CCUL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT0             (*((volatile unsigned int*)(0x42A616D0UL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT1             (*((volatile unsigned int*)(0x42A616D4UL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT2             (*((volatile unsigned int*)(0x42A616D8UL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT3             (*((volatile unsigned int*)(0x42A616DCUL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT4             (*((volatile unsigned int*)(0x42A616E0UL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT5             (*((volatile unsigned int*)(0x42A616E4UL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT6             (*((volatile unsigned int*)(0x42A616E8UL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT7             (*((volatile unsigned int*)(0x42A616ECUL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT8             (*((volatile unsigned int*)(0x42A616F0UL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT9             (*((volatile unsigned int*)(0x42A616F4UL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT10            (*((volatile unsigned int*)(0x42A616F8UL)))
#define bM4_DMA1_MONDNSEQCTL1_DNSCNT11            (*((volatile unsigned int*)(0x42A616FCUL)))
#define bM4_DMA1_DTCTL2_BLKSIZE0                  (*((volatile unsigned int*)(0x42A61900UL)))
#define bM4_DMA1_DTCTL2_BLKSIZE1                  (*((volatile unsigned int*)(0x42A61904UL)))
#define bM4_DMA1_DTCTL2_BLKSIZE2                  (*((volatile unsigned int*)(0x42A61908UL)))
#define bM4_DMA1_DTCTL2_BLKSIZE3                  (*((volatile unsigned int*)(0x42A6190CUL)))
#define bM4_DMA1_DTCTL2_BLKSIZE4                  (*((volatile unsigned int*)(0x42A61910UL)))
#define bM4_DMA1_DTCTL2_BLKSIZE5                  (*((volatile unsigned int*)(0x42A61914UL)))
#define bM4_DMA1_DTCTL2_BLKSIZE6                  (*((volatile unsigned int*)(0x42A61918UL)))
#define bM4_DMA1_DTCTL2_BLKSIZE7                  (*((volatile unsigned int*)(0x42A6191CUL)))
#define bM4_DMA1_DTCTL2_BLKSIZE8                  (*((volatile unsigned int*)(0x42A61920UL)))
#define bM4_DMA1_DTCTL2_BLKSIZE9                  (*((volatile unsigned int*)(0x42A61924UL)))
#define bM4_DMA1_DTCTL2_CNT0                      (*((volatile unsigned int*)(0x42A61940UL)))
#define bM4_DMA1_DTCTL2_CNT1                      (*((volatile unsigned int*)(0x42A61944UL)))
#define bM4_DMA1_DTCTL2_CNT2                      (*((volatile unsigned int*)(0x42A61948UL)))
#define bM4_DMA1_DTCTL2_CNT3                      (*((volatile unsigned int*)(0x42A6194CUL)))
#define bM4_DMA1_DTCTL2_CNT4                      (*((volatile unsigned int*)(0x42A61950UL)))
#define bM4_DMA1_DTCTL2_CNT5                      (*((volatile unsigned int*)(0x42A61954UL)))
#define bM4_DMA1_DTCTL2_CNT6                      (*((volatile unsigned int*)(0x42A61958UL)))
#define bM4_DMA1_DTCTL2_CNT7                      (*((volatile unsigned int*)(0x42A6195CUL)))
#define bM4_DMA1_DTCTL2_CNT8                      (*((volatile unsigned int*)(0x42A61960UL)))
#define bM4_DMA1_DTCTL2_CNT9                      (*((volatile unsigned int*)(0x42A61964UL)))
#define bM4_DMA1_DTCTL2_CNT10                     (*((volatile unsigned int*)(0x42A61968UL)))
#define bM4_DMA1_DTCTL2_CNT11                     (*((volatile unsigned int*)(0x42A6196CUL)))
#define bM4_DMA1_DTCTL2_CNT12                     (*((volatile unsigned int*)(0x42A61970UL)))
#define bM4_DMA1_DTCTL2_CNT13                     (*((volatile unsigned int*)(0x42A61974UL)))
#define bM4_DMA1_DTCTL2_CNT14                     (*((volatile unsigned int*)(0x42A61978UL)))
#define bM4_DMA1_DTCTL2_CNT15                     (*((volatile unsigned int*)(0x42A6197CUL)))
#define bM4_DMA1_RPT2_SRPT0                       (*((volatile unsigned int*)(0x42A61980UL)))
#define bM4_DMA1_RPT2_SRPT1                       (*((volatile unsigned int*)(0x42A61984UL)))
#define bM4_DMA1_RPT2_SRPT2                       (*((volatile unsigned int*)(0x42A61988UL)))
#define bM4_DMA1_RPT2_SRPT3                       (*((volatile unsigned int*)(0x42A6198CUL)))
#define bM4_DMA1_RPT2_SRPT4                       (*((volatile unsigned int*)(0x42A61990UL)))
#define bM4_DMA1_RPT2_SRPT5                       (*((volatile unsigned int*)(0x42A61994UL)))
#define bM4_DMA1_RPT2_SRPT6                       (*((volatile unsigned int*)(0x42A61998UL)))
#define bM4_DMA1_RPT2_SRPT7                       (*((volatile unsigned int*)(0x42A6199CUL)))
#define bM4_DMA1_RPT2_SRPT8                       (*((volatile unsigned int*)(0x42A619A0UL)))
#define bM4_DMA1_RPT2_SRPT9                       (*((volatile unsigned int*)(0x42A619A4UL)))
#define bM4_DMA1_RPT2_DRPT0                       (*((volatile unsigned int*)(0x42A619C0UL)))
#define bM4_DMA1_RPT2_DRPT1                       (*((volatile unsigned int*)(0x42A619C4UL)))
#define bM4_DMA1_RPT2_DRPT2                       (*((volatile unsigned int*)(0x42A619C8UL)))
#define bM4_DMA1_RPT2_DRPT3                       (*((volatile unsigned int*)(0x42A619CCUL)))
#define bM4_DMA1_RPT2_DRPT4                       (*((volatile unsigned int*)(0x42A619D0UL)))
#define bM4_DMA1_RPT2_DRPT5                       (*((volatile unsigned int*)(0x42A619D4UL)))
#define bM4_DMA1_RPT2_DRPT6                       (*((volatile unsigned int*)(0x42A619D8UL)))
#define bM4_DMA1_RPT2_DRPT7                       (*((volatile unsigned int*)(0x42A619DCUL)))
#define bM4_DMA1_RPT2_DRPT8                       (*((volatile unsigned int*)(0x42A619E0UL)))
#define bM4_DMA1_RPT2_DRPT9                       (*((volatile unsigned int*)(0x42A619E4UL)))
#define bM4_DMA1_RPTB2_SRPTB0                     (*((volatile unsigned int*)(0x42A61980UL)))
#define bM4_DMA1_RPTB2_SRPTB1                     (*((volatile unsigned int*)(0x42A61984UL)))
#define bM4_DMA1_RPTB2_SRPTB2                     (*((volatile unsigned int*)(0x42A61988UL)))
#define bM4_DMA1_RPTB2_SRPTB3                     (*((volatile unsigned int*)(0x42A6198CUL)))
#define bM4_DMA1_RPTB2_SRPTB4                     (*((volatile unsigned int*)(0x42A61990UL)))
#define bM4_DMA1_RPTB2_SRPTB5                     (*((volatile unsigned int*)(0x42A61994UL)))
#define bM4_DMA1_RPTB2_SRPTB6                     (*((volatile unsigned int*)(0x42A61998UL)))
#define bM4_DMA1_RPTB2_SRPTB7                     (*((volatile unsigned int*)(0x42A6199CUL)))
#define bM4_DMA1_RPTB2_SRPTB8                     (*((volatile unsigned int*)(0x42A619A0UL)))
#define bM4_DMA1_RPTB2_SRPTB9                     (*((volatile unsigned int*)(0x42A619A4UL)))
#define bM4_DMA1_RPTB2_DRPTB0                     (*((volatile unsigned int*)(0x42A619C0UL)))
#define bM4_DMA1_RPTB2_DRPTB1                     (*((volatile unsigned int*)(0x42A619C4UL)))
#define bM4_DMA1_RPTB2_DRPTB2                     (*((volatile unsigned int*)(0x42A619C8UL)))
#define bM4_DMA1_RPTB2_DRPTB3                     (*((volatile unsigned int*)(0x42A619CCUL)))
#define bM4_DMA1_RPTB2_DRPTB4                     (*((volatile unsigned int*)(0x42A619D0UL)))
#define bM4_DMA1_RPTB2_DRPTB5                     (*((volatile unsigned int*)(0x42A619D4UL)))
#define bM4_DMA1_RPTB2_DRPTB6                     (*((volatile unsigned int*)(0x42A619D8UL)))
#define bM4_DMA1_RPTB2_DRPTB7                     (*((volatile unsigned int*)(0x42A619DCUL)))
#define bM4_DMA1_RPTB2_DRPTB8                     (*((volatile unsigned int*)(0x42A619E0UL)))
#define bM4_DMA1_RPTB2_DRPTB9                     (*((volatile unsigned int*)(0x42A619E4UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET0               (*((volatile unsigned int*)(0x42A61A00UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET1               (*((volatile unsigned int*)(0x42A61A04UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET2               (*((volatile unsigned int*)(0x42A61A08UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET3               (*((volatile unsigned int*)(0x42A61A0CUL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET4               (*((volatile unsigned int*)(0x42A61A10UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET5               (*((volatile unsigned int*)(0x42A61A14UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET6               (*((volatile unsigned int*)(0x42A61A18UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET7               (*((volatile unsigned int*)(0x42A61A1CUL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET8               (*((volatile unsigned int*)(0x42A61A20UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET9               (*((volatile unsigned int*)(0x42A61A24UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET10              (*((volatile unsigned int*)(0x42A61A28UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET11              (*((volatile unsigned int*)(0x42A61A2CUL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET12              (*((volatile unsigned int*)(0x42A61A30UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET13              (*((volatile unsigned int*)(0x42A61A34UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET14              (*((volatile unsigned int*)(0x42A61A38UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET15              (*((volatile unsigned int*)(0x42A61A3CUL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET16              (*((volatile unsigned int*)(0x42A61A40UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET17              (*((volatile unsigned int*)(0x42A61A44UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET18              (*((volatile unsigned int*)(0x42A61A48UL)))
#define bM4_DMA1_SNSEQCTL2_SOFFSET19              (*((volatile unsigned int*)(0x42A61A4CUL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT0                (*((volatile unsigned int*)(0x42A61A50UL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT1                (*((volatile unsigned int*)(0x42A61A54UL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT2                (*((volatile unsigned int*)(0x42A61A58UL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT3                (*((volatile unsigned int*)(0x42A61A5CUL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT4                (*((volatile unsigned int*)(0x42A61A60UL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT5                (*((volatile unsigned int*)(0x42A61A64UL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT6                (*((volatile unsigned int*)(0x42A61A68UL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT7                (*((volatile unsigned int*)(0x42A61A6CUL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT8                (*((volatile unsigned int*)(0x42A61A70UL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT9                (*((volatile unsigned int*)(0x42A61A74UL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT10               (*((volatile unsigned int*)(0x42A61A78UL)))
#define bM4_DMA1_SNSEQCTL2_SNSCNT11               (*((volatile unsigned int*)(0x42A61A7CUL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST0              (*((volatile unsigned int*)(0x42A61A00UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST1              (*((volatile unsigned int*)(0x42A61A04UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST2              (*((volatile unsigned int*)(0x42A61A08UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST3              (*((volatile unsigned int*)(0x42A61A0CUL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST4              (*((volatile unsigned int*)(0x42A61A10UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST5              (*((volatile unsigned int*)(0x42A61A14UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST6              (*((volatile unsigned int*)(0x42A61A18UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST7              (*((volatile unsigned int*)(0x42A61A1CUL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST8              (*((volatile unsigned int*)(0x42A61A20UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST9              (*((volatile unsigned int*)(0x42A61A24UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST10             (*((volatile unsigned int*)(0x42A61A28UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST11             (*((volatile unsigned int*)(0x42A61A2CUL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST12             (*((volatile unsigned int*)(0x42A61A30UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST13             (*((volatile unsigned int*)(0x42A61A34UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST14             (*((volatile unsigned int*)(0x42A61A38UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST15             (*((volatile unsigned int*)(0x42A61A3CUL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST16             (*((volatile unsigned int*)(0x42A61A40UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST17             (*((volatile unsigned int*)(0x42A61A44UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST18             (*((volatile unsigned int*)(0x42A61A48UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSDIST19             (*((volatile unsigned int*)(0x42A61A4CUL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB0              (*((volatile unsigned int*)(0x42A61A50UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB1              (*((volatile unsigned int*)(0x42A61A54UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB2              (*((volatile unsigned int*)(0x42A61A58UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB3              (*((volatile unsigned int*)(0x42A61A5CUL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB4              (*((volatile unsigned int*)(0x42A61A60UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB5              (*((volatile unsigned int*)(0x42A61A64UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB6              (*((volatile unsigned int*)(0x42A61A68UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB7              (*((volatile unsigned int*)(0x42A61A6CUL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB8              (*((volatile unsigned int*)(0x42A61A70UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB9              (*((volatile unsigned int*)(0x42A61A74UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB10             (*((volatile unsigned int*)(0x42A61A78UL)))
#define bM4_DMA1_SNSEQCTLB2_SNSCNTB11             (*((volatile unsigned int*)(0x42A61A7CUL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET0               (*((volatile unsigned int*)(0x42A61A80UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET1               (*((volatile unsigned int*)(0x42A61A84UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET2               (*((volatile unsigned int*)(0x42A61A88UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET3               (*((volatile unsigned int*)(0x42A61A8CUL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET4               (*((volatile unsigned int*)(0x42A61A90UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET5               (*((volatile unsigned int*)(0x42A61A94UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET6               (*((volatile unsigned int*)(0x42A61A98UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET7               (*((volatile unsigned int*)(0x42A61A9CUL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET8               (*((volatile unsigned int*)(0x42A61AA0UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET9               (*((volatile unsigned int*)(0x42A61AA4UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET10              (*((volatile unsigned int*)(0x42A61AA8UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET11              (*((volatile unsigned int*)(0x42A61AACUL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET12              (*((volatile unsigned int*)(0x42A61AB0UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET13              (*((volatile unsigned int*)(0x42A61AB4UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET14              (*((volatile unsigned int*)(0x42A61AB8UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET15              (*((volatile unsigned int*)(0x42A61ABCUL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET16              (*((volatile unsigned int*)(0x42A61AC0UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET17              (*((volatile unsigned int*)(0x42A61AC4UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET18              (*((volatile unsigned int*)(0x42A61AC8UL)))
#define bM4_DMA1_DNSEQCTL2_DOFFSET19              (*((volatile unsigned int*)(0x42A61ACCUL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT0                (*((volatile unsigned int*)(0x42A61AD0UL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT1                (*((volatile unsigned int*)(0x42A61AD4UL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT2                (*((volatile unsigned int*)(0x42A61AD8UL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT3                (*((volatile unsigned int*)(0x42A61ADCUL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT4                (*((volatile unsigned int*)(0x42A61AE0UL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT5                (*((volatile unsigned int*)(0x42A61AE4UL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT6                (*((volatile unsigned int*)(0x42A61AE8UL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT7                (*((volatile unsigned int*)(0x42A61AECUL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT8                (*((volatile unsigned int*)(0x42A61AF0UL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT9                (*((volatile unsigned int*)(0x42A61AF4UL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT10               (*((volatile unsigned int*)(0x42A61AF8UL)))
#define bM4_DMA1_DNSEQCTL2_DNSCNT11               (*((volatile unsigned int*)(0x42A61AFCUL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST0              (*((volatile unsigned int*)(0x42A61A80UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST1              (*((volatile unsigned int*)(0x42A61A84UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST2              (*((volatile unsigned int*)(0x42A61A88UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST3              (*((volatile unsigned int*)(0x42A61A8CUL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST4              (*((volatile unsigned int*)(0x42A61A90UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST5              (*((volatile unsigned int*)(0x42A61A94UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST6              (*((volatile unsigned int*)(0x42A61A98UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST7              (*((volatile unsigned int*)(0x42A61A9CUL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST8              (*((volatile unsigned int*)(0x42A61AA0UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST9              (*((volatile unsigned int*)(0x42A61AA4UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST10             (*((volatile unsigned int*)(0x42A61AA8UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST11             (*((volatile unsigned int*)(0x42A61AACUL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST12             (*((volatile unsigned int*)(0x42A61AB0UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST13             (*((volatile unsigned int*)(0x42A61AB4UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST14             (*((volatile unsigned int*)(0x42A61AB8UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST15             (*((volatile unsigned int*)(0x42A61ABCUL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST16             (*((volatile unsigned int*)(0x42A61AC0UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST17             (*((volatile unsigned int*)(0x42A61AC4UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST18             (*((volatile unsigned int*)(0x42A61AC8UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSDIST19             (*((volatile unsigned int*)(0x42A61ACCUL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB0              (*((volatile unsigned int*)(0x42A61AD0UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB1              (*((volatile unsigned int*)(0x42A61AD4UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB2              (*((volatile unsigned int*)(0x42A61AD8UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB3              (*((volatile unsigned int*)(0x42A61ADCUL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB4              (*((volatile unsigned int*)(0x42A61AE0UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB5              (*((volatile unsigned int*)(0x42A61AE4UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB6              (*((volatile unsigned int*)(0x42A61AE8UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB7              (*((volatile unsigned int*)(0x42A61AECUL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB8              (*((volatile unsigned int*)(0x42A61AF0UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB9              (*((volatile unsigned int*)(0x42A61AF4UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB10             (*((volatile unsigned int*)(0x42A61AF8UL)))
#define bM4_DMA1_DNSEQCTLB2_DNSCNTB11             (*((volatile unsigned int*)(0x42A61AFCUL)))
#define bM4_DMA1_LLP2_LLP0                        (*((volatile unsigned int*)(0x42A61B08UL)))
#define bM4_DMA1_LLP2_LLP1                        (*((volatile unsigned int*)(0x42A61B0CUL)))
#define bM4_DMA1_LLP2_LLP2                        (*((volatile unsigned int*)(0x42A61B10UL)))
#define bM4_DMA1_LLP2_LLP3                        (*((volatile unsigned int*)(0x42A61B14UL)))
#define bM4_DMA1_LLP2_LLP4                        (*((volatile unsigned int*)(0x42A61B18UL)))
#define bM4_DMA1_LLP2_LLP5                        (*((volatile unsigned int*)(0x42A61B1CUL)))
#define bM4_DMA1_LLP2_LLP6                        (*((volatile unsigned int*)(0x42A61B20UL)))
#define bM4_DMA1_LLP2_LLP7                        (*((volatile unsigned int*)(0x42A61B24UL)))
#define bM4_DMA1_LLP2_LLP8                        (*((volatile unsigned int*)(0x42A61B28UL)))
#define bM4_DMA1_LLP2_LLP9                        (*((volatile unsigned int*)(0x42A61B2CUL)))
#define bM4_DMA1_LLP2_LLP10                       (*((volatile unsigned int*)(0x42A61B30UL)))
#define bM4_DMA1_LLP2_LLP11                       (*((volatile unsigned int*)(0x42A61B34UL)))
#define bM4_DMA1_LLP2_LLP12                       (*((volatile unsigned int*)(0x42A61B38UL)))
#define bM4_DMA1_LLP2_LLP13                       (*((volatile unsigned int*)(0x42A61B3CUL)))
#define bM4_DMA1_LLP2_LLP14                       (*((volatile unsigned int*)(0x42A61B40UL)))
#define bM4_DMA1_LLP2_LLP15                       (*((volatile unsigned int*)(0x42A61B44UL)))
#define bM4_DMA1_LLP2_LLP16                       (*((volatile unsigned int*)(0x42A61B48UL)))
#define bM4_DMA1_LLP2_LLP17                       (*((volatile unsigned int*)(0x42A61B4CUL)))
#define bM4_DMA1_LLP2_LLP18                       (*((volatile unsigned int*)(0x42A61B50UL)))
#define bM4_DMA1_LLP2_LLP19                       (*((volatile unsigned int*)(0x42A61B54UL)))
#define bM4_DMA1_LLP2_LLP20                       (*((volatile unsigned int*)(0x42A61B58UL)))
#define bM4_DMA1_LLP2_LLP21                       (*((volatile unsigned int*)(0x42A61B5CUL)))
#define bM4_DMA1_LLP2_LLP22                       (*((volatile unsigned int*)(0x42A61B60UL)))
#define bM4_DMA1_LLP2_LLP23                       (*((volatile unsigned int*)(0x42A61B64UL)))
#define bM4_DMA1_LLP2_LLP24                       (*((volatile unsigned int*)(0x42A61B68UL)))
#define bM4_DMA1_LLP2_LLP25                       (*((volatile unsigned int*)(0x42A61B6CUL)))
#define bM4_DMA1_LLP2_LLP26                       (*((volatile unsigned int*)(0x42A61B70UL)))
#define bM4_DMA1_LLP2_LLP27                       (*((volatile unsigned int*)(0x42A61B74UL)))
#define bM4_DMA1_LLP2_LLP28                       (*((volatile unsigned int*)(0x42A61B78UL)))
#define bM4_DMA1_LLP2_LLP29                       (*((volatile unsigned int*)(0x42A61B7CUL)))
#define bM4_DMA1_CHCTL2_SINC0                     (*((volatile unsigned int*)(0x42A61B80UL)))
#define bM4_DMA1_CHCTL2_SINC1                     (*((volatile unsigned int*)(0x42A61B84UL)))
#define bM4_DMA1_CHCTL2_DINC0                     (*((volatile unsigned int*)(0x42A61B88UL)))
#define bM4_DMA1_CHCTL2_DINC1                     (*((volatile unsigned int*)(0x42A61B8CUL)))
#define bM4_DMA1_CHCTL2_SRPTEN                    (*((volatile unsigned int*)(0x42A61B90UL)))
#define bM4_DMA1_CHCTL2_DRPTEN                    (*((volatile unsigned int*)(0x42A61B94UL)))
#define bM4_DMA1_CHCTL2_SNSEQEN                   (*((volatile unsigned int*)(0x42A61B98UL)))
#define bM4_DMA1_CHCTL2_DNSEQEN                   (*((volatile unsigned int*)(0x42A61B9CUL)))
#define bM4_DMA1_CHCTL2_HSIZE0                    (*((volatile unsigned int*)(0x42A61BA0UL)))
#define bM4_DMA1_CHCTL2_HSIZE1                    (*((volatile unsigned int*)(0x42A61BA4UL)))
#define bM4_DMA1_CHCTL2_LLPEN                     (*((volatile unsigned int*)(0x42A61BA8UL)))
#define bM4_DMA1_CHCTL2_LLPRUN                    (*((volatile unsigned int*)(0x42A61BACUL)))
#define bM4_DMA1_CHCTL2_IE                        (*((volatile unsigned int*)(0x42A61BB0UL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE0               (*((volatile unsigned int*)(0x42A61D00UL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE1               (*((volatile unsigned int*)(0x42A61D04UL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE2               (*((volatile unsigned int*)(0x42A61D08UL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE3               (*((volatile unsigned int*)(0x42A61D0CUL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE4               (*((volatile unsigned int*)(0x42A61D10UL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE5               (*((volatile unsigned int*)(0x42A61D14UL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE6               (*((volatile unsigned int*)(0x42A61D18UL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE7               (*((volatile unsigned int*)(0x42A61D1CUL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE8               (*((volatile unsigned int*)(0x42A61D20UL)))
#define bM4_DMA1_MONDTCTL2_BLKSIZE9               (*((volatile unsigned int*)(0x42A61D24UL)))
#define bM4_DMA1_MONDTCTL2_CNT0                   (*((volatile unsigned int*)(0x42A61D40UL)))
#define bM4_DMA1_MONDTCTL2_CNT1                   (*((volatile unsigned int*)(0x42A61D44UL)))
#define bM4_DMA1_MONDTCTL2_CNT2                   (*((volatile unsigned int*)(0x42A61D48UL)))
#define bM4_DMA1_MONDTCTL2_CNT3                   (*((volatile unsigned int*)(0x42A61D4CUL)))
#define bM4_DMA1_MONDTCTL2_CNT4                   (*((volatile unsigned int*)(0x42A61D50UL)))
#define bM4_DMA1_MONDTCTL2_CNT5                   (*((volatile unsigned int*)(0x42A61D54UL)))
#define bM4_DMA1_MONDTCTL2_CNT6                   (*((volatile unsigned int*)(0x42A61D58UL)))
#define bM4_DMA1_MONDTCTL2_CNT7                   (*((volatile unsigned int*)(0x42A61D5CUL)))
#define bM4_DMA1_MONDTCTL2_CNT8                   (*((volatile unsigned int*)(0x42A61D60UL)))
#define bM4_DMA1_MONDTCTL2_CNT9                   (*((volatile unsigned int*)(0x42A61D64UL)))
#define bM4_DMA1_MONDTCTL2_CNT10                  (*((volatile unsigned int*)(0x42A61D68UL)))
#define bM4_DMA1_MONDTCTL2_CNT11                  (*((volatile unsigned int*)(0x42A61D6CUL)))
#define bM4_DMA1_MONDTCTL2_CNT12                  (*((volatile unsigned int*)(0x42A61D70UL)))
#define bM4_DMA1_MONDTCTL2_CNT13                  (*((volatile unsigned int*)(0x42A61D74UL)))
#define bM4_DMA1_MONDTCTL2_CNT14                  (*((volatile unsigned int*)(0x42A61D78UL)))
#define bM4_DMA1_MONDTCTL2_CNT15                  (*((volatile unsigned int*)(0x42A61D7CUL)))
#define bM4_DMA1_MONRPT2_SRPT0                    (*((volatile unsigned int*)(0x42A61D80UL)))
#define bM4_DMA1_MONRPT2_SRPT1                    (*((volatile unsigned int*)(0x42A61D84UL)))
#define bM4_DMA1_MONRPT2_SRPT2                    (*((volatile unsigned int*)(0x42A61D88UL)))
#define bM4_DMA1_MONRPT2_SRPT3                    (*((volatile unsigned int*)(0x42A61D8CUL)))
#define bM4_DMA1_MONRPT2_SRPT4                    (*((volatile unsigned int*)(0x42A61D90UL)))
#define bM4_DMA1_MONRPT2_SRPT5                    (*((volatile unsigned int*)(0x42A61D94UL)))
#define bM4_DMA1_MONRPT2_SRPT6                    (*((volatile unsigned int*)(0x42A61D98UL)))
#define bM4_DMA1_MONRPT2_SRPT7                    (*((volatile unsigned int*)(0x42A61D9CUL)))
#define bM4_DMA1_MONRPT2_SRPT8                    (*((volatile unsigned int*)(0x42A61DA0UL)))
#define bM4_DMA1_MONRPT2_SRPT9                    (*((volatile unsigned int*)(0x42A61DA4UL)))
#define bM4_DMA1_MONRPT2_DRPT0                    (*((volatile unsigned int*)(0x42A61DC0UL)))
#define bM4_DMA1_MONRPT2_DRPT1                    (*((volatile unsigned int*)(0x42A61DC4UL)))
#define bM4_DMA1_MONRPT2_DRPT2                    (*((volatile unsigned int*)(0x42A61DC8UL)))
#define bM4_DMA1_MONRPT2_DRPT3                    (*((volatile unsigned int*)(0x42A61DCCUL)))
#define bM4_DMA1_MONRPT2_DRPT4                    (*((volatile unsigned int*)(0x42A61DD0UL)))
#define bM4_DMA1_MONRPT2_DRPT5                    (*((volatile unsigned int*)(0x42A61DD4UL)))
#define bM4_DMA1_MONRPT2_DRPT6                    (*((volatile unsigned int*)(0x42A61DD8UL)))
#define bM4_DMA1_MONRPT2_DRPT7                    (*((volatile unsigned int*)(0x42A61DDCUL)))
#define bM4_DMA1_MONRPT2_DRPT8                    (*((volatile unsigned int*)(0x42A61DE0UL)))
#define bM4_DMA1_MONRPT2_DRPT9                    (*((volatile unsigned int*)(0x42A61DE4UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET0            (*((volatile unsigned int*)(0x42A61E00UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET1            (*((volatile unsigned int*)(0x42A61E04UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET2            (*((volatile unsigned int*)(0x42A61E08UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET3            (*((volatile unsigned int*)(0x42A61E0CUL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET4            (*((volatile unsigned int*)(0x42A61E10UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET5            (*((volatile unsigned int*)(0x42A61E14UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET6            (*((volatile unsigned int*)(0x42A61E18UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET7            (*((volatile unsigned int*)(0x42A61E1CUL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET8            (*((volatile unsigned int*)(0x42A61E20UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET9            (*((volatile unsigned int*)(0x42A61E24UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET10           (*((volatile unsigned int*)(0x42A61E28UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET11           (*((volatile unsigned int*)(0x42A61E2CUL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET12           (*((volatile unsigned int*)(0x42A61E30UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET13           (*((volatile unsigned int*)(0x42A61E34UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET14           (*((volatile unsigned int*)(0x42A61E38UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET15           (*((volatile unsigned int*)(0x42A61E3CUL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET16           (*((volatile unsigned int*)(0x42A61E40UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET17           (*((volatile unsigned int*)(0x42A61E44UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET18           (*((volatile unsigned int*)(0x42A61E48UL)))
#define bM4_DMA1_MONSNSEQCTL2_SOFFSET19           (*((volatile unsigned int*)(0x42A61E4CUL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT0             (*((volatile unsigned int*)(0x42A61E50UL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT1             (*((volatile unsigned int*)(0x42A61E54UL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT2             (*((volatile unsigned int*)(0x42A61E58UL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT3             (*((volatile unsigned int*)(0x42A61E5CUL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT4             (*((volatile unsigned int*)(0x42A61E60UL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT5             (*((volatile unsigned int*)(0x42A61E64UL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT6             (*((volatile unsigned int*)(0x42A61E68UL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT7             (*((volatile unsigned int*)(0x42A61E6CUL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT8             (*((volatile unsigned int*)(0x42A61E70UL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT9             (*((volatile unsigned int*)(0x42A61E74UL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT10            (*((volatile unsigned int*)(0x42A61E78UL)))
#define bM4_DMA1_MONSNSEQCTL2_SNSCNT11            (*((volatile unsigned int*)(0x42A61E7CUL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET0            (*((volatile unsigned int*)(0x42A61E80UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET1            (*((volatile unsigned int*)(0x42A61E84UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET2            (*((volatile unsigned int*)(0x42A61E88UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET3            (*((volatile unsigned int*)(0x42A61E8CUL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET4            (*((volatile unsigned int*)(0x42A61E90UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET5            (*((volatile unsigned int*)(0x42A61E94UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET6            (*((volatile unsigned int*)(0x42A61E98UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET7            (*((volatile unsigned int*)(0x42A61E9CUL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET8            (*((volatile unsigned int*)(0x42A61EA0UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET9            (*((volatile unsigned int*)(0x42A61EA4UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET10           (*((volatile unsigned int*)(0x42A61EA8UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET11           (*((volatile unsigned int*)(0x42A61EACUL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET12           (*((volatile unsigned int*)(0x42A61EB0UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET13           (*((volatile unsigned int*)(0x42A61EB4UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET14           (*((volatile unsigned int*)(0x42A61EB8UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET15           (*((volatile unsigned int*)(0x42A61EBCUL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET16           (*((volatile unsigned int*)(0x42A61EC0UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET17           (*((volatile unsigned int*)(0x42A61EC4UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET18           (*((volatile unsigned int*)(0x42A61EC8UL)))
#define bM4_DMA1_MONDNSEQCTL2_DOFFSET19           (*((volatile unsigned int*)(0x42A61ECCUL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT0             (*((volatile unsigned int*)(0x42A61ED0UL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT1             (*((volatile unsigned int*)(0x42A61ED4UL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT2             (*((volatile unsigned int*)(0x42A61ED8UL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT3             (*((volatile unsigned int*)(0x42A61EDCUL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT4             (*((volatile unsigned int*)(0x42A61EE0UL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT5             (*((volatile unsigned int*)(0x42A61EE4UL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT6             (*((volatile unsigned int*)(0x42A61EE8UL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT7             (*((volatile unsigned int*)(0x42A61EECUL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT8             (*((volatile unsigned int*)(0x42A61EF0UL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT9             (*((volatile unsigned int*)(0x42A61EF4UL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT10            (*((volatile unsigned int*)(0x42A61EF8UL)))
#define bM4_DMA1_MONDNSEQCTL2_DNSCNT11            (*((volatile unsigned int*)(0x42A61EFCUL)))
#define bM4_DMA1_DTCTL3_BLKSIZE0                  (*((volatile unsigned int*)(0x42A62100UL)))
#define bM4_DMA1_DTCTL3_BLKSIZE1                  (*((volatile unsigned int*)(0x42A62104UL)))
#define bM4_DMA1_DTCTL3_BLKSIZE2                  (*((volatile unsigned int*)(0x42A62108UL)))
#define bM4_DMA1_DTCTL3_BLKSIZE3                  (*((volatile unsigned int*)(0x42A6210CUL)))
#define bM4_DMA1_DTCTL3_BLKSIZE4                  (*((volatile unsigned int*)(0x42A62110UL)))
#define bM4_DMA1_DTCTL3_BLKSIZE5                  (*((volatile unsigned int*)(0x42A62114UL)))
#define bM4_DMA1_DTCTL3_BLKSIZE6                  (*((volatile unsigned int*)(0x42A62118UL)))
#define bM4_DMA1_DTCTL3_BLKSIZE7                  (*((volatile unsigned int*)(0x42A6211CUL)))
#define bM4_DMA1_DTCTL3_BLKSIZE8                  (*((volatile unsigned int*)(0x42A62120UL)))
#define bM4_DMA1_DTCTL3_BLKSIZE9                  (*((volatile unsigned int*)(0x42A62124UL)))
#define bM4_DMA1_DTCTL3_CNT0                      (*((volatile unsigned int*)(0x42A62140UL)))
#define bM4_DMA1_DTCTL3_CNT1                      (*((volatile unsigned int*)(0x42A62144UL)))
#define bM4_DMA1_DTCTL3_CNT2                      (*((volatile unsigned int*)(0x42A62148UL)))
#define bM4_DMA1_DTCTL3_CNT3                      (*((volatile unsigned int*)(0x42A6214CUL)))
#define bM4_DMA1_DTCTL3_CNT4                      (*((volatile unsigned int*)(0x42A62150UL)))
#define bM4_DMA1_DTCTL3_CNT5                      (*((volatile unsigned int*)(0x42A62154UL)))
#define bM4_DMA1_DTCTL3_CNT6                      (*((volatile unsigned int*)(0x42A62158UL)))
#define bM4_DMA1_DTCTL3_CNT7                      (*((volatile unsigned int*)(0x42A6215CUL)))
#define bM4_DMA1_DTCTL3_CNT8                      (*((volatile unsigned int*)(0x42A62160UL)))
#define bM4_DMA1_DTCTL3_CNT9                      (*((volatile unsigned int*)(0x42A62164UL)))
#define bM4_DMA1_DTCTL3_CNT10                     (*((volatile unsigned int*)(0x42A62168UL)))
#define bM4_DMA1_DTCTL3_CNT11                     (*((volatile unsigned int*)(0x42A6216CUL)))
#define bM4_DMA1_DTCTL3_CNT12                     (*((volatile unsigned int*)(0x42A62170UL)))
#define bM4_DMA1_DTCTL3_CNT13                     (*((volatile unsigned int*)(0x42A62174UL)))
#define bM4_DMA1_DTCTL3_CNT14                     (*((volatile unsigned int*)(0x42A62178UL)))
#define bM4_DMA1_DTCTL3_CNT15                     (*((volatile unsigned int*)(0x42A6217CUL)))
#define bM4_DMA1_RPT3_SRPT0                       (*((volatile unsigned int*)(0x42A62180UL)))
#define bM4_DMA1_RPT3_SRPT1                       (*((volatile unsigned int*)(0x42A62184UL)))
#define bM4_DMA1_RPT3_SRPT2                       (*((volatile unsigned int*)(0x42A62188UL)))
#define bM4_DMA1_RPT3_SRPT3                       (*((volatile unsigned int*)(0x42A6218CUL)))
#define bM4_DMA1_RPT3_SRPT4                       (*((volatile unsigned int*)(0x42A62190UL)))
#define bM4_DMA1_RPT3_SRPT5                       (*((volatile unsigned int*)(0x42A62194UL)))
#define bM4_DMA1_RPT3_SRPT6                       (*((volatile unsigned int*)(0x42A62198UL)))
#define bM4_DMA1_RPT3_SRPT7                       (*((volatile unsigned int*)(0x42A6219CUL)))
#define bM4_DMA1_RPT3_SRPT8                       (*((volatile unsigned int*)(0x42A621A0UL)))
#define bM4_DMA1_RPT3_SRPT9                       (*((volatile unsigned int*)(0x42A621A4UL)))
#define bM4_DMA1_RPT3_DRPT0                       (*((volatile unsigned int*)(0x42A621C0UL)))
#define bM4_DMA1_RPT3_DRPT1                       (*((volatile unsigned int*)(0x42A621C4UL)))
#define bM4_DMA1_RPT3_DRPT2                       (*((volatile unsigned int*)(0x42A621C8UL)))
#define bM4_DMA1_RPT3_DRPT3                       (*((volatile unsigned int*)(0x42A621CCUL)))
#define bM4_DMA1_RPT3_DRPT4                       (*((volatile unsigned int*)(0x42A621D0UL)))
#define bM4_DMA1_RPT3_DRPT5                       (*((volatile unsigned int*)(0x42A621D4UL)))
#define bM4_DMA1_RPT3_DRPT6                       (*((volatile unsigned int*)(0x42A621D8UL)))
#define bM4_DMA1_RPT3_DRPT7                       (*((volatile unsigned int*)(0x42A621DCUL)))
#define bM4_DMA1_RPT3_DRPT8                       (*((volatile unsigned int*)(0x42A621E0UL)))
#define bM4_DMA1_RPT3_DRPT9                       (*((volatile unsigned int*)(0x42A621E4UL)))
#define bM4_DMA1_RPTB3_SRPTB0                     (*((volatile unsigned int*)(0x42A62180UL)))
#define bM4_DMA1_RPTB3_SRPTB1                     (*((volatile unsigned int*)(0x42A62184UL)))
#define bM4_DMA1_RPTB3_SRPTB2                     (*((volatile unsigned int*)(0x42A62188UL)))
#define bM4_DMA1_RPTB3_SRPTB3                     (*((volatile unsigned int*)(0x42A6218CUL)))
#define bM4_DMA1_RPTB3_SRPTB4                     (*((volatile unsigned int*)(0x42A62190UL)))
#define bM4_DMA1_RPTB3_SRPTB5                     (*((volatile unsigned int*)(0x42A62194UL)))
#define bM4_DMA1_RPTB3_SRPTB6                     (*((volatile unsigned int*)(0x42A62198UL)))
#define bM4_DMA1_RPTB3_SRPTB7                     (*((volatile unsigned int*)(0x42A6219CUL)))
#define bM4_DMA1_RPTB3_SRPTB8                     (*((volatile unsigned int*)(0x42A621A0UL)))
#define bM4_DMA1_RPTB3_SRPTB9                     (*((volatile unsigned int*)(0x42A621A4UL)))
#define bM4_DMA1_RPTB3_DRPTB0                     (*((volatile unsigned int*)(0x42A621C0UL)))
#define bM4_DMA1_RPTB3_DRPTB1                     (*((volatile unsigned int*)(0x42A621C4UL)))
#define bM4_DMA1_RPTB3_DRPTB2                     (*((volatile unsigned int*)(0x42A621C8UL)))
#define bM4_DMA1_RPTB3_DRPTB3                     (*((volatile unsigned int*)(0x42A621CCUL)))
#define bM4_DMA1_RPTB3_DRPTB4                     (*((volatile unsigned int*)(0x42A621D0UL)))
#define bM4_DMA1_RPTB3_DRPTB5                     (*((volatile unsigned int*)(0x42A621D4UL)))
#define bM4_DMA1_RPTB3_DRPTB6                     (*((volatile unsigned int*)(0x42A621D8UL)))
#define bM4_DMA1_RPTB3_DRPTB7                     (*((volatile unsigned int*)(0x42A621DCUL)))
#define bM4_DMA1_RPTB3_DRPTB8                     (*((volatile unsigned int*)(0x42A621E0UL)))
#define bM4_DMA1_RPTB3_DRPTB9                     (*((volatile unsigned int*)(0x42A621E4UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET0               (*((volatile unsigned int*)(0x42A62200UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET1               (*((volatile unsigned int*)(0x42A62204UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET2               (*((volatile unsigned int*)(0x42A62208UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET3               (*((volatile unsigned int*)(0x42A6220CUL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET4               (*((volatile unsigned int*)(0x42A62210UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET5               (*((volatile unsigned int*)(0x42A62214UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET6               (*((volatile unsigned int*)(0x42A62218UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET7               (*((volatile unsigned int*)(0x42A6221CUL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET8               (*((volatile unsigned int*)(0x42A62220UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET9               (*((volatile unsigned int*)(0x42A62224UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET10              (*((volatile unsigned int*)(0x42A62228UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET11              (*((volatile unsigned int*)(0x42A6222CUL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET12              (*((volatile unsigned int*)(0x42A62230UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET13              (*((volatile unsigned int*)(0x42A62234UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET14              (*((volatile unsigned int*)(0x42A62238UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET15              (*((volatile unsigned int*)(0x42A6223CUL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET16              (*((volatile unsigned int*)(0x42A62240UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET17              (*((volatile unsigned int*)(0x42A62244UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET18              (*((volatile unsigned int*)(0x42A62248UL)))
#define bM4_DMA1_SNSEQCTL3_SOFFSET19              (*((volatile unsigned int*)(0x42A6224CUL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT0                (*((volatile unsigned int*)(0x42A62250UL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT1                (*((volatile unsigned int*)(0x42A62254UL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT2                (*((volatile unsigned int*)(0x42A62258UL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT3                (*((volatile unsigned int*)(0x42A6225CUL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT4                (*((volatile unsigned int*)(0x42A62260UL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT5                (*((volatile unsigned int*)(0x42A62264UL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT6                (*((volatile unsigned int*)(0x42A62268UL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT7                (*((volatile unsigned int*)(0x42A6226CUL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT8                (*((volatile unsigned int*)(0x42A62270UL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT9                (*((volatile unsigned int*)(0x42A62274UL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT10               (*((volatile unsigned int*)(0x42A62278UL)))
#define bM4_DMA1_SNSEQCTL3_SNSCNT11               (*((volatile unsigned int*)(0x42A6227CUL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST0              (*((volatile unsigned int*)(0x42A62200UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST1              (*((volatile unsigned int*)(0x42A62204UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST2              (*((volatile unsigned int*)(0x42A62208UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST3              (*((volatile unsigned int*)(0x42A6220CUL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST4              (*((volatile unsigned int*)(0x42A62210UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST5              (*((volatile unsigned int*)(0x42A62214UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST6              (*((volatile unsigned int*)(0x42A62218UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST7              (*((volatile unsigned int*)(0x42A6221CUL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST8              (*((volatile unsigned int*)(0x42A62220UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST9              (*((volatile unsigned int*)(0x42A62224UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST10             (*((volatile unsigned int*)(0x42A62228UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST11             (*((volatile unsigned int*)(0x42A6222CUL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST12             (*((volatile unsigned int*)(0x42A62230UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST13             (*((volatile unsigned int*)(0x42A62234UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST14             (*((volatile unsigned int*)(0x42A62238UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST15             (*((volatile unsigned int*)(0x42A6223CUL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST16             (*((volatile unsigned int*)(0x42A62240UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST17             (*((volatile unsigned int*)(0x42A62244UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST18             (*((volatile unsigned int*)(0x42A62248UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSDIST19             (*((volatile unsigned int*)(0x42A6224CUL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB0              (*((volatile unsigned int*)(0x42A62250UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB1              (*((volatile unsigned int*)(0x42A62254UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB2              (*((volatile unsigned int*)(0x42A62258UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB3              (*((volatile unsigned int*)(0x42A6225CUL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB4              (*((volatile unsigned int*)(0x42A62260UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB5              (*((volatile unsigned int*)(0x42A62264UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB6              (*((volatile unsigned int*)(0x42A62268UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB7              (*((volatile unsigned int*)(0x42A6226CUL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB8              (*((volatile unsigned int*)(0x42A62270UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB9              (*((volatile unsigned int*)(0x42A62274UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB10             (*((volatile unsigned int*)(0x42A62278UL)))
#define bM4_DMA1_SNSEQCTLB3_SNSCNTB11             (*((volatile unsigned int*)(0x42A6227CUL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET0               (*((volatile unsigned int*)(0x42A62280UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET1               (*((volatile unsigned int*)(0x42A62284UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET2               (*((volatile unsigned int*)(0x42A62288UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET3               (*((volatile unsigned int*)(0x42A6228CUL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET4               (*((volatile unsigned int*)(0x42A62290UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET5               (*((volatile unsigned int*)(0x42A62294UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET6               (*((volatile unsigned int*)(0x42A62298UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET7               (*((volatile unsigned int*)(0x42A6229CUL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET8               (*((volatile unsigned int*)(0x42A622A0UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET9               (*((volatile unsigned int*)(0x42A622A4UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET10              (*((volatile unsigned int*)(0x42A622A8UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET11              (*((volatile unsigned int*)(0x42A622ACUL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET12              (*((volatile unsigned int*)(0x42A622B0UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET13              (*((volatile unsigned int*)(0x42A622B4UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET14              (*((volatile unsigned int*)(0x42A622B8UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET15              (*((volatile unsigned int*)(0x42A622BCUL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET16              (*((volatile unsigned int*)(0x42A622C0UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET17              (*((volatile unsigned int*)(0x42A622C4UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET18              (*((volatile unsigned int*)(0x42A622C8UL)))
#define bM4_DMA1_DNSEQCTL3_DOFFSET19              (*((volatile unsigned int*)(0x42A622CCUL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT0                (*((volatile unsigned int*)(0x42A622D0UL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT1                (*((volatile unsigned int*)(0x42A622D4UL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT2                (*((volatile unsigned int*)(0x42A622D8UL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT3                (*((volatile unsigned int*)(0x42A622DCUL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT4                (*((volatile unsigned int*)(0x42A622E0UL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT5                (*((volatile unsigned int*)(0x42A622E4UL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT6                (*((volatile unsigned int*)(0x42A622E8UL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT7                (*((volatile unsigned int*)(0x42A622ECUL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT8                (*((volatile unsigned int*)(0x42A622F0UL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT9                (*((volatile unsigned int*)(0x42A622F4UL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT10               (*((volatile unsigned int*)(0x42A622F8UL)))
#define bM4_DMA1_DNSEQCTL3_DNSCNT11               (*((volatile unsigned int*)(0x42A622FCUL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST0              (*((volatile unsigned int*)(0x42A62280UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST1              (*((volatile unsigned int*)(0x42A62284UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST2              (*((volatile unsigned int*)(0x42A62288UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST3              (*((volatile unsigned int*)(0x42A6228CUL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST4              (*((volatile unsigned int*)(0x42A62290UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST5              (*((volatile unsigned int*)(0x42A62294UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST6              (*((volatile unsigned int*)(0x42A62298UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST7              (*((volatile unsigned int*)(0x42A6229CUL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST8              (*((volatile unsigned int*)(0x42A622A0UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST9              (*((volatile unsigned int*)(0x42A622A4UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST10             (*((volatile unsigned int*)(0x42A622A8UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST11             (*((volatile unsigned int*)(0x42A622ACUL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST12             (*((volatile unsigned int*)(0x42A622B0UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST13             (*((volatile unsigned int*)(0x42A622B4UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST14             (*((volatile unsigned int*)(0x42A622B8UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST15             (*((volatile unsigned int*)(0x42A622BCUL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST16             (*((volatile unsigned int*)(0x42A622C0UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST17             (*((volatile unsigned int*)(0x42A622C4UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST18             (*((volatile unsigned int*)(0x42A622C8UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSDIST19             (*((volatile unsigned int*)(0x42A622CCUL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB0              (*((volatile unsigned int*)(0x42A622D0UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB1              (*((volatile unsigned int*)(0x42A622D4UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB2              (*((volatile unsigned int*)(0x42A622D8UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB3              (*((volatile unsigned int*)(0x42A622DCUL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB4              (*((volatile unsigned int*)(0x42A622E0UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB5              (*((volatile unsigned int*)(0x42A622E4UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB6              (*((volatile unsigned int*)(0x42A622E8UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB7              (*((volatile unsigned int*)(0x42A622ECUL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB8              (*((volatile unsigned int*)(0x42A622F0UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB9              (*((volatile unsigned int*)(0x42A622F4UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB10             (*((volatile unsigned int*)(0x42A622F8UL)))
#define bM4_DMA1_DNSEQCTLB3_DNSCNTB11             (*((volatile unsigned int*)(0x42A622FCUL)))
#define bM4_DMA1_LLP3_LLP0                        (*((volatile unsigned int*)(0x42A62308UL)))
#define bM4_DMA1_LLP3_LLP1                        (*((volatile unsigned int*)(0x42A6230CUL)))
#define bM4_DMA1_LLP3_LLP2                        (*((volatile unsigned int*)(0x42A62310UL)))
#define bM4_DMA1_LLP3_LLP3                        (*((volatile unsigned int*)(0x42A62314UL)))
#define bM4_DMA1_LLP3_LLP4                        (*((volatile unsigned int*)(0x42A62318UL)))
#define bM4_DMA1_LLP3_LLP5                        (*((volatile unsigned int*)(0x42A6231CUL)))
#define bM4_DMA1_LLP3_LLP6                        (*((volatile unsigned int*)(0x42A62320UL)))
#define bM4_DMA1_LLP3_LLP7                        (*((volatile unsigned int*)(0x42A62324UL)))
#define bM4_DMA1_LLP3_LLP8                        (*((volatile unsigned int*)(0x42A62328UL)))
#define bM4_DMA1_LLP3_LLP9                        (*((volatile unsigned int*)(0x42A6232CUL)))
#define bM4_DMA1_LLP3_LLP10                       (*((volatile unsigned int*)(0x42A62330UL)))
#define bM4_DMA1_LLP3_LLP11                       (*((volatile unsigned int*)(0x42A62334UL)))
#define bM4_DMA1_LLP3_LLP12                       (*((volatile unsigned int*)(0x42A62338UL)))
#define bM4_DMA1_LLP3_LLP13                       (*((volatile unsigned int*)(0x42A6233CUL)))
#define bM4_DMA1_LLP3_LLP14                       (*((volatile unsigned int*)(0x42A62340UL)))
#define bM4_DMA1_LLP3_LLP15                       (*((volatile unsigned int*)(0x42A62344UL)))
#define bM4_DMA1_LLP3_LLP16                       (*((volatile unsigned int*)(0x42A62348UL)))
#define bM4_DMA1_LLP3_LLP17                       (*((volatile unsigned int*)(0x42A6234CUL)))
#define bM4_DMA1_LLP3_LLP18                       (*((volatile unsigned int*)(0x42A62350UL)))
#define bM4_DMA1_LLP3_LLP19                       (*((volatile unsigned int*)(0x42A62354UL)))
#define bM4_DMA1_LLP3_LLP20                       (*((volatile unsigned int*)(0x42A62358UL)))
#define bM4_DMA1_LLP3_LLP21                       (*((volatile unsigned int*)(0x42A6235CUL)))
#define bM4_DMA1_LLP3_LLP22                       (*((volatile unsigned int*)(0x42A62360UL)))
#define bM4_DMA1_LLP3_LLP23                       (*((volatile unsigned int*)(0x42A62364UL)))
#define bM4_DMA1_LLP3_LLP24                       (*((volatile unsigned int*)(0x42A62368UL)))
#define bM4_DMA1_LLP3_LLP25                       (*((volatile unsigned int*)(0x42A6236CUL)))
#define bM4_DMA1_LLP3_LLP26                       (*((volatile unsigned int*)(0x42A62370UL)))
#define bM4_DMA1_LLP3_LLP27                       (*((volatile unsigned int*)(0x42A62374UL)))
#define bM4_DMA1_LLP3_LLP28                       (*((volatile unsigned int*)(0x42A62378UL)))
#define bM4_DMA1_LLP3_LLP29                       (*((volatile unsigned int*)(0x42A6237CUL)))
#define bM4_DMA1_CHCTL3_SINC0                     (*((volatile unsigned int*)(0x42A62380UL)))
#define bM4_DMA1_CHCTL3_SINC1                     (*((volatile unsigned int*)(0x42A62384UL)))
#define bM4_DMA1_CHCTL3_DINC0                     (*((volatile unsigned int*)(0x42A62388UL)))
#define bM4_DMA1_CHCTL3_DINC1                     (*((volatile unsigned int*)(0x42A6238CUL)))
#define bM4_DMA1_CHCTL3_SRPTEN                    (*((volatile unsigned int*)(0x42A62390UL)))
#define bM4_DMA1_CHCTL3_DRPTEN                    (*((volatile unsigned int*)(0x42A62394UL)))
#define bM4_DMA1_CHCTL3_SNSEQEN                   (*((volatile unsigned int*)(0x42A62398UL)))
#define bM4_DMA1_CHCTL3_DNSEQEN                   (*((volatile unsigned int*)(0x42A6239CUL)))
#define bM4_DMA1_CHCTL3_HSIZE0                    (*((volatile unsigned int*)(0x42A623A0UL)))
#define bM4_DMA1_CHCTL3_HSIZE1                    (*((volatile unsigned int*)(0x42A623A4UL)))
#define bM4_DMA1_CHCTL3_LLPEN                     (*((volatile unsigned int*)(0x42A623A8UL)))
#define bM4_DMA1_CHCTL3_LLPRUN                    (*((volatile unsigned int*)(0x42A623ACUL)))
#define bM4_DMA1_CHCTL3_IE                        (*((volatile unsigned int*)(0x42A623B0UL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE0               (*((volatile unsigned int*)(0x42A62500UL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE1               (*((volatile unsigned int*)(0x42A62504UL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE2               (*((volatile unsigned int*)(0x42A62508UL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE3               (*((volatile unsigned int*)(0x42A6250CUL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE4               (*((volatile unsigned int*)(0x42A62510UL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE5               (*((volatile unsigned int*)(0x42A62514UL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE6               (*((volatile unsigned int*)(0x42A62518UL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE7               (*((volatile unsigned int*)(0x42A6251CUL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE8               (*((volatile unsigned int*)(0x42A62520UL)))
#define bM4_DMA1_MONDTCTL3_BLKSIZE9               (*((volatile unsigned int*)(0x42A62524UL)))
#define bM4_DMA1_MONDTCTL3_CNT0                   (*((volatile unsigned int*)(0x42A62540UL)))
#define bM4_DMA1_MONDTCTL3_CNT1                   (*((volatile unsigned int*)(0x42A62544UL)))
#define bM4_DMA1_MONDTCTL3_CNT2                   (*((volatile unsigned int*)(0x42A62548UL)))
#define bM4_DMA1_MONDTCTL3_CNT3                   (*((volatile unsigned int*)(0x42A6254CUL)))
#define bM4_DMA1_MONDTCTL3_CNT4                   (*((volatile unsigned int*)(0x42A62550UL)))
#define bM4_DMA1_MONDTCTL3_CNT5                   (*((volatile unsigned int*)(0x42A62554UL)))
#define bM4_DMA1_MONDTCTL3_CNT6                   (*((volatile unsigned int*)(0x42A62558UL)))
#define bM4_DMA1_MONDTCTL3_CNT7                   (*((volatile unsigned int*)(0x42A6255CUL)))
#define bM4_DMA1_MONDTCTL3_CNT8                   (*((volatile unsigned int*)(0x42A62560UL)))
#define bM4_DMA1_MONDTCTL3_CNT9                   (*((volatile unsigned int*)(0x42A62564UL)))
#define bM4_DMA1_MONDTCTL3_CNT10                  (*((volatile unsigned int*)(0x42A62568UL)))
#define bM4_DMA1_MONDTCTL3_CNT11                  (*((volatile unsigned int*)(0x42A6256CUL)))
#define bM4_DMA1_MONDTCTL3_CNT12                  (*((volatile unsigned int*)(0x42A62570UL)))
#define bM4_DMA1_MONDTCTL3_CNT13                  (*((volatile unsigned int*)(0x42A62574UL)))
#define bM4_DMA1_MONDTCTL3_CNT14                  (*((volatile unsigned int*)(0x42A62578UL)))
#define bM4_DMA1_MONDTCTL3_CNT15                  (*((volatile unsigned int*)(0x42A6257CUL)))
#define bM4_DMA1_MONRPT3_SRPT0                    (*((volatile unsigned int*)(0x42A62580UL)))
#define bM4_DMA1_MONRPT3_SRPT1                    (*((volatile unsigned int*)(0x42A62584UL)))
#define bM4_DMA1_MONRPT3_SRPT2                    (*((volatile unsigned int*)(0x42A62588UL)))
#define bM4_DMA1_MONRPT3_SRPT3                    (*((volatile unsigned int*)(0x42A6258CUL)))
#define bM4_DMA1_MONRPT3_SRPT4                    (*((volatile unsigned int*)(0x42A62590UL)))
#define bM4_DMA1_MONRPT3_SRPT5                    (*((volatile unsigned int*)(0x42A62594UL)))
#define bM4_DMA1_MONRPT3_SRPT6                    (*((volatile unsigned int*)(0x42A62598UL)))
#define bM4_DMA1_MONRPT3_SRPT7                    (*((volatile unsigned int*)(0x42A6259CUL)))
#define bM4_DMA1_MONRPT3_SRPT8                    (*((volatile unsigned int*)(0x42A625A0UL)))
#define bM4_DMA1_MONRPT3_SRPT9                    (*((volatile unsigned int*)(0x42A625A4UL)))
#define bM4_DMA1_MONRPT3_DRPT0                    (*((volatile unsigned int*)(0x42A625C0UL)))
#define bM4_DMA1_MONRPT3_DRPT1                    (*((volatile unsigned int*)(0x42A625C4UL)))
#define bM4_DMA1_MONRPT3_DRPT2                    (*((volatile unsigned int*)(0x42A625C8UL)))
#define bM4_DMA1_MONRPT3_DRPT3                    (*((volatile unsigned int*)(0x42A625CCUL)))
#define bM4_DMA1_MONRPT3_DRPT4                    (*((volatile unsigned int*)(0x42A625D0UL)))
#define bM4_DMA1_MONRPT3_DRPT5                    (*((volatile unsigned int*)(0x42A625D4UL)))
#define bM4_DMA1_MONRPT3_DRPT6                    (*((volatile unsigned int*)(0x42A625D8UL)))
#define bM4_DMA1_MONRPT3_DRPT7                    (*((volatile unsigned int*)(0x42A625DCUL)))
#define bM4_DMA1_MONRPT3_DRPT8                    (*((volatile unsigned int*)(0x42A625E0UL)))
#define bM4_DMA1_MONRPT3_DRPT9                    (*((volatile unsigned int*)(0x42A625E4UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET0            (*((volatile unsigned int*)(0x42A62600UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET1            (*((volatile unsigned int*)(0x42A62604UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET2            (*((volatile unsigned int*)(0x42A62608UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET3            (*((volatile unsigned int*)(0x42A6260CUL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET4            (*((volatile unsigned int*)(0x42A62610UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET5            (*((volatile unsigned int*)(0x42A62614UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET6            (*((volatile unsigned int*)(0x42A62618UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET7            (*((volatile unsigned int*)(0x42A6261CUL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET8            (*((volatile unsigned int*)(0x42A62620UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET9            (*((volatile unsigned int*)(0x42A62624UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET10           (*((volatile unsigned int*)(0x42A62628UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET11           (*((volatile unsigned int*)(0x42A6262CUL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET12           (*((volatile unsigned int*)(0x42A62630UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET13           (*((volatile unsigned int*)(0x42A62634UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET14           (*((volatile unsigned int*)(0x42A62638UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET15           (*((volatile unsigned int*)(0x42A6263CUL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET16           (*((volatile unsigned int*)(0x42A62640UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET17           (*((volatile unsigned int*)(0x42A62644UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET18           (*((volatile unsigned int*)(0x42A62648UL)))
#define bM4_DMA1_MONSNSEQCTL3_SOFFSET19           (*((volatile unsigned int*)(0x42A6264CUL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT0             (*((volatile unsigned int*)(0x42A62650UL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT1             (*((volatile unsigned int*)(0x42A62654UL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT2             (*((volatile unsigned int*)(0x42A62658UL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT3             (*((volatile unsigned int*)(0x42A6265CUL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT4             (*((volatile unsigned int*)(0x42A62660UL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT5             (*((volatile unsigned int*)(0x42A62664UL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT6             (*((volatile unsigned int*)(0x42A62668UL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT7             (*((volatile unsigned int*)(0x42A6266CUL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT8             (*((volatile unsigned int*)(0x42A62670UL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT9             (*((volatile unsigned int*)(0x42A62674UL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT10            (*((volatile unsigned int*)(0x42A62678UL)))
#define bM4_DMA1_MONSNSEQCTL3_SNSCNT11            (*((volatile unsigned int*)(0x42A6267CUL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET0            (*((volatile unsigned int*)(0x42A62680UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET1            (*((volatile unsigned int*)(0x42A62684UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET2            (*((volatile unsigned int*)(0x42A62688UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET3            (*((volatile unsigned int*)(0x42A6268CUL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET4            (*((volatile unsigned int*)(0x42A62690UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET5            (*((volatile unsigned int*)(0x42A62694UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET6            (*((volatile unsigned int*)(0x42A62698UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET7            (*((volatile unsigned int*)(0x42A6269CUL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET8            (*((volatile unsigned int*)(0x42A626A0UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET9            (*((volatile unsigned int*)(0x42A626A4UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET10           (*((volatile unsigned int*)(0x42A626A8UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET11           (*((volatile unsigned int*)(0x42A626ACUL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET12           (*((volatile unsigned int*)(0x42A626B0UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET13           (*((volatile unsigned int*)(0x42A626B4UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET14           (*((volatile unsigned int*)(0x42A626B8UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET15           (*((volatile unsigned int*)(0x42A626BCUL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET16           (*((volatile unsigned int*)(0x42A626C0UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET17           (*((volatile unsigned int*)(0x42A626C4UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET18           (*((volatile unsigned int*)(0x42A626C8UL)))
#define bM4_DMA1_MONDNSEQCTL3_DOFFSET19           (*((volatile unsigned int*)(0x42A626CCUL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT0             (*((volatile unsigned int*)(0x42A626D0UL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT1             (*((volatile unsigned int*)(0x42A626D4UL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT2             (*((volatile unsigned int*)(0x42A626D8UL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT3             (*((volatile unsigned int*)(0x42A626DCUL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT4             (*((volatile unsigned int*)(0x42A626E0UL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT5             (*((volatile unsigned int*)(0x42A626E4UL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT6             (*((volatile unsigned int*)(0x42A626E8UL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT7             (*((volatile unsigned int*)(0x42A626ECUL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT8             (*((volatile unsigned int*)(0x42A626F0UL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT9             (*((volatile unsigned int*)(0x42A626F4UL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT10            (*((volatile unsigned int*)(0x42A626F8UL)))
#define bM4_DMA1_MONDNSEQCTL3_DNSCNT11            (*((volatile unsigned int*)(0x42A626FCUL)))
#define bM4_DMA2_EN_EN                            (*((volatile unsigned int*)(0x42A68000UL)))
#define bM4_DMA2_INTSTAT0_TRNERR0                 (*((volatile unsigned int*)(0x42A68080UL)))
#define bM4_DMA2_INTSTAT0_TRNERR1                 (*((volatile unsigned int*)(0x42A68084UL)))
#define bM4_DMA2_INTSTAT0_TRNERR2                 (*((volatile unsigned int*)(0x42A68088UL)))
#define bM4_DMA2_INTSTAT0_TRNERR3                 (*((volatile unsigned int*)(0x42A6808CUL)))
#define bM4_DMA2_INTSTAT0_REQERR0                 (*((volatile unsigned int*)(0x42A680C0UL)))
#define bM4_DMA2_INTSTAT0_REQERR1                 (*((volatile unsigned int*)(0x42A680C4UL)))
#define bM4_DMA2_INTSTAT0_REQERR2                 (*((volatile unsigned int*)(0x42A680C8UL)))
#define bM4_DMA2_INTSTAT0_REQERR3                 (*((volatile unsigned int*)(0x42A680CCUL)))
#define bM4_DMA2_INTSTAT1_TC0                     (*((volatile unsigned int*)(0x42A68100UL)))
#define bM4_DMA2_INTSTAT1_TC1                     (*((volatile unsigned int*)(0x42A68104UL)))
#define bM4_DMA2_INTSTAT1_TC2                     (*((volatile unsigned int*)(0x42A68108UL)))
#define bM4_DMA2_INTSTAT1_TC3                     (*((volatile unsigned int*)(0x42A6810CUL)))
#define bM4_DMA2_INTSTAT1_BTC0                    (*((volatile unsigned int*)(0x42A68140UL)))
#define bM4_DMA2_INTSTAT1_BTC1                    (*((volatile unsigned int*)(0x42A68144UL)))
#define bM4_DMA2_INTSTAT1_BTC2                    (*((volatile unsigned int*)(0x42A68148UL)))
#define bM4_DMA2_INTSTAT1_BTC3                    (*((volatile unsigned int*)(0x42A6814CUL)))
#define bM4_DMA2_INTMASK0_MSKTRNERR0              (*((volatile unsigned int*)(0x42A68180UL)))
#define bM4_DMA2_INTMASK0_MSKTRNERR1              (*((volatile unsigned int*)(0x42A68184UL)))
#define bM4_DMA2_INTMASK0_MSKTRNERR2              (*((volatile unsigned int*)(0x42A68188UL)))
#define bM4_DMA2_INTMASK0_MSKTRNERR3              (*((volatile unsigned int*)(0x42A6818CUL)))
#define bM4_DMA2_INTMASK0_MSKREQERR0              (*((volatile unsigned int*)(0x42A681C0UL)))
#define bM4_DMA2_INTMASK0_MSKREQERR1              (*((volatile unsigned int*)(0x42A681C4UL)))
#define bM4_DMA2_INTMASK0_MSKREQERR2              (*((volatile unsigned int*)(0x42A681C8UL)))
#define bM4_DMA2_INTMASK0_MSKREQERR3              (*((volatile unsigned int*)(0x42A681CCUL)))
#define bM4_DMA2_INTMASK1_MSKTC0                  (*((volatile unsigned int*)(0x42A68200UL)))
#define bM4_DMA2_INTMASK1_MSKTC1                  (*((volatile unsigned int*)(0x42A68204UL)))
#define bM4_DMA2_INTMASK1_MSKTC2                  (*((volatile unsigned int*)(0x42A68208UL)))
#define bM4_DMA2_INTMASK1_MSKTC3                  (*((volatile unsigned int*)(0x42A6820CUL)))
#define bM4_DMA2_INTMASK1_MSKBTC0                 (*((volatile unsigned int*)(0x42A68240UL)))
#define bM4_DMA2_INTMASK1_MSKBTC1                 (*((volatile unsigned int*)(0x42A68244UL)))
#define bM4_DMA2_INTMASK1_MSKBTC2                 (*((volatile unsigned int*)(0x42A68248UL)))
#define bM4_DMA2_INTMASK1_MSKBTC3                 (*((volatile unsigned int*)(0x42A6824CUL)))
#define bM4_DMA2_INTCLR0_CLRTRNERR0               (*((volatile unsigned int*)(0x42A68280UL)))
#define bM4_DMA2_INTCLR0_CLRTRNERR1               (*((volatile unsigned int*)(0x42A68284UL)))
#define bM4_DMA2_INTCLR0_CLRTRNERR2               (*((volatile unsigned int*)(0x42A68288UL)))
#define bM4_DMA2_INTCLR0_CLRTRNERR3               (*((volatile unsigned int*)(0x42A6828CUL)))
#define bM4_DMA2_INTCLR0_CLRREQERR0               (*((volatile unsigned int*)(0x42A682C0UL)))
#define bM4_DMA2_INTCLR0_CLRREQERR1               (*((volatile unsigned int*)(0x42A682C4UL)))
#define bM4_DMA2_INTCLR0_CLRREQERR2               (*((volatile unsigned int*)(0x42A682C8UL)))
#define bM4_DMA2_INTCLR0_CLRREQERR3               (*((volatile unsigned int*)(0x42A682CCUL)))
#define bM4_DMA2_INTCLR1_CLRTC0                   (*((volatile unsigned int*)(0x42A68300UL)))
#define bM4_DMA2_INTCLR1_CLRTC1                   (*((volatile unsigned int*)(0x42A68304UL)))
#define bM4_DMA2_INTCLR1_CLRTC2                   (*((volatile unsigned int*)(0x42A68308UL)))
#define bM4_DMA2_INTCLR1_CLRTC3                   (*((volatile unsigned int*)(0x42A6830CUL)))
#define bM4_DMA2_INTCLR1_CLRBTC0                  (*((volatile unsigned int*)(0x42A68340UL)))
#define bM4_DMA2_INTCLR1_CLRBTC1                  (*((volatile unsigned int*)(0x42A68344UL)))
#define bM4_DMA2_INTCLR1_CLRBTC2                  (*((volatile unsigned int*)(0x42A68348UL)))
#define bM4_DMA2_INTCLR1_CLRBTC3                  (*((volatile unsigned int*)(0x42A6834CUL)))
#define bM4_DMA2_CHEN_CHEN0                       (*((volatile unsigned int*)(0x42A68380UL)))
#define bM4_DMA2_CHEN_CHEN1                       (*((volatile unsigned int*)(0x42A68384UL)))
#define bM4_DMA2_CHEN_CHEN2                       (*((volatile unsigned int*)(0x42A68388UL)))
#define bM4_DMA2_CHEN_CHEN3                       (*((volatile unsigned int*)(0x42A6838CUL)))
#define bM4_DMA2_REQSTAT_CHREQ0                   (*((volatile unsigned int*)(0x42A68400UL)))
#define bM4_DMA2_REQSTAT_CHREQ1                   (*((volatile unsigned int*)(0x42A68404UL)))
#define bM4_DMA2_REQSTAT_CHREQ2                   (*((volatile unsigned int*)(0x42A68408UL)))
#define bM4_DMA2_REQSTAT_CHREQ3                   (*((volatile unsigned int*)(0x42A6840CUL)))
#define bM4_DMA2_REQSTAT_RCFGREQ                  (*((volatile unsigned int*)(0x42A6843CUL)))
#define bM4_DMA2_CHSTAT_DMAACT                    (*((volatile unsigned int*)(0x42A68480UL)))
#define bM4_DMA2_CHSTAT_RCFGACT                   (*((volatile unsigned int*)(0x42A68484UL)))
#define bM4_DMA2_CHSTAT_CHACT0                    (*((volatile unsigned int*)(0x42A684C0UL)))
#define bM4_DMA2_CHSTAT_CHACT1                    (*((volatile unsigned int*)(0x42A684C4UL)))
#define bM4_DMA2_CHSTAT_CHACT2                    (*((volatile unsigned int*)(0x42A684C8UL)))
#define bM4_DMA2_CHSTAT_CHACT3                    (*((volatile unsigned int*)(0x42A684CCUL)))
#define bM4_DMA2_RCFGCTL_RCFGEN                   (*((volatile unsigned int*)(0x42A68580UL)))
#define bM4_DMA2_RCFGCTL_RCFGLLP                  (*((volatile unsigned int*)(0x42A68584UL)))
#define bM4_DMA2_RCFGCTL_RCFGCHS0                 (*((volatile unsigned int*)(0x42A685A0UL)))
#define bM4_DMA2_RCFGCTL_RCFGCHS1                 (*((volatile unsigned int*)(0x42A685A4UL)))
#define bM4_DMA2_RCFGCTL_RCFGCHS2                 (*((volatile unsigned int*)(0x42A685A8UL)))
#define bM4_DMA2_RCFGCTL_RCFGCHS3                 (*((volatile unsigned int*)(0x42A685ACUL)))
#define bM4_DMA2_RCFGCTL_SARMD0                   (*((volatile unsigned int*)(0x42A685C0UL)))
#define bM4_DMA2_RCFGCTL_SARMD1                   (*((volatile unsigned int*)(0x42A685C4UL)))
#define bM4_DMA2_RCFGCTL_DARMD0                   (*((volatile unsigned int*)(0x42A685C8UL)))
#define bM4_DMA2_RCFGCTL_DARMD1                   (*((volatile unsigned int*)(0x42A685CCUL)))
#define bM4_DMA2_RCFGCTL_CNTMD0                   (*((volatile unsigned int*)(0x42A685D0UL)))
#define bM4_DMA2_RCFGCTL_CNTMD1                   (*((volatile unsigned int*)(0x42A685D4UL)))
#define bM4_DMA2_DTCTL0_BLKSIZE0                  (*((volatile unsigned int*)(0x42A68900UL)))
#define bM4_DMA2_DTCTL0_BLKSIZE1                  (*((volatile unsigned int*)(0x42A68904UL)))
#define bM4_DMA2_DTCTL0_BLKSIZE2                  (*((volatile unsigned int*)(0x42A68908UL)))
#define bM4_DMA2_DTCTL0_BLKSIZE3                  (*((volatile unsigned int*)(0x42A6890CUL)))
#define bM4_DMA2_DTCTL0_BLKSIZE4                  (*((volatile unsigned int*)(0x42A68910UL)))
#define bM4_DMA2_DTCTL0_BLKSIZE5                  (*((volatile unsigned int*)(0x42A68914UL)))
#define bM4_DMA2_DTCTL0_BLKSIZE6                  (*((volatile unsigned int*)(0x42A68918UL)))
#define bM4_DMA2_DTCTL0_BLKSIZE7                  (*((volatile unsigned int*)(0x42A6891CUL)))
#define bM4_DMA2_DTCTL0_BLKSIZE8                  (*((volatile unsigned int*)(0x42A68920UL)))
#define bM4_DMA2_DTCTL0_BLKSIZE9                  (*((volatile unsigned int*)(0x42A68924UL)))
#define bM4_DMA2_DTCTL0_CNT0                      (*((volatile unsigned int*)(0x42A68940UL)))
#define bM4_DMA2_DTCTL0_CNT1                      (*((volatile unsigned int*)(0x42A68944UL)))
#define bM4_DMA2_DTCTL0_CNT2                      (*((volatile unsigned int*)(0x42A68948UL)))
#define bM4_DMA2_DTCTL0_CNT3                      (*((volatile unsigned int*)(0x42A6894CUL)))
#define bM4_DMA2_DTCTL0_CNT4                      (*((volatile unsigned int*)(0x42A68950UL)))
#define bM4_DMA2_DTCTL0_CNT5                      (*((volatile unsigned int*)(0x42A68954UL)))
#define bM4_DMA2_DTCTL0_CNT6                      (*((volatile unsigned int*)(0x42A68958UL)))
#define bM4_DMA2_DTCTL0_CNT7                      (*((volatile unsigned int*)(0x42A6895CUL)))
#define bM4_DMA2_DTCTL0_CNT8                      (*((volatile unsigned int*)(0x42A68960UL)))
#define bM4_DMA2_DTCTL0_CNT9                      (*((volatile unsigned int*)(0x42A68964UL)))
#define bM4_DMA2_DTCTL0_CNT10                     (*((volatile unsigned int*)(0x42A68968UL)))
#define bM4_DMA2_DTCTL0_CNT11                     (*((volatile unsigned int*)(0x42A6896CUL)))
#define bM4_DMA2_DTCTL0_CNT12                     (*((volatile unsigned int*)(0x42A68970UL)))
#define bM4_DMA2_DTCTL0_CNT13                     (*((volatile unsigned int*)(0x42A68974UL)))
#define bM4_DMA2_DTCTL0_CNT14                     (*((volatile unsigned int*)(0x42A68978UL)))
#define bM4_DMA2_DTCTL0_CNT15                     (*((volatile unsigned int*)(0x42A6897CUL)))
#define bM4_DMA2_RPT0_SRPT0                       (*((volatile unsigned int*)(0x42A68980UL)))
#define bM4_DMA2_RPT0_SRPT1                       (*((volatile unsigned int*)(0x42A68984UL)))
#define bM4_DMA2_RPT0_SRPT2                       (*((volatile unsigned int*)(0x42A68988UL)))
#define bM4_DMA2_RPT0_SRPT3                       (*((volatile unsigned int*)(0x42A6898CUL)))
#define bM4_DMA2_RPT0_SRPT4                       (*((volatile unsigned int*)(0x42A68990UL)))
#define bM4_DMA2_RPT0_SRPT5                       (*((volatile unsigned int*)(0x42A68994UL)))
#define bM4_DMA2_RPT0_SRPT6                       (*((volatile unsigned int*)(0x42A68998UL)))
#define bM4_DMA2_RPT0_SRPT7                       (*((volatile unsigned int*)(0x42A6899CUL)))
#define bM4_DMA2_RPT0_SRPT8                       (*((volatile unsigned int*)(0x42A689A0UL)))
#define bM4_DMA2_RPT0_SRPT9                       (*((volatile unsigned int*)(0x42A689A4UL)))
#define bM4_DMA2_RPT0_DRPT0                       (*((volatile unsigned int*)(0x42A689C0UL)))
#define bM4_DMA2_RPT0_DRPT1                       (*((volatile unsigned int*)(0x42A689C4UL)))
#define bM4_DMA2_RPT0_DRPT2                       (*((volatile unsigned int*)(0x42A689C8UL)))
#define bM4_DMA2_RPT0_DRPT3                       (*((volatile unsigned int*)(0x42A689CCUL)))
#define bM4_DMA2_RPT0_DRPT4                       (*((volatile unsigned int*)(0x42A689D0UL)))
#define bM4_DMA2_RPT0_DRPT5                       (*((volatile unsigned int*)(0x42A689D4UL)))
#define bM4_DMA2_RPT0_DRPT6                       (*((volatile unsigned int*)(0x42A689D8UL)))
#define bM4_DMA2_RPT0_DRPT7                       (*((volatile unsigned int*)(0x42A689DCUL)))
#define bM4_DMA2_RPT0_DRPT8                       (*((volatile unsigned int*)(0x42A689E0UL)))
#define bM4_DMA2_RPT0_DRPT9                       (*((volatile unsigned int*)(0x42A689E4UL)))
#define bM4_DMA2_RPTB0_SRPTB0                     (*((volatile unsigned int*)(0x42A68980UL)))
#define bM4_DMA2_RPTB0_SRPTB1                     (*((volatile unsigned int*)(0x42A68984UL)))
#define bM4_DMA2_RPTB0_SRPTB2                     (*((volatile unsigned int*)(0x42A68988UL)))
#define bM4_DMA2_RPTB0_SRPTB3                     (*((volatile unsigned int*)(0x42A6898CUL)))
#define bM4_DMA2_RPTB0_SRPTB4                     (*((volatile unsigned int*)(0x42A68990UL)))
#define bM4_DMA2_RPTB0_SRPTB5                     (*((volatile unsigned int*)(0x42A68994UL)))
#define bM4_DMA2_RPTB0_SRPTB6                     (*((volatile unsigned int*)(0x42A68998UL)))
#define bM4_DMA2_RPTB0_SRPTB7                     (*((volatile unsigned int*)(0x42A6899CUL)))
#define bM4_DMA2_RPTB0_SRPTB8                     (*((volatile unsigned int*)(0x42A689A0UL)))
#define bM4_DMA2_RPTB0_SRPTB9                     (*((volatile unsigned int*)(0x42A689A4UL)))
#define bM4_DMA2_RPTB0_DRPTB0                     (*((volatile unsigned int*)(0x42A689C0UL)))
#define bM4_DMA2_RPTB0_DRPTB1                     (*((volatile unsigned int*)(0x42A689C4UL)))
#define bM4_DMA2_RPTB0_DRPTB2                     (*((volatile unsigned int*)(0x42A689C8UL)))
#define bM4_DMA2_RPTB0_DRPTB3                     (*((volatile unsigned int*)(0x42A689CCUL)))
#define bM4_DMA2_RPTB0_DRPTB4                     (*((volatile unsigned int*)(0x42A689D0UL)))
#define bM4_DMA2_RPTB0_DRPTB5                     (*((volatile unsigned int*)(0x42A689D4UL)))
#define bM4_DMA2_RPTB0_DRPTB6                     (*((volatile unsigned int*)(0x42A689D8UL)))
#define bM4_DMA2_RPTB0_DRPTB7                     (*((volatile unsigned int*)(0x42A689DCUL)))
#define bM4_DMA2_RPTB0_DRPTB8                     (*((volatile unsigned int*)(0x42A689E0UL)))
#define bM4_DMA2_RPTB0_DRPTB9                     (*((volatile unsigned int*)(0x42A689E4UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET0               (*((volatile unsigned int*)(0x42A68A00UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET1               (*((volatile unsigned int*)(0x42A68A04UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET2               (*((volatile unsigned int*)(0x42A68A08UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET3               (*((volatile unsigned int*)(0x42A68A0CUL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET4               (*((volatile unsigned int*)(0x42A68A10UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET5               (*((volatile unsigned int*)(0x42A68A14UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET6               (*((volatile unsigned int*)(0x42A68A18UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET7               (*((volatile unsigned int*)(0x42A68A1CUL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET8               (*((volatile unsigned int*)(0x42A68A20UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET9               (*((volatile unsigned int*)(0x42A68A24UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET10              (*((volatile unsigned int*)(0x42A68A28UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET11              (*((volatile unsigned int*)(0x42A68A2CUL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET12              (*((volatile unsigned int*)(0x42A68A30UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET13              (*((volatile unsigned int*)(0x42A68A34UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET14              (*((volatile unsigned int*)(0x42A68A38UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET15              (*((volatile unsigned int*)(0x42A68A3CUL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET16              (*((volatile unsigned int*)(0x42A68A40UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET17              (*((volatile unsigned int*)(0x42A68A44UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET18              (*((volatile unsigned int*)(0x42A68A48UL)))
#define bM4_DMA2_SNSEQCTL0_SOFFSET19              (*((volatile unsigned int*)(0x42A68A4CUL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT0                (*((volatile unsigned int*)(0x42A68A50UL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT1                (*((volatile unsigned int*)(0x42A68A54UL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT2                (*((volatile unsigned int*)(0x42A68A58UL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT3                (*((volatile unsigned int*)(0x42A68A5CUL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT4                (*((volatile unsigned int*)(0x42A68A60UL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT5                (*((volatile unsigned int*)(0x42A68A64UL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT6                (*((volatile unsigned int*)(0x42A68A68UL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT7                (*((volatile unsigned int*)(0x42A68A6CUL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT8                (*((volatile unsigned int*)(0x42A68A70UL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT9                (*((volatile unsigned int*)(0x42A68A74UL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT10               (*((volatile unsigned int*)(0x42A68A78UL)))
#define bM4_DMA2_SNSEQCTL0_SNSCNT11               (*((volatile unsigned int*)(0x42A68A7CUL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST0              (*((volatile unsigned int*)(0x42A68A00UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST1              (*((volatile unsigned int*)(0x42A68A04UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST2              (*((volatile unsigned int*)(0x42A68A08UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST3              (*((volatile unsigned int*)(0x42A68A0CUL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST4              (*((volatile unsigned int*)(0x42A68A10UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST5              (*((volatile unsigned int*)(0x42A68A14UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST6              (*((volatile unsigned int*)(0x42A68A18UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST7              (*((volatile unsigned int*)(0x42A68A1CUL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST8              (*((volatile unsigned int*)(0x42A68A20UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST9              (*((volatile unsigned int*)(0x42A68A24UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST10             (*((volatile unsigned int*)(0x42A68A28UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST11             (*((volatile unsigned int*)(0x42A68A2CUL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST12             (*((volatile unsigned int*)(0x42A68A30UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST13             (*((volatile unsigned int*)(0x42A68A34UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST14             (*((volatile unsigned int*)(0x42A68A38UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST15             (*((volatile unsigned int*)(0x42A68A3CUL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST16             (*((volatile unsigned int*)(0x42A68A40UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST17             (*((volatile unsigned int*)(0x42A68A44UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST18             (*((volatile unsigned int*)(0x42A68A48UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSDIST19             (*((volatile unsigned int*)(0x42A68A4CUL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB0              (*((volatile unsigned int*)(0x42A68A50UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB1              (*((volatile unsigned int*)(0x42A68A54UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB2              (*((volatile unsigned int*)(0x42A68A58UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB3              (*((volatile unsigned int*)(0x42A68A5CUL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB4              (*((volatile unsigned int*)(0x42A68A60UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB5              (*((volatile unsigned int*)(0x42A68A64UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB6              (*((volatile unsigned int*)(0x42A68A68UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB7              (*((volatile unsigned int*)(0x42A68A6CUL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB8              (*((volatile unsigned int*)(0x42A68A70UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB9              (*((volatile unsigned int*)(0x42A68A74UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB10             (*((volatile unsigned int*)(0x42A68A78UL)))
#define bM4_DMA2_SNSEQCTLB0_SNSCNTB11             (*((volatile unsigned int*)(0x42A68A7CUL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET0               (*((volatile unsigned int*)(0x42A68A80UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET1               (*((volatile unsigned int*)(0x42A68A84UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET2               (*((volatile unsigned int*)(0x42A68A88UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET3               (*((volatile unsigned int*)(0x42A68A8CUL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET4               (*((volatile unsigned int*)(0x42A68A90UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET5               (*((volatile unsigned int*)(0x42A68A94UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET6               (*((volatile unsigned int*)(0x42A68A98UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET7               (*((volatile unsigned int*)(0x42A68A9CUL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET8               (*((volatile unsigned int*)(0x42A68AA0UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET9               (*((volatile unsigned int*)(0x42A68AA4UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET10              (*((volatile unsigned int*)(0x42A68AA8UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET11              (*((volatile unsigned int*)(0x42A68AACUL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET12              (*((volatile unsigned int*)(0x42A68AB0UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET13              (*((volatile unsigned int*)(0x42A68AB4UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET14              (*((volatile unsigned int*)(0x42A68AB8UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET15              (*((volatile unsigned int*)(0x42A68ABCUL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET16              (*((volatile unsigned int*)(0x42A68AC0UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET17              (*((volatile unsigned int*)(0x42A68AC4UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET18              (*((volatile unsigned int*)(0x42A68AC8UL)))
#define bM4_DMA2_DNSEQCTL0_DOFFSET19              (*((volatile unsigned int*)(0x42A68ACCUL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT0                (*((volatile unsigned int*)(0x42A68AD0UL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT1                (*((volatile unsigned int*)(0x42A68AD4UL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT2                (*((volatile unsigned int*)(0x42A68AD8UL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT3                (*((volatile unsigned int*)(0x42A68ADCUL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT4                (*((volatile unsigned int*)(0x42A68AE0UL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT5                (*((volatile unsigned int*)(0x42A68AE4UL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT6                (*((volatile unsigned int*)(0x42A68AE8UL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT7                (*((volatile unsigned int*)(0x42A68AECUL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT8                (*((volatile unsigned int*)(0x42A68AF0UL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT9                (*((volatile unsigned int*)(0x42A68AF4UL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT10               (*((volatile unsigned int*)(0x42A68AF8UL)))
#define bM4_DMA2_DNSEQCTL0_DNSCNT11               (*((volatile unsigned int*)(0x42A68AFCUL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST0              (*((volatile unsigned int*)(0x42A68A80UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST1              (*((volatile unsigned int*)(0x42A68A84UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST2              (*((volatile unsigned int*)(0x42A68A88UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST3              (*((volatile unsigned int*)(0x42A68A8CUL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST4              (*((volatile unsigned int*)(0x42A68A90UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST5              (*((volatile unsigned int*)(0x42A68A94UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST6              (*((volatile unsigned int*)(0x42A68A98UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST7              (*((volatile unsigned int*)(0x42A68A9CUL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST8              (*((volatile unsigned int*)(0x42A68AA0UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST9              (*((volatile unsigned int*)(0x42A68AA4UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST10             (*((volatile unsigned int*)(0x42A68AA8UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST11             (*((volatile unsigned int*)(0x42A68AACUL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST12             (*((volatile unsigned int*)(0x42A68AB0UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST13             (*((volatile unsigned int*)(0x42A68AB4UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST14             (*((volatile unsigned int*)(0x42A68AB8UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST15             (*((volatile unsigned int*)(0x42A68ABCUL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST16             (*((volatile unsigned int*)(0x42A68AC0UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST17             (*((volatile unsigned int*)(0x42A68AC4UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST18             (*((volatile unsigned int*)(0x42A68AC8UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSDIST19             (*((volatile unsigned int*)(0x42A68ACCUL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB0              (*((volatile unsigned int*)(0x42A68AD0UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB1              (*((volatile unsigned int*)(0x42A68AD4UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB2              (*((volatile unsigned int*)(0x42A68AD8UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB3              (*((volatile unsigned int*)(0x42A68ADCUL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB4              (*((volatile unsigned int*)(0x42A68AE0UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB5              (*((volatile unsigned int*)(0x42A68AE4UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB6              (*((volatile unsigned int*)(0x42A68AE8UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB7              (*((volatile unsigned int*)(0x42A68AECUL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB8              (*((volatile unsigned int*)(0x42A68AF0UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB9              (*((volatile unsigned int*)(0x42A68AF4UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB10             (*((volatile unsigned int*)(0x42A68AF8UL)))
#define bM4_DMA2_DNSEQCTLB0_DNSCNTB11             (*((volatile unsigned int*)(0x42A68AFCUL)))
#define bM4_DMA2_LLP0_LLP0                        (*((volatile unsigned int*)(0x42A68B08UL)))
#define bM4_DMA2_LLP0_LLP1                        (*((volatile unsigned int*)(0x42A68B0CUL)))
#define bM4_DMA2_LLP0_LLP2                        (*((volatile unsigned int*)(0x42A68B10UL)))
#define bM4_DMA2_LLP0_LLP3                        (*((volatile unsigned int*)(0x42A68B14UL)))
#define bM4_DMA2_LLP0_LLP4                        (*((volatile unsigned int*)(0x42A68B18UL)))
#define bM4_DMA2_LLP0_LLP5                        (*((volatile unsigned int*)(0x42A68B1CUL)))
#define bM4_DMA2_LLP0_LLP6                        (*((volatile unsigned int*)(0x42A68B20UL)))
#define bM4_DMA2_LLP0_LLP7                        (*((volatile unsigned int*)(0x42A68B24UL)))
#define bM4_DMA2_LLP0_LLP8                        (*((volatile unsigned int*)(0x42A68B28UL)))
#define bM4_DMA2_LLP0_LLP9                        (*((volatile unsigned int*)(0x42A68B2CUL)))
#define bM4_DMA2_LLP0_LLP10                       (*((volatile unsigned int*)(0x42A68B30UL)))
#define bM4_DMA2_LLP0_LLP11                       (*((volatile unsigned int*)(0x42A68B34UL)))
#define bM4_DMA2_LLP0_LLP12                       (*((volatile unsigned int*)(0x42A68B38UL)))
#define bM4_DMA2_LLP0_LLP13                       (*((volatile unsigned int*)(0x42A68B3CUL)))
#define bM4_DMA2_LLP0_LLP14                       (*((volatile unsigned int*)(0x42A68B40UL)))
#define bM4_DMA2_LLP0_LLP15                       (*((volatile unsigned int*)(0x42A68B44UL)))
#define bM4_DMA2_LLP0_LLP16                       (*((volatile unsigned int*)(0x42A68B48UL)))
#define bM4_DMA2_LLP0_LLP17                       (*((volatile unsigned int*)(0x42A68B4CUL)))
#define bM4_DMA2_LLP0_LLP18                       (*((volatile unsigned int*)(0x42A68B50UL)))
#define bM4_DMA2_LLP0_LLP19                       (*((volatile unsigned int*)(0x42A68B54UL)))
#define bM4_DMA2_LLP0_LLP20                       (*((volatile unsigned int*)(0x42A68B58UL)))
#define bM4_DMA2_LLP0_LLP21                       (*((volatile unsigned int*)(0x42A68B5CUL)))
#define bM4_DMA2_LLP0_LLP22                       (*((volatile unsigned int*)(0x42A68B60UL)))
#define bM4_DMA2_LLP0_LLP23                       (*((volatile unsigned int*)(0x42A68B64UL)))
#define bM4_DMA2_LLP0_LLP24                       (*((volatile unsigned int*)(0x42A68B68UL)))
#define bM4_DMA2_LLP0_LLP25                       (*((volatile unsigned int*)(0x42A68B6CUL)))
#define bM4_DMA2_LLP0_LLP26                       (*((volatile unsigned int*)(0x42A68B70UL)))
#define bM4_DMA2_LLP0_LLP27                       (*((volatile unsigned int*)(0x42A68B74UL)))
#define bM4_DMA2_LLP0_LLP28                       (*((volatile unsigned int*)(0x42A68B78UL)))
#define bM4_DMA2_LLP0_LLP29                       (*((volatile unsigned int*)(0x42A68B7CUL)))
#define bM4_DMA2_CHCTL0_SINC0                     (*((volatile unsigned int*)(0x42A68B80UL)))
#define bM4_DMA2_CHCTL0_SINC1                     (*((volatile unsigned int*)(0x42A68B84UL)))
#define bM4_DMA2_CHCTL0_DINC0                     (*((volatile unsigned int*)(0x42A68B88UL)))
#define bM4_DMA2_CHCTL0_DINC1                     (*((volatile unsigned int*)(0x42A68B8CUL)))
#define bM4_DMA2_CHCTL0_SRPTEN                    (*((volatile unsigned int*)(0x42A68B90UL)))
#define bM4_DMA2_CHCTL0_DRPTEN                    (*((volatile unsigned int*)(0x42A68B94UL)))
#define bM4_DMA2_CHCTL0_SNSEQEN                   (*((volatile unsigned int*)(0x42A68B98UL)))
#define bM4_DMA2_CHCTL0_DNSEQEN                   (*((volatile unsigned int*)(0x42A68B9CUL)))
#define bM4_DMA2_CHCTL0_HSIZE0                    (*((volatile unsigned int*)(0x42A68BA0UL)))
#define bM4_DMA2_CHCTL0_HSIZE1                    (*((volatile unsigned int*)(0x42A68BA4UL)))
#define bM4_DMA2_CHCTL0_LLPEN                     (*((volatile unsigned int*)(0x42A68BA8UL)))
#define bM4_DMA2_CHCTL0_LLPRUN                    (*((volatile unsigned int*)(0x42A68BACUL)))
#define bM4_DMA2_CHCTL0_IE                        (*((volatile unsigned int*)(0x42A68BB0UL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE0               (*((volatile unsigned int*)(0x42A68D00UL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE1               (*((volatile unsigned int*)(0x42A68D04UL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE2               (*((volatile unsigned int*)(0x42A68D08UL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE3               (*((volatile unsigned int*)(0x42A68D0CUL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE4               (*((volatile unsigned int*)(0x42A68D10UL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE5               (*((volatile unsigned int*)(0x42A68D14UL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE6               (*((volatile unsigned int*)(0x42A68D18UL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE7               (*((volatile unsigned int*)(0x42A68D1CUL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE8               (*((volatile unsigned int*)(0x42A68D20UL)))
#define bM4_DMA2_MONDTCTL0_BLKSIZE9               (*((volatile unsigned int*)(0x42A68D24UL)))
#define bM4_DMA2_MONDTCTL0_CNT0                   (*((volatile unsigned int*)(0x42A68D40UL)))
#define bM4_DMA2_MONDTCTL0_CNT1                   (*((volatile unsigned int*)(0x42A68D44UL)))
#define bM4_DMA2_MONDTCTL0_CNT2                   (*((volatile unsigned int*)(0x42A68D48UL)))
#define bM4_DMA2_MONDTCTL0_CNT3                   (*((volatile unsigned int*)(0x42A68D4CUL)))
#define bM4_DMA2_MONDTCTL0_CNT4                   (*((volatile unsigned int*)(0x42A68D50UL)))
#define bM4_DMA2_MONDTCTL0_CNT5                   (*((volatile unsigned int*)(0x42A68D54UL)))
#define bM4_DMA2_MONDTCTL0_CNT6                   (*((volatile unsigned int*)(0x42A68D58UL)))
#define bM4_DMA2_MONDTCTL0_CNT7                   (*((volatile unsigned int*)(0x42A68D5CUL)))
#define bM4_DMA2_MONDTCTL0_CNT8                   (*((volatile unsigned int*)(0x42A68D60UL)))
#define bM4_DMA2_MONDTCTL0_CNT9                   (*((volatile unsigned int*)(0x42A68D64UL)))
#define bM4_DMA2_MONDTCTL0_CNT10                  (*((volatile unsigned int*)(0x42A68D68UL)))
#define bM4_DMA2_MONDTCTL0_CNT11                  (*((volatile unsigned int*)(0x42A68D6CUL)))
#define bM4_DMA2_MONDTCTL0_CNT12                  (*((volatile unsigned int*)(0x42A68D70UL)))
#define bM4_DMA2_MONDTCTL0_CNT13                  (*((volatile unsigned int*)(0x42A68D74UL)))
#define bM4_DMA2_MONDTCTL0_CNT14                  (*((volatile unsigned int*)(0x42A68D78UL)))
#define bM4_DMA2_MONDTCTL0_CNT15                  (*((volatile unsigned int*)(0x42A68D7CUL)))
#define bM4_DMA2_MONRPT0_SRPT0                    (*((volatile unsigned int*)(0x42A68D80UL)))
#define bM4_DMA2_MONRPT0_SRPT1                    (*((volatile unsigned int*)(0x42A68D84UL)))
#define bM4_DMA2_MONRPT0_SRPT2                    (*((volatile unsigned int*)(0x42A68D88UL)))
#define bM4_DMA2_MONRPT0_SRPT3                    (*((volatile unsigned int*)(0x42A68D8CUL)))
#define bM4_DMA2_MONRPT0_SRPT4                    (*((volatile unsigned int*)(0x42A68D90UL)))
#define bM4_DMA2_MONRPT0_SRPT5                    (*((volatile unsigned int*)(0x42A68D94UL)))
#define bM4_DMA2_MONRPT0_SRPT6                    (*((volatile unsigned int*)(0x42A68D98UL)))
#define bM4_DMA2_MONRPT0_SRPT7                    (*((volatile unsigned int*)(0x42A68D9CUL)))
#define bM4_DMA2_MONRPT0_SRPT8                    (*((volatile unsigned int*)(0x42A68DA0UL)))
#define bM4_DMA2_MONRPT0_SRPT9                    (*((volatile unsigned int*)(0x42A68DA4UL)))
#define bM4_DMA2_MONRPT0_DRPT0                    (*((volatile unsigned int*)(0x42A68DC0UL)))
#define bM4_DMA2_MONRPT0_DRPT1                    (*((volatile unsigned int*)(0x42A68DC4UL)))
#define bM4_DMA2_MONRPT0_DRPT2                    (*((volatile unsigned int*)(0x42A68DC8UL)))
#define bM4_DMA2_MONRPT0_DRPT3                    (*((volatile unsigned int*)(0x42A68DCCUL)))
#define bM4_DMA2_MONRPT0_DRPT4                    (*((volatile unsigned int*)(0x42A68DD0UL)))
#define bM4_DMA2_MONRPT0_DRPT5                    (*((volatile unsigned int*)(0x42A68DD4UL)))
#define bM4_DMA2_MONRPT0_DRPT6                    (*((volatile unsigned int*)(0x42A68DD8UL)))
#define bM4_DMA2_MONRPT0_DRPT7                    (*((volatile unsigned int*)(0x42A68DDCUL)))
#define bM4_DMA2_MONRPT0_DRPT8                    (*((volatile unsigned int*)(0x42A68DE0UL)))
#define bM4_DMA2_MONRPT0_DRPT9                    (*((volatile unsigned int*)(0x42A68DE4UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET0            (*((volatile unsigned int*)(0x42A68E00UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET1            (*((volatile unsigned int*)(0x42A68E04UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET2            (*((volatile unsigned int*)(0x42A68E08UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET3            (*((volatile unsigned int*)(0x42A68E0CUL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET4            (*((volatile unsigned int*)(0x42A68E10UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET5            (*((volatile unsigned int*)(0x42A68E14UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET6            (*((volatile unsigned int*)(0x42A68E18UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET7            (*((volatile unsigned int*)(0x42A68E1CUL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET8            (*((volatile unsigned int*)(0x42A68E20UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET9            (*((volatile unsigned int*)(0x42A68E24UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET10           (*((volatile unsigned int*)(0x42A68E28UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET11           (*((volatile unsigned int*)(0x42A68E2CUL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET12           (*((volatile unsigned int*)(0x42A68E30UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET13           (*((volatile unsigned int*)(0x42A68E34UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET14           (*((volatile unsigned int*)(0x42A68E38UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET15           (*((volatile unsigned int*)(0x42A68E3CUL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET16           (*((volatile unsigned int*)(0x42A68E40UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET17           (*((volatile unsigned int*)(0x42A68E44UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET18           (*((volatile unsigned int*)(0x42A68E48UL)))
#define bM4_DMA2_MONSNSEQCTL0_SOFFSET19           (*((volatile unsigned int*)(0x42A68E4CUL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT0             (*((volatile unsigned int*)(0x42A68E50UL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT1             (*((volatile unsigned int*)(0x42A68E54UL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT2             (*((volatile unsigned int*)(0x42A68E58UL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT3             (*((volatile unsigned int*)(0x42A68E5CUL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT4             (*((volatile unsigned int*)(0x42A68E60UL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT5             (*((volatile unsigned int*)(0x42A68E64UL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT6             (*((volatile unsigned int*)(0x42A68E68UL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT7             (*((volatile unsigned int*)(0x42A68E6CUL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT8             (*((volatile unsigned int*)(0x42A68E70UL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT9             (*((volatile unsigned int*)(0x42A68E74UL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT10            (*((volatile unsigned int*)(0x42A68E78UL)))
#define bM4_DMA2_MONSNSEQCTL0_SNSCNT11            (*((volatile unsigned int*)(0x42A68E7CUL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET0            (*((volatile unsigned int*)(0x42A68E80UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET1            (*((volatile unsigned int*)(0x42A68E84UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET2            (*((volatile unsigned int*)(0x42A68E88UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET3            (*((volatile unsigned int*)(0x42A68E8CUL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET4            (*((volatile unsigned int*)(0x42A68E90UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET5            (*((volatile unsigned int*)(0x42A68E94UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET6            (*((volatile unsigned int*)(0x42A68E98UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET7            (*((volatile unsigned int*)(0x42A68E9CUL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET8            (*((volatile unsigned int*)(0x42A68EA0UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET9            (*((volatile unsigned int*)(0x42A68EA4UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET10           (*((volatile unsigned int*)(0x42A68EA8UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET11           (*((volatile unsigned int*)(0x42A68EACUL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET12           (*((volatile unsigned int*)(0x42A68EB0UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET13           (*((volatile unsigned int*)(0x42A68EB4UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET14           (*((volatile unsigned int*)(0x42A68EB8UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET15           (*((volatile unsigned int*)(0x42A68EBCUL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET16           (*((volatile unsigned int*)(0x42A68EC0UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET17           (*((volatile unsigned int*)(0x42A68EC4UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET18           (*((volatile unsigned int*)(0x42A68EC8UL)))
#define bM4_DMA2_MONDNSEQCTL0_DOFFSET19           (*((volatile unsigned int*)(0x42A68ECCUL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT0             (*((volatile unsigned int*)(0x42A68ED0UL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT1             (*((volatile unsigned int*)(0x42A68ED4UL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT2             (*((volatile unsigned int*)(0x42A68ED8UL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT3             (*((volatile unsigned int*)(0x42A68EDCUL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT4             (*((volatile unsigned int*)(0x42A68EE0UL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT5             (*((volatile unsigned int*)(0x42A68EE4UL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT6             (*((volatile unsigned int*)(0x42A68EE8UL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT7             (*((volatile unsigned int*)(0x42A68EECUL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT8             (*((volatile unsigned int*)(0x42A68EF0UL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT9             (*((volatile unsigned int*)(0x42A68EF4UL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT10            (*((volatile unsigned int*)(0x42A68EF8UL)))
#define bM4_DMA2_MONDNSEQCTL0_DNSCNT11            (*((volatile unsigned int*)(0x42A68EFCUL)))
#define bM4_DMA2_DTCTL1_BLKSIZE0                  (*((volatile unsigned int*)(0x42A69100UL)))
#define bM4_DMA2_DTCTL1_BLKSIZE1                  (*((volatile unsigned int*)(0x42A69104UL)))
#define bM4_DMA2_DTCTL1_BLKSIZE2                  (*((volatile unsigned int*)(0x42A69108UL)))
#define bM4_DMA2_DTCTL1_BLKSIZE3                  (*((volatile unsigned int*)(0x42A6910CUL)))
#define bM4_DMA2_DTCTL1_BLKSIZE4                  (*((volatile unsigned int*)(0x42A69110UL)))
#define bM4_DMA2_DTCTL1_BLKSIZE5                  (*((volatile unsigned int*)(0x42A69114UL)))
#define bM4_DMA2_DTCTL1_BLKSIZE6                  (*((volatile unsigned int*)(0x42A69118UL)))
#define bM4_DMA2_DTCTL1_BLKSIZE7                  (*((volatile unsigned int*)(0x42A6911CUL)))
#define bM4_DMA2_DTCTL1_BLKSIZE8                  (*((volatile unsigned int*)(0x42A69120UL)))
#define bM4_DMA2_DTCTL1_BLKSIZE9                  (*((volatile unsigned int*)(0x42A69124UL)))
#define bM4_DMA2_DTCTL1_CNT0                      (*((volatile unsigned int*)(0x42A69140UL)))
#define bM4_DMA2_DTCTL1_CNT1                      (*((volatile unsigned int*)(0x42A69144UL)))
#define bM4_DMA2_DTCTL1_CNT2                      (*((volatile unsigned int*)(0x42A69148UL)))
#define bM4_DMA2_DTCTL1_CNT3                      (*((volatile unsigned int*)(0x42A6914CUL)))
#define bM4_DMA2_DTCTL1_CNT4                      (*((volatile unsigned int*)(0x42A69150UL)))
#define bM4_DMA2_DTCTL1_CNT5                      (*((volatile unsigned int*)(0x42A69154UL)))
#define bM4_DMA2_DTCTL1_CNT6                      (*((volatile unsigned int*)(0x42A69158UL)))
#define bM4_DMA2_DTCTL1_CNT7                      (*((volatile unsigned int*)(0x42A6915CUL)))
#define bM4_DMA2_DTCTL1_CNT8                      (*((volatile unsigned int*)(0x42A69160UL)))
#define bM4_DMA2_DTCTL1_CNT9                      (*((volatile unsigned int*)(0x42A69164UL)))
#define bM4_DMA2_DTCTL1_CNT10                     (*((volatile unsigned int*)(0x42A69168UL)))
#define bM4_DMA2_DTCTL1_CNT11                     (*((volatile unsigned int*)(0x42A6916CUL)))
#define bM4_DMA2_DTCTL1_CNT12                     (*((volatile unsigned int*)(0x42A69170UL)))
#define bM4_DMA2_DTCTL1_CNT13                     (*((volatile unsigned int*)(0x42A69174UL)))
#define bM4_DMA2_DTCTL1_CNT14                     (*((volatile unsigned int*)(0x42A69178UL)))
#define bM4_DMA2_DTCTL1_CNT15                     (*((volatile unsigned int*)(0x42A6917CUL)))
#define bM4_DMA2_RPT1_SRPT0                       (*((volatile unsigned int*)(0x42A69180UL)))
#define bM4_DMA2_RPT1_SRPT1                       (*((volatile unsigned int*)(0x42A69184UL)))
#define bM4_DMA2_RPT1_SRPT2                       (*((volatile unsigned int*)(0x42A69188UL)))
#define bM4_DMA2_RPT1_SRPT3                       (*((volatile unsigned int*)(0x42A6918CUL)))
#define bM4_DMA2_RPT1_SRPT4                       (*((volatile unsigned int*)(0x42A69190UL)))
#define bM4_DMA2_RPT1_SRPT5                       (*((volatile unsigned int*)(0x42A69194UL)))
#define bM4_DMA2_RPT1_SRPT6                       (*((volatile unsigned int*)(0x42A69198UL)))
#define bM4_DMA2_RPT1_SRPT7                       (*((volatile unsigned int*)(0x42A6919CUL)))
#define bM4_DMA2_RPT1_SRPT8                       (*((volatile unsigned int*)(0x42A691A0UL)))
#define bM4_DMA2_RPT1_SRPT9                       (*((volatile unsigned int*)(0x42A691A4UL)))
#define bM4_DMA2_RPT1_DRPT0                       (*((volatile unsigned int*)(0x42A691C0UL)))
#define bM4_DMA2_RPT1_DRPT1                       (*((volatile unsigned int*)(0x42A691C4UL)))
#define bM4_DMA2_RPT1_DRPT2                       (*((volatile unsigned int*)(0x42A691C8UL)))
#define bM4_DMA2_RPT1_DRPT3                       (*((volatile unsigned int*)(0x42A691CCUL)))
#define bM4_DMA2_RPT1_DRPT4                       (*((volatile unsigned int*)(0x42A691D0UL)))
#define bM4_DMA2_RPT1_DRPT5                       (*((volatile unsigned int*)(0x42A691D4UL)))
#define bM4_DMA2_RPT1_DRPT6                       (*((volatile unsigned int*)(0x42A691D8UL)))
#define bM4_DMA2_RPT1_DRPT7                       (*((volatile unsigned int*)(0x42A691DCUL)))
#define bM4_DMA2_RPT1_DRPT8                       (*((volatile unsigned int*)(0x42A691E0UL)))
#define bM4_DMA2_RPT1_DRPT9                       (*((volatile unsigned int*)(0x42A691E4UL)))
#define bM4_DMA2_RPTB1_SRPTB0                     (*((volatile unsigned int*)(0x42A69180UL)))
#define bM4_DMA2_RPTB1_SRPTB1                     (*((volatile unsigned int*)(0x42A69184UL)))
#define bM4_DMA2_RPTB1_SRPTB2                     (*((volatile unsigned int*)(0x42A69188UL)))
#define bM4_DMA2_RPTB1_SRPTB3                     (*((volatile unsigned int*)(0x42A6918CUL)))
#define bM4_DMA2_RPTB1_SRPTB4                     (*((volatile unsigned int*)(0x42A69190UL)))
#define bM4_DMA2_RPTB1_SRPTB5                     (*((volatile unsigned int*)(0x42A69194UL)))
#define bM4_DMA2_RPTB1_SRPTB6                     (*((volatile unsigned int*)(0x42A69198UL)))
#define bM4_DMA2_RPTB1_SRPTB7                     (*((volatile unsigned int*)(0x42A6919CUL)))
#define bM4_DMA2_RPTB1_SRPTB8                     (*((volatile unsigned int*)(0x42A691A0UL)))
#define bM4_DMA2_RPTB1_SRPTB9                     (*((volatile unsigned int*)(0x42A691A4UL)))
#define bM4_DMA2_RPTB1_DRPTB0                     (*((volatile unsigned int*)(0x42A691C0UL)))
#define bM4_DMA2_RPTB1_DRPTB1                     (*((volatile unsigned int*)(0x42A691C4UL)))
#define bM4_DMA2_RPTB1_DRPTB2                     (*((volatile unsigned int*)(0x42A691C8UL)))
#define bM4_DMA2_RPTB1_DRPTB3                     (*((volatile unsigned int*)(0x42A691CCUL)))
#define bM4_DMA2_RPTB1_DRPTB4                     (*((volatile unsigned int*)(0x42A691D0UL)))
#define bM4_DMA2_RPTB1_DRPTB5                     (*((volatile unsigned int*)(0x42A691D4UL)))
#define bM4_DMA2_RPTB1_DRPTB6                     (*((volatile unsigned int*)(0x42A691D8UL)))
#define bM4_DMA2_RPTB1_DRPTB7                     (*((volatile unsigned int*)(0x42A691DCUL)))
#define bM4_DMA2_RPTB1_DRPTB8                     (*((volatile unsigned int*)(0x42A691E0UL)))
#define bM4_DMA2_RPTB1_DRPTB9                     (*((volatile unsigned int*)(0x42A691E4UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET0               (*((volatile unsigned int*)(0x42A69200UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET1               (*((volatile unsigned int*)(0x42A69204UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET2               (*((volatile unsigned int*)(0x42A69208UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET3               (*((volatile unsigned int*)(0x42A6920CUL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET4               (*((volatile unsigned int*)(0x42A69210UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET5               (*((volatile unsigned int*)(0x42A69214UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET6               (*((volatile unsigned int*)(0x42A69218UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET7               (*((volatile unsigned int*)(0x42A6921CUL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET8               (*((volatile unsigned int*)(0x42A69220UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET9               (*((volatile unsigned int*)(0x42A69224UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET10              (*((volatile unsigned int*)(0x42A69228UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET11              (*((volatile unsigned int*)(0x42A6922CUL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET12              (*((volatile unsigned int*)(0x42A69230UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET13              (*((volatile unsigned int*)(0x42A69234UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET14              (*((volatile unsigned int*)(0x42A69238UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET15              (*((volatile unsigned int*)(0x42A6923CUL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET16              (*((volatile unsigned int*)(0x42A69240UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET17              (*((volatile unsigned int*)(0x42A69244UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET18              (*((volatile unsigned int*)(0x42A69248UL)))
#define bM4_DMA2_SNSEQCTL1_SOFFSET19              (*((volatile unsigned int*)(0x42A6924CUL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT0                (*((volatile unsigned int*)(0x42A69250UL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT1                (*((volatile unsigned int*)(0x42A69254UL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT2                (*((volatile unsigned int*)(0x42A69258UL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT3                (*((volatile unsigned int*)(0x42A6925CUL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT4                (*((volatile unsigned int*)(0x42A69260UL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT5                (*((volatile unsigned int*)(0x42A69264UL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT6                (*((volatile unsigned int*)(0x42A69268UL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT7                (*((volatile unsigned int*)(0x42A6926CUL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT8                (*((volatile unsigned int*)(0x42A69270UL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT9                (*((volatile unsigned int*)(0x42A69274UL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT10               (*((volatile unsigned int*)(0x42A69278UL)))
#define bM4_DMA2_SNSEQCTL1_SNSCNT11               (*((volatile unsigned int*)(0x42A6927CUL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST0              (*((volatile unsigned int*)(0x42A69200UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST1              (*((volatile unsigned int*)(0x42A69204UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST2              (*((volatile unsigned int*)(0x42A69208UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST3              (*((volatile unsigned int*)(0x42A6920CUL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST4              (*((volatile unsigned int*)(0x42A69210UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST5              (*((volatile unsigned int*)(0x42A69214UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST6              (*((volatile unsigned int*)(0x42A69218UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST7              (*((volatile unsigned int*)(0x42A6921CUL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST8              (*((volatile unsigned int*)(0x42A69220UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST9              (*((volatile unsigned int*)(0x42A69224UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST10             (*((volatile unsigned int*)(0x42A69228UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST11             (*((volatile unsigned int*)(0x42A6922CUL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST12             (*((volatile unsigned int*)(0x42A69230UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST13             (*((volatile unsigned int*)(0x42A69234UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST14             (*((volatile unsigned int*)(0x42A69238UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST15             (*((volatile unsigned int*)(0x42A6923CUL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST16             (*((volatile unsigned int*)(0x42A69240UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST17             (*((volatile unsigned int*)(0x42A69244UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST18             (*((volatile unsigned int*)(0x42A69248UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSDIST19             (*((volatile unsigned int*)(0x42A6924CUL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB0              (*((volatile unsigned int*)(0x42A69250UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB1              (*((volatile unsigned int*)(0x42A69254UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB2              (*((volatile unsigned int*)(0x42A69258UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB3              (*((volatile unsigned int*)(0x42A6925CUL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB4              (*((volatile unsigned int*)(0x42A69260UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB5              (*((volatile unsigned int*)(0x42A69264UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB6              (*((volatile unsigned int*)(0x42A69268UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB7              (*((volatile unsigned int*)(0x42A6926CUL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB8              (*((volatile unsigned int*)(0x42A69270UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB9              (*((volatile unsigned int*)(0x42A69274UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB10             (*((volatile unsigned int*)(0x42A69278UL)))
#define bM4_DMA2_SNSEQCTLB1_SNSCNTB11             (*((volatile unsigned int*)(0x42A6927CUL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET0               (*((volatile unsigned int*)(0x42A69280UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET1               (*((volatile unsigned int*)(0x42A69284UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET2               (*((volatile unsigned int*)(0x42A69288UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET3               (*((volatile unsigned int*)(0x42A6928CUL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET4               (*((volatile unsigned int*)(0x42A69290UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET5               (*((volatile unsigned int*)(0x42A69294UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET6               (*((volatile unsigned int*)(0x42A69298UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET7               (*((volatile unsigned int*)(0x42A6929CUL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET8               (*((volatile unsigned int*)(0x42A692A0UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET9               (*((volatile unsigned int*)(0x42A692A4UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET10              (*((volatile unsigned int*)(0x42A692A8UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET11              (*((volatile unsigned int*)(0x42A692ACUL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET12              (*((volatile unsigned int*)(0x42A692B0UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET13              (*((volatile unsigned int*)(0x42A692B4UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET14              (*((volatile unsigned int*)(0x42A692B8UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET15              (*((volatile unsigned int*)(0x42A692BCUL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET16              (*((volatile unsigned int*)(0x42A692C0UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET17              (*((volatile unsigned int*)(0x42A692C4UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET18              (*((volatile unsigned int*)(0x42A692C8UL)))
#define bM4_DMA2_DNSEQCTL1_DOFFSET19              (*((volatile unsigned int*)(0x42A692CCUL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT0                (*((volatile unsigned int*)(0x42A692D0UL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT1                (*((volatile unsigned int*)(0x42A692D4UL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT2                (*((volatile unsigned int*)(0x42A692D8UL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT3                (*((volatile unsigned int*)(0x42A692DCUL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT4                (*((volatile unsigned int*)(0x42A692E0UL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT5                (*((volatile unsigned int*)(0x42A692E4UL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT6                (*((volatile unsigned int*)(0x42A692E8UL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT7                (*((volatile unsigned int*)(0x42A692ECUL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT8                (*((volatile unsigned int*)(0x42A692F0UL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT9                (*((volatile unsigned int*)(0x42A692F4UL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT10               (*((volatile unsigned int*)(0x42A692F8UL)))
#define bM4_DMA2_DNSEQCTL1_DNSCNT11               (*((volatile unsigned int*)(0x42A692FCUL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST0              (*((volatile unsigned int*)(0x42A69280UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST1              (*((volatile unsigned int*)(0x42A69284UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST2              (*((volatile unsigned int*)(0x42A69288UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST3              (*((volatile unsigned int*)(0x42A6928CUL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST4              (*((volatile unsigned int*)(0x42A69290UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST5              (*((volatile unsigned int*)(0x42A69294UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST6              (*((volatile unsigned int*)(0x42A69298UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST7              (*((volatile unsigned int*)(0x42A6929CUL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST8              (*((volatile unsigned int*)(0x42A692A0UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST9              (*((volatile unsigned int*)(0x42A692A4UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST10             (*((volatile unsigned int*)(0x42A692A8UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST11             (*((volatile unsigned int*)(0x42A692ACUL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST12             (*((volatile unsigned int*)(0x42A692B0UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST13             (*((volatile unsigned int*)(0x42A692B4UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST14             (*((volatile unsigned int*)(0x42A692B8UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST15             (*((volatile unsigned int*)(0x42A692BCUL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST16             (*((volatile unsigned int*)(0x42A692C0UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST17             (*((volatile unsigned int*)(0x42A692C4UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST18             (*((volatile unsigned int*)(0x42A692C8UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSDIST19             (*((volatile unsigned int*)(0x42A692CCUL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB0              (*((volatile unsigned int*)(0x42A692D0UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB1              (*((volatile unsigned int*)(0x42A692D4UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB2              (*((volatile unsigned int*)(0x42A692D8UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB3              (*((volatile unsigned int*)(0x42A692DCUL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB4              (*((volatile unsigned int*)(0x42A692E0UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB5              (*((volatile unsigned int*)(0x42A692E4UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB6              (*((volatile unsigned int*)(0x42A692E8UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB7              (*((volatile unsigned int*)(0x42A692ECUL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB8              (*((volatile unsigned int*)(0x42A692F0UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB9              (*((volatile unsigned int*)(0x42A692F4UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB10             (*((volatile unsigned int*)(0x42A692F8UL)))
#define bM4_DMA2_DNSEQCTLB1_DNSCNTB11             (*((volatile unsigned int*)(0x42A692FCUL)))
#define bM4_DMA2_LLP1_LLP0                        (*((volatile unsigned int*)(0x42A69308UL)))
#define bM4_DMA2_LLP1_LLP1                        (*((volatile unsigned int*)(0x42A6930CUL)))
#define bM4_DMA2_LLP1_LLP2                        (*((volatile unsigned int*)(0x42A69310UL)))
#define bM4_DMA2_LLP1_LLP3                        (*((volatile unsigned int*)(0x42A69314UL)))
#define bM4_DMA2_LLP1_LLP4                        (*((volatile unsigned int*)(0x42A69318UL)))
#define bM4_DMA2_LLP1_LLP5                        (*((volatile unsigned int*)(0x42A6931CUL)))
#define bM4_DMA2_LLP1_LLP6                        (*((volatile unsigned int*)(0x42A69320UL)))
#define bM4_DMA2_LLP1_LLP7                        (*((volatile unsigned int*)(0x42A69324UL)))
#define bM4_DMA2_LLP1_LLP8                        (*((volatile unsigned int*)(0x42A69328UL)))
#define bM4_DMA2_LLP1_LLP9                        (*((volatile unsigned int*)(0x42A6932CUL)))
#define bM4_DMA2_LLP1_LLP10                       (*((volatile unsigned int*)(0x42A69330UL)))
#define bM4_DMA2_LLP1_LLP11                       (*((volatile unsigned int*)(0x42A69334UL)))
#define bM4_DMA2_LLP1_LLP12                       (*((volatile unsigned int*)(0x42A69338UL)))
#define bM4_DMA2_LLP1_LLP13                       (*((volatile unsigned int*)(0x42A6933CUL)))
#define bM4_DMA2_LLP1_LLP14                       (*((volatile unsigned int*)(0x42A69340UL)))
#define bM4_DMA2_LLP1_LLP15                       (*((volatile unsigned int*)(0x42A69344UL)))
#define bM4_DMA2_LLP1_LLP16                       (*((volatile unsigned int*)(0x42A69348UL)))
#define bM4_DMA2_LLP1_LLP17                       (*((volatile unsigned int*)(0x42A6934CUL)))
#define bM4_DMA2_LLP1_LLP18                       (*((volatile unsigned int*)(0x42A69350UL)))
#define bM4_DMA2_LLP1_LLP19                       (*((volatile unsigned int*)(0x42A69354UL)))
#define bM4_DMA2_LLP1_LLP20                       (*((volatile unsigned int*)(0x42A69358UL)))
#define bM4_DMA2_LLP1_LLP21                       (*((volatile unsigned int*)(0x42A6935CUL)))
#define bM4_DMA2_LLP1_LLP22                       (*((volatile unsigned int*)(0x42A69360UL)))
#define bM4_DMA2_LLP1_LLP23                       (*((volatile unsigned int*)(0x42A69364UL)))
#define bM4_DMA2_LLP1_LLP24                       (*((volatile unsigned int*)(0x42A69368UL)))
#define bM4_DMA2_LLP1_LLP25                       (*((volatile unsigned int*)(0x42A6936CUL)))
#define bM4_DMA2_LLP1_LLP26                       (*((volatile unsigned int*)(0x42A69370UL)))
#define bM4_DMA2_LLP1_LLP27                       (*((volatile unsigned int*)(0x42A69374UL)))
#define bM4_DMA2_LLP1_LLP28                       (*((volatile unsigned int*)(0x42A69378UL)))
#define bM4_DMA2_LLP1_LLP29                       (*((volatile unsigned int*)(0x42A6937CUL)))
#define bM4_DMA2_CHCTL1_SINC0                     (*((volatile unsigned int*)(0x42A69380UL)))
#define bM4_DMA2_CHCTL1_SINC1                     (*((volatile unsigned int*)(0x42A69384UL)))
#define bM4_DMA2_CHCTL1_DINC0                     (*((volatile unsigned int*)(0x42A69388UL)))
#define bM4_DMA2_CHCTL1_DINC1                     (*((volatile unsigned int*)(0x42A6938CUL)))
#define bM4_DMA2_CHCTL1_SRPTEN                    (*((volatile unsigned int*)(0x42A69390UL)))
#define bM4_DMA2_CHCTL1_DRPTEN                    (*((volatile unsigned int*)(0x42A69394UL)))
#define bM4_DMA2_CHCTL1_SNSEQEN                   (*((volatile unsigned int*)(0x42A69398UL)))
#define bM4_DMA2_CHCTL1_DNSEQEN                   (*((volatile unsigned int*)(0x42A6939CUL)))
#define bM4_DMA2_CHCTL1_HSIZE0                    (*((volatile unsigned int*)(0x42A693A0UL)))
#define bM4_DMA2_CHCTL1_HSIZE1                    (*((volatile unsigned int*)(0x42A693A4UL)))
#define bM4_DMA2_CHCTL1_LLPEN                     (*((volatile unsigned int*)(0x42A693A8UL)))
#define bM4_DMA2_CHCTL1_LLPRUN                    (*((volatile unsigned int*)(0x42A693ACUL)))
#define bM4_DMA2_CHCTL1_IE                        (*((volatile unsigned int*)(0x42A693B0UL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE0               (*((volatile unsigned int*)(0x42A69500UL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE1               (*((volatile unsigned int*)(0x42A69504UL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE2               (*((volatile unsigned int*)(0x42A69508UL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE3               (*((volatile unsigned int*)(0x42A6950CUL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE4               (*((volatile unsigned int*)(0x42A69510UL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE5               (*((volatile unsigned int*)(0x42A69514UL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE6               (*((volatile unsigned int*)(0x42A69518UL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE7               (*((volatile unsigned int*)(0x42A6951CUL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE8               (*((volatile unsigned int*)(0x42A69520UL)))
#define bM4_DMA2_MONDTCTL1_BLKSIZE9               (*((volatile unsigned int*)(0x42A69524UL)))
#define bM4_DMA2_MONDTCTL1_CNT0                   (*((volatile unsigned int*)(0x42A69540UL)))
#define bM4_DMA2_MONDTCTL1_CNT1                   (*((volatile unsigned int*)(0x42A69544UL)))
#define bM4_DMA2_MONDTCTL1_CNT2                   (*((volatile unsigned int*)(0x42A69548UL)))
#define bM4_DMA2_MONDTCTL1_CNT3                   (*((volatile unsigned int*)(0x42A6954CUL)))
#define bM4_DMA2_MONDTCTL1_CNT4                   (*((volatile unsigned int*)(0x42A69550UL)))
#define bM4_DMA2_MONDTCTL1_CNT5                   (*((volatile unsigned int*)(0x42A69554UL)))
#define bM4_DMA2_MONDTCTL1_CNT6                   (*((volatile unsigned int*)(0x42A69558UL)))
#define bM4_DMA2_MONDTCTL1_CNT7                   (*((volatile unsigned int*)(0x42A6955CUL)))
#define bM4_DMA2_MONDTCTL1_CNT8                   (*((volatile unsigned int*)(0x42A69560UL)))
#define bM4_DMA2_MONDTCTL1_CNT9                   (*((volatile unsigned int*)(0x42A69564UL)))
#define bM4_DMA2_MONDTCTL1_CNT10                  (*((volatile unsigned int*)(0x42A69568UL)))
#define bM4_DMA2_MONDTCTL1_CNT11                  (*((volatile unsigned int*)(0x42A6956CUL)))
#define bM4_DMA2_MONDTCTL1_CNT12                  (*((volatile unsigned int*)(0x42A69570UL)))
#define bM4_DMA2_MONDTCTL1_CNT13                  (*((volatile unsigned int*)(0x42A69574UL)))
#define bM4_DMA2_MONDTCTL1_CNT14                  (*((volatile unsigned int*)(0x42A69578UL)))
#define bM4_DMA2_MONDTCTL1_CNT15                  (*((volatile unsigned int*)(0x42A6957CUL)))
#define bM4_DMA2_MONRPT1_SRPT0                    (*((volatile unsigned int*)(0x42A69580UL)))
#define bM4_DMA2_MONRPT1_SRPT1                    (*((volatile unsigned int*)(0x42A69584UL)))
#define bM4_DMA2_MONRPT1_SRPT2                    (*((volatile unsigned int*)(0x42A69588UL)))
#define bM4_DMA2_MONRPT1_SRPT3                    (*((volatile unsigned int*)(0x42A6958CUL)))
#define bM4_DMA2_MONRPT1_SRPT4                    (*((volatile unsigned int*)(0x42A69590UL)))
#define bM4_DMA2_MONRPT1_SRPT5                    (*((volatile unsigned int*)(0x42A69594UL)))
#define bM4_DMA2_MONRPT1_SRPT6                    (*((volatile unsigned int*)(0x42A69598UL)))
#define bM4_DMA2_MONRPT1_SRPT7                    (*((volatile unsigned int*)(0x42A6959CUL)))
#define bM4_DMA2_MONRPT1_SRPT8                    (*((volatile unsigned int*)(0x42A695A0UL)))
#define bM4_DMA2_MONRPT1_SRPT9                    (*((volatile unsigned int*)(0x42A695A4UL)))
#define bM4_DMA2_MONRPT1_DRPT0                    (*((volatile unsigned int*)(0x42A695C0UL)))
#define bM4_DMA2_MONRPT1_DRPT1                    (*((volatile unsigned int*)(0x42A695C4UL)))
#define bM4_DMA2_MONRPT1_DRPT2                    (*((volatile unsigned int*)(0x42A695C8UL)))
#define bM4_DMA2_MONRPT1_DRPT3                    (*((volatile unsigned int*)(0x42A695CCUL)))
#define bM4_DMA2_MONRPT1_DRPT4                    (*((volatile unsigned int*)(0x42A695D0UL)))
#define bM4_DMA2_MONRPT1_DRPT5                    (*((volatile unsigned int*)(0x42A695D4UL)))
#define bM4_DMA2_MONRPT1_DRPT6                    (*((volatile unsigned int*)(0x42A695D8UL)))
#define bM4_DMA2_MONRPT1_DRPT7                    (*((volatile unsigned int*)(0x42A695DCUL)))
#define bM4_DMA2_MONRPT1_DRPT8                    (*((volatile unsigned int*)(0x42A695E0UL)))
#define bM4_DMA2_MONRPT1_DRPT9                    (*((volatile unsigned int*)(0x42A695E4UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET0            (*((volatile unsigned int*)(0x42A69600UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET1            (*((volatile unsigned int*)(0x42A69604UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET2            (*((volatile unsigned int*)(0x42A69608UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET3            (*((volatile unsigned int*)(0x42A6960CUL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET4            (*((volatile unsigned int*)(0x42A69610UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET5            (*((volatile unsigned int*)(0x42A69614UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET6            (*((volatile unsigned int*)(0x42A69618UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET7            (*((volatile unsigned int*)(0x42A6961CUL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET8            (*((volatile unsigned int*)(0x42A69620UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET9            (*((volatile unsigned int*)(0x42A69624UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET10           (*((volatile unsigned int*)(0x42A69628UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET11           (*((volatile unsigned int*)(0x42A6962CUL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET12           (*((volatile unsigned int*)(0x42A69630UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET13           (*((volatile unsigned int*)(0x42A69634UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET14           (*((volatile unsigned int*)(0x42A69638UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET15           (*((volatile unsigned int*)(0x42A6963CUL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET16           (*((volatile unsigned int*)(0x42A69640UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET17           (*((volatile unsigned int*)(0x42A69644UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET18           (*((volatile unsigned int*)(0x42A69648UL)))
#define bM4_DMA2_MONSNSEQCTL1_SOFFSET19           (*((volatile unsigned int*)(0x42A6964CUL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT0             (*((volatile unsigned int*)(0x42A69650UL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT1             (*((volatile unsigned int*)(0x42A69654UL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT2             (*((volatile unsigned int*)(0x42A69658UL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT3             (*((volatile unsigned int*)(0x42A6965CUL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT4             (*((volatile unsigned int*)(0x42A69660UL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT5             (*((volatile unsigned int*)(0x42A69664UL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT6             (*((volatile unsigned int*)(0x42A69668UL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT7             (*((volatile unsigned int*)(0x42A6966CUL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT8             (*((volatile unsigned int*)(0x42A69670UL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT9             (*((volatile unsigned int*)(0x42A69674UL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT10            (*((volatile unsigned int*)(0x42A69678UL)))
#define bM4_DMA2_MONSNSEQCTL1_SNSCNT11            (*((volatile unsigned int*)(0x42A6967CUL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET0            (*((volatile unsigned int*)(0x42A69680UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET1            (*((volatile unsigned int*)(0x42A69684UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET2            (*((volatile unsigned int*)(0x42A69688UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET3            (*((volatile unsigned int*)(0x42A6968CUL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET4            (*((volatile unsigned int*)(0x42A69690UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET5            (*((volatile unsigned int*)(0x42A69694UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET6            (*((volatile unsigned int*)(0x42A69698UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET7            (*((volatile unsigned int*)(0x42A6969CUL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET8            (*((volatile unsigned int*)(0x42A696A0UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET9            (*((volatile unsigned int*)(0x42A696A4UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET10           (*((volatile unsigned int*)(0x42A696A8UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET11           (*((volatile unsigned int*)(0x42A696ACUL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET12           (*((volatile unsigned int*)(0x42A696B0UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET13           (*((volatile unsigned int*)(0x42A696B4UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET14           (*((volatile unsigned int*)(0x42A696B8UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET15           (*((volatile unsigned int*)(0x42A696BCUL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET16           (*((volatile unsigned int*)(0x42A696C0UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET17           (*((volatile unsigned int*)(0x42A696C4UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET18           (*((volatile unsigned int*)(0x42A696C8UL)))
#define bM4_DMA2_MONDNSEQCTL1_DOFFSET19           (*((volatile unsigned int*)(0x42A696CCUL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT0             (*((volatile unsigned int*)(0x42A696D0UL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT1             (*((volatile unsigned int*)(0x42A696D4UL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT2             (*((volatile unsigned int*)(0x42A696D8UL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT3             (*((volatile unsigned int*)(0x42A696DCUL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT4             (*((volatile unsigned int*)(0x42A696E0UL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT5             (*((volatile unsigned int*)(0x42A696E4UL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT6             (*((volatile unsigned int*)(0x42A696E8UL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT7             (*((volatile unsigned int*)(0x42A696ECUL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT8             (*((volatile unsigned int*)(0x42A696F0UL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT9             (*((volatile unsigned int*)(0x42A696F4UL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT10            (*((volatile unsigned int*)(0x42A696F8UL)))
#define bM4_DMA2_MONDNSEQCTL1_DNSCNT11            (*((volatile unsigned int*)(0x42A696FCUL)))
#define bM4_DMA2_DTCTL2_BLKSIZE0                  (*((volatile unsigned int*)(0x42A69900UL)))
#define bM4_DMA2_DTCTL2_BLKSIZE1                  (*((volatile unsigned int*)(0x42A69904UL)))
#define bM4_DMA2_DTCTL2_BLKSIZE2                  (*((volatile unsigned int*)(0x42A69908UL)))
#define bM4_DMA2_DTCTL2_BLKSIZE3                  (*((volatile unsigned int*)(0x42A6990CUL)))
#define bM4_DMA2_DTCTL2_BLKSIZE4                  (*((volatile unsigned int*)(0x42A69910UL)))
#define bM4_DMA2_DTCTL2_BLKSIZE5                  (*((volatile unsigned int*)(0x42A69914UL)))
#define bM4_DMA2_DTCTL2_BLKSIZE6                  (*((volatile unsigned int*)(0x42A69918UL)))
#define bM4_DMA2_DTCTL2_BLKSIZE7                  (*((volatile unsigned int*)(0x42A6991CUL)))
#define bM4_DMA2_DTCTL2_BLKSIZE8                  (*((volatile unsigned int*)(0x42A69920UL)))
#define bM4_DMA2_DTCTL2_BLKSIZE9                  (*((volatile unsigned int*)(0x42A69924UL)))
#define bM4_DMA2_DTCTL2_CNT0                      (*((volatile unsigned int*)(0x42A69940UL)))
#define bM4_DMA2_DTCTL2_CNT1                      (*((volatile unsigned int*)(0x42A69944UL)))
#define bM4_DMA2_DTCTL2_CNT2                      (*((volatile unsigned int*)(0x42A69948UL)))
#define bM4_DMA2_DTCTL2_CNT3                      (*((volatile unsigned int*)(0x42A6994CUL)))
#define bM4_DMA2_DTCTL2_CNT4                      (*((volatile unsigned int*)(0x42A69950UL)))
#define bM4_DMA2_DTCTL2_CNT5                      (*((volatile unsigned int*)(0x42A69954UL)))
#define bM4_DMA2_DTCTL2_CNT6                      (*((volatile unsigned int*)(0x42A69958UL)))
#define bM4_DMA2_DTCTL2_CNT7                      (*((volatile unsigned int*)(0x42A6995CUL)))
#define bM4_DMA2_DTCTL2_CNT8                      (*((volatile unsigned int*)(0x42A69960UL)))
#define bM4_DMA2_DTCTL2_CNT9                      (*((volatile unsigned int*)(0x42A69964UL)))
#define bM4_DMA2_DTCTL2_CNT10                     (*((volatile unsigned int*)(0x42A69968UL)))
#define bM4_DMA2_DTCTL2_CNT11                     (*((volatile unsigned int*)(0x42A6996CUL)))
#define bM4_DMA2_DTCTL2_CNT12                     (*((volatile unsigned int*)(0x42A69970UL)))
#define bM4_DMA2_DTCTL2_CNT13                     (*((volatile unsigned int*)(0x42A69974UL)))
#define bM4_DMA2_DTCTL2_CNT14                     (*((volatile unsigned int*)(0x42A69978UL)))
#define bM4_DMA2_DTCTL2_CNT15                     (*((volatile unsigned int*)(0x42A6997CUL)))
#define bM4_DMA2_RPT2_SRPT0                       (*((volatile unsigned int*)(0x42A69980UL)))
#define bM4_DMA2_RPT2_SRPT1                       (*((volatile unsigned int*)(0x42A69984UL)))
#define bM4_DMA2_RPT2_SRPT2                       (*((volatile unsigned int*)(0x42A69988UL)))
#define bM4_DMA2_RPT2_SRPT3                       (*((volatile unsigned int*)(0x42A6998CUL)))
#define bM4_DMA2_RPT2_SRPT4                       (*((volatile unsigned int*)(0x42A69990UL)))
#define bM4_DMA2_RPT2_SRPT5                       (*((volatile unsigned int*)(0x42A69994UL)))
#define bM4_DMA2_RPT2_SRPT6                       (*((volatile unsigned int*)(0x42A69998UL)))
#define bM4_DMA2_RPT2_SRPT7                       (*((volatile unsigned int*)(0x42A6999CUL)))
#define bM4_DMA2_RPT2_SRPT8                       (*((volatile unsigned int*)(0x42A699A0UL)))
#define bM4_DMA2_RPT2_SRPT9                       (*((volatile unsigned int*)(0x42A699A4UL)))
#define bM4_DMA2_RPT2_DRPT0                       (*((volatile unsigned int*)(0x42A699C0UL)))
#define bM4_DMA2_RPT2_DRPT1                       (*((volatile unsigned int*)(0x42A699C4UL)))
#define bM4_DMA2_RPT2_DRPT2                       (*((volatile unsigned int*)(0x42A699C8UL)))
#define bM4_DMA2_RPT2_DRPT3                       (*((volatile unsigned int*)(0x42A699CCUL)))
#define bM4_DMA2_RPT2_DRPT4                       (*((volatile unsigned int*)(0x42A699D0UL)))
#define bM4_DMA2_RPT2_DRPT5                       (*((volatile unsigned int*)(0x42A699D4UL)))
#define bM4_DMA2_RPT2_DRPT6                       (*((volatile unsigned int*)(0x42A699D8UL)))
#define bM4_DMA2_RPT2_DRPT7                       (*((volatile unsigned int*)(0x42A699DCUL)))
#define bM4_DMA2_RPT2_DRPT8                       (*((volatile unsigned int*)(0x42A699E0UL)))
#define bM4_DMA2_RPT2_DRPT9                       (*((volatile unsigned int*)(0x42A699E4UL)))
#define bM4_DMA2_RPTB2_SRPTB0                     (*((volatile unsigned int*)(0x42A69980UL)))
#define bM4_DMA2_RPTB2_SRPTB1                     (*((volatile unsigned int*)(0x42A69984UL)))
#define bM4_DMA2_RPTB2_SRPTB2                     (*((volatile unsigned int*)(0x42A69988UL)))
#define bM4_DMA2_RPTB2_SRPTB3                     (*((volatile unsigned int*)(0x42A6998CUL)))
#define bM4_DMA2_RPTB2_SRPTB4                     (*((volatile unsigned int*)(0x42A69990UL)))
#define bM4_DMA2_RPTB2_SRPTB5                     (*((volatile unsigned int*)(0x42A69994UL)))
#define bM4_DMA2_RPTB2_SRPTB6                     (*((volatile unsigned int*)(0x42A69998UL)))
#define bM4_DMA2_RPTB2_SRPTB7                     (*((volatile unsigned int*)(0x42A6999CUL)))
#define bM4_DMA2_RPTB2_SRPTB8                     (*((volatile unsigned int*)(0x42A699A0UL)))
#define bM4_DMA2_RPTB2_SRPTB9                     (*((volatile unsigned int*)(0x42A699A4UL)))
#define bM4_DMA2_RPTB2_DRPTB0                     (*((volatile unsigned int*)(0x42A699C0UL)))
#define bM4_DMA2_RPTB2_DRPTB1                     (*((volatile unsigned int*)(0x42A699C4UL)))
#define bM4_DMA2_RPTB2_DRPTB2                     (*((volatile unsigned int*)(0x42A699C8UL)))
#define bM4_DMA2_RPTB2_DRPTB3                     (*((volatile unsigned int*)(0x42A699CCUL)))
#define bM4_DMA2_RPTB2_DRPTB4                     (*((volatile unsigned int*)(0x42A699D0UL)))
#define bM4_DMA2_RPTB2_DRPTB5                     (*((volatile unsigned int*)(0x42A699D4UL)))
#define bM4_DMA2_RPTB2_DRPTB6                     (*((volatile unsigned int*)(0x42A699D8UL)))
#define bM4_DMA2_RPTB2_DRPTB7                     (*((volatile unsigned int*)(0x42A699DCUL)))
#define bM4_DMA2_RPTB2_DRPTB8                     (*((volatile unsigned int*)(0x42A699E0UL)))
#define bM4_DMA2_RPTB2_DRPTB9                     (*((volatile unsigned int*)(0x42A699E4UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET0               (*((volatile unsigned int*)(0x42A69A00UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET1               (*((volatile unsigned int*)(0x42A69A04UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET2               (*((volatile unsigned int*)(0x42A69A08UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET3               (*((volatile unsigned int*)(0x42A69A0CUL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET4               (*((volatile unsigned int*)(0x42A69A10UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET5               (*((volatile unsigned int*)(0x42A69A14UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET6               (*((volatile unsigned int*)(0x42A69A18UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET7               (*((volatile unsigned int*)(0x42A69A1CUL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET8               (*((volatile unsigned int*)(0x42A69A20UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET9               (*((volatile unsigned int*)(0x42A69A24UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET10              (*((volatile unsigned int*)(0x42A69A28UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET11              (*((volatile unsigned int*)(0x42A69A2CUL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET12              (*((volatile unsigned int*)(0x42A69A30UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET13              (*((volatile unsigned int*)(0x42A69A34UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET14              (*((volatile unsigned int*)(0x42A69A38UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET15              (*((volatile unsigned int*)(0x42A69A3CUL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET16              (*((volatile unsigned int*)(0x42A69A40UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET17              (*((volatile unsigned int*)(0x42A69A44UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET18              (*((volatile unsigned int*)(0x42A69A48UL)))
#define bM4_DMA2_SNSEQCTL2_SOFFSET19              (*((volatile unsigned int*)(0x42A69A4CUL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT0                (*((volatile unsigned int*)(0x42A69A50UL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT1                (*((volatile unsigned int*)(0x42A69A54UL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT2                (*((volatile unsigned int*)(0x42A69A58UL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT3                (*((volatile unsigned int*)(0x42A69A5CUL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT4                (*((volatile unsigned int*)(0x42A69A60UL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT5                (*((volatile unsigned int*)(0x42A69A64UL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT6                (*((volatile unsigned int*)(0x42A69A68UL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT7                (*((volatile unsigned int*)(0x42A69A6CUL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT8                (*((volatile unsigned int*)(0x42A69A70UL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT9                (*((volatile unsigned int*)(0x42A69A74UL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT10               (*((volatile unsigned int*)(0x42A69A78UL)))
#define bM4_DMA2_SNSEQCTL2_SNSCNT11               (*((volatile unsigned int*)(0x42A69A7CUL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST0              (*((volatile unsigned int*)(0x42A69A00UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST1              (*((volatile unsigned int*)(0x42A69A04UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST2              (*((volatile unsigned int*)(0x42A69A08UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST3              (*((volatile unsigned int*)(0x42A69A0CUL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST4              (*((volatile unsigned int*)(0x42A69A10UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST5              (*((volatile unsigned int*)(0x42A69A14UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST6              (*((volatile unsigned int*)(0x42A69A18UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST7              (*((volatile unsigned int*)(0x42A69A1CUL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST8              (*((volatile unsigned int*)(0x42A69A20UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST9              (*((volatile unsigned int*)(0x42A69A24UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST10             (*((volatile unsigned int*)(0x42A69A28UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST11             (*((volatile unsigned int*)(0x42A69A2CUL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST12             (*((volatile unsigned int*)(0x42A69A30UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST13             (*((volatile unsigned int*)(0x42A69A34UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST14             (*((volatile unsigned int*)(0x42A69A38UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST15             (*((volatile unsigned int*)(0x42A69A3CUL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST16             (*((volatile unsigned int*)(0x42A69A40UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST17             (*((volatile unsigned int*)(0x42A69A44UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST18             (*((volatile unsigned int*)(0x42A69A48UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSDIST19             (*((volatile unsigned int*)(0x42A69A4CUL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB0              (*((volatile unsigned int*)(0x42A69A50UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB1              (*((volatile unsigned int*)(0x42A69A54UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB2              (*((volatile unsigned int*)(0x42A69A58UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB3              (*((volatile unsigned int*)(0x42A69A5CUL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB4              (*((volatile unsigned int*)(0x42A69A60UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB5              (*((volatile unsigned int*)(0x42A69A64UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB6              (*((volatile unsigned int*)(0x42A69A68UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB7              (*((volatile unsigned int*)(0x42A69A6CUL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB8              (*((volatile unsigned int*)(0x42A69A70UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB9              (*((volatile unsigned int*)(0x42A69A74UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB10             (*((volatile unsigned int*)(0x42A69A78UL)))
#define bM4_DMA2_SNSEQCTLB2_SNSCNTB11             (*((volatile unsigned int*)(0x42A69A7CUL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET0               (*((volatile unsigned int*)(0x42A69A80UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET1               (*((volatile unsigned int*)(0x42A69A84UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET2               (*((volatile unsigned int*)(0x42A69A88UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET3               (*((volatile unsigned int*)(0x42A69A8CUL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET4               (*((volatile unsigned int*)(0x42A69A90UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET5               (*((volatile unsigned int*)(0x42A69A94UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET6               (*((volatile unsigned int*)(0x42A69A98UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET7               (*((volatile unsigned int*)(0x42A69A9CUL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET8               (*((volatile unsigned int*)(0x42A69AA0UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET9               (*((volatile unsigned int*)(0x42A69AA4UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET10              (*((volatile unsigned int*)(0x42A69AA8UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET11              (*((volatile unsigned int*)(0x42A69AACUL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET12              (*((volatile unsigned int*)(0x42A69AB0UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET13              (*((volatile unsigned int*)(0x42A69AB4UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET14              (*((volatile unsigned int*)(0x42A69AB8UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET15              (*((volatile unsigned int*)(0x42A69ABCUL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET16              (*((volatile unsigned int*)(0x42A69AC0UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET17              (*((volatile unsigned int*)(0x42A69AC4UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET18              (*((volatile unsigned int*)(0x42A69AC8UL)))
#define bM4_DMA2_DNSEQCTL2_DOFFSET19              (*((volatile unsigned int*)(0x42A69ACCUL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT0                (*((volatile unsigned int*)(0x42A69AD0UL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT1                (*((volatile unsigned int*)(0x42A69AD4UL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT2                (*((volatile unsigned int*)(0x42A69AD8UL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT3                (*((volatile unsigned int*)(0x42A69ADCUL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT4                (*((volatile unsigned int*)(0x42A69AE0UL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT5                (*((volatile unsigned int*)(0x42A69AE4UL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT6                (*((volatile unsigned int*)(0x42A69AE8UL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT7                (*((volatile unsigned int*)(0x42A69AECUL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT8                (*((volatile unsigned int*)(0x42A69AF0UL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT9                (*((volatile unsigned int*)(0x42A69AF4UL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT10               (*((volatile unsigned int*)(0x42A69AF8UL)))
#define bM4_DMA2_DNSEQCTL2_DNSCNT11               (*((volatile unsigned int*)(0x42A69AFCUL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST0              (*((volatile unsigned int*)(0x42A69A80UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST1              (*((volatile unsigned int*)(0x42A69A84UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST2              (*((volatile unsigned int*)(0x42A69A88UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST3              (*((volatile unsigned int*)(0x42A69A8CUL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST4              (*((volatile unsigned int*)(0x42A69A90UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST5              (*((volatile unsigned int*)(0x42A69A94UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST6              (*((volatile unsigned int*)(0x42A69A98UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST7              (*((volatile unsigned int*)(0x42A69A9CUL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST8              (*((volatile unsigned int*)(0x42A69AA0UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST9              (*((volatile unsigned int*)(0x42A69AA4UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST10             (*((volatile unsigned int*)(0x42A69AA8UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST11             (*((volatile unsigned int*)(0x42A69AACUL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST12             (*((volatile unsigned int*)(0x42A69AB0UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST13             (*((volatile unsigned int*)(0x42A69AB4UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST14             (*((volatile unsigned int*)(0x42A69AB8UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST15             (*((volatile unsigned int*)(0x42A69ABCUL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST16             (*((volatile unsigned int*)(0x42A69AC0UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST17             (*((volatile unsigned int*)(0x42A69AC4UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST18             (*((volatile unsigned int*)(0x42A69AC8UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSDIST19             (*((volatile unsigned int*)(0x42A69ACCUL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB0              (*((volatile unsigned int*)(0x42A69AD0UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB1              (*((volatile unsigned int*)(0x42A69AD4UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB2              (*((volatile unsigned int*)(0x42A69AD8UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB3              (*((volatile unsigned int*)(0x42A69ADCUL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB4              (*((volatile unsigned int*)(0x42A69AE0UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB5              (*((volatile unsigned int*)(0x42A69AE4UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB6              (*((volatile unsigned int*)(0x42A69AE8UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB7              (*((volatile unsigned int*)(0x42A69AECUL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB8              (*((volatile unsigned int*)(0x42A69AF0UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB9              (*((volatile unsigned int*)(0x42A69AF4UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB10             (*((volatile unsigned int*)(0x42A69AF8UL)))
#define bM4_DMA2_DNSEQCTLB2_DNSCNTB11             (*((volatile unsigned int*)(0x42A69AFCUL)))
#define bM4_DMA2_LLP2_LLP0                        (*((volatile unsigned int*)(0x42A69B08UL)))
#define bM4_DMA2_LLP2_LLP1                        (*((volatile unsigned int*)(0x42A69B0CUL)))
#define bM4_DMA2_LLP2_LLP2                        (*((volatile unsigned int*)(0x42A69B10UL)))
#define bM4_DMA2_LLP2_LLP3                        (*((volatile unsigned int*)(0x42A69B14UL)))
#define bM4_DMA2_LLP2_LLP4                        (*((volatile unsigned int*)(0x42A69B18UL)))
#define bM4_DMA2_LLP2_LLP5                        (*((volatile unsigned int*)(0x42A69B1CUL)))
#define bM4_DMA2_LLP2_LLP6                        (*((volatile unsigned int*)(0x42A69B20UL)))
#define bM4_DMA2_LLP2_LLP7                        (*((volatile unsigned int*)(0x42A69B24UL)))
#define bM4_DMA2_LLP2_LLP8                        (*((volatile unsigned int*)(0x42A69B28UL)))
#define bM4_DMA2_LLP2_LLP9                        (*((volatile unsigned int*)(0x42A69B2CUL)))
#define bM4_DMA2_LLP2_LLP10                       (*((volatile unsigned int*)(0x42A69B30UL)))
#define bM4_DMA2_LLP2_LLP11                       (*((volatile unsigned int*)(0x42A69B34UL)))
#define bM4_DMA2_LLP2_LLP12                       (*((volatile unsigned int*)(0x42A69B38UL)))
#define bM4_DMA2_LLP2_LLP13                       (*((volatile unsigned int*)(0x42A69B3CUL)))
#define bM4_DMA2_LLP2_LLP14                       (*((volatile unsigned int*)(0x42A69B40UL)))
#define bM4_DMA2_LLP2_LLP15                       (*((volatile unsigned int*)(0x42A69B44UL)))
#define bM4_DMA2_LLP2_LLP16                       (*((volatile unsigned int*)(0x42A69B48UL)))
#define bM4_DMA2_LLP2_LLP17                       (*((volatile unsigned int*)(0x42A69B4CUL)))
#define bM4_DMA2_LLP2_LLP18                       (*((volatile unsigned int*)(0x42A69B50UL)))
#define bM4_DMA2_LLP2_LLP19                       (*((volatile unsigned int*)(0x42A69B54UL)))
#define bM4_DMA2_LLP2_LLP20                       (*((volatile unsigned int*)(0x42A69B58UL)))
#define bM4_DMA2_LLP2_LLP21                       (*((volatile unsigned int*)(0x42A69B5CUL)))
#define bM4_DMA2_LLP2_LLP22                       (*((volatile unsigned int*)(0x42A69B60UL)))
#define bM4_DMA2_LLP2_LLP23                       (*((volatile unsigned int*)(0x42A69B64UL)))
#define bM4_DMA2_LLP2_LLP24                       (*((volatile unsigned int*)(0x42A69B68UL)))
#define bM4_DMA2_LLP2_LLP25                       (*((volatile unsigned int*)(0x42A69B6CUL)))
#define bM4_DMA2_LLP2_LLP26                       (*((volatile unsigned int*)(0x42A69B70UL)))
#define bM4_DMA2_LLP2_LLP27                       (*((volatile unsigned int*)(0x42A69B74UL)))
#define bM4_DMA2_LLP2_LLP28                       (*((volatile unsigned int*)(0x42A69B78UL)))
#define bM4_DMA2_LLP2_LLP29                       (*((volatile unsigned int*)(0x42A69B7CUL)))
#define bM4_DMA2_CHCTL2_SINC0                     (*((volatile unsigned int*)(0x42A69B80UL)))
#define bM4_DMA2_CHCTL2_SINC1                     (*((volatile unsigned int*)(0x42A69B84UL)))
#define bM4_DMA2_CHCTL2_DINC0                     (*((volatile unsigned int*)(0x42A69B88UL)))
#define bM4_DMA2_CHCTL2_DINC1                     (*((volatile unsigned int*)(0x42A69B8CUL)))
#define bM4_DMA2_CHCTL2_SRPTEN                    (*((volatile unsigned int*)(0x42A69B90UL)))
#define bM4_DMA2_CHCTL2_DRPTEN                    (*((volatile unsigned int*)(0x42A69B94UL)))
#define bM4_DMA2_CHCTL2_SNSEQEN                   (*((volatile unsigned int*)(0x42A69B98UL)))
#define bM4_DMA2_CHCTL2_DNSEQEN                   (*((volatile unsigned int*)(0x42A69B9CUL)))
#define bM4_DMA2_CHCTL2_HSIZE0                    (*((volatile unsigned int*)(0x42A69BA0UL)))
#define bM4_DMA2_CHCTL2_HSIZE1                    (*((volatile unsigned int*)(0x42A69BA4UL)))
#define bM4_DMA2_CHCTL2_LLPEN                     (*((volatile unsigned int*)(0x42A69BA8UL)))
#define bM4_DMA2_CHCTL2_LLPRUN                    (*((volatile unsigned int*)(0x42A69BACUL)))
#define bM4_DMA2_CHCTL2_IE                        (*((volatile unsigned int*)(0x42A69BB0UL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE0               (*((volatile unsigned int*)(0x42A69D00UL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE1               (*((volatile unsigned int*)(0x42A69D04UL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE2               (*((volatile unsigned int*)(0x42A69D08UL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE3               (*((volatile unsigned int*)(0x42A69D0CUL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE4               (*((volatile unsigned int*)(0x42A69D10UL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE5               (*((volatile unsigned int*)(0x42A69D14UL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE6               (*((volatile unsigned int*)(0x42A69D18UL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE7               (*((volatile unsigned int*)(0x42A69D1CUL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE8               (*((volatile unsigned int*)(0x42A69D20UL)))
#define bM4_DMA2_MONDTCTL2_BLKSIZE9               (*((volatile unsigned int*)(0x42A69D24UL)))
#define bM4_DMA2_MONDTCTL2_CNT0                   (*((volatile unsigned int*)(0x42A69D40UL)))
#define bM4_DMA2_MONDTCTL2_CNT1                   (*((volatile unsigned int*)(0x42A69D44UL)))
#define bM4_DMA2_MONDTCTL2_CNT2                   (*((volatile unsigned int*)(0x42A69D48UL)))
#define bM4_DMA2_MONDTCTL2_CNT3                   (*((volatile unsigned int*)(0x42A69D4CUL)))
#define bM4_DMA2_MONDTCTL2_CNT4                   (*((volatile unsigned int*)(0x42A69D50UL)))
#define bM4_DMA2_MONDTCTL2_CNT5                   (*((volatile unsigned int*)(0x42A69D54UL)))
#define bM4_DMA2_MONDTCTL2_CNT6                   (*((volatile unsigned int*)(0x42A69D58UL)))
#define bM4_DMA2_MONDTCTL2_CNT7                   (*((volatile unsigned int*)(0x42A69D5CUL)))
#define bM4_DMA2_MONDTCTL2_CNT8                   (*((volatile unsigned int*)(0x42A69D60UL)))
#define bM4_DMA2_MONDTCTL2_CNT9                   (*((volatile unsigned int*)(0x42A69D64UL)))
#define bM4_DMA2_MONDTCTL2_CNT10                  (*((volatile unsigned int*)(0x42A69D68UL)))
#define bM4_DMA2_MONDTCTL2_CNT11                  (*((volatile unsigned int*)(0x42A69D6CUL)))
#define bM4_DMA2_MONDTCTL2_CNT12                  (*((volatile unsigned int*)(0x42A69D70UL)))
#define bM4_DMA2_MONDTCTL2_CNT13                  (*((volatile unsigned int*)(0x42A69D74UL)))
#define bM4_DMA2_MONDTCTL2_CNT14                  (*((volatile unsigned int*)(0x42A69D78UL)))
#define bM4_DMA2_MONDTCTL2_CNT15                  (*((volatile unsigned int*)(0x42A69D7CUL)))
#define bM4_DMA2_MONRPT2_SRPT0                    (*((volatile unsigned int*)(0x42A69D80UL)))
#define bM4_DMA2_MONRPT2_SRPT1                    (*((volatile unsigned int*)(0x42A69D84UL)))
#define bM4_DMA2_MONRPT2_SRPT2                    (*((volatile unsigned int*)(0x42A69D88UL)))
#define bM4_DMA2_MONRPT2_SRPT3                    (*((volatile unsigned int*)(0x42A69D8CUL)))
#define bM4_DMA2_MONRPT2_SRPT4                    (*((volatile unsigned int*)(0x42A69D90UL)))
#define bM4_DMA2_MONRPT2_SRPT5                    (*((volatile unsigned int*)(0x42A69D94UL)))
#define bM4_DMA2_MONRPT2_SRPT6                    (*((volatile unsigned int*)(0x42A69D98UL)))
#define bM4_DMA2_MONRPT2_SRPT7                    (*((volatile unsigned int*)(0x42A69D9CUL)))
#define bM4_DMA2_MONRPT2_SRPT8                    (*((volatile unsigned int*)(0x42A69DA0UL)))
#define bM4_DMA2_MONRPT2_SRPT9                    (*((volatile unsigned int*)(0x42A69DA4UL)))
#define bM4_DMA2_MONRPT2_DRPT0                    (*((volatile unsigned int*)(0x42A69DC0UL)))
#define bM4_DMA2_MONRPT2_DRPT1                    (*((volatile unsigned int*)(0x42A69DC4UL)))
#define bM4_DMA2_MONRPT2_DRPT2                    (*((volatile unsigned int*)(0x42A69DC8UL)))
#define bM4_DMA2_MONRPT2_DRPT3                    (*((volatile unsigned int*)(0x42A69DCCUL)))
#define bM4_DMA2_MONRPT2_DRPT4                    (*((volatile unsigned int*)(0x42A69DD0UL)))
#define bM4_DMA2_MONRPT2_DRPT5                    (*((volatile unsigned int*)(0x42A69DD4UL)))
#define bM4_DMA2_MONRPT2_DRPT6                    (*((volatile unsigned int*)(0x42A69DD8UL)))
#define bM4_DMA2_MONRPT2_DRPT7                    (*((volatile unsigned int*)(0x42A69DDCUL)))
#define bM4_DMA2_MONRPT2_DRPT8                    (*((volatile unsigned int*)(0x42A69DE0UL)))
#define bM4_DMA2_MONRPT2_DRPT9                    (*((volatile unsigned int*)(0x42A69DE4UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET0            (*((volatile unsigned int*)(0x42A69E00UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET1            (*((volatile unsigned int*)(0x42A69E04UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET2            (*((volatile unsigned int*)(0x42A69E08UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET3            (*((volatile unsigned int*)(0x42A69E0CUL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET4            (*((volatile unsigned int*)(0x42A69E10UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET5            (*((volatile unsigned int*)(0x42A69E14UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET6            (*((volatile unsigned int*)(0x42A69E18UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET7            (*((volatile unsigned int*)(0x42A69E1CUL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET8            (*((volatile unsigned int*)(0x42A69E20UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET9            (*((volatile unsigned int*)(0x42A69E24UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET10           (*((volatile unsigned int*)(0x42A69E28UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET11           (*((volatile unsigned int*)(0x42A69E2CUL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET12           (*((volatile unsigned int*)(0x42A69E30UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET13           (*((volatile unsigned int*)(0x42A69E34UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET14           (*((volatile unsigned int*)(0x42A69E38UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET15           (*((volatile unsigned int*)(0x42A69E3CUL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET16           (*((volatile unsigned int*)(0x42A69E40UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET17           (*((volatile unsigned int*)(0x42A69E44UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET18           (*((volatile unsigned int*)(0x42A69E48UL)))
#define bM4_DMA2_MONSNSEQCTL2_SOFFSET19           (*((volatile unsigned int*)(0x42A69E4CUL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT0             (*((volatile unsigned int*)(0x42A69E50UL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT1             (*((volatile unsigned int*)(0x42A69E54UL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT2             (*((volatile unsigned int*)(0x42A69E58UL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT3             (*((volatile unsigned int*)(0x42A69E5CUL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT4             (*((volatile unsigned int*)(0x42A69E60UL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT5             (*((volatile unsigned int*)(0x42A69E64UL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT6             (*((volatile unsigned int*)(0x42A69E68UL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT7             (*((volatile unsigned int*)(0x42A69E6CUL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT8             (*((volatile unsigned int*)(0x42A69E70UL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT9             (*((volatile unsigned int*)(0x42A69E74UL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT10            (*((volatile unsigned int*)(0x42A69E78UL)))
#define bM4_DMA2_MONSNSEQCTL2_SNSCNT11            (*((volatile unsigned int*)(0x42A69E7CUL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET0            (*((volatile unsigned int*)(0x42A69E80UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET1            (*((volatile unsigned int*)(0x42A69E84UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET2            (*((volatile unsigned int*)(0x42A69E88UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET3            (*((volatile unsigned int*)(0x42A69E8CUL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET4            (*((volatile unsigned int*)(0x42A69E90UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET5            (*((volatile unsigned int*)(0x42A69E94UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET6            (*((volatile unsigned int*)(0x42A69E98UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET7            (*((volatile unsigned int*)(0x42A69E9CUL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET8            (*((volatile unsigned int*)(0x42A69EA0UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET9            (*((volatile unsigned int*)(0x42A69EA4UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET10           (*((volatile unsigned int*)(0x42A69EA8UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET11           (*((volatile unsigned int*)(0x42A69EACUL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET12           (*((volatile unsigned int*)(0x42A69EB0UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET13           (*((volatile unsigned int*)(0x42A69EB4UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET14           (*((volatile unsigned int*)(0x42A69EB8UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET15           (*((volatile unsigned int*)(0x42A69EBCUL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET16           (*((volatile unsigned int*)(0x42A69EC0UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET17           (*((volatile unsigned int*)(0x42A69EC4UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET18           (*((volatile unsigned int*)(0x42A69EC8UL)))
#define bM4_DMA2_MONDNSEQCTL2_DOFFSET19           (*((volatile unsigned int*)(0x42A69ECCUL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT0             (*((volatile unsigned int*)(0x42A69ED0UL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT1             (*((volatile unsigned int*)(0x42A69ED4UL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT2             (*((volatile unsigned int*)(0x42A69ED8UL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT3             (*((volatile unsigned int*)(0x42A69EDCUL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT4             (*((volatile unsigned int*)(0x42A69EE0UL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT5             (*((volatile unsigned int*)(0x42A69EE4UL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT6             (*((volatile unsigned int*)(0x42A69EE8UL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT7             (*((volatile unsigned int*)(0x42A69EECUL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT8             (*((volatile unsigned int*)(0x42A69EF0UL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT9             (*((volatile unsigned int*)(0x42A69EF4UL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT10            (*((volatile unsigned int*)(0x42A69EF8UL)))
#define bM4_DMA2_MONDNSEQCTL2_DNSCNT11            (*((volatile unsigned int*)(0x42A69EFCUL)))
#define bM4_DMA2_DTCTL3_BLKSIZE0                  (*((volatile unsigned int*)(0x42A6A100UL)))
#define bM4_DMA2_DTCTL3_BLKSIZE1                  (*((volatile unsigned int*)(0x42A6A104UL)))
#define bM4_DMA2_DTCTL3_BLKSIZE2                  (*((volatile unsigned int*)(0x42A6A108UL)))
#define bM4_DMA2_DTCTL3_BLKSIZE3                  (*((volatile unsigned int*)(0x42A6A10CUL)))
#define bM4_DMA2_DTCTL3_BLKSIZE4                  (*((volatile unsigned int*)(0x42A6A110UL)))
#define bM4_DMA2_DTCTL3_BLKSIZE5                  (*((volatile unsigned int*)(0x42A6A114UL)))
#define bM4_DMA2_DTCTL3_BLKSIZE6                  (*((volatile unsigned int*)(0x42A6A118UL)))
#define bM4_DMA2_DTCTL3_BLKSIZE7                  (*((volatile unsigned int*)(0x42A6A11CUL)))
#define bM4_DMA2_DTCTL3_BLKSIZE8                  (*((volatile unsigned int*)(0x42A6A120UL)))
#define bM4_DMA2_DTCTL3_BLKSIZE9                  (*((volatile unsigned int*)(0x42A6A124UL)))
#define bM4_DMA2_DTCTL3_CNT0                      (*((volatile unsigned int*)(0x42A6A140UL)))
#define bM4_DMA2_DTCTL3_CNT1                      (*((volatile unsigned int*)(0x42A6A144UL)))
#define bM4_DMA2_DTCTL3_CNT2                      (*((volatile unsigned int*)(0x42A6A148UL)))
#define bM4_DMA2_DTCTL3_CNT3                      (*((volatile unsigned int*)(0x42A6A14CUL)))
#define bM4_DMA2_DTCTL3_CNT4                      (*((volatile unsigned int*)(0x42A6A150UL)))
#define bM4_DMA2_DTCTL3_CNT5                      (*((volatile unsigned int*)(0x42A6A154UL)))
#define bM4_DMA2_DTCTL3_CNT6                      (*((volatile unsigned int*)(0x42A6A158UL)))
#define bM4_DMA2_DTCTL3_CNT7                      (*((volatile unsigned int*)(0x42A6A15CUL)))
#define bM4_DMA2_DTCTL3_CNT8                      (*((volatile unsigned int*)(0x42A6A160UL)))
#define bM4_DMA2_DTCTL3_CNT9                      (*((volatile unsigned int*)(0x42A6A164UL)))
#define bM4_DMA2_DTCTL3_CNT10                     (*((volatile unsigned int*)(0x42A6A168UL)))
#define bM4_DMA2_DTCTL3_CNT11                     (*((volatile unsigned int*)(0x42A6A16CUL)))
#define bM4_DMA2_DTCTL3_CNT12                     (*((volatile unsigned int*)(0x42A6A170UL)))
#define bM4_DMA2_DTCTL3_CNT13                     (*((volatile unsigned int*)(0x42A6A174UL)))
#define bM4_DMA2_DTCTL3_CNT14                     (*((volatile unsigned int*)(0x42A6A178UL)))
#define bM4_DMA2_DTCTL3_CNT15                     (*((volatile unsigned int*)(0x42A6A17CUL)))
#define bM4_DMA2_RPT3_SRPT0                       (*((volatile unsigned int*)(0x42A6A180UL)))
#define bM4_DMA2_RPT3_SRPT1                       (*((volatile unsigned int*)(0x42A6A184UL)))
#define bM4_DMA2_RPT3_SRPT2                       (*((volatile unsigned int*)(0x42A6A188UL)))
#define bM4_DMA2_RPT3_SRPT3                       (*((volatile unsigned int*)(0x42A6A18CUL)))
#define bM4_DMA2_RPT3_SRPT4                       (*((volatile unsigned int*)(0x42A6A190UL)))
#define bM4_DMA2_RPT3_SRPT5                       (*((volatile unsigned int*)(0x42A6A194UL)))
#define bM4_DMA2_RPT3_SRPT6                       (*((volatile unsigned int*)(0x42A6A198UL)))
#define bM4_DMA2_RPT3_SRPT7                       (*((volatile unsigned int*)(0x42A6A19CUL)))
#define bM4_DMA2_RPT3_SRPT8                       (*((volatile unsigned int*)(0x42A6A1A0UL)))
#define bM4_DMA2_RPT3_SRPT9                       (*((volatile unsigned int*)(0x42A6A1A4UL)))
#define bM4_DMA2_RPT3_DRPT0                       (*((volatile unsigned int*)(0x42A6A1C0UL)))
#define bM4_DMA2_RPT3_DRPT1                       (*((volatile unsigned int*)(0x42A6A1C4UL)))
#define bM4_DMA2_RPT3_DRPT2                       (*((volatile unsigned int*)(0x42A6A1C8UL)))
#define bM4_DMA2_RPT3_DRPT3                       (*((volatile unsigned int*)(0x42A6A1CCUL)))
#define bM4_DMA2_RPT3_DRPT4                       (*((volatile unsigned int*)(0x42A6A1D0UL)))
#define bM4_DMA2_RPT3_DRPT5                       (*((volatile unsigned int*)(0x42A6A1D4UL)))
#define bM4_DMA2_RPT3_DRPT6                       (*((volatile unsigned int*)(0x42A6A1D8UL)))
#define bM4_DMA2_RPT3_DRPT7                       (*((volatile unsigned int*)(0x42A6A1DCUL)))
#define bM4_DMA2_RPT3_DRPT8                       (*((volatile unsigned int*)(0x42A6A1E0UL)))
#define bM4_DMA2_RPT3_DRPT9                       (*((volatile unsigned int*)(0x42A6A1E4UL)))
#define bM4_DMA2_RPTB3_SRPTB0                     (*((volatile unsigned int*)(0x42A6A180UL)))
#define bM4_DMA2_RPTB3_SRPTB1                     (*((volatile unsigned int*)(0x42A6A184UL)))
#define bM4_DMA2_RPTB3_SRPTB2                     (*((volatile unsigned int*)(0x42A6A188UL)))
#define bM4_DMA2_RPTB3_SRPTB3                     (*((volatile unsigned int*)(0x42A6A18CUL)))
#define bM4_DMA2_RPTB3_SRPTB4                     (*((volatile unsigned int*)(0x42A6A190UL)))
#define bM4_DMA2_RPTB3_SRPTB5                     (*((volatile unsigned int*)(0x42A6A194UL)))
#define bM4_DMA2_RPTB3_SRPTB6                     (*((volatile unsigned int*)(0x42A6A198UL)))
#define bM4_DMA2_RPTB3_SRPTB7                     (*((volatile unsigned int*)(0x42A6A19CUL)))
#define bM4_DMA2_RPTB3_SRPTB8                     (*((volatile unsigned int*)(0x42A6A1A0UL)))
#define bM4_DMA2_RPTB3_SRPTB9                     (*((volatile unsigned int*)(0x42A6A1A4UL)))
#define bM4_DMA2_RPTB3_DRPTB0                     (*((volatile unsigned int*)(0x42A6A1C0UL)))
#define bM4_DMA2_RPTB3_DRPTB1                     (*((volatile unsigned int*)(0x42A6A1C4UL)))
#define bM4_DMA2_RPTB3_DRPTB2                     (*((volatile unsigned int*)(0x42A6A1C8UL)))
#define bM4_DMA2_RPTB3_DRPTB3                     (*((volatile unsigned int*)(0x42A6A1CCUL)))
#define bM4_DMA2_RPTB3_DRPTB4                     (*((volatile unsigned int*)(0x42A6A1D0UL)))
#define bM4_DMA2_RPTB3_DRPTB5                     (*((volatile unsigned int*)(0x42A6A1D4UL)))
#define bM4_DMA2_RPTB3_DRPTB6                     (*((volatile unsigned int*)(0x42A6A1D8UL)))
#define bM4_DMA2_RPTB3_DRPTB7                     (*((volatile unsigned int*)(0x42A6A1DCUL)))
#define bM4_DMA2_RPTB3_DRPTB8                     (*((volatile unsigned int*)(0x42A6A1E0UL)))
#define bM4_DMA2_RPTB3_DRPTB9                     (*((volatile unsigned int*)(0x42A6A1E4UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET0               (*((volatile unsigned int*)(0x42A6A200UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET1               (*((volatile unsigned int*)(0x42A6A204UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET2               (*((volatile unsigned int*)(0x42A6A208UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET3               (*((volatile unsigned int*)(0x42A6A20CUL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET4               (*((volatile unsigned int*)(0x42A6A210UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET5               (*((volatile unsigned int*)(0x42A6A214UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET6               (*((volatile unsigned int*)(0x42A6A218UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET7               (*((volatile unsigned int*)(0x42A6A21CUL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET8               (*((volatile unsigned int*)(0x42A6A220UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET9               (*((volatile unsigned int*)(0x42A6A224UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET10              (*((volatile unsigned int*)(0x42A6A228UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET11              (*((volatile unsigned int*)(0x42A6A22CUL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET12              (*((volatile unsigned int*)(0x42A6A230UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET13              (*((volatile unsigned int*)(0x42A6A234UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET14              (*((volatile unsigned int*)(0x42A6A238UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET15              (*((volatile unsigned int*)(0x42A6A23CUL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET16              (*((volatile unsigned int*)(0x42A6A240UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET17              (*((volatile unsigned int*)(0x42A6A244UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET18              (*((volatile unsigned int*)(0x42A6A248UL)))
#define bM4_DMA2_SNSEQCTL3_SOFFSET19              (*((volatile unsigned int*)(0x42A6A24CUL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT0                (*((volatile unsigned int*)(0x42A6A250UL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT1                (*((volatile unsigned int*)(0x42A6A254UL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT2                (*((volatile unsigned int*)(0x42A6A258UL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT3                (*((volatile unsigned int*)(0x42A6A25CUL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT4                (*((volatile unsigned int*)(0x42A6A260UL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT5                (*((volatile unsigned int*)(0x42A6A264UL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT6                (*((volatile unsigned int*)(0x42A6A268UL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT7                (*((volatile unsigned int*)(0x42A6A26CUL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT8                (*((volatile unsigned int*)(0x42A6A270UL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT9                (*((volatile unsigned int*)(0x42A6A274UL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT10               (*((volatile unsigned int*)(0x42A6A278UL)))
#define bM4_DMA2_SNSEQCTL3_SNSCNT11               (*((volatile unsigned int*)(0x42A6A27CUL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST0              (*((volatile unsigned int*)(0x42A6A200UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST1              (*((volatile unsigned int*)(0x42A6A204UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST2              (*((volatile unsigned int*)(0x42A6A208UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST3              (*((volatile unsigned int*)(0x42A6A20CUL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST4              (*((volatile unsigned int*)(0x42A6A210UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST5              (*((volatile unsigned int*)(0x42A6A214UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST6              (*((volatile unsigned int*)(0x42A6A218UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST7              (*((volatile unsigned int*)(0x42A6A21CUL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST8              (*((volatile unsigned int*)(0x42A6A220UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST9              (*((volatile unsigned int*)(0x42A6A224UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST10             (*((volatile unsigned int*)(0x42A6A228UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST11             (*((volatile unsigned int*)(0x42A6A22CUL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST12             (*((volatile unsigned int*)(0x42A6A230UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST13             (*((volatile unsigned int*)(0x42A6A234UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST14             (*((volatile unsigned int*)(0x42A6A238UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST15             (*((volatile unsigned int*)(0x42A6A23CUL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST16             (*((volatile unsigned int*)(0x42A6A240UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST17             (*((volatile unsigned int*)(0x42A6A244UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST18             (*((volatile unsigned int*)(0x42A6A248UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSDIST19             (*((volatile unsigned int*)(0x42A6A24CUL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB0              (*((volatile unsigned int*)(0x42A6A250UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB1              (*((volatile unsigned int*)(0x42A6A254UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB2              (*((volatile unsigned int*)(0x42A6A258UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB3              (*((volatile unsigned int*)(0x42A6A25CUL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB4              (*((volatile unsigned int*)(0x42A6A260UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB5              (*((volatile unsigned int*)(0x42A6A264UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB6              (*((volatile unsigned int*)(0x42A6A268UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB7              (*((volatile unsigned int*)(0x42A6A26CUL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB8              (*((volatile unsigned int*)(0x42A6A270UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB9              (*((volatile unsigned int*)(0x42A6A274UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB10             (*((volatile unsigned int*)(0x42A6A278UL)))
#define bM4_DMA2_SNSEQCTLB3_SNSCNTB11             (*((volatile unsigned int*)(0x42A6A27CUL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET0               (*((volatile unsigned int*)(0x42A6A280UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET1               (*((volatile unsigned int*)(0x42A6A284UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET2               (*((volatile unsigned int*)(0x42A6A288UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET3               (*((volatile unsigned int*)(0x42A6A28CUL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET4               (*((volatile unsigned int*)(0x42A6A290UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET5               (*((volatile unsigned int*)(0x42A6A294UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET6               (*((volatile unsigned int*)(0x42A6A298UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET7               (*((volatile unsigned int*)(0x42A6A29CUL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET8               (*((volatile unsigned int*)(0x42A6A2A0UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET9               (*((volatile unsigned int*)(0x42A6A2A4UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET10              (*((volatile unsigned int*)(0x42A6A2A8UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET11              (*((volatile unsigned int*)(0x42A6A2ACUL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET12              (*((volatile unsigned int*)(0x42A6A2B0UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET13              (*((volatile unsigned int*)(0x42A6A2B4UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET14              (*((volatile unsigned int*)(0x42A6A2B8UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET15              (*((volatile unsigned int*)(0x42A6A2BCUL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET16              (*((volatile unsigned int*)(0x42A6A2C0UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET17              (*((volatile unsigned int*)(0x42A6A2C4UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET18              (*((volatile unsigned int*)(0x42A6A2C8UL)))
#define bM4_DMA2_DNSEQCTL3_DOFFSET19              (*((volatile unsigned int*)(0x42A6A2CCUL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT0                (*((volatile unsigned int*)(0x42A6A2D0UL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT1                (*((volatile unsigned int*)(0x42A6A2D4UL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT2                (*((volatile unsigned int*)(0x42A6A2D8UL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT3                (*((volatile unsigned int*)(0x42A6A2DCUL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT4                (*((volatile unsigned int*)(0x42A6A2E0UL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT5                (*((volatile unsigned int*)(0x42A6A2E4UL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT6                (*((volatile unsigned int*)(0x42A6A2E8UL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT7                (*((volatile unsigned int*)(0x42A6A2ECUL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT8                (*((volatile unsigned int*)(0x42A6A2F0UL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT9                (*((volatile unsigned int*)(0x42A6A2F4UL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT10               (*((volatile unsigned int*)(0x42A6A2F8UL)))
#define bM4_DMA2_DNSEQCTL3_DNSCNT11               (*((volatile unsigned int*)(0x42A6A2FCUL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST0              (*((volatile unsigned int*)(0x42A6A280UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST1              (*((volatile unsigned int*)(0x42A6A284UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST2              (*((volatile unsigned int*)(0x42A6A288UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST3              (*((volatile unsigned int*)(0x42A6A28CUL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST4              (*((volatile unsigned int*)(0x42A6A290UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST5              (*((volatile unsigned int*)(0x42A6A294UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST6              (*((volatile unsigned int*)(0x42A6A298UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST7              (*((volatile unsigned int*)(0x42A6A29CUL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST8              (*((volatile unsigned int*)(0x42A6A2A0UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST9              (*((volatile unsigned int*)(0x42A6A2A4UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST10             (*((volatile unsigned int*)(0x42A6A2A8UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST11             (*((volatile unsigned int*)(0x42A6A2ACUL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST12             (*((volatile unsigned int*)(0x42A6A2B0UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST13             (*((volatile unsigned int*)(0x42A6A2B4UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST14             (*((volatile unsigned int*)(0x42A6A2B8UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST15             (*((volatile unsigned int*)(0x42A6A2BCUL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST16             (*((volatile unsigned int*)(0x42A6A2C0UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST17             (*((volatile unsigned int*)(0x42A6A2C4UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST18             (*((volatile unsigned int*)(0x42A6A2C8UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSDIST19             (*((volatile unsigned int*)(0x42A6A2CCUL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB0              (*((volatile unsigned int*)(0x42A6A2D0UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB1              (*((volatile unsigned int*)(0x42A6A2D4UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB2              (*((volatile unsigned int*)(0x42A6A2D8UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB3              (*((volatile unsigned int*)(0x42A6A2DCUL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB4              (*((volatile unsigned int*)(0x42A6A2E0UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB5              (*((volatile unsigned int*)(0x42A6A2E4UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB6              (*((volatile unsigned int*)(0x42A6A2E8UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB7              (*((volatile unsigned int*)(0x42A6A2ECUL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB8              (*((volatile unsigned int*)(0x42A6A2F0UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB9              (*((volatile unsigned int*)(0x42A6A2F4UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB10             (*((volatile unsigned int*)(0x42A6A2F8UL)))
#define bM4_DMA2_DNSEQCTLB3_DNSCNTB11             (*((volatile unsigned int*)(0x42A6A2FCUL)))
#define bM4_DMA2_LLP3_LLP0                        (*((volatile unsigned int*)(0x42A6A308UL)))
#define bM4_DMA2_LLP3_LLP1                        (*((volatile unsigned int*)(0x42A6A30CUL)))
#define bM4_DMA2_LLP3_LLP2                        (*((volatile unsigned int*)(0x42A6A310UL)))
#define bM4_DMA2_LLP3_LLP3                        (*((volatile unsigned int*)(0x42A6A314UL)))
#define bM4_DMA2_LLP3_LLP4                        (*((volatile unsigned int*)(0x42A6A318UL)))
#define bM4_DMA2_LLP3_LLP5                        (*((volatile unsigned int*)(0x42A6A31CUL)))
#define bM4_DMA2_LLP3_LLP6                        (*((volatile unsigned int*)(0x42A6A320UL)))
#define bM4_DMA2_LLP3_LLP7                        (*((volatile unsigned int*)(0x42A6A324UL)))
#define bM4_DMA2_LLP3_LLP8                        (*((volatile unsigned int*)(0x42A6A328UL)))
#define bM4_DMA2_LLP3_LLP9                        (*((volatile unsigned int*)(0x42A6A32CUL)))
#define bM4_DMA2_LLP3_LLP10                       (*((volatile unsigned int*)(0x42A6A330UL)))
#define bM4_DMA2_LLP3_LLP11                       (*((volatile unsigned int*)(0x42A6A334UL)))
#define bM4_DMA2_LLP3_LLP12                       (*((volatile unsigned int*)(0x42A6A338UL)))
#define bM4_DMA2_LLP3_LLP13                       (*((volatile unsigned int*)(0x42A6A33CUL)))
#define bM4_DMA2_LLP3_LLP14                       (*((volatile unsigned int*)(0x42A6A340UL)))
#define bM4_DMA2_LLP3_LLP15                       (*((volatile unsigned int*)(0x42A6A344UL)))
#define bM4_DMA2_LLP3_LLP16                       (*((volatile unsigned int*)(0x42A6A348UL)))
#define bM4_DMA2_LLP3_LLP17                       (*((volatile unsigned int*)(0x42A6A34CUL)))
#define bM4_DMA2_LLP3_LLP18                       (*((volatile unsigned int*)(0x42A6A350UL)))
#define bM4_DMA2_LLP3_LLP19                       (*((volatile unsigned int*)(0x42A6A354UL)))
#define bM4_DMA2_LLP3_LLP20                       (*((volatile unsigned int*)(0x42A6A358UL)))
#define bM4_DMA2_LLP3_LLP21                       (*((volatile unsigned int*)(0x42A6A35CUL)))
#define bM4_DMA2_LLP3_LLP22                       (*((volatile unsigned int*)(0x42A6A360UL)))
#define bM4_DMA2_LLP3_LLP23                       (*((volatile unsigned int*)(0x42A6A364UL)))
#define bM4_DMA2_LLP3_LLP24                       (*((volatile unsigned int*)(0x42A6A368UL)))
#define bM4_DMA2_LLP3_LLP25                       (*((volatile unsigned int*)(0x42A6A36CUL)))
#define bM4_DMA2_LLP3_LLP26                       (*((volatile unsigned int*)(0x42A6A370UL)))
#define bM4_DMA2_LLP3_LLP27                       (*((volatile unsigned int*)(0x42A6A374UL)))
#define bM4_DMA2_LLP3_LLP28                       (*((volatile unsigned int*)(0x42A6A378UL)))
#define bM4_DMA2_LLP3_LLP29                       (*((volatile unsigned int*)(0x42A6A37CUL)))
#define bM4_DMA2_CHCTL3_SINC0                     (*((volatile unsigned int*)(0x42A6A380UL)))
#define bM4_DMA2_CHCTL3_SINC1                     (*((volatile unsigned int*)(0x42A6A384UL)))
#define bM4_DMA2_CHCTL3_DINC0                     (*((volatile unsigned int*)(0x42A6A388UL)))
#define bM4_DMA2_CHCTL3_DINC1                     (*((volatile unsigned int*)(0x42A6A38CUL)))
#define bM4_DMA2_CHCTL3_SRPTEN                    (*((volatile unsigned int*)(0x42A6A390UL)))
#define bM4_DMA2_CHCTL3_DRPTEN                    (*((volatile unsigned int*)(0x42A6A394UL)))
#define bM4_DMA2_CHCTL3_SNSEQEN                   (*((volatile unsigned int*)(0x42A6A398UL)))
#define bM4_DMA2_CHCTL3_DNSEQEN                   (*((volatile unsigned int*)(0x42A6A39CUL)))
#define bM4_DMA2_CHCTL3_HSIZE0                    (*((volatile unsigned int*)(0x42A6A3A0UL)))
#define bM4_DMA2_CHCTL3_HSIZE1                    (*((volatile unsigned int*)(0x42A6A3A4UL)))
#define bM4_DMA2_CHCTL3_LLPEN                     (*((volatile unsigned int*)(0x42A6A3A8UL)))
#define bM4_DMA2_CHCTL3_LLPRUN                    (*((volatile unsigned int*)(0x42A6A3ACUL)))
#define bM4_DMA2_CHCTL3_IE                        (*((volatile unsigned int*)(0x42A6A3B0UL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE0               (*((volatile unsigned int*)(0x42A6A500UL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE1               (*((volatile unsigned int*)(0x42A6A504UL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE2               (*((volatile unsigned int*)(0x42A6A508UL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE3               (*((volatile unsigned int*)(0x42A6A50CUL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE4               (*((volatile unsigned int*)(0x42A6A510UL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE5               (*((volatile unsigned int*)(0x42A6A514UL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE6               (*((volatile unsigned int*)(0x42A6A518UL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE7               (*((volatile unsigned int*)(0x42A6A51CUL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE8               (*((volatile unsigned int*)(0x42A6A520UL)))
#define bM4_DMA2_MONDTCTL3_BLKSIZE9               (*((volatile unsigned int*)(0x42A6A524UL)))
#define bM4_DMA2_MONDTCTL3_CNT0                   (*((volatile unsigned int*)(0x42A6A540UL)))
#define bM4_DMA2_MONDTCTL3_CNT1                   (*((volatile unsigned int*)(0x42A6A544UL)))
#define bM4_DMA2_MONDTCTL3_CNT2                   (*((volatile unsigned int*)(0x42A6A548UL)))
#define bM4_DMA2_MONDTCTL3_CNT3                   (*((volatile unsigned int*)(0x42A6A54CUL)))
#define bM4_DMA2_MONDTCTL3_CNT4                   (*((volatile unsigned int*)(0x42A6A550UL)))
#define bM4_DMA2_MONDTCTL3_CNT5                   (*((volatile unsigned int*)(0x42A6A554UL)))
#define bM4_DMA2_MONDTCTL3_CNT6                   (*((volatile unsigned int*)(0x42A6A558UL)))
#define bM4_DMA2_MONDTCTL3_CNT7                   (*((volatile unsigned int*)(0x42A6A55CUL)))
#define bM4_DMA2_MONDTCTL3_CNT8                   (*((volatile unsigned int*)(0x42A6A560UL)))
#define bM4_DMA2_MONDTCTL3_CNT9                   (*((volatile unsigned int*)(0x42A6A564UL)))
#define bM4_DMA2_MONDTCTL3_CNT10                  (*((volatile unsigned int*)(0x42A6A568UL)))
#define bM4_DMA2_MONDTCTL3_CNT11                  (*((volatile unsigned int*)(0x42A6A56CUL)))
#define bM4_DMA2_MONDTCTL3_CNT12                  (*((volatile unsigned int*)(0x42A6A570UL)))
#define bM4_DMA2_MONDTCTL3_CNT13                  (*((volatile unsigned int*)(0x42A6A574UL)))
#define bM4_DMA2_MONDTCTL3_CNT14                  (*((volatile unsigned int*)(0x42A6A578UL)))
#define bM4_DMA2_MONDTCTL3_CNT15                  (*((volatile unsigned int*)(0x42A6A57CUL)))
#define bM4_DMA2_MONRPT3_SRPT0                    (*((volatile unsigned int*)(0x42A6A580UL)))
#define bM4_DMA2_MONRPT3_SRPT1                    (*((volatile unsigned int*)(0x42A6A584UL)))
#define bM4_DMA2_MONRPT3_SRPT2                    (*((volatile unsigned int*)(0x42A6A588UL)))
#define bM4_DMA2_MONRPT3_SRPT3                    (*((volatile unsigned int*)(0x42A6A58CUL)))
#define bM4_DMA2_MONRPT3_SRPT4                    (*((volatile unsigned int*)(0x42A6A590UL)))
#define bM4_DMA2_MONRPT3_SRPT5                    (*((volatile unsigned int*)(0x42A6A594UL)))
#define bM4_DMA2_MONRPT3_SRPT6                    (*((volatile unsigned int*)(0x42A6A598UL)))
#define bM4_DMA2_MONRPT3_SRPT7                    (*((volatile unsigned int*)(0x42A6A59CUL)))
#define bM4_DMA2_MONRPT3_SRPT8                    (*((volatile unsigned int*)(0x42A6A5A0UL)))
#define bM4_DMA2_MONRPT3_SRPT9                    (*((volatile unsigned int*)(0x42A6A5A4UL)))
#define bM4_DMA2_MONRPT3_DRPT0                    (*((volatile unsigned int*)(0x42A6A5C0UL)))
#define bM4_DMA2_MONRPT3_DRPT1                    (*((volatile unsigned int*)(0x42A6A5C4UL)))
#define bM4_DMA2_MONRPT3_DRPT2                    (*((volatile unsigned int*)(0x42A6A5C8UL)))
#define bM4_DMA2_MONRPT3_DRPT3                    (*((volatile unsigned int*)(0x42A6A5CCUL)))
#define bM4_DMA2_MONRPT3_DRPT4                    (*((volatile unsigned int*)(0x42A6A5D0UL)))
#define bM4_DMA2_MONRPT3_DRPT5                    (*((volatile unsigned int*)(0x42A6A5D4UL)))
#define bM4_DMA2_MONRPT3_DRPT6                    (*((volatile unsigned int*)(0x42A6A5D8UL)))
#define bM4_DMA2_MONRPT3_DRPT7                    (*((volatile unsigned int*)(0x42A6A5DCUL)))
#define bM4_DMA2_MONRPT3_DRPT8                    (*((volatile unsigned int*)(0x42A6A5E0UL)))
#define bM4_DMA2_MONRPT3_DRPT9                    (*((volatile unsigned int*)(0x42A6A5E4UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET0            (*((volatile unsigned int*)(0x42A6A600UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET1            (*((volatile unsigned int*)(0x42A6A604UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET2            (*((volatile unsigned int*)(0x42A6A608UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET3            (*((volatile unsigned int*)(0x42A6A60CUL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET4            (*((volatile unsigned int*)(0x42A6A610UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET5            (*((volatile unsigned int*)(0x42A6A614UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET6            (*((volatile unsigned int*)(0x42A6A618UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET7            (*((volatile unsigned int*)(0x42A6A61CUL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET8            (*((volatile unsigned int*)(0x42A6A620UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET9            (*((volatile unsigned int*)(0x42A6A624UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET10           (*((volatile unsigned int*)(0x42A6A628UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET11           (*((volatile unsigned int*)(0x42A6A62CUL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET12           (*((volatile unsigned int*)(0x42A6A630UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET13           (*((volatile unsigned int*)(0x42A6A634UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET14           (*((volatile unsigned int*)(0x42A6A638UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET15           (*((volatile unsigned int*)(0x42A6A63CUL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET16           (*((volatile unsigned int*)(0x42A6A640UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET17           (*((volatile unsigned int*)(0x42A6A644UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET18           (*((volatile unsigned int*)(0x42A6A648UL)))
#define bM4_DMA2_MONSNSEQCTL3_SOFFSET19           (*((volatile unsigned int*)(0x42A6A64CUL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT0             (*((volatile unsigned int*)(0x42A6A650UL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT1             (*((volatile unsigned int*)(0x42A6A654UL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT2             (*((volatile unsigned int*)(0x42A6A658UL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT3             (*((volatile unsigned int*)(0x42A6A65CUL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT4             (*((volatile unsigned int*)(0x42A6A660UL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT5             (*((volatile unsigned int*)(0x42A6A664UL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT6             (*((volatile unsigned int*)(0x42A6A668UL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT7             (*((volatile unsigned int*)(0x42A6A66CUL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT8             (*((volatile unsigned int*)(0x42A6A670UL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT9             (*((volatile unsigned int*)(0x42A6A674UL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT10            (*((volatile unsigned int*)(0x42A6A678UL)))
#define bM4_DMA2_MONSNSEQCTL3_SNSCNT11            (*((volatile unsigned int*)(0x42A6A67CUL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET0            (*((volatile unsigned int*)(0x42A6A680UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET1            (*((volatile unsigned int*)(0x42A6A684UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET2            (*((volatile unsigned int*)(0x42A6A688UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET3            (*((volatile unsigned int*)(0x42A6A68CUL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET4            (*((volatile unsigned int*)(0x42A6A690UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET5            (*((volatile unsigned int*)(0x42A6A694UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET6            (*((volatile unsigned int*)(0x42A6A698UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET7            (*((volatile unsigned int*)(0x42A6A69CUL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET8            (*((volatile unsigned int*)(0x42A6A6A0UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET9            (*((volatile unsigned int*)(0x42A6A6A4UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET10           (*((volatile unsigned int*)(0x42A6A6A8UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET11           (*((volatile unsigned int*)(0x42A6A6ACUL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET12           (*((volatile unsigned int*)(0x42A6A6B0UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET13           (*((volatile unsigned int*)(0x42A6A6B4UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET14           (*((volatile unsigned int*)(0x42A6A6B8UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET15           (*((volatile unsigned int*)(0x42A6A6BCUL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET16           (*((volatile unsigned int*)(0x42A6A6C0UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET17           (*((volatile unsigned int*)(0x42A6A6C4UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET18           (*((volatile unsigned int*)(0x42A6A6C8UL)))
#define bM4_DMA2_MONDNSEQCTL3_DOFFSET19           (*((volatile unsigned int*)(0x42A6A6CCUL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT0             (*((volatile unsigned int*)(0x42A6A6D0UL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT1             (*((volatile unsigned int*)(0x42A6A6D4UL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT2             (*((volatile unsigned int*)(0x42A6A6D8UL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT3             (*((volatile unsigned int*)(0x42A6A6DCUL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT4             (*((volatile unsigned int*)(0x42A6A6E0UL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT5             (*((volatile unsigned int*)(0x42A6A6E4UL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT6             (*((volatile unsigned int*)(0x42A6A6E8UL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT7             (*((volatile unsigned int*)(0x42A6A6ECUL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT8             (*((volatile unsigned int*)(0x42A6A6F0UL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT9             (*((volatile unsigned int*)(0x42A6A6F4UL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT10            (*((volatile unsigned int*)(0x42A6A6F8UL)))
#define bM4_DMA2_MONDNSEQCTL3_DNSCNT11            (*((volatile unsigned int*)(0x42A6A6FCUL)))
#define bM4_EFM_FAPRT_FAPRT0                      (*((volatile unsigned int*)(0x42208000UL)))
#define bM4_EFM_FAPRT_FAPRT1                      (*((volatile unsigned int*)(0x42208004UL)))
#define bM4_EFM_FAPRT_FAPRT2                      (*((volatile unsigned int*)(0x42208008UL)))
#define bM4_EFM_FAPRT_FAPRT3                      (*((volatile unsigned int*)(0x4220800CUL)))
#define bM4_EFM_FAPRT_FAPRT4                      (*((volatile unsigned int*)(0x42208010UL)))
#define bM4_EFM_FAPRT_FAPRT5                      (*((volatile unsigned int*)(0x42208014UL)))
#define bM4_EFM_FAPRT_FAPRT6                      (*((volatile unsigned int*)(0x42208018UL)))
#define bM4_EFM_FAPRT_FAPRT7                      (*((volatile unsigned int*)(0x4220801CUL)))
#define bM4_EFM_FAPRT_FAPRT8                      (*((volatile unsigned int*)(0x42208020UL)))
#define bM4_EFM_FAPRT_FAPRT9                      (*((volatile unsigned int*)(0x42208024UL)))
#define bM4_EFM_FAPRT_FAPRT10                     (*((volatile unsigned int*)(0x42208028UL)))
#define bM4_EFM_FAPRT_FAPRT11                     (*((volatile unsigned int*)(0x4220802CUL)))
#define bM4_EFM_FAPRT_FAPRT12                     (*((volatile unsigned int*)(0x42208030UL)))
#define bM4_EFM_FAPRT_FAPRT13                     (*((volatile unsigned int*)(0x42208034UL)))
#define bM4_EFM_FAPRT_FAPRT14                     (*((volatile unsigned int*)(0x42208038UL)))
#define bM4_EFM_FAPRT_FAPRT15                     (*((volatile unsigned int*)(0x4220803CUL)))
#define bM4_EFM_FSTP_FSTP                         (*((volatile unsigned int*)(0x42208080UL)))
#define bM4_EFM_FRMC_SLPMD                        (*((volatile unsigned int*)(0x42208100UL)))
#define bM4_EFM_FRMC_FLWT0                        (*((volatile unsigned int*)(0x42208110UL)))
#define bM4_EFM_FRMC_FLWT1                        (*((volatile unsigned int*)(0x42208114UL)))
#define bM4_EFM_FRMC_FLWT2                        (*((volatile unsigned int*)(0x42208118UL)))
#define bM4_EFM_FRMC_FLWT3                        (*((volatile unsigned int*)(0x4220811CUL)))
#define bM4_EFM_FRMC_LVM                          (*((volatile unsigned int*)(0x42208120UL)))
#define bM4_EFM_FRMC_CACHE                        (*((volatile unsigned int*)(0x42208140UL)))
#define bM4_EFM_FRMC_CRST                         (*((volatile unsigned int*)(0x42208160UL)))
#define bM4_EFM_FWMC_PEMODE                       (*((volatile unsigned int*)(0x42208180UL)))
#define bM4_EFM_FWMC_PEMOD0                       (*((volatile unsigned int*)(0x42208190UL)))
#define bM4_EFM_FWMC_PEMOD1                       (*((volatile unsigned int*)(0x42208194UL)))
#define bM4_EFM_FWMC_PEMOD2                       (*((volatile unsigned int*)(0x42208198UL)))
#define bM4_EFM_FWMC_BUSHLDCTL                    (*((volatile unsigned int*)(0x422081A0UL)))
#define bM4_EFM_FSR_PEWERR                        (*((volatile unsigned int*)(0x42208200UL)))
#define bM4_EFM_FSR_PEPRTERR                      (*((volatile unsigned int*)(0x42208204UL)))
#define bM4_EFM_FSR_PGSZERR                       (*((volatile unsigned int*)(0x42208208UL)))
#define bM4_EFM_FSR_PGMISMTCH                     (*((volatile unsigned int*)(0x4220820CUL)))
#define bM4_EFM_FSR_OPTEND                        (*((volatile unsigned int*)(0x42208210UL)))
#define bM4_EFM_FSR_COLERR                        (*((volatile unsigned int*)(0x42208214UL)))
#define bM4_EFM_FSR_RDY                           (*((volatile unsigned int*)(0x42208220UL)))
#define bM4_EFM_FSCLR_PEWERRCLR                   (*((volatile unsigned int*)(0x42208280UL)))
#define bM4_EFM_FSCLR_PEPRTERRCLR                 (*((volatile unsigned int*)(0x42208284UL)))
#define bM4_EFM_FSCLR_PGSZERRCLR                  (*((volatile unsigned int*)(0x42208288UL)))
#define bM4_EFM_FSCLR_PGMISMTCHCLR                (*((volatile unsigned int*)(0x4220828CUL)))
#define bM4_EFM_FSCLR_OPTENDCLR                   (*((volatile unsigned int*)(0x42208290UL)))
#define bM4_EFM_FSCLR_COLERRCLR                   (*((volatile unsigned int*)(0x42208294UL)))
#define bM4_EFM_FITE_PEERRITE                     (*((volatile unsigned int*)(0x42208300UL)))
#define bM4_EFM_FITE_OPTENDITE                    (*((volatile unsigned int*)(0x42208304UL)))
#define bM4_EFM_FITE_COLERRITE                    (*((volatile unsigned int*)(0x42208308UL)))
#define bM4_EFM_FSWP_FSWP                         (*((volatile unsigned int*)(0x42208380UL)))
#define bM4_EFM_FPMTSW_FPMTSW0                    (*((volatile unsigned int*)(0x42208400UL)))
#define bM4_EFM_FPMTSW_FPMTSW1                    (*((volatile unsigned int*)(0x42208404UL)))
#define bM4_EFM_FPMTSW_FPMTSW2                    (*((volatile unsigned int*)(0x42208408UL)))
#define bM4_EFM_FPMTSW_FPMTSW3                    (*((volatile unsigned int*)(0x4220840CUL)))
#define bM4_EFM_FPMTSW_FPMTSW4                    (*((volatile unsigned int*)(0x42208410UL)))
#define bM4_EFM_FPMTSW_FPMTSW5                    (*((volatile unsigned int*)(0x42208414UL)))
#define bM4_EFM_FPMTSW_FPMTSW6                    (*((volatile unsigned int*)(0x42208418UL)))
#define bM4_EFM_FPMTSW_FPMTSW7                    (*((volatile unsigned int*)(0x4220841CUL)))
#define bM4_EFM_FPMTSW_FPMTSW8                    (*((volatile unsigned int*)(0x42208420UL)))
#define bM4_EFM_FPMTSW_FPMTSW9                    (*((volatile unsigned int*)(0x42208424UL)))
#define bM4_EFM_FPMTSW_FPMTSW10                   (*((volatile unsigned int*)(0x42208428UL)))
#define bM4_EFM_FPMTSW_FPMTSW11                   (*((volatile unsigned int*)(0x4220842CUL)))
#define bM4_EFM_FPMTSW_FPMTSW12                   (*((volatile unsigned int*)(0x42208430UL)))
#define bM4_EFM_FPMTSW_FPMTSW13                   (*((volatile unsigned int*)(0x42208434UL)))
#define bM4_EFM_FPMTSW_FPMTSW14                   (*((volatile unsigned int*)(0x42208438UL)))
#define bM4_EFM_FPMTSW_FPMTSW15                   (*((volatile unsigned int*)(0x4220843CUL)))
#define bM4_EFM_FPMTSW_FPMTSW16                   (*((volatile unsigned int*)(0x42208440UL)))
#define bM4_EFM_FPMTSW_FPMTSW17                   (*((volatile unsigned int*)(0x42208444UL)))
#define bM4_EFM_FPMTSW_FPMTSW18                   (*((volatile unsigned int*)(0x42208448UL)))
#define bM4_EFM_FPMTEW_FPMTEW0                    (*((volatile unsigned int*)(0x42208480UL)))
#define bM4_EFM_FPMTEW_FPMTEW1                    (*((volatile unsigned int*)(0x42208484UL)))
#define bM4_EFM_FPMTEW_FPMTEW2                    (*((volatile unsigned int*)(0x42208488UL)))
#define bM4_EFM_FPMTEW_FPMTEW3                    (*((volatile unsigned int*)(0x4220848CUL)))
#define bM4_EFM_FPMTEW_FPMTEW4                    (*((volatile unsigned int*)(0x42208490UL)))
#define bM4_EFM_FPMTEW_FPMTEW5                    (*((volatile unsigned int*)(0x42208494UL)))
#define bM4_EFM_FPMTEW_FPMTEW6                    (*((volatile unsigned int*)(0x42208498UL)))
#define bM4_EFM_FPMTEW_FPMTEW7                    (*((volatile unsigned int*)(0x4220849CUL)))
#define bM4_EFM_FPMTEW_FPMTEW8                    (*((volatile unsigned int*)(0x422084A0UL)))
#define bM4_EFM_FPMTEW_FPMTEW9                    (*((volatile unsigned int*)(0x422084A4UL)))
#define bM4_EFM_FPMTEW_FPMTEW10                   (*((volatile unsigned int*)(0x422084A8UL)))
#define bM4_EFM_FPMTEW_FPMTEW11                   (*((volatile unsigned int*)(0x422084ACUL)))
#define bM4_EFM_FPMTEW_FPMTEW12                   (*((volatile unsigned int*)(0x422084B0UL)))
#define bM4_EFM_FPMTEW_FPMTEW13                   (*((volatile unsigned int*)(0x422084B4UL)))
#define bM4_EFM_FPMTEW_FPMTEW14                   (*((volatile unsigned int*)(0x422084B8UL)))
#define bM4_EFM_FPMTEW_FPMTEW15                   (*((volatile unsigned int*)(0x422084BCUL)))
#define bM4_EFM_FPMTEW_FPMTEW16                   (*((volatile unsigned int*)(0x422084C0UL)))
#define bM4_EFM_FPMTEW_FPMTEW17                   (*((volatile unsigned int*)(0x422084C4UL)))
#define bM4_EFM_FPMTEW_FPMTEW18                   (*((volatile unsigned int*)(0x422084C8UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT0                (*((volatile unsigned int*)(0x4220A000UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT1                (*((volatile unsigned int*)(0x4220A004UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT2                (*((volatile unsigned int*)(0x4220A008UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT3                (*((volatile unsigned int*)(0x4220A00CUL)))
#define bM4_EFM_MMF_REMPRT_REMPRT4                (*((volatile unsigned int*)(0x4220A010UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT5                (*((volatile unsigned int*)(0x4220A014UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT6                (*((volatile unsigned int*)(0x4220A018UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT7                (*((volatile unsigned int*)(0x4220A01CUL)))
#define bM4_EFM_MMF_REMPRT_REMPRT8                (*((volatile unsigned int*)(0x4220A020UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT9                (*((volatile unsigned int*)(0x4220A024UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT10               (*((volatile unsigned int*)(0x4220A028UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT11               (*((volatile unsigned int*)(0x4220A02CUL)))
#define bM4_EFM_MMF_REMPRT_REMPRT12               (*((volatile unsigned int*)(0x4220A030UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT13               (*((volatile unsigned int*)(0x4220A034UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT14               (*((volatile unsigned int*)(0x4220A038UL)))
#define bM4_EFM_MMF_REMPRT_REMPRT15               (*((volatile unsigned int*)(0x4220A03CUL)))
#define bM4_EFM_MMF_REMCR0_RM0SIZE0               (*((volatile unsigned int*)(0x4220A080UL)))
#define bM4_EFM_MMF_REMCR0_RM0SIZE1               (*((volatile unsigned int*)(0x4220A084UL)))
#define bM4_EFM_MMF_REMCR0_RM0SIZE2               (*((volatile unsigned int*)(0x4220A088UL)))
#define bM4_EFM_MMF_REMCR0_RM0SIZE3               (*((volatile unsigned int*)(0x4220A08CUL)))
#define bM4_EFM_MMF_REMCR0_RM0SIZE4               (*((volatile unsigned int*)(0x4220A090UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR0              (*((volatile unsigned int*)(0x4220A0B0UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR1              (*((volatile unsigned int*)(0x4220A0B4UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR2              (*((volatile unsigned int*)(0x4220A0B8UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR3              (*((volatile unsigned int*)(0x4220A0BCUL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR4              (*((volatile unsigned int*)(0x4220A0C0UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR5              (*((volatile unsigned int*)(0x4220A0C4UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR6              (*((volatile unsigned int*)(0x4220A0C8UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR7              (*((volatile unsigned int*)(0x4220A0CCUL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR8              (*((volatile unsigned int*)(0x4220A0D0UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR9              (*((volatile unsigned int*)(0x4220A0D4UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR10             (*((volatile unsigned int*)(0x4220A0D8UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR11             (*((volatile unsigned int*)(0x4220A0DCUL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR12             (*((volatile unsigned int*)(0x4220A0E0UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR13             (*((volatile unsigned int*)(0x4220A0E4UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR14             (*((volatile unsigned int*)(0x4220A0E8UL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR15             (*((volatile unsigned int*)(0x4220A0ECUL)))
#define bM4_EFM_MMF_REMCR0_RM0TADDR16             (*((volatile unsigned int*)(0x4220A0F0UL)))
#define bM4_EFM_MMF_REMCR0_EN0                    (*((volatile unsigned int*)(0x4220A0FCUL)))
#define bM4_EFM_MMF_REMCR1_RM1SIZE0               (*((volatile unsigned int*)(0x4220A100UL)))
#define bM4_EFM_MMF_REMCR1_RM1SIZE1               (*((volatile unsigned int*)(0x4220A104UL)))
#define bM4_EFM_MMF_REMCR1_RM1SIZE2               (*((volatile unsigned int*)(0x4220A108UL)))
#define bM4_EFM_MMF_REMCR1_RM1SIZE3               (*((volatile unsigned int*)(0x4220A10CUL)))
#define bM4_EFM_MMF_REMCR1_RM1SIZE4               (*((volatile unsigned int*)(0x4220A110UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR0              (*((volatile unsigned int*)(0x4220A130UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR1              (*((volatile unsigned int*)(0x4220A134UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR2              (*((volatile unsigned int*)(0x4220A138UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR3              (*((volatile unsigned int*)(0x4220A13CUL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR4              (*((volatile unsigned int*)(0x4220A140UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR5              (*((volatile unsigned int*)(0x4220A144UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR6              (*((volatile unsigned int*)(0x4220A148UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR7              (*((volatile unsigned int*)(0x4220A14CUL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR8              (*((volatile unsigned int*)(0x4220A150UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR9              (*((volatile unsigned int*)(0x4220A154UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR10             (*((volatile unsigned int*)(0x4220A158UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR11             (*((volatile unsigned int*)(0x4220A15CUL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR12             (*((volatile unsigned int*)(0x4220A160UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR13             (*((volatile unsigned int*)(0x4220A164UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR14             (*((volatile unsigned int*)(0x4220A168UL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR15             (*((volatile unsigned int*)(0x4220A16CUL)))
#define bM4_EFM_MMF_REMCR1_RM1TADDR16             (*((volatile unsigned int*)(0x4220A170UL)))
#define bM4_EFM_MMF_REMCR1_EN1                    (*((volatile unsigned int*)(0x4220A17CUL)))
#define bM4_EFM_FRANDS_FRANDS0                    (*((volatile unsigned int*)(0x4220C084UL)))
#define bM4_EFM_FRANDS_FRANDS1                    (*((volatile unsigned int*)(0x4220C088UL)))
#define bM4_EFM_FRANDS_FRANDS2                    (*((volatile unsigned int*)(0x4220C08CUL)))
#define bM4_EFM_FRANDS_FRANDS3                    (*((volatile unsigned int*)(0x4220C090UL)))
#define bM4_EFM_FRANDS_FRANDS4                    (*((volatile unsigned int*)(0x4220C094UL)))
#define bM4_EFM_FRANDS_FRANDS5                    (*((volatile unsigned int*)(0x4220C098UL)))
#define bM4_EFM_FRANDS_FRANDS6                    (*((volatile unsigned int*)(0x4220C09CUL)))
#define bM4_EFM_FRANDS_FRANDS7                    (*((volatile unsigned int*)(0x4220C0A0UL)))
#define bM4_EFM_FRANDS_FRANDS8                    (*((volatile unsigned int*)(0x4220C0A4UL)))
#define bM4_EFM_FRANDS_FRANDS9                    (*((volatile unsigned int*)(0x4220C0A8UL)))
#define bM4_EFM_FRANDS_FRANDS10                   (*((volatile unsigned int*)(0x4220C0ACUL)))
#define bM4_EFM_FRANDS_FRANDS11                   (*((volatile unsigned int*)(0x4220C0B0UL)))
#define bM4_EFM_FRANDS_FRANDS12                   (*((volatile unsigned int*)(0x4220C0B4UL)))
#define bM4_EFM_FRANDS_FRANDS13                   (*((volatile unsigned int*)(0x4220C0B8UL)))
#define bM4_EFM_FRANDS_FRANDFG                    (*((volatile unsigned int*)(0x4220C0C0UL)))
#define bM4_EMB1_CTL_PORTINEN                     (*((volatile unsigned int*)(0x422F8000UL)))
#define bM4_EMB1_CTL_CMPEN0                       (*((volatile unsigned int*)(0x422F8004UL)))
#define bM4_EMB1_CTL_CMPEN1                       (*((volatile unsigned int*)(0x422F8008UL)))
#define bM4_EMB1_CTL_CMPEN2                       (*((volatile unsigned int*)(0x422F800CUL)))
#define bM4_EMB1_CTL_OSCSTPEN                     (*((volatile unsigned int*)(0x422F8014UL)))
#define bM4_EMB1_CTL_PWMSEN0                      (*((volatile unsigned int*)(0x422F8018UL)))
#define bM4_EMB1_CTL_PWMSEN1                      (*((volatile unsigned int*)(0x422F801CUL)))
#define bM4_EMB1_CTL_PWMSEN2                      (*((volatile unsigned int*)(0x422F8020UL)))
#define bM4_EMB1_CTL_NFSEL0                       (*((volatile unsigned int*)(0x422F8070UL)))
#define bM4_EMB1_CTL_NFSEL1                       (*((volatile unsigned int*)(0x422F8074UL)))
#define bM4_EMB1_CTL_NFEN                         (*((volatile unsigned int*)(0x422F8078UL)))
#define bM4_EMB1_CTL_INVSEL                       (*((volatile unsigned int*)(0x422F807CUL)))
#define bM4_EMB1_PWMLV_PWMLV0                     (*((volatile unsigned int*)(0x422F8080UL)))
#define bM4_EMB1_PWMLV_PWMLV1                     (*((volatile unsigned int*)(0x422F8084UL)))
#define bM4_EMB1_PWMLV_PWMLV2                     (*((volatile unsigned int*)(0x422F8088UL)))
#define bM4_EMB1_SOE_SOE                          (*((volatile unsigned int*)(0x422F8100UL)))
#define bM4_EMB1_STAT_PORTINF                     (*((volatile unsigned int*)(0x422F8180UL)))
#define bM4_EMB1_STAT_PWMSF                       (*((volatile unsigned int*)(0x422F8184UL)))
#define bM4_EMB1_STAT_CMPF                        (*((volatile unsigned int*)(0x422F8188UL)))
#define bM4_EMB1_STAT_OSF                         (*((volatile unsigned int*)(0x422F818CUL)))
#define bM4_EMB1_STAT_PORTINST                    (*((volatile unsigned int*)(0x422F8190UL)))
#define bM4_EMB1_STAT_PWMST                       (*((volatile unsigned int*)(0x422F8194UL)))
#define bM4_EMB1_STATCLR_PORTINFCLR               (*((volatile unsigned int*)(0x422F8200UL)))
#define bM4_EMB1_STATCLR_PWMSFCLR                 (*((volatile unsigned int*)(0x422F8204UL)))
#define bM4_EMB1_STATCLR_CMPFCLR                  (*((volatile unsigned int*)(0x422F8208UL)))
#define bM4_EMB1_STATCLR_OSFCLR                   (*((volatile unsigned int*)(0x422F820CUL)))
#define bM4_EMB1_INTEN_PORTINTEN                  (*((volatile unsigned int*)(0x422F8280UL)))
#define bM4_EMB1_INTEN_PWMINTEN                   (*((volatile unsigned int*)(0x422F8284UL)))
#define bM4_EMB1_INTEN_CMPINTEN                   (*((volatile unsigned int*)(0x422F8288UL)))
#define bM4_EMB1_INTEN_OSINTEN                    (*((volatile unsigned int*)(0x422F828CUL)))
#define bM4_EMB2_CTL_PORTINEN                     (*((volatile unsigned int*)(0x422F8400UL)))
#define bM4_EMB2_CTL_CMPEN0                       (*((volatile unsigned int*)(0x422F8404UL)))
#define bM4_EMB2_CTL_CMPEN1                       (*((volatile unsigned int*)(0x422F8408UL)))
#define bM4_EMB2_CTL_CMPEN2                       (*((volatile unsigned int*)(0x422F840CUL)))
#define bM4_EMB2_CTL_OSCSTPEN                     (*((volatile unsigned int*)(0x422F8414UL)))
#define bM4_EMB2_CTL_PWMSEN0                      (*((volatile unsigned int*)(0x422F8418UL)))
#define bM4_EMB2_CTL_PWMSEN1                      (*((volatile unsigned int*)(0x422F841CUL)))
#define bM4_EMB2_CTL_PWMSEN2                      (*((volatile unsigned int*)(0x422F8420UL)))
#define bM4_EMB2_CTL_NFSEL0                       (*((volatile unsigned int*)(0x422F8470UL)))
#define bM4_EMB2_CTL_NFSEL1                       (*((volatile unsigned int*)(0x422F8474UL)))
#define bM4_EMB2_CTL_NFEN                         (*((volatile unsigned int*)(0x422F8478UL)))
#define bM4_EMB2_CTL_INVSEL                       (*((volatile unsigned int*)(0x422F847CUL)))
#define bM4_EMB2_PWMLV_PWMLV0                     (*((volatile unsigned int*)(0x422F8480UL)))
#define bM4_EMB2_PWMLV_PWMLV1                     (*((volatile unsigned int*)(0x422F8484UL)))
#define bM4_EMB2_PWMLV_PWMLV2                     (*((volatile unsigned int*)(0x422F8488UL)))
#define bM4_EMB2_SOE_SOE                          (*((volatile unsigned int*)(0x422F8500UL)))
#define bM4_EMB2_STAT_PORTINF                     (*((volatile unsigned int*)(0x422F8580UL)))
#define bM4_EMB2_STAT_PWMSF                       (*((volatile unsigned int*)(0x422F8584UL)))
#define bM4_EMB2_STAT_CMPF                        (*((volatile unsigned int*)(0x422F8588UL)))
#define bM4_EMB2_STAT_OSF                         (*((volatile unsigned int*)(0x422F858CUL)))
#define bM4_EMB2_STAT_PORTINST                    (*((volatile unsigned int*)(0x422F8590UL)))
#define bM4_EMB2_STAT_PWMST                       (*((volatile unsigned int*)(0x422F8594UL)))
#define bM4_EMB2_STATCLR_PORTINFCLR               (*((volatile unsigned int*)(0x422F8600UL)))
#define bM4_EMB2_STATCLR_PWMSFCLR                 (*((volatile unsigned int*)(0x422F8604UL)))
#define bM4_EMB2_STATCLR_CMPFCLR                  (*((volatile unsigned int*)(0x422F8608UL)))
#define bM4_EMB2_STATCLR_OSFCLR                   (*((volatile unsigned int*)(0x422F860CUL)))
#define bM4_EMB2_INTEN_PORTINTEN                  (*((volatile unsigned int*)(0x422F8680UL)))
#define bM4_EMB2_INTEN_PWMINTEN                   (*((volatile unsigned int*)(0x422F8684UL)))
#define bM4_EMB2_INTEN_CMPINTEN                   (*((volatile unsigned int*)(0x422F8688UL)))
#define bM4_EMB2_INTEN_OSINTEN                    (*((volatile unsigned int*)(0x422F868CUL)))
#define bM4_EMB3_CTL_PORTINEN                     (*((volatile unsigned int*)(0x422F8800UL)))
#define bM4_EMB3_CTL_CMPEN0                       (*((volatile unsigned int*)(0x422F8804UL)))
#define bM4_EMB3_CTL_CMPEN1                       (*((volatile unsigned int*)(0x422F8808UL)))
#define bM4_EMB3_CTL_CMPEN2                       (*((volatile unsigned int*)(0x422F880CUL)))
#define bM4_EMB3_CTL_OSCSTPEN                     (*((volatile unsigned int*)(0x422F8814UL)))
#define bM4_EMB3_CTL_PWMSEN0                      (*((volatile unsigned int*)(0x422F8818UL)))
#define bM4_EMB3_CTL_PWMSEN1                      (*((volatile unsigned int*)(0x422F881CUL)))
#define bM4_EMB3_CTL_PWMSEN2                      (*((volatile unsigned int*)(0x422F8820UL)))
#define bM4_EMB3_CTL_NFSEL0                       (*((volatile unsigned int*)(0x422F8870UL)))
#define bM4_EMB3_CTL_NFSEL1                       (*((volatile unsigned int*)(0x422F8874UL)))
#define bM4_EMB3_CTL_NFEN                         (*((volatile unsigned int*)(0x422F8878UL)))
#define bM4_EMB3_CTL_INVSEL                       (*((volatile unsigned int*)(0x422F887CUL)))
#define bM4_EMB3_PWMLV_PWMLV0                     (*((volatile unsigned int*)(0x422F8880UL)))
#define bM4_EMB3_PWMLV_PWMLV1                     (*((volatile unsigned int*)(0x422F8884UL)))
#define bM4_EMB3_PWMLV_PWMLV2                     (*((volatile unsigned int*)(0x422F8888UL)))
#define bM4_EMB3_SOE_SOE                          (*((volatile unsigned int*)(0x422F8900UL)))
#define bM4_EMB3_STAT_PORTINF                     (*((volatile unsigned int*)(0x422F8980UL)))
#define bM4_EMB3_STAT_PWMSF                       (*((volatile unsigned int*)(0x422F8984UL)))
#define bM4_EMB3_STAT_CMPF                        (*((volatile unsigned int*)(0x422F8988UL)))
#define bM4_EMB3_STAT_OSF                         (*((volatile unsigned int*)(0x422F898CUL)))
#define bM4_EMB3_STAT_PORTINST                    (*((volatile unsigned int*)(0x422F8990UL)))
#define bM4_EMB3_STAT_PWMST                       (*((volatile unsigned int*)(0x422F8994UL)))
#define bM4_EMB3_STATCLR_PORTINFCLR               (*((volatile unsigned int*)(0x422F8A00UL)))
#define bM4_EMB3_STATCLR_PWMSFCLR                 (*((volatile unsigned int*)(0x422F8A04UL)))
#define bM4_EMB3_STATCLR_CMPFCLR                  (*((volatile unsigned int*)(0x422F8A08UL)))
#define bM4_EMB3_STATCLR_OSFCLR                   (*((volatile unsigned int*)(0x422F8A0CUL)))
#define bM4_EMB3_INTEN_PORTINTEN                  (*((volatile unsigned int*)(0x422F8A80UL)))
#define bM4_EMB3_INTEN_PWMINTEN                   (*((volatile unsigned int*)(0x422F8A84UL)))
#define bM4_EMB3_INTEN_CMPINTEN                   (*((volatile unsigned int*)(0x422F8A88UL)))
#define bM4_EMB3_INTEN_OSINTEN                    (*((volatile unsigned int*)(0x422F8A8CUL)))
#define bM4_EMB4_CTL_PORTINEN                     (*((volatile unsigned int*)(0x422F8C00UL)))
#define bM4_EMB4_CTL_CMPEN0                       (*((volatile unsigned int*)(0x422F8C04UL)))
#define bM4_EMB4_CTL_CMPEN1                       (*((volatile unsigned int*)(0x422F8C08UL)))
#define bM4_EMB4_CTL_CMPEN2                       (*((volatile unsigned int*)(0x422F8C0CUL)))
#define bM4_EMB4_CTL_OSCSTPEN                     (*((volatile unsigned int*)(0x422F8C14UL)))
#define bM4_EMB4_CTL_PWMSEN0                      (*((volatile unsigned int*)(0x422F8C18UL)))
#define bM4_EMB4_CTL_PWMSEN1                      (*((volatile unsigned int*)(0x422F8C1CUL)))
#define bM4_EMB4_CTL_PWMSEN2                      (*((volatile unsigned int*)(0x422F8C20UL)))
#define bM4_EMB4_CTL_NFSEL0                       (*((volatile unsigned int*)(0x422F8C70UL)))
#define bM4_EMB4_CTL_NFSEL1                       (*((volatile unsigned int*)(0x422F8C74UL)))
#define bM4_EMB4_CTL_NFEN                         (*((volatile unsigned int*)(0x422F8C78UL)))
#define bM4_EMB4_CTL_INVSEL                       (*((volatile unsigned int*)(0x422F8C7CUL)))
#define bM4_EMB4_PWMLV_PWMLV0                     (*((volatile unsigned int*)(0x422F8C80UL)))
#define bM4_EMB4_PWMLV_PWMLV1                     (*((volatile unsigned int*)(0x422F8C84UL)))
#define bM4_EMB4_PWMLV_PWMLV2                     (*((volatile unsigned int*)(0x422F8C88UL)))
#define bM4_EMB4_SOE_SOE                          (*((volatile unsigned int*)(0x422F8D00UL)))
#define bM4_EMB4_STAT_PORTINF                     (*((volatile unsigned int*)(0x422F8D80UL)))
#define bM4_EMB4_STAT_PWMSF                       (*((volatile unsigned int*)(0x422F8D84UL)))
#define bM4_EMB4_STAT_CMPF                        (*((volatile unsigned int*)(0x422F8D88UL)))
#define bM4_EMB4_STAT_OSF                         (*((volatile unsigned int*)(0x422F8D8CUL)))
#define bM4_EMB4_STAT_PORTINST                    (*((volatile unsigned int*)(0x422F8D90UL)))
#define bM4_EMB4_STAT_PWMST                       (*((volatile unsigned int*)(0x422F8D94UL)))
#define bM4_EMB4_STATCLR_PORTINFCLR               (*((volatile unsigned int*)(0x422F8E00UL)))
#define bM4_EMB4_STATCLR_PWMSFCLR                 (*((volatile unsigned int*)(0x422F8E04UL)))
#define bM4_EMB4_STATCLR_CMPFCLR                  (*((volatile unsigned int*)(0x422F8E08UL)))
#define bM4_EMB4_STATCLR_OSFCLR                   (*((volatile unsigned int*)(0x422F8E0CUL)))
#define bM4_EMB4_INTEN_PORTINTEN                  (*((volatile unsigned int*)(0x422F8E80UL)))
#define bM4_EMB4_INTEN_PWMINTEN                   (*((volatile unsigned int*)(0x422F8E84UL)))
#define bM4_EMB4_INTEN_CMPINTEN                   (*((volatile unsigned int*)(0x422F8E88UL)))
#define bM4_EMB4_INTEN_OSINTEN                    (*((volatile unsigned int*)(0x422F8E8CUL)))
#define bM4_FCM_LVR_LVR0                          (*((volatile unsigned int*)(0x42908000UL)))
#define bM4_FCM_LVR_LVR1                          (*((volatile unsigned int*)(0x42908004UL)))
#define bM4_FCM_LVR_LVR2                          (*((volatile unsigned int*)(0x42908008UL)))
#define bM4_FCM_LVR_LVR3                          (*((volatile unsigned int*)(0x4290800CUL)))
#define bM4_FCM_LVR_LVR4                          (*((volatile unsigned int*)(0x42908010UL)))
#define bM4_FCM_LVR_LVR5                          (*((volatile unsigned int*)(0x42908014UL)))
#define bM4_FCM_LVR_LVR6                          (*((volatile unsigned int*)(0x42908018UL)))
#define bM4_FCM_LVR_LVR7                          (*((volatile unsigned int*)(0x4290801CUL)))
#define bM4_FCM_LVR_LVR8                          (*((volatile unsigned int*)(0x42908020UL)))
#define bM4_FCM_LVR_LVR9                          (*((volatile unsigned int*)(0x42908024UL)))
#define bM4_FCM_LVR_LVR10                         (*((volatile unsigned int*)(0x42908028UL)))
#define bM4_FCM_LVR_LVR11                         (*((volatile unsigned int*)(0x4290802CUL)))
#define bM4_FCM_LVR_LVR12                         (*((volatile unsigned int*)(0x42908030UL)))
#define bM4_FCM_LVR_LVR13                         (*((volatile unsigned int*)(0x42908034UL)))
#define bM4_FCM_LVR_LVR14                         (*((volatile unsigned int*)(0x42908038UL)))
#define bM4_FCM_LVR_LVR15                         (*((volatile unsigned int*)(0x4290803CUL)))
#define bM4_FCM_UVR_UVR0                          (*((volatile unsigned int*)(0x42908080UL)))
#define bM4_FCM_UVR_UVR1                          (*((volatile unsigned int*)(0x42908084UL)))
#define bM4_FCM_UVR_UVR2                          (*((volatile unsigned int*)(0x42908088UL)))
#define bM4_FCM_UVR_UVR3                          (*((volatile unsigned int*)(0x4290808CUL)))
#define bM4_FCM_UVR_UVR4                          (*((volatile unsigned int*)(0x42908090UL)))
#define bM4_FCM_UVR_UVR5                          (*((volatile unsigned int*)(0x42908094UL)))
#define bM4_FCM_UVR_UVR6                          (*((volatile unsigned int*)(0x42908098UL)))
#define bM4_FCM_UVR_UVR7                          (*((volatile unsigned int*)(0x4290809CUL)))
#define bM4_FCM_UVR_UVR8                          (*((volatile unsigned int*)(0x429080A0UL)))
#define bM4_FCM_UVR_UVR9                          (*((volatile unsigned int*)(0x429080A4UL)))
#define bM4_FCM_UVR_UVR10                         (*((volatile unsigned int*)(0x429080A8UL)))
#define bM4_FCM_UVR_UVR11                         (*((volatile unsigned int*)(0x429080ACUL)))
#define bM4_FCM_UVR_UVR12                         (*((volatile unsigned int*)(0x429080B0UL)))
#define bM4_FCM_UVR_UVR13                         (*((volatile unsigned int*)(0x429080B4UL)))
#define bM4_FCM_UVR_UVR14                         (*((volatile unsigned int*)(0x429080B8UL)))
#define bM4_FCM_UVR_UVR15                         (*((volatile unsigned int*)(0x429080BCUL)))
#define bM4_FCM_CNTR_CNTR0                        (*((volatile unsigned int*)(0x42908100UL)))
#define bM4_FCM_CNTR_CNTR1                        (*((volatile unsigned int*)(0x42908104UL)))
#define bM4_FCM_CNTR_CNTR2                        (*((volatile unsigned int*)(0x42908108UL)))
#define bM4_FCM_CNTR_CNTR3                        (*((volatile unsigned int*)(0x4290810CUL)))
#define bM4_FCM_CNTR_CNTR4                        (*((volatile unsigned int*)(0x42908110UL)))
#define bM4_FCM_CNTR_CNTR5                        (*((volatile unsigned int*)(0x42908114UL)))
#define bM4_FCM_CNTR_CNTR6                        (*((volatile unsigned int*)(0x42908118UL)))
#define bM4_FCM_CNTR_CNTR7                        (*((volatile unsigned int*)(0x4290811CUL)))
#define bM4_FCM_CNTR_CNTR8                        (*((volatile unsigned int*)(0x42908120UL)))
#define bM4_FCM_CNTR_CNTR9                        (*((volatile unsigned int*)(0x42908124UL)))
#define bM4_FCM_CNTR_CNTR10                       (*((volatile unsigned int*)(0x42908128UL)))
#define bM4_FCM_CNTR_CNTR11                       (*((volatile unsigned int*)(0x4290812CUL)))
#define bM4_FCM_CNTR_CNTR12                       (*((volatile unsigned int*)(0x42908130UL)))
#define bM4_FCM_CNTR_CNTR13                       (*((volatile unsigned int*)(0x42908134UL)))
#define bM4_FCM_CNTR_CNTR14                       (*((volatile unsigned int*)(0x42908138UL)))
#define bM4_FCM_CNTR_CNTR15                       (*((volatile unsigned int*)(0x4290813CUL)))
#define bM4_FCM_STR_START                         (*((volatile unsigned int*)(0x42908180UL)))
#define bM4_FCM_MCCR_MDIVS0                       (*((volatile unsigned int*)(0x42908200UL)))
#define bM4_FCM_MCCR_MDIVS1                       (*((volatile unsigned int*)(0x42908204UL)))
#define bM4_FCM_MCCR_MCKS0                        (*((volatile unsigned int*)(0x42908210UL)))
#define bM4_FCM_MCCR_MCKS1                        (*((volatile unsigned int*)(0x42908214UL)))
#define bM4_FCM_MCCR_MCKS2                        (*((volatile unsigned int*)(0x42908218UL)))
#define bM4_FCM_MCCR_MCKS3                        (*((volatile unsigned int*)(0x4290821CUL)))
#define bM4_FCM_RCCR_RDIVS0                       (*((volatile unsigned int*)(0x42908280UL)))
#define bM4_FCM_RCCR_RDIVS1                       (*((volatile unsigned int*)(0x42908284UL)))
#define bM4_FCM_RCCR_RCKS0                        (*((volatile unsigned int*)(0x4290828CUL)))
#define bM4_FCM_RCCR_RCKS1                        (*((volatile unsigned int*)(0x42908290UL)))
#define bM4_FCM_RCCR_RCKS2                        (*((volatile unsigned int*)(0x42908294UL)))
#define bM4_FCM_RCCR_RCKS3                        (*((volatile unsigned int*)(0x42908298UL)))
#define bM4_FCM_RCCR_INEXS                        (*((volatile unsigned int*)(0x4290829CUL)))
#define bM4_FCM_RCCR_DNFS0                        (*((volatile unsigned int*)(0x429082A0UL)))
#define bM4_FCM_RCCR_DNFS1                        (*((volatile unsigned int*)(0x429082A4UL)))
#define bM4_FCM_RCCR_EDGES0                       (*((volatile unsigned int*)(0x429082B0UL)))
#define bM4_FCM_RCCR_EDGES1                       (*((volatile unsigned int*)(0x429082B4UL)))
#define bM4_FCM_RCCR_EXREFE                       (*((volatile unsigned int*)(0x429082BCUL)))
#define bM4_FCM_RIER_ERRIE                        (*((volatile unsigned int*)(0x42908300UL)))
#define bM4_FCM_RIER_MENDIE                       (*((volatile unsigned int*)(0x42908304UL)))
#define bM4_FCM_RIER_OVFIE                        (*((volatile unsigned int*)(0x42908308UL)))
#define bM4_FCM_RIER_ERRINTRS                     (*((volatile unsigned int*)(0x42908310UL)))
#define bM4_FCM_RIER_ERRE                         (*((volatile unsigned int*)(0x4290831CUL)))
#define bM4_FCM_SR_ERRF                           (*((volatile unsigned int*)(0x42908380UL)))
#define bM4_FCM_SR_MENDF                          (*((volatile unsigned int*)(0x42908384UL)))
#define bM4_FCM_SR_OVF                            (*((volatile unsigned int*)(0x42908388UL)))
#define bM4_FCM_CLR_ERRFCLR                       (*((volatile unsigned int*)(0x42908400UL)))
#define bM4_FCM_CLR_MENDFCLR                      (*((volatile unsigned int*)(0x42908404UL)))
#define bM4_FCM_CLR_OVFCLR                        (*((volatile unsigned int*)(0x42908408UL)))
#define bM4_HASH_CR_START                         (*((volatile unsigned int*)(0x42108000UL)))
#define bM4_HASH_CR_FST_GRP                       (*((volatile unsigned int*)(0x42108004UL)))
#define bM4_I2C1_CR1_PE                           (*((volatile unsigned int*)(0x429C0000UL)))
#define bM4_I2C1_CR1_SMBUS                        (*((volatile unsigned int*)(0x429C0004UL)))
#define bM4_I2C1_CR1_SMBALRTEN                    (*((volatile unsigned int*)(0x429C0008UL)))
#define bM4_I2C1_CR1_SMBDEFAULTEN                 (*((volatile unsigned int*)(0x429C000CUL)))
#define bM4_I2C1_CR1_SMBHOSTEN                    (*((volatile unsigned int*)(0x429C0010UL)))
#define bM4_I2C1_CR1_ENGC                         (*((volatile unsigned int*)(0x429C0018UL)))
#define bM4_I2C1_CR1_RESTART                      (*((volatile unsigned int*)(0x429C001CUL)))
#define bM4_I2C1_CR1_START                        (*((volatile unsigned int*)(0x429C0020UL)))
#define bM4_I2C1_CR1_STOP                         (*((volatile unsigned int*)(0x429C0024UL)))
#define bM4_I2C1_CR1_ACK                          (*((volatile unsigned int*)(0x429C0028UL)))
#define bM4_I2C1_CR1_SWRST                        (*((volatile unsigned int*)(0x429C003CUL)))
#define bM4_I2C1_CR2_STARTIE                      (*((volatile unsigned int*)(0x429C0080UL)))
#define bM4_I2C1_CR2_SLADDR0IE                    (*((volatile unsigned int*)(0x429C0084UL)))
#define bM4_I2C1_CR2_SLADDR1IE                    (*((volatile unsigned int*)(0x429C0088UL)))
#define bM4_I2C1_CR2_TENDIE                       (*((volatile unsigned int*)(0x429C008CUL)))
#define bM4_I2C1_CR2_STOPIE                       (*((volatile unsigned int*)(0x429C0090UL)))
#define bM4_I2C1_CR2_RFULLIE                      (*((volatile unsigned int*)(0x429C0098UL)))
#define bM4_I2C1_CR2_TEMPTYIE                     (*((volatile unsigned int*)(0x429C009CUL)))
#define bM4_I2C1_CR2_ARLOIE                       (*((volatile unsigned int*)(0x429C00A4UL)))
#define bM4_I2C1_CR2_NACKIE                       (*((volatile unsigned int*)(0x429C00B0UL)))
#define bM4_I2C1_CR2_TMOUTIE                      (*((volatile unsigned int*)(0x429C00B8UL)))
#define bM4_I2C1_CR2_GENCALLIE                    (*((volatile unsigned int*)(0x429C00D0UL)))
#define bM4_I2C1_CR2_SMBDEFAULTIE                 (*((volatile unsigned int*)(0x429C00D4UL)))
#define bM4_I2C1_CR2_SMBHOSTIE                    (*((volatile unsigned int*)(0x429C00D8UL)))
#define bM4_I2C1_CR2_SMBALRTIE                    (*((volatile unsigned int*)(0x429C00DCUL)))
#define bM4_I2C1_CR3_TMOUTEN                      (*((volatile unsigned int*)(0x429C0100UL)))
#define bM4_I2C1_CR3_LTMOUT                       (*((volatile unsigned int*)(0x429C0104UL)))
#define bM4_I2C1_CR3_HTMOUT                       (*((volatile unsigned int*)(0x429C0108UL)))
#define bM4_I2C1_CR3_FACKEN                       (*((volatile unsigned int*)(0x429C011CUL)))
#define bM4_I2C1_CR4_BUSWAIT                      (*((volatile unsigned int*)(0x429C01A8UL)))
#define bM4_I2C1_SLR0_SLADDR00                    (*((volatile unsigned int*)(0x429C0200UL)))
#define bM4_I2C1_SLR0_SLADDR01                    (*((volatile unsigned int*)(0x429C0204UL)))
#define bM4_I2C1_SLR0_SLADDR02                    (*((volatile unsigned int*)(0x429C0208UL)))
#define bM4_I2C1_SLR0_SLADDR03                    (*((volatile unsigned int*)(0x429C020CUL)))
#define bM4_I2C1_SLR0_SLADDR04                    (*((volatile unsigned int*)(0x429C0210UL)))
#define bM4_I2C1_SLR0_SLADDR05                    (*((volatile unsigned int*)(0x429C0214UL)))
#define bM4_I2C1_SLR0_SLADDR06                    (*((volatile unsigned int*)(0x429C0218UL)))
#define bM4_I2C1_SLR0_SLADDR07                    (*((volatile unsigned int*)(0x429C021CUL)))
#define bM4_I2C1_SLR0_SLADDR08                    (*((volatile unsigned int*)(0x429C0220UL)))
#define bM4_I2C1_SLR0_SLADDR09                    (*((volatile unsigned int*)(0x429C0224UL)))
#define bM4_I2C1_SLR0_SLADDR0EN                   (*((volatile unsigned int*)(0x429C0230UL)))
#define bM4_I2C1_SLR0_ADDRMOD0                    (*((volatile unsigned int*)(0x429C023CUL)))
#define bM4_I2C1_SLR1_SLADDR10                    (*((volatile unsigned int*)(0x429C0280UL)))
#define bM4_I2C1_SLR1_SLADDR11                    (*((volatile unsigned int*)(0x429C0284UL)))
#define bM4_I2C1_SLR1_SLADDR12                    (*((volatile unsigned int*)(0x429C0288UL)))
#define bM4_I2C1_SLR1_SLADDR13                    (*((volatile unsigned int*)(0x429C028CUL)))
#define bM4_I2C1_SLR1_SLADDR14                    (*((volatile unsigned int*)(0x429C0290UL)))
#define bM4_I2C1_SLR1_SLADDR15                    (*((volatile unsigned int*)(0x429C0294UL)))
#define bM4_I2C1_SLR1_SLADDR16                    (*((volatile unsigned int*)(0x429C0298UL)))
#define bM4_I2C1_SLR1_SLADDR17                    (*((volatile unsigned int*)(0x429C029CUL)))
#define bM4_I2C1_SLR1_SLADDR18                    (*((volatile unsigned int*)(0x429C02A0UL)))
#define bM4_I2C1_SLR1_SLADDR19                    (*((volatile unsigned int*)(0x429C02A4UL)))
#define bM4_I2C1_SLR1_SLADDR1EN                   (*((volatile unsigned int*)(0x429C02B0UL)))
#define bM4_I2C1_SLR1_ADDRMOD1                    (*((volatile unsigned int*)(0x429C02BCUL)))
#define bM4_I2C1_SLTR_TOUTLOW0                    (*((volatile unsigned int*)(0x429C0300UL)))
#define bM4_I2C1_SLTR_TOUTLOW1                    (*((volatile unsigned int*)(0x429C0304UL)))
#define bM4_I2C1_SLTR_TOUTLOW2                    (*((volatile unsigned int*)(0x429C0308UL)))
#define bM4_I2C1_SLTR_TOUTLOW3                    (*((volatile unsigned int*)(0x429C030CUL)))
#define bM4_I2C1_SLTR_TOUTLOW4                    (*((volatile unsigned int*)(0x429C0310UL)))
#define bM4_I2C1_SLTR_TOUTLOW5                    (*((volatile unsigned int*)(0x429C0314UL)))
#define bM4_I2C1_SLTR_TOUTLOW6                    (*((volatile unsigned int*)(0x429C0318UL)))
#define bM4_I2C1_SLTR_TOUTLOW7                    (*((volatile unsigned int*)(0x429C031CUL)))
#define bM4_I2C1_SLTR_TOUTLOW8                    (*((volatile unsigned int*)(0x429C0320UL)))
#define bM4_I2C1_SLTR_TOUTLOW9                    (*((volatile unsigned int*)(0x429C0324UL)))
#define bM4_I2C1_SLTR_TOUTLOW10                   (*((volatile unsigned int*)(0x429C0328UL)))
#define bM4_I2C1_SLTR_TOUTLOW11                   (*((volatile unsigned int*)(0x429C032CUL)))
#define bM4_I2C1_SLTR_TOUTLOW12                   (*((volatile unsigned int*)(0x429C0330UL)))
#define bM4_I2C1_SLTR_TOUTLOW13                   (*((volatile unsigned int*)(0x429C0334UL)))
#define bM4_I2C1_SLTR_TOUTLOW14                   (*((volatile unsigned int*)(0x429C0338UL)))
#define bM4_I2C1_SLTR_TOUTLOW15                   (*((volatile unsigned int*)(0x429C033CUL)))
#define bM4_I2C1_SLTR_TOUTHIGH0                   (*((volatile unsigned int*)(0x429C0340UL)))
#define bM4_I2C1_SLTR_TOUTHIGH1                   (*((volatile unsigned int*)(0x429C0344UL)))
#define bM4_I2C1_SLTR_TOUTHIGH2                   (*((volatile unsigned int*)(0x429C0348UL)))
#define bM4_I2C1_SLTR_TOUTHIGH3                   (*((volatile unsigned int*)(0x429C034CUL)))
#define bM4_I2C1_SLTR_TOUTHIGH4                   (*((volatile unsigned int*)(0x429C0350UL)))
#define bM4_I2C1_SLTR_TOUTHIGH5                   (*((volatile unsigned int*)(0x429C0354UL)))
#define bM4_I2C1_SLTR_TOUTHIGH6                   (*((volatile unsigned int*)(0x429C0358UL)))
#define bM4_I2C1_SLTR_TOUTHIGH7                   (*((volatile unsigned int*)(0x429C035CUL)))
#define bM4_I2C1_SLTR_TOUTHIGH8                   (*((volatile unsigned int*)(0x429C0360UL)))
#define bM4_I2C1_SLTR_TOUTHIGH9                   (*((volatile unsigned int*)(0x429C0364UL)))
#define bM4_I2C1_SLTR_TOUTHIGH10                  (*((volatile unsigned int*)(0x429C0368UL)))
#define bM4_I2C1_SLTR_TOUTHIGH11                  (*((volatile unsigned int*)(0x429C036CUL)))
#define bM4_I2C1_SLTR_TOUTHIGH12                  (*((volatile unsigned int*)(0x429C0370UL)))
#define bM4_I2C1_SLTR_TOUTHIGH13                  (*((volatile unsigned int*)(0x429C0374UL)))
#define bM4_I2C1_SLTR_TOUTHIGH14                  (*((volatile unsigned int*)(0x429C0378UL)))
#define bM4_I2C1_SLTR_TOUTHIGH15                  (*((volatile unsigned int*)(0x429C037CUL)))
#define bM4_I2C1_SR_STARTF                        (*((volatile unsigned int*)(0x429C0380UL)))
#define bM4_I2C1_SR_SLADDR0F                      (*((volatile unsigned int*)(0x429C0384UL)))
#define bM4_I2C1_SR_SLADDR1F                      (*((volatile unsigned int*)(0x429C0388UL)))
#define bM4_I2C1_SR_TENDF                         (*((volatile unsigned int*)(0x429C038CUL)))
#define bM4_I2C1_SR_STOPF                         (*((volatile unsigned int*)(0x429C0390UL)))
#define bM4_I2C1_SR_RFULLF                        (*((volatile unsigned int*)(0x429C0398UL)))
#define bM4_I2C1_SR_TEMPTYF                       (*((volatile unsigned int*)(0x429C039CUL)))
#define bM4_I2C1_SR_ARLOF                         (*((volatile unsigned int*)(0x429C03A4UL)))
#define bM4_I2C1_SR_ACKRF                         (*((volatile unsigned int*)(0x429C03A8UL)))
#define bM4_I2C1_SR_NACKF                         (*((volatile unsigned int*)(0x429C03B0UL)))
#define bM4_I2C1_SR_TMOUTF                        (*((volatile unsigned int*)(0x429C03B8UL)))
#define bM4_I2C1_SR_MSL                           (*((volatile unsigned int*)(0x429C03C0UL)))
#define bM4_I2C1_SR_BUSY                          (*((volatile unsigned int*)(0x429C03C4UL)))
#define bM4_I2C1_SR_TRA                           (*((volatile unsigned int*)(0x429C03C8UL)))
#define bM4_I2C1_SR_GENCALLF                      (*((volatile unsigned int*)(0x429C03D0UL)))
#define bM4_I2C1_SR_SMBDEFAULTF                   (*((volatile unsigned int*)(0x429C03D4UL)))
#define bM4_I2C1_SR_SMBHOSTF                      (*((volatile unsigned int*)(0x429C03D8UL)))
#define bM4_I2C1_SR_SMBALRTF                      (*((volatile unsigned int*)(0x429C03DCUL)))
#define bM4_I2C1_CLR_STARTFCLR                    (*((volatile unsigned int*)(0x429C0400UL)))
#define bM4_I2C1_CLR_SLADDR0FCLR                  (*((volatile unsigned int*)(0x429C0404UL)))
#define bM4_I2C1_CLR_SLADDR1FCLR                  (*((volatile unsigned int*)(0x429C0408UL)))
#define bM4_I2C1_CLR_TENDFCLR                     (*((volatile unsigned int*)(0x429C040CUL)))
#define bM4_I2C1_CLR_STOPFCLR                     (*((volatile unsigned int*)(0x429C0410UL)))
#define bM4_I2C1_CLR_RFULLFCLR                    (*((volatile unsigned int*)(0x429C0418UL)))
#define bM4_I2C1_CLR_TEMPTYFCLR                   (*((volatile unsigned int*)(0x429C041CUL)))
#define bM4_I2C1_CLR_ARLOFCLR                     (*((volatile unsigned int*)(0x429C0424UL)))
#define bM4_I2C1_CLR_NACKFCLR                     (*((volatile unsigned int*)(0x429C0430UL)))
#define bM4_I2C1_CLR_TMOUTFCLR                    (*((volatile unsigned int*)(0x429C0438UL)))
#define bM4_I2C1_CLR_GENCALLFCLR                  (*((volatile unsigned int*)(0x429C0450UL)))
#define bM4_I2C1_CLR_SMBDEFAULTFCLR               (*((volatile unsigned int*)(0x429C0454UL)))
#define bM4_I2C1_CLR_SMBHOSTFCLR                  (*((volatile unsigned int*)(0x429C0458UL)))
#define bM4_I2C1_CLR_SMBALRTFCLR                  (*((volatile unsigned int*)(0x429C045CUL)))
#define bM4_I2C1_DTR_DT0                          (*((volatile unsigned int*)(0x429C0480UL)))
#define bM4_I2C1_DTR_DT1                          (*((volatile unsigned int*)(0x429C0484UL)))
#define bM4_I2C1_DTR_DT2                          (*((volatile unsigned int*)(0x429C0488UL)))
#define bM4_I2C1_DTR_DT3                          (*((volatile unsigned int*)(0x429C048CUL)))
#define bM4_I2C1_DTR_DT4                          (*((volatile unsigned int*)(0x429C0490UL)))
#define bM4_I2C1_DTR_DT5                          (*((volatile unsigned int*)(0x429C0494UL)))
#define bM4_I2C1_DTR_DT6                          (*((volatile unsigned int*)(0x429C0498UL)))
#define bM4_I2C1_DTR_DT7                          (*((volatile unsigned int*)(0x429C049CUL)))
#define bM4_I2C1_DRR_DR0                          (*((volatile unsigned int*)(0x429C0500UL)))
#define bM4_I2C1_DRR_DR1                          (*((volatile unsigned int*)(0x429C0504UL)))
#define bM4_I2C1_DRR_DR2                          (*((volatile unsigned int*)(0x429C0508UL)))
#define bM4_I2C1_DRR_DR3                          (*((volatile unsigned int*)(0x429C050CUL)))
#define bM4_I2C1_DRR_DR4                          (*((volatile unsigned int*)(0x429C0510UL)))
#define bM4_I2C1_DRR_DR5                          (*((volatile unsigned int*)(0x429C0514UL)))
#define bM4_I2C1_DRR_DR6                          (*((volatile unsigned int*)(0x429C0518UL)))
#define bM4_I2C1_DRR_DR7                          (*((volatile unsigned int*)(0x429C051CUL)))
#define bM4_I2C1_CCR_SLOWW0                       (*((volatile unsigned int*)(0x429C0580UL)))
#define bM4_I2C1_CCR_SLOWW1                       (*((volatile unsigned int*)(0x429C0584UL)))
#define bM4_I2C1_CCR_SLOWW2                       (*((volatile unsigned int*)(0x429C0588UL)))
#define bM4_I2C1_CCR_SLOWW3                       (*((volatile unsigned int*)(0x429C058CUL)))
#define bM4_I2C1_CCR_SLOWW4                       (*((volatile unsigned int*)(0x429C0590UL)))
#define bM4_I2C1_CCR_SHIGHW0                      (*((volatile unsigned int*)(0x429C05A0UL)))
#define bM4_I2C1_CCR_SHIGHW1                      (*((volatile unsigned int*)(0x429C05A4UL)))
#define bM4_I2C1_CCR_SHIGHW2                      (*((volatile unsigned int*)(0x429C05A8UL)))
#define bM4_I2C1_CCR_SHIGHW3                      (*((volatile unsigned int*)(0x429C05ACUL)))
#define bM4_I2C1_CCR_SHIGHW4                      (*((volatile unsigned int*)(0x429C05B0UL)))
#define bM4_I2C1_CCR_FREQ0                        (*((volatile unsigned int*)(0x429C05C0UL)))
#define bM4_I2C1_CCR_FREQ1                        (*((volatile unsigned int*)(0x429C05C4UL)))
#define bM4_I2C1_CCR_FREQ2                        (*((volatile unsigned int*)(0x429C05C8UL)))
#define bM4_I2C1_FLTR_DNF0                        (*((volatile unsigned int*)(0x429C0600UL)))
#define bM4_I2C1_FLTR_DNF1                        (*((volatile unsigned int*)(0x429C0604UL)))
#define bM4_I2C1_FLTR_DNFEN                       (*((volatile unsigned int*)(0x429C0610UL)))
#define bM4_I2C1_FLTR_ANFEN                       (*((volatile unsigned int*)(0x429C0614UL)))
#define bM4_I2C2_CR1_PE                           (*((volatile unsigned int*)(0x429C8000UL)))
#define bM4_I2C2_CR1_SMBUS                        (*((volatile unsigned int*)(0x429C8004UL)))
#define bM4_I2C2_CR1_SMBALRTEN                    (*((volatile unsigned int*)(0x429C8008UL)))
#define bM4_I2C2_CR1_SMBDEFAULTEN                 (*((volatile unsigned int*)(0x429C800CUL)))
#define bM4_I2C2_CR1_SMBHOSTEN                    (*((volatile unsigned int*)(0x429C8010UL)))
#define bM4_I2C2_CR1_ENGC                         (*((volatile unsigned int*)(0x429C8018UL)))
#define bM4_I2C2_CR1_RESTART                      (*((volatile unsigned int*)(0x429C801CUL)))
#define bM4_I2C2_CR1_START                        (*((volatile unsigned int*)(0x429C8020UL)))
#define bM4_I2C2_CR1_STOP                         (*((volatile unsigned int*)(0x429C8024UL)))
#define bM4_I2C2_CR1_ACK                          (*((volatile unsigned int*)(0x429C8028UL)))
#define bM4_I2C2_CR1_SWRST                        (*((volatile unsigned int*)(0x429C803CUL)))
#define bM4_I2C2_CR2_STARTIE                      (*((volatile unsigned int*)(0x429C8080UL)))
#define bM4_I2C2_CR2_SLADDR0IE                    (*((volatile unsigned int*)(0x429C8084UL)))
#define bM4_I2C2_CR2_SLADDR1IE                    (*((volatile unsigned int*)(0x429C8088UL)))
#define bM4_I2C2_CR2_TENDIE                       (*((volatile unsigned int*)(0x429C808CUL)))
#define bM4_I2C2_CR2_STOPIE                       (*((volatile unsigned int*)(0x429C8090UL)))
#define bM4_I2C2_CR2_RFULLIE                      (*((volatile unsigned int*)(0x429C8098UL)))
#define bM4_I2C2_CR2_TEMPTYIE                     (*((volatile unsigned int*)(0x429C809CUL)))
#define bM4_I2C2_CR2_ARLOIE                       (*((volatile unsigned int*)(0x429C80A4UL)))
#define bM4_I2C2_CR2_NACKIE                       (*((volatile unsigned int*)(0x429C80B0UL)))
#define bM4_I2C2_CR2_TMOUTIE                      (*((volatile unsigned int*)(0x429C80B8UL)))
#define bM4_I2C2_CR2_GENCALLIE                    (*((volatile unsigned int*)(0x429C80D0UL)))
#define bM4_I2C2_CR2_SMBDEFAULTIE                 (*((volatile unsigned int*)(0x429C80D4UL)))
#define bM4_I2C2_CR2_SMBHOSTIE                    (*((volatile unsigned int*)(0x429C80D8UL)))
#define bM4_I2C2_CR2_SMBALRTIE                    (*((volatile unsigned int*)(0x429C80DCUL)))
#define bM4_I2C2_CR3_TMOUTEN                      (*((volatile unsigned int*)(0x429C8100UL)))
#define bM4_I2C2_CR3_LTMOUT                       (*((volatile unsigned int*)(0x429C8104UL)))
#define bM4_I2C2_CR3_HTMOUT                       (*((volatile unsigned int*)(0x429C8108UL)))
#define bM4_I2C2_CR3_FACKEN                       (*((volatile unsigned int*)(0x429C811CUL)))
#define bM4_I2C2_CR4_BUSWAIT                      (*((volatile unsigned int*)(0x429C81A8UL)))
#define bM4_I2C2_SLR0_SLADDR00                    (*((volatile unsigned int*)(0x429C8200UL)))
#define bM4_I2C2_SLR0_SLADDR01                    (*((volatile unsigned int*)(0x429C8204UL)))
#define bM4_I2C2_SLR0_SLADDR02                    (*((volatile unsigned int*)(0x429C8208UL)))
#define bM4_I2C2_SLR0_SLADDR03                    (*((volatile unsigned int*)(0x429C820CUL)))
#define bM4_I2C2_SLR0_SLADDR04                    (*((volatile unsigned int*)(0x429C8210UL)))
#define bM4_I2C2_SLR0_SLADDR05                    (*((volatile unsigned int*)(0x429C8214UL)))
#define bM4_I2C2_SLR0_SLADDR06                    (*((volatile unsigned int*)(0x429C8218UL)))
#define bM4_I2C2_SLR0_SLADDR07                    (*((volatile unsigned int*)(0x429C821CUL)))
#define bM4_I2C2_SLR0_SLADDR08                    (*((volatile unsigned int*)(0x429C8220UL)))
#define bM4_I2C2_SLR0_SLADDR09                    (*((volatile unsigned int*)(0x429C8224UL)))
#define bM4_I2C2_SLR0_SLADDR0EN                   (*((volatile unsigned int*)(0x429C8230UL)))
#define bM4_I2C2_SLR0_ADDRMOD0                    (*((volatile unsigned int*)(0x429C823CUL)))
#define bM4_I2C2_SLR1_SLADDR10                    (*((volatile unsigned int*)(0x429C8280UL)))
#define bM4_I2C2_SLR1_SLADDR11                    (*((volatile unsigned int*)(0x429C8284UL)))
#define bM4_I2C2_SLR1_SLADDR12                    (*((volatile unsigned int*)(0x429C8288UL)))
#define bM4_I2C2_SLR1_SLADDR13                    (*((volatile unsigned int*)(0x429C828CUL)))
#define bM4_I2C2_SLR1_SLADDR14                    (*((volatile unsigned int*)(0x429C8290UL)))
#define bM4_I2C2_SLR1_SLADDR15                    (*((volatile unsigned int*)(0x429C8294UL)))
#define bM4_I2C2_SLR1_SLADDR16                    (*((volatile unsigned int*)(0x429C8298UL)))
#define bM4_I2C2_SLR1_SLADDR17                    (*((volatile unsigned int*)(0x429C829CUL)))
#define bM4_I2C2_SLR1_SLADDR18                    (*((volatile unsigned int*)(0x429C82A0UL)))
#define bM4_I2C2_SLR1_SLADDR19                    (*((volatile unsigned int*)(0x429C82A4UL)))
#define bM4_I2C2_SLR1_SLADDR1EN                   (*((volatile unsigned int*)(0x429C82B0UL)))
#define bM4_I2C2_SLR1_ADDRMOD1                    (*((volatile unsigned int*)(0x429C82BCUL)))
#define bM4_I2C2_SLTR_TOUTLOW0                    (*((volatile unsigned int*)(0x429C8300UL)))
#define bM4_I2C2_SLTR_TOUTLOW1                    (*((volatile unsigned int*)(0x429C8304UL)))
#define bM4_I2C2_SLTR_TOUTLOW2                    (*((volatile unsigned int*)(0x429C8308UL)))
#define bM4_I2C2_SLTR_TOUTLOW3                    (*((volatile unsigned int*)(0x429C830CUL)))
#define bM4_I2C2_SLTR_TOUTLOW4                    (*((volatile unsigned int*)(0x429C8310UL)))
#define bM4_I2C2_SLTR_TOUTLOW5                    (*((volatile unsigned int*)(0x429C8314UL)))
#define bM4_I2C2_SLTR_TOUTLOW6                    (*((volatile unsigned int*)(0x429C8318UL)))
#define bM4_I2C2_SLTR_TOUTLOW7                    (*((volatile unsigned int*)(0x429C831CUL)))
#define bM4_I2C2_SLTR_TOUTLOW8                    (*((volatile unsigned int*)(0x429C8320UL)))
#define bM4_I2C2_SLTR_TOUTLOW9                    (*((volatile unsigned int*)(0x429C8324UL)))
#define bM4_I2C2_SLTR_TOUTLOW10                   (*((volatile unsigned int*)(0x429C8328UL)))
#define bM4_I2C2_SLTR_TOUTLOW11                   (*((volatile unsigned int*)(0x429C832CUL)))
#define bM4_I2C2_SLTR_TOUTLOW12                   (*((volatile unsigned int*)(0x429C8330UL)))
#define bM4_I2C2_SLTR_TOUTLOW13                   (*((volatile unsigned int*)(0x429C8334UL)))
#define bM4_I2C2_SLTR_TOUTLOW14                   (*((volatile unsigned int*)(0x429C8338UL)))
#define bM4_I2C2_SLTR_TOUTLOW15                   (*((volatile unsigned int*)(0x429C833CUL)))
#define bM4_I2C2_SLTR_TOUTHIGH0                   (*((volatile unsigned int*)(0x429C8340UL)))
#define bM4_I2C2_SLTR_TOUTHIGH1                   (*((volatile unsigned int*)(0x429C8344UL)))
#define bM4_I2C2_SLTR_TOUTHIGH2                   (*((volatile unsigned int*)(0x429C8348UL)))
#define bM4_I2C2_SLTR_TOUTHIGH3                   (*((volatile unsigned int*)(0x429C834CUL)))
#define bM4_I2C2_SLTR_TOUTHIGH4                   (*((volatile unsigned int*)(0x429C8350UL)))
#define bM4_I2C2_SLTR_TOUTHIGH5                   (*((volatile unsigned int*)(0x429C8354UL)))
#define bM4_I2C2_SLTR_TOUTHIGH6                   (*((volatile unsigned int*)(0x429C8358UL)))
#define bM4_I2C2_SLTR_TOUTHIGH7                   (*((volatile unsigned int*)(0x429C835CUL)))
#define bM4_I2C2_SLTR_TOUTHIGH8                   (*((volatile unsigned int*)(0x429C8360UL)))
#define bM4_I2C2_SLTR_TOUTHIGH9                   (*((volatile unsigned int*)(0x429C8364UL)))
#define bM4_I2C2_SLTR_TOUTHIGH10                  (*((volatile unsigned int*)(0x429C8368UL)))
#define bM4_I2C2_SLTR_TOUTHIGH11                  (*((volatile unsigned int*)(0x429C836CUL)))
#define bM4_I2C2_SLTR_TOUTHIGH12                  (*((volatile unsigned int*)(0x429C8370UL)))
#define bM4_I2C2_SLTR_TOUTHIGH13                  (*((volatile unsigned int*)(0x429C8374UL)))
#define bM4_I2C2_SLTR_TOUTHIGH14                  (*((volatile unsigned int*)(0x429C8378UL)))
#define bM4_I2C2_SLTR_TOUTHIGH15                  (*((volatile unsigned int*)(0x429C837CUL)))
#define bM4_I2C2_SR_STARTF                        (*((volatile unsigned int*)(0x429C8380UL)))
#define bM4_I2C2_SR_SLADDR0F                      (*((volatile unsigned int*)(0x429C8384UL)))
#define bM4_I2C2_SR_SLADDR1F                      (*((volatile unsigned int*)(0x429C8388UL)))
#define bM4_I2C2_SR_TENDF                         (*((volatile unsigned int*)(0x429C838CUL)))
#define bM4_I2C2_SR_STOPF                         (*((volatile unsigned int*)(0x429C8390UL)))
#define bM4_I2C2_SR_RFULLF                        (*((volatile unsigned int*)(0x429C8398UL)))
#define bM4_I2C2_SR_TEMPTYF                       (*((volatile unsigned int*)(0x429C839CUL)))
#define bM4_I2C2_SR_ARLOF                         (*((volatile unsigned int*)(0x429C83A4UL)))
#define bM4_I2C2_SR_ACKRF                         (*((volatile unsigned int*)(0x429C83A8UL)))
#define bM4_I2C2_SR_NACKF                         (*((volatile unsigned int*)(0x429C83B0UL)))
#define bM4_I2C2_SR_TMOUTF                        (*((volatile unsigned int*)(0x429C83B8UL)))
#define bM4_I2C2_SR_MSL                           (*((volatile unsigned int*)(0x429C83C0UL)))
#define bM4_I2C2_SR_BUSY                          (*((volatile unsigned int*)(0x429C83C4UL)))
#define bM4_I2C2_SR_TRA                           (*((volatile unsigned int*)(0x429C83C8UL)))
#define bM4_I2C2_SR_GENCALLF                      (*((volatile unsigned int*)(0x429C83D0UL)))
#define bM4_I2C2_SR_SMBDEFAULTF                   (*((volatile unsigned int*)(0x429C83D4UL)))
#define bM4_I2C2_SR_SMBHOSTF                      (*((volatile unsigned int*)(0x429C83D8UL)))
#define bM4_I2C2_SR_SMBALRTF                      (*((volatile unsigned int*)(0x429C83DCUL)))
#define bM4_I2C2_CLR_STARTFCLR                    (*((volatile unsigned int*)(0x429C8400UL)))
#define bM4_I2C2_CLR_SLADDR0FCLR                  (*((volatile unsigned int*)(0x429C8404UL)))
#define bM4_I2C2_CLR_SLADDR1FCLR                  (*((volatile unsigned int*)(0x429C8408UL)))
#define bM4_I2C2_CLR_TENDFCLR                     (*((volatile unsigned int*)(0x429C840CUL)))
#define bM4_I2C2_CLR_STOPFCLR                     (*((volatile unsigned int*)(0x429C8410UL)))
#define bM4_I2C2_CLR_RFULLFCLR                    (*((volatile unsigned int*)(0x429C8418UL)))
#define bM4_I2C2_CLR_TEMPTYFCLR                   (*((volatile unsigned int*)(0x429C841CUL)))
#define bM4_I2C2_CLR_ARLOFCLR                     (*((volatile unsigned int*)(0x429C8424UL)))
#define bM4_I2C2_CLR_NACKFCLR                     (*((volatile unsigned int*)(0x429C8430UL)))
#define bM4_I2C2_CLR_TMOUTFCLR                    (*((volatile unsigned int*)(0x429C8438UL)))
#define bM4_I2C2_CLR_GENCALLFCLR                  (*((volatile unsigned int*)(0x429C8450UL)))
#define bM4_I2C2_CLR_SMBDEFAULTFCLR               (*((volatile unsigned int*)(0x429C8454UL)))
#define bM4_I2C2_CLR_SMBHOSTFCLR                  (*((volatile unsigned int*)(0x429C8458UL)))
#define bM4_I2C2_CLR_SMBALRTFCLR                  (*((volatile unsigned int*)(0x429C845CUL)))
#define bM4_I2C2_DTR_DT0                          (*((volatile unsigned int*)(0x429C8480UL)))
#define bM4_I2C2_DTR_DT1                          (*((volatile unsigned int*)(0x429C8484UL)))
#define bM4_I2C2_DTR_DT2                          (*((volatile unsigned int*)(0x429C8488UL)))
#define bM4_I2C2_DTR_DT3                          (*((volatile unsigned int*)(0x429C848CUL)))
#define bM4_I2C2_DTR_DT4                          (*((volatile unsigned int*)(0x429C8490UL)))
#define bM4_I2C2_DTR_DT5                          (*((volatile unsigned int*)(0x429C8494UL)))
#define bM4_I2C2_DTR_DT6                          (*((volatile unsigned int*)(0x429C8498UL)))
#define bM4_I2C2_DTR_DT7                          (*((volatile unsigned int*)(0x429C849CUL)))
#define bM4_I2C2_DRR_DR0                          (*((volatile unsigned int*)(0x429C8500UL)))
#define bM4_I2C2_DRR_DR1                          (*((volatile unsigned int*)(0x429C8504UL)))
#define bM4_I2C2_DRR_DR2                          (*((volatile unsigned int*)(0x429C8508UL)))
#define bM4_I2C2_DRR_DR3                          (*((volatile unsigned int*)(0x429C850CUL)))
#define bM4_I2C2_DRR_DR4                          (*((volatile unsigned int*)(0x429C8510UL)))
#define bM4_I2C2_DRR_DR5                          (*((volatile unsigned int*)(0x429C8514UL)))
#define bM4_I2C2_DRR_DR6                          (*((volatile unsigned int*)(0x429C8518UL)))
#define bM4_I2C2_DRR_DR7                          (*((volatile unsigned int*)(0x429C851CUL)))
#define bM4_I2C2_CCR_SLOWW0                       (*((volatile unsigned int*)(0x429C8580UL)))
#define bM4_I2C2_CCR_SLOWW1                       (*((volatile unsigned int*)(0x429C8584UL)))
#define bM4_I2C2_CCR_SLOWW2                       (*((volatile unsigned int*)(0x429C8588UL)))
#define bM4_I2C2_CCR_SLOWW3                       (*((volatile unsigned int*)(0x429C858CUL)))
#define bM4_I2C2_CCR_SLOWW4                       (*((volatile unsigned int*)(0x429C8590UL)))
#define bM4_I2C2_CCR_SHIGHW0                      (*((volatile unsigned int*)(0x429C85A0UL)))
#define bM4_I2C2_CCR_SHIGHW1                      (*((volatile unsigned int*)(0x429C85A4UL)))
#define bM4_I2C2_CCR_SHIGHW2                      (*((volatile unsigned int*)(0x429C85A8UL)))
#define bM4_I2C2_CCR_SHIGHW3                      (*((volatile unsigned int*)(0x429C85ACUL)))
#define bM4_I2C2_CCR_SHIGHW4                      (*((volatile unsigned int*)(0x429C85B0UL)))
#define bM4_I2C2_CCR_FREQ0                        (*((volatile unsigned int*)(0x429C85C0UL)))
#define bM4_I2C2_CCR_FREQ1                        (*((volatile unsigned int*)(0x429C85C4UL)))
#define bM4_I2C2_CCR_FREQ2                        (*((volatile unsigned int*)(0x429C85C8UL)))
#define bM4_I2C2_FLTR_DNF0                        (*((volatile unsigned int*)(0x429C8600UL)))
#define bM4_I2C2_FLTR_DNF1                        (*((volatile unsigned int*)(0x429C8604UL)))
#define bM4_I2C2_FLTR_DNFEN                       (*((volatile unsigned int*)(0x429C8610UL)))
#define bM4_I2C2_FLTR_ANFEN                       (*((volatile unsigned int*)(0x429C8614UL)))
#define bM4_I2C3_CR1_PE                           (*((volatile unsigned int*)(0x429D0000UL)))
#define bM4_I2C3_CR1_SMBUS                        (*((volatile unsigned int*)(0x429D0004UL)))
#define bM4_I2C3_CR1_SMBALRTEN                    (*((volatile unsigned int*)(0x429D0008UL)))
#define bM4_I2C3_CR1_SMBDEFAULTEN                 (*((volatile unsigned int*)(0x429D000CUL)))
#define bM4_I2C3_CR1_SMBHOSTEN                    (*((volatile unsigned int*)(0x429D0010UL)))
#define bM4_I2C3_CR1_ENGC                         (*((volatile unsigned int*)(0x429D0018UL)))
#define bM4_I2C3_CR1_RESTART                      (*((volatile unsigned int*)(0x429D001CUL)))
#define bM4_I2C3_CR1_START                        (*((volatile unsigned int*)(0x429D0020UL)))
#define bM4_I2C3_CR1_STOP                         (*((volatile unsigned int*)(0x429D0024UL)))
#define bM4_I2C3_CR1_ACK                          (*((volatile unsigned int*)(0x429D0028UL)))
#define bM4_I2C3_CR1_SWRST                        (*((volatile unsigned int*)(0x429D003CUL)))
#define bM4_I2C3_CR2_STARTIE                      (*((volatile unsigned int*)(0x429D0080UL)))
#define bM4_I2C3_CR2_SLADDR0IE                    (*((volatile unsigned int*)(0x429D0084UL)))
#define bM4_I2C3_CR2_SLADDR1IE                    (*((volatile unsigned int*)(0x429D0088UL)))
#define bM4_I2C3_CR2_TENDIE                       (*((volatile unsigned int*)(0x429D008CUL)))
#define bM4_I2C3_CR2_STOPIE                       (*((volatile unsigned int*)(0x429D0090UL)))
#define bM4_I2C3_CR2_RFULLIE                      (*((volatile unsigned int*)(0x429D0098UL)))
#define bM4_I2C3_CR2_TEMPTYIE                     (*((volatile unsigned int*)(0x429D009CUL)))
#define bM4_I2C3_CR2_ARLOIE                       (*((volatile unsigned int*)(0x429D00A4UL)))
#define bM4_I2C3_CR2_NACKIE                       (*((volatile unsigned int*)(0x429D00B0UL)))
#define bM4_I2C3_CR2_TMOUTIE                      (*((volatile unsigned int*)(0x429D00B8UL)))
#define bM4_I2C3_CR2_GENCALLIE                    (*((volatile unsigned int*)(0x429D00D0UL)))
#define bM4_I2C3_CR2_SMBDEFAULTIE                 (*((volatile unsigned int*)(0x429D00D4UL)))
#define bM4_I2C3_CR2_SMBHOSTIE                    (*((volatile unsigned int*)(0x429D00D8UL)))
#define bM4_I2C3_CR2_SMBALRTIE                    (*((volatile unsigned int*)(0x429D00DCUL)))
#define bM4_I2C3_CR3_TMOUTEN                      (*((volatile unsigned int*)(0x429D0100UL)))
#define bM4_I2C3_CR3_LTMOUT                       (*((volatile unsigned int*)(0x429D0104UL)))
#define bM4_I2C3_CR3_HTMOUT                       (*((volatile unsigned int*)(0x429D0108UL)))
#define bM4_I2C3_CR3_FACKEN                       (*((volatile unsigned int*)(0x429D011CUL)))
#define bM4_I2C3_CR4_BUSWAIT                      (*((volatile unsigned int*)(0x429D01A8UL)))
#define bM4_I2C3_SLR0_SLADDR00                    (*((volatile unsigned int*)(0x429D0200UL)))
#define bM4_I2C3_SLR0_SLADDR01                    (*((volatile unsigned int*)(0x429D0204UL)))
#define bM4_I2C3_SLR0_SLADDR02                    (*((volatile unsigned int*)(0x429D0208UL)))
#define bM4_I2C3_SLR0_SLADDR03                    (*((volatile unsigned int*)(0x429D020CUL)))
#define bM4_I2C3_SLR0_SLADDR04                    (*((volatile unsigned int*)(0x429D0210UL)))
#define bM4_I2C3_SLR0_SLADDR05                    (*((volatile unsigned int*)(0x429D0214UL)))
#define bM4_I2C3_SLR0_SLADDR06                    (*((volatile unsigned int*)(0x429D0218UL)))
#define bM4_I2C3_SLR0_SLADDR07                    (*((volatile unsigned int*)(0x429D021CUL)))
#define bM4_I2C3_SLR0_SLADDR08                    (*((volatile unsigned int*)(0x429D0220UL)))
#define bM4_I2C3_SLR0_SLADDR09                    (*((volatile unsigned int*)(0x429D0224UL)))
#define bM4_I2C3_SLR0_SLADDR0EN                   (*((volatile unsigned int*)(0x429D0230UL)))
#define bM4_I2C3_SLR0_ADDRMOD0                    (*((volatile unsigned int*)(0x429D023CUL)))
#define bM4_I2C3_SLR1_SLADDR10                    (*((volatile unsigned int*)(0x429D0280UL)))
#define bM4_I2C3_SLR1_SLADDR11                    (*((volatile unsigned int*)(0x429D0284UL)))
#define bM4_I2C3_SLR1_SLADDR12                    (*((volatile unsigned int*)(0x429D0288UL)))
#define bM4_I2C3_SLR1_SLADDR13                    (*((volatile unsigned int*)(0x429D028CUL)))
#define bM4_I2C3_SLR1_SLADDR14                    (*((volatile unsigned int*)(0x429D0290UL)))
#define bM4_I2C3_SLR1_SLADDR15                    (*((volatile unsigned int*)(0x429D0294UL)))
#define bM4_I2C3_SLR1_SLADDR16                    (*((volatile unsigned int*)(0x429D0298UL)))
#define bM4_I2C3_SLR1_SLADDR17                    (*((volatile unsigned int*)(0x429D029CUL)))
#define bM4_I2C3_SLR1_SLADDR18                    (*((volatile unsigned int*)(0x429D02A0UL)))
#define bM4_I2C3_SLR1_SLADDR19                    (*((volatile unsigned int*)(0x429D02A4UL)))
#define bM4_I2C3_SLR1_SLADDR1EN                   (*((volatile unsigned int*)(0x429D02B0UL)))
#define bM4_I2C3_SLR1_ADDRMOD1                    (*((volatile unsigned int*)(0x429D02BCUL)))
#define bM4_I2C3_SLTR_TOUTLOW0                    (*((volatile unsigned int*)(0x429D0300UL)))
#define bM4_I2C3_SLTR_TOUTLOW1                    (*((volatile unsigned int*)(0x429D0304UL)))
#define bM4_I2C3_SLTR_TOUTLOW2                    (*((volatile unsigned int*)(0x429D0308UL)))
#define bM4_I2C3_SLTR_TOUTLOW3                    (*((volatile unsigned int*)(0x429D030CUL)))
#define bM4_I2C3_SLTR_TOUTLOW4                    (*((volatile unsigned int*)(0x429D0310UL)))
#define bM4_I2C3_SLTR_TOUTLOW5                    (*((volatile unsigned int*)(0x429D0314UL)))
#define bM4_I2C3_SLTR_TOUTLOW6                    (*((volatile unsigned int*)(0x429D0318UL)))
#define bM4_I2C3_SLTR_TOUTLOW7                    (*((volatile unsigned int*)(0x429D031CUL)))
#define bM4_I2C3_SLTR_TOUTLOW8                    (*((volatile unsigned int*)(0x429D0320UL)))
#define bM4_I2C3_SLTR_TOUTLOW9                    (*((volatile unsigned int*)(0x429D0324UL)))
#define bM4_I2C3_SLTR_TOUTLOW10                   (*((volatile unsigned int*)(0x429D0328UL)))
#define bM4_I2C3_SLTR_TOUTLOW11                   (*((volatile unsigned int*)(0x429D032CUL)))
#define bM4_I2C3_SLTR_TOUTLOW12                   (*((volatile unsigned int*)(0x429D0330UL)))
#define bM4_I2C3_SLTR_TOUTLOW13                   (*((volatile unsigned int*)(0x429D0334UL)))
#define bM4_I2C3_SLTR_TOUTLOW14                   (*((volatile unsigned int*)(0x429D0338UL)))
#define bM4_I2C3_SLTR_TOUTLOW15                   (*((volatile unsigned int*)(0x429D033CUL)))
#define bM4_I2C3_SLTR_TOUTHIGH0                   (*((volatile unsigned int*)(0x429D0340UL)))
#define bM4_I2C3_SLTR_TOUTHIGH1                   (*((volatile unsigned int*)(0x429D0344UL)))
#define bM4_I2C3_SLTR_TOUTHIGH2                   (*((volatile unsigned int*)(0x429D0348UL)))
#define bM4_I2C3_SLTR_TOUTHIGH3                   (*((volatile unsigned int*)(0x429D034CUL)))
#define bM4_I2C3_SLTR_TOUTHIGH4                   (*((volatile unsigned int*)(0x429D0350UL)))
#define bM4_I2C3_SLTR_TOUTHIGH5                   (*((volatile unsigned int*)(0x429D0354UL)))
#define bM4_I2C3_SLTR_TOUTHIGH6                   (*((volatile unsigned int*)(0x429D0358UL)))
#define bM4_I2C3_SLTR_TOUTHIGH7                   (*((volatile unsigned int*)(0x429D035CUL)))
#define bM4_I2C3_SLTR_TOUTHIGH8                   (*((volatile unsigned int*)(0x429D0360UL)))
#define bM4_I2C3_SLTR_TOUTHIGH9                   (*((volatile unsigned int*)(0x429D0364UL)))
#define bM4_I2C3_SLTR_TOUTHIGH10                  (*((volatile unsigned int*)(0x429D0368UL)))
#define bM4_I2C3_SLTR_TOUTHIGH11                  (*((volatile unsigned int*)(0x429D036CUL)))
#define bM4_I2C3_SLTR_TOUTHIGH12                  (*((volatile unsigned int*)(0x429D0370UL)))
#define bM4_I2C3_SLTR_TOUTHIGH13                  (*((volatile unsigned int*)(0x429D0374UL)))
#define bM4_I2C3_SLTR_TOUTHIGH14                  (*((volatile unsigned int*)(0x429D0378UL)))
#define bM4_I2C3_SLTR_TOUTHIGH15                  (*((volatile unsigned int*)(0x429D037CUL)))
#define bM4_I2C3_SR_STARTF                        (*((volatile unsigned int*)(0x429D0380UL)))
#define bM4_I2C3_SR_SLADDR0F                      (*((volatile unsigned int*)(0x429D0384UL)))
#define bM4_I2C3_SR_SLADDR1F                      (*((volatile unsigned int*)(0x429D0388UL)))
#define bM4_I2C3_SR_TENDF                         (*((volatile unsigned int*)(0x429D038CUL)))
#define bM4_I2C3_SR_STOPF                         (*((volatile unsigned int*)(0x429D0390UL)))
#define bM4_I2C3_SR_RFULLF                        (*((volatile unsigned int*)(0x429D0398UL)))
#define bM4_I2C3_SR_TEMPTYF                       (*((volatile unsigned int*)(0x429D039CUL)))
#define bM4_I2C3_SR_ARLOF                         (*((volatile unsigned int*)(0x429D03A4UL)))
#define bM4_I2C3_SR_ACKRF                         (*((volatile unsigned int*)(0x429D03A8UL)))
#define bM4_I2C3_SR_NACKF                         (*((volatile unsigned int*)(0x429D03B0UL)))
#define bM4_I2C3_SR_TMOUTF                        (*((volatile unsigned int*)(0x429D03B8UL)))
#define bM4_I2C3_SR_MSL                           (*((volatile unsigned int*)(0x429D03C0UL)))
#define bM4_I2C3_SR_BUSY                          (*((volatile unsigned int*)(0x429D03C4UL)))
#define bM4_I2C3_SR_TRA                           (*((volatile unsigned int*)(0x429D03C8UL)))
#define bM4_I2C3_SR_GENCALLF                      (*((volatile unsigned int*)(0x429D03D0UL)))
#define bM4_I2C3_SR_SMBDEFAULTF                   (*((volatile unsigned int*)(0x429D03D4UL)))
#define bM4_I2C3_SR_SMBHOSTF                      (*((volatile unsigned int*)(0x429D03D8UL)))
#define bM4_I2C3_SR_SMBALRTF                      (*((volatile unsigned int*)(0x429D03DCUL)))
#define bM4_I2C3_CLR_STARTFCLR                    (*((volatile unsigned int*)(0x429D0400UL)))
#define bM4_I2C3_CLR_SLADDR0FCLR                  (*((volatile unsigned int*)(0x429D0404UL)))
#define bM4_I2C3_CLR_SLADDR1FCLR                  (*((volatile unsigned int*)(0x429D0408UL)))
#define bM4_I2C3_CLR_TENDFCLR                     (*((volatile unsigned int*)(0x429D040CUL)))
#define bM4_I2C3_CLR_STOPFCLR                     (*((volatile unsigned int*)(0x429D0410UL)))
#define bM4_I2C3_CLR_RFULLFCLR                    (*((volatile unsigned int*)(0x429D0418UL)))
#define bM4_I2C3_CLR_TEMPTYFCLR                   (*((volatile unsigned int*)(0x429D041CUL)))
#define bM4_I2C3_CLR_ARLOFCLR                     (*((volatile unsigned int*)(0x429D0424UL)))
#define bM4_I2C3_CLR_NACKFCLR                     (*((volatile unsigned int*)(0x429D0430UL)))
#define bM4_I2C3_CLR_TMOUTFCLR                    (*((volatile unsigned int*)(0x429D0438UL)))
#define bM4_I2C3_CLR_GENCALLFCLR                  (*((volatile unsigned int*)(0x429D0450UL)))
#define bM4_I2C3_CLR_SMBDEFAULTFCLR               (*((volatile unsigned int*)(0x429D0454UL)))
#define bM4_I2C3_CLR_SMBHOSTFCLR                  (*((volatile unsigned int*)(0x429D0458UL)))
#define bM4_I2C3_CLR_SMBALRTFCLR                  (*((volatile unsigned int*)(0x429D045CUL)))
#define bM4_I2C3_DTR_DT0                          (*((volatile unsigned int*)(0x429D0480UL)))
#define bM4_I2C3_DTR_DT1                          (*((volatile unsigned int*)(0x429D0484UL)))
#define bM4_I2C3_DTR_DT2                          (*((volatile unsigned int*)(0x429D0488UL)))
#define bM4_I2C3_DTR_DT3                          (*((volatile unsigned int*)(0x429D048CUL)))
#define bM4_I2C3_DTR_DT4                          (*((volatile unsigned int*)(0x429D0490UL)))
#define bM4_I2C3_DTR_DT5                          (*((volatile unsigned int*)(0x429D0494UL)))
#define bM4_I2C3_DTR_DT6                          (*((volatile unsigned int*)(0x429D0498UL)))
#define bM4_I2C3_DTR_DT7                          (*((volatile unsigned int*)(0x429D049CUL)))
#define bM4_I2C3_DRR_DR0                          (*((volatile unsigned int*)(0x429D0500UL)))
#define bM4_I2C3_DRR_DR1                          (*((volatile unsigned int*)(0x429D0504UL)))
#define bM4_I2C3_DRR_DR2                          (*((volatile unsigned int*)(0x429D0508UL)))
#define bM4_I2C3_DRR_DR3                          (*((volatile unsigned int*)(0x429D050CUL)))
#define bM4_I2C3_DRR_DR4                          (*((volatile unsigned int*)(0x429D0510UL)))
#define bM4_I2C3_DRR_DR5                          (*((volatile unsigned int*)(0x429D0514UL)))
#define bM4_I2C3_DRR_DR6                          (*((volatile unsigned int*)(0x429D0518UL)))
#define bM4_I2C3_DRR_DR7                          (*((volatile unsigned int*)(0x429D051CUL)))
#define bM4_I2C3_CCR_SLOWW0                       (*((volatile unsigned int*)(0x429D0580UL)))
#define bM4_I2C3_CCR_SLOWW1                       (*((volatile unsigned int*)(0x429D0584UL)))
#define bM4_I2C3_CCR_SLOWW2                       (*((volatile unsigned int*)(0x429D0588UL)))
#define bM4_I2C3_CCR_SLOWW3                       (*((volatile unsigned int*)(0x429D058CUL)))
#define bM4_I2C3_CCR_SLOWW4                       (*((volatile unsigned int*)(0x429D0590UL)))
#define bM4_I2C3_CCR_SHIGHW0                      (*((volatile unsigned int*)(0x429D05A0UL)))
#define bM4_I2C3_CCR_SHIGHW1                      (*((volatile unsigned int*)(0x429D05A4UL)))
#define bM4_I2C3_CCR_SHIGHW2                      (*((volatile unsigned int*)(0x429D05A8UL)))
#define bM4_I2C3_CCR_SHIGHW3                      (*((volatile unsigned int*)(0x429D05ACUL)))
#define bM4_I2C3_CCR_SHIGHW4                      (*((volatile unsigned int*)(0x429D05B0UL)))
#define bM4_I2C3_CCR_FREQ0                        (*((volatile unsigned int*)(0x429D05C0UL)))
#define bM4_I2C3_CCR_FREQ1                        (*((volatile unsigned int*)(0x429D05C4UL)))
#define bM4_I2C3_CCR_FREQ2                        (*((volatile unsigned int*)(0x429D05C8UL)))
#define bM4_I2C3_FLTR_DNF0                        (*((volatile unsigned int*)(0x429D0600UL)))
#define bM4_I2C3_FLTR_DNF1                        (*((volatile unsigned int*)(0x429D0604UL)))
#define bM4_I2C3_FLTR_DNFEN                       (*((volatile unsigned int*)(0x429D0610UL)))
#define bM4_I2C3_FLTR_ANFEN                       (*((volatile unsigned int*)(0x429D0614UL)))
#define bM4_I2S1_CTRL_TXE                         (*((volatile unsigned int*)(0x423C0000UL)))
#define bM4_I2S1_CTRL_TXIE                        (*((volatile unsigned int*)(0x423C0004UL)))
#define bM4_I2S1_CTRL_RXE                         (*((volatile unsigned int*)(0x423C0008UL)))
#define bM4_I2S1_CTRL_RXIE                        (*((volatile unsigned int*)(0x423C000CUL)))
#define bM4_I2S1_CTRL_EIE                         (*((volatile unsigned int*)(0x423C0010UL)))
#define bM4_I2S1_CTRL_WMS                         (*((volatile unsigned int*)(0x423C0014UL)))
#define bM4_I2S1_CTRL_ODD                         (*((volatile unsigned int*)(0x423C0018UL)))
#define bM4_I2S1_CTRL_MCKOE                       (*((volatile unsigned int*)(0x423C001CUL)))
#define bM4_I2S1_CTRL_TXBIRQWL0                   (*((volatile unsigned int*)(0x423C0020UL)))
#define bM4_I2S1_CTRL_TXBIRQWL1                   (*((volatile unsigned int*)(0x423C0024UL)))
#define bM4_I2S1_CTRL_TXBIRQWL2                   (*((volatile unsigned int*)(0x423C0028UL)))
#define bM4_I2S1_CTRL_RXBIRQWL0                   (*((volatile unsigned int*)(0x423C0030UL)))
#define bM4_I2S1_CTRL_RXBIRQWL1                   (*((volatile unsigned int*)(0x423C0034UL)))
#define bM4_I2S1_CTRL_RXBIRQWL2                   (*((volatile unsigned int*)(0x423C0038UL)))
#define bM4_I2S1_CTRL_FIFOR                       (*((volatile unsigned int*)(0x423C0040UL)))
#define bM4_I2S1_CTRL_CODECRC                     (*((volatile unsigned int*)(0x423C0044UL)))
#define bM4_I2S1_CTRL_I2SPLLSEL                   (*((volatile unsigned int*)(0x423C0048UL)))
#define bM4_I2S1_CTRL_SDOE                        (*((volatile unsigned int*)(0x423C004CUL)))
#define bM4_I2S1_CTRL_LRCKOE                      (*((volatile unsigned int*)(0x423C0050UL)))
#define bM4_I2S1_CTRL_CKOE                        (*((volatile unsigned int*)(0x423C0054UL)))
#define bM4_I2S1_CTRL_DUPLEX                      (*((volatile unsigned int*)(0x423C0058UL)))
#define bM4_I2S1_CTRL_CLKSEL                      (*((volatile unsigned int*)(0x423C005CUL)))
#define bM4_I2S1_SR_TXBA                          (*((volatile unsigned int*)(0x423C0080UL)))
#define bM4_I2S1_SR_RXBA                          (*((volatile unsigned int*)(0x423C0084UL)))
#define bM4_I2S1_SR_TXBE                          (*((volatile unsigned int*)(0x423C0088UL)))
#define bM4_I2S1_SR_TXBF                          (*((volatile unsigned int*)(0x423C008CUL)))
#define bM4_I2S1_SR_RXBE                          (*((volatile unsigned int*)(0x423C0090UL)))
#define bM4_I2S1_SR_RXBF                          (*((volatile unsigned int*)(0x423C0094UL)))
#define bM4_I2S1_ER_TXERR                         (*((volatile unsigned int*)(0x423C0100UL)))
#define bM4_I2S1_ER_RXERR                         (*((volatile unsigned int*)(0x423C0104UL)))
#define bM4_I2S1_CFGR_I2SSTD0                     (*((volatile unsigned int*)(0x423C0180UL)))
#define bM4_I2S1_CFGR_I2SSTD1                     (*((volatile unsigned int*)(0x423C0184UL)))
#define bM4_I2S1_CFGR_DATLEN0                     (*((volatile unsigned int*)(0x423C0188UL)))
#define bM4_I2S1_CFGR_DATLEN1                     (*((volatile unsigned int*)(0x423C018CUL)))
#define bM4_I2S1_CFGR_CHLEN                       (*((volatile unsigned int*)(0x423C0190UL)))
#define bM4_I2S1_CFGR_PCMSYNC                     (*((volatile unsigned int*)(0x423C0194UL)))
#define bM4_I2S1_PR_I2SDIV0                       (*((volatile unsigned int*)(0x423C0300UL)))
#define bM4_I2S1_PR_I2SDIV1                       (*((volatile unsigned int*)(0x423C0304UL)))
#define bM4_I2S1_PR_I2SDIV2                       (*((volatile unsigned int*)(0x423C0308UL)))
#define bM4_I2S1_PR_I2SDIV3                       (*((volatile unsigned int*)(0x423C030CUL)))
#define bM4_I2S1_PR_I2SDIV4                       (*((volatile unsigned int*)(0x423C0310UL)))
#define bM4_I2S1_PR_I2SDIV5                       (*((volatile unsigned int*)(0x423C0314UL)))
#define bM4_I2S1_PR_I2SDIV6                       (*((volatile unsigned int*)(0x423C0318UL)))
#define bM4_I2S1_PR_I2SDIV7                       (*((volatile unsigned int*)(0x423C031CUL)))
#define bM4_I2S2_CTRL_TXE                         (*((volatile unsigned int*)(0x423C8000UL)))
#define bM4_I2S2_CTRL_TXIE                        (*((volatile unsigned int*)(0x423C8004UL)))
#define bM4_I2S2_CTRL_RXE                         (*((volatile unsigned int*)(0x423C8008UL)))
#define bM4_I2S2_CTRL_RXIE                        (*((volatile unsigned int*)(0x423C800CUL)))
#define bM4_I2S2_CTRL_EIE                         (*((volatile unsigned int*)(0x423C8010UL)))
#define bM4_I2S2_CTRL_WMS                         (*((volatile unsigned int*)(0x423C8014UL)))
#define bM4_I2S2_CTRL_ODD                         (*((volatile unsigned int*)(0x423C8018UL)))
#define bM4_I2S2_CTRL_MCKOE                       (*((volatile unsigned int*)(0x423C801CUL)))
#define bM4_I2S2_CTRL_TXBIRQWL0                   (*((volatile unsigned int*)(0x423C8020UL)))
#define bM4_I2S2_CTRL_TXBIRQWL1                   (*((volatile unsigned int*)(0x423C8024UL)))
#define bM4_I2S2_CTRL_TXBIRQWL2                   (*((volatile unsigned int*)(0x423C8028UL)))
#define bM4_I2S2_CTRL_RXBIRQWL0                   (*((volatile unsigned int*)(0x423C8030UL)))
#define bM4_I2S2_CTRL_RXBIRQWL1                   (*((volatile unsigned int*)(0x423C8034UL)))
#define bM4_I2S2_CTRL_RXBIRQWL2                   (*((volatile unsigned int*)(0x423C8038UL)))
#define bM4_I2S2_CTRL_FIFOR                       (*((volatile unsigned int*)(0x423C8040UL)))
#define bM4_I2S2_CTRL_CODECRC                     (*((volatile unsigned int*)(0x423C8044UL)))
#define bM4_I2S2_CTRL_I2SPLLSEL                   (*((volatile unsigned int*)(0x423C8048UL)))
#define bM4_I2S2_CTRL_SDOE                        (*((volatile unsigned int*)(0x423C804CUL)))
#define bM4_I2S2_CTRL_LRCKOE                      (*((volatile unsigned int*)(0x423C8050UL)))
#define bM4_I2S2_CTRL_CKOE                        (*((volatile unsigned int*)(0x423C8054UL)))
#define bM4_I2S2_CTRL_DUPLEX                      (*((volatile unsigned int*)(0x423C8058UL)))
#define bM4_I2S2_CTRL_CLKSEL                      (*((volatile unsigned int*)(0x423C805CUL)))
#define bM4_I2S2_SR_TXBA                          (*((volatile unsigned int*)(0x423C8080UL)))
#define bM4_I2S2_SR_RXBA                          (*((volatile unsigned int*)(0x423C8084UL)))
#define bM4_I2S2_SR_TXBE                          (*((volatile unsigned int*)(0x423C8088UL)))
#define bM4_I2S2_SR_TXBF                          (*((volatile unsigned int*)(0x423C808CUL)))
#define bM4_I2S2_SR_RXBE                          (*((volatile unsigned int*)(0x423C8090UL)))
#define bM4_I2S2_SR_RXBF                          (*((volatile unsigned int*)(0x423C8094UL)))
#define bM4_I2S2_ER_TXERR                         (*((volatile unsigned int*)(0x423C8100UL)))
#define bM4_I2S2_ER_RXERR                         (*((volatile unsigned int*)(0x423C8104UL)))
#define bM4_I2S2_CFGR_I2SSTD0                     (*((volatile unsigned int*)(0x423C8180UL)))
#define bM4_I2S2_CFGR_I2SSTD1                     (*((volatile unsigned int*)(0x423C8184UL)))
#define bM4_I2S2_CFGR_DATLEN0                     (*((volatile unsigned int*)(0x423C8188UL)))
#define bM4_I2S2_CFGR_DATLEN1                     (*((volatile unsigned int*)(0x423C818CUL)))
#define bM4_I2S2_CFGR_CHLEN                       (*((volatile unsigned int*)(0x423C8190UL)))
#define bM4_I2S2_CFGR_PCMSYNC                     (*((volatile unsigned int*)(0x423C8194UL)))
#define bM4_I2S2_PR_I2SDIV0                       (*((volatile unsigned int*)(0x423C8300UL)))
#define bM4_I2S2_PR_I2SDIV1                       (*((volatile unsigned int*)(0x423C8304UL)))
#define bM4_I2S2_PR_I2SDIV2                       (*((volatile unsigned int*)(0x423C8308UL)))
#define bM4_I2S2_PR_I2SDIV3                       (*((volatile unsigned int*)(0x423C830CUL)))
#define bM4_I2S2_PR_I2SDIV4                       (*((volatile unsigned int*)(0x423C8310UL)))
#define bM4_I2S2_PR_I2SDIV5                       (*((volatile unsigned int*)(0x423C8314UL)))
#define bM4_I2S2_PR_I2SDIV6                       (*((volatile unsigned int*)(0x423C8318UL)))
#define bM4_I2S2_PR_I2SDIV7                       (*((volatile unsigned int*)(0x423C831CUL)))
#define bM4_I2S3_CTRL_TXE                         (*((volatile unsigned int*)(0x42440000UL)))
#define bM4_I2S3_CTRL_TXIE                        (*((volatile unsigned int*)(0x42440004UL)))
#define bM4_I2S3_CTRL_RXE                         (*((volatile unsigned int*)(0x42440008UL)))
#define bM4_I2S3_CTRL_RXIE                        (*((volatile unsigned int*)(0x4244000CUL)))
#define bM4_I2S3_CTRL_EIE                         (*((volatile unsigned int*)(0x42440010UL)))
#define bM4_I2S3_CTRL_WMS                         (*((volatile unsigned int*)(0x42440014UL)))
#define bM4_I2S3_CTRL_ODD                         (*((volatile unsigned int*)(0x42440018UL)))
#define bM4_I2S3_CTRL_MCKOE                       (*((volatile unsigned int*)(0x4244001CUL)))
#define bM4_I2S3_CTRL_TXBIRQWL0                   (*((volatile unsigned int*)(0x42440020UL)))
#define bM4_I2S3_CTRL_TXBIRQWL1                   (*((volatile unsigned int*)(0x42440024UL)))
#define bM4_I2S3_CTRL_TXBIRQWL2                   (*((volatile unsigned int*)(0x42440028UL)))
#define bM4_I2S3_CTRL_RXBIRQWL0                   (*((volatile unsigned int*)(0x42440030UL)))
#define bM4_I2S3_CTRL_RXBIRQWL1                   (*((volatile unsigned int*)(0x42440034UL)))
#define bM4_I2S3_CTRL_RXBIRQWL2                   (*((volatile unsigned int*)(0x42440038UL)))
#define bM4_I2S3_CTRL_FIFOR                       (*((volatile unsigned int*)(0x42440040UL)))
#define bM4_I2S3_CTRL_CODECRC                     (*((volatile unsigned int*)(0x42440044UL)))
#define bM4_I2S3_CTRL_I2SPLLSEL                   (*((volatile unsigned int*)(0x42440048UL)))
#define bM4_I2S3_CTRL_SDOE                        (*((volatile unsigned int*)(0x4244004CUL)))
#define bM4_I2S3_CTRL_LRCKOE                      (*((volatile unsigned int*)(0x42440050UL)))
#define bM4_I2S3_CTRL_CKOE                        (*((volatile unsigned int*)(0x42440054UL)))
#define bM4_I2S3_CTRL_DUPLEX                      (*((volatile unsigned int*)(0x42440058UL)))
#define bM4_I2S3_CTRL_CLKSEL                      (*((volatile unsigned int*)(0x4244005CUL)))
#define bM4_I2S3_SR_TXBA                          (*((volatile unsigned int*)(0x42440080UL)))
#define bM4_I2S3_SR_RXBA                          (*((volatile unsigned int*)(0x42440084UL)))
#define bM4_I2S3_SR_TXBE                          (*((volatile unsigned int*)(0x42440088UL)))
#define bM4_I2S3_SR_TXBF                          (*((volatile unsigned int*)(0x4244008CUL)))
#define bM4_I2S3_SR_RXBE                          (*((volatile unsigned int*)(0x42440090UL)))
#define bM4_I2S3_SR_RXBF                          (*((volatile unsigned int*)(0x42440094UL)))
#define bM4_I2S3_ER_TXERR                         (*((volatile unsigned int*)(0x42440100UL)))
#define bM4_I2S3_ER_RXERR                         (*((volatile unsigned int*)(0x42440104UL)))
#define bM4_I2S3_CFGR_I2SSTD0                     (*((volatile unsigned int*)(0x42440180UL)))
#define bM4_I2S3_CFGR_I2SSTD1                     (*((volatile unsigned int*)(0x42440184UL)))
#define bM4_I2S3_CFGR_DATLEN0                     (*((volatile unsigned int*)(0x42440188UL)))
#define bM4_I2S3_CFGR_DATLEN1                     (*((volatile unsigned int*)(0x4244018CUL)))
#define bM4_I2S3_CFGR_CHLEN                       (*((volatile unsigned int*)(0x42440190UL)))
#define bM4_I2S3_CFGR_PCMSYNC                     (*((volatile unsigned int*)(0x42440194UL)))
#define bM4_I2S3_PR_I2SDIV0                       (*((volatile unsigned int*)(0x42440300UL)))
#define bM4_I2S3_PR_I2SDIV1                       (*((volatile unsigned int*)(0x42440304UL)))
#define bM4_I2S3_PR_I2SDIV2                       (*((volatile unsigned int*)(0x42440308UL)))
#define bM4_I2S3_PR_I2SDIV3                       (*((volatile unsigned int*)(0x4244030CUL)))
#define bM4_I2S3_PR_I2SDIV4                       (*((volatile unsigned int*)(0x42440310UL)))
#define bM4_I2S3_PR_I2SDIV5                       (*((volatile unsigned int*)(0x42440314UL)))
#define bM4_I2S3_PR_I2SDIV6                       (*((volatile unsigned int*)(0x42440318UL)))
#define bM4_I2S3_PR_I2SDIV7                       (*((volatile unsigned int*)(0x4244031CUL)))
#define bM4_I2S4_CTRL_TXE                         (*((volatile unsigned int*)(0x42448000UL)))
#define bM4_I2S4_CTRL_TXIE                        (*((volatile unsigned int*)(0x42448004UL)))
#define bM4_I2S4_CTRL_RXE                         (*((volatile unsigned int*)(0x42448008UL)))
#define bM4_I2S4_CTRL_RXIE                        (*((volatile unsigned int*)(0x4244800CUL)))
#define bM4_I2S4_CTRL_EIE                         (*((volatile unsigned int*)(0x42448010UL)))
#define bM4_I2S4_CTRL_WMS                         (*((volatile unsigned int*)(0x42448014UL)))
#define bM4_I2S4_CTRL_ODD                         (*((volatile unsigned int*)(0x42448018UL)))
#define bM4_I2S4_CTRL_MCKOE                       (*((volatile unsigned int*)(0x4244801CUL)))
#define bM4_I2S4_CTRL_TXBIRQWL0                   (*((volatile unsigned int*)(0x42448020UL)))
#define bM4_I2S4_CTRL_TXBIRQWL1                   (*((volatile unsigned int*)(0x42448024UL)))
#define bM4_I2S4_CTRL_TXBIRQWL2                   (*((volatile unsigned int*)(0x42448028UL)))
#define bM4_I2S4_CTRL_RXBIRQWL0                   (*((volatile unsigned int*)(0x42448030UL)))
#define bM4_I2S4_CTRL_RXBIRQWL1                   (*((volatile unsigned int*)(0x42448034UL)))
#define bM4_I2S4_CTRL_RXBIRQWL2                   (*((volatile unsigned int*)(0x42448038UL)))
#define bM4_I2S4_CTRL_FIFOR                       (*((volatile unsigned int*)(0x42448040UL)))
#define bM4_I2S4_CTRL_CODECRC                     (*((volatile unsigned int*)(0x42448044UL)))
#define bM4_I2S4_CTRL_I2SPLLSEL                   (*((volatile unsigned int*)(0x42448048UL)))
#define bM4_I2S4_CTRL_SDOE                        (*((volatile unsigned int*)(0x4244804CUL)))
#define bM4_I2S4_CTRL_LRCKOE                      (*((volatile unsigned int*)(0x42448050UL)))
#define bM4_I2S4_CTRL_CKOE                        (*((volatile unsigned int*)(0x42448054UL)))
#define bM4_I2S4_CTRL_DUPLEX                      (*((volatile unsigned int*)(0x42448058UL)))
#define bM4_I2S4_CTRL_CLKSEL                      (*((volatile unsigned int*)(0x4244805CUL)))
#define bM4_I2S4_SR_TXBA                          (*((volatile unsigned int*)(0x42448080UL)))
#define bM4_I2S4_SR_RXBA                          (*((volatile unsigned int*)(0x42448084UL)))
#define bM4_I2S4_SR_TXBE                          (*((volatile unsigned int*)(0x42448088UL)))
#define bM4_I2S4_SR_TXBF                          (*((volatile unsigned int*)(0x4244808CUL)))
#define bM4_I2S4_SR_RXBE                          (*((volatile unsigned int*)(0x42448090UL)))
#define bM4_I2S4_SR_RXBF                          (*((volatile unsigned int*)(0x42448094UL)))
#define bM4_I2S4_ER_TXERR                         (*((volatile unsigned int*)(0x42448100UL)))
#define bM4_I2S4_ER_RXERR                         (*((volatile unsigned int*)(0x42448104UL)))
#define bM4_I2S4_CFGR_I2SSTD0                     (*((volatile unsigned int*)(0x42448180UL)))
#define bM4_I2S4_CFGR_I2SSTD1                     (*((volatile unsigned int*)(0x42448184UL)))
#define bM4_I2S4_CFGR_DATLEN0                     (*((volatile unsigned int*)(0x42448188UL)))
#define bM4_I2S4_CFGR_DATLEN1                     (*((volatile unsigned int*)(0x4244818CUL)))
#define bM4_I2S4_CFGR_CHLEN                       (*((volatile unsigned int*)(0x42448190UL)))
#define bM4_I2S4_CFGR_PCMSYNC                     (*((volatile unsigned int*)(0x42448194UL)))
#define bM4_I2S4_PR_I2SDIV0                       (*((volatile unsigned int*)(0x42448300UL)))
#define bM4_I2S4_PR_I2SDIV1                       (*((volatile unsigned int*)(0x42448304UL)))
#define bM4_I2S4_PR_I2SDIV2                       (*((volatile unsigned int*)(0x42448308UL)))
#define bM4_I2S4_PR_I2SDIV3                       (*((volatile unsigned int*)(0x4244830CUL)))
#define bM4_I2S4_PR_I2SDIV4                       (*((volatile unsigned int*)(0x42448310UL)))
#define bM4_I2S4_PR_I2SDIV5                       (*((volatile unsigned int*)(0x42448314UL)))
#define bM4_I2S4_PR_I2SDIV6                       (*((volatile unsigned int*)(0x42448318UL)))
#define bM4_I2S4_PR_I2SDIV7                       (*((volatile unsigned int*)(0x4244831CUL)))
#define bM4_INTC_NMICR_NMITRG                     (*((volatile unsigned int*)(0x42A20000UL)))
#define bM4_INTC_NMICR_NSMPCLK0                   (*((volatile unsigned int*)(0x42A20010UL)))
#define bM4_INTC_NMICR_NSMPCLK1                   (*((volatile unsigned int*)(0x42A20014UL)))
#define bM4_INTC_NMICR_NFEN                       (*((volatile unsigned int*)(0x42A2001CUL)))
#define bM4_INTC_NMIENR_NMIENR                    (*((volatile unsigned int*)(0x42A20080UL)))
#define bM4_INTC_NMIENR_SWDTENR                   (*((volatile unsigned int*)(0x42A20084UL)))
#define bM4_INTC_NMIENR_PVD1ENR                   (*((volatile unsigned int*)(0x42A20088UL)))
#define bM4_INTC_NMIENR_PVD2ENR                   (*((volatile unsigned int*)(0x42A2008CUL)))
#define bM4_INTC_NMIENR_XTALSTPENR                (*((volatile unsigned int*)(0x42A20094UL)))
#define bM4_INTC_NMIENR_REPENR                    (*((volatile unsigned int*)(0x42A200A0UL)))
#define bM4_INTC_NMIENR_RECCENR                   (*((volatile unsigned int*)(0x42A200A4UL)))
#define bM4_INTC_NMIENR_BUSMENR                   (*((volatile unsigned int*)(0x42A200A8UL)))
#define bM4_INTC_NMIENR_WDTENR                    (*((volatile unsigned int*)(0x42A200ACUL)))
#define bM4_INTC_NMIFR_NMIFR                      (*((volatile unsigned int*)(0x42A20100UL)))
#define bM4_INTC_NMIFR_SWDTFR                     (*((volatile unsigned int*)(0x42A20104UL)))
#define bM4_INTC_NMIFR_PVD1FR                     (*((volatile unsigned int*)(0x42A20108UL)))
#define bM4_INTC_NMIFR_PVD2FR                     (*((volatile unsigned int*)(0x42A2010CUL)))
#define bM4_INTC_NMIFR_XTALSTPFR                  (*((volatile unsigned int*)(0x42A20114UL)))
#define bM4_INTC_NMIFR_REPFR                      (*((volatile unsigned int*)(0x42A20120UL)))
#define bM4_INTC_NMIFR_RECCFR                     (*((volatile unsigned int*)(0x42A20124UL)))
#define bM4_INTC_NMIFR_BUSMFR                     (*((volatile unsigned int*)(0x42A20128UL)))
#define bM4_INTC_NMIFR_WDTFR                      (*((volatile unsigned int*)(0x42A2012CUL)))
#define bM4_INTC_NMICFR_NMICFR                    (*((volatile unsigned int*)(0x42A20180UL)))
#define bM4_INTC_NMICFR_SWDTCFR                   (*((volatile unsigned int*)(0x42A20184UL)))
#define bM4_INTC_NMICFR_PVD1CFR                   (*((volatile unsigned int*)(0x42A20188UL)))
#define bM4_INTC_NMICFR_PVD2CFR                   (*((volatile unsigned int*)(0x42A2018CUL)))
#define bM4_INTC_NMICFR_XTALSTPCFR                (*((volatile unsigned int*)(0x42A20194UL)))
#define bM4_INTC_NMICFR_REPCFR                    (*((volatile unsigned int*)(0x42A201A0UL)))
#define bM4_INTC_NMICFR_RECCCFR                   (*((volatile unsigned int*)(0x42A201A4UL)))
#define bM4_INTC_NMICFR_BUSMCFR                   (*((volatile unsigned int*)(0x42A201A8UL)))
#define bM4_INTC_NMICFR_WDTCFR                    (*((volatile unsigned int*)(0x42A201ACUL)))
#define bM4_INTC_EIRQCR0_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20200UL)))
#define bM4_INTC_EIRQCR0_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20204UL)))
#define bM4_INTC_EIRQCR0_EISMPCLK0                (*((volatile unsigned int*)(0x42A20210UL)))
#define bM4_INTC_EIRQCR0_EISMPCLK1                (*((volatile unsigned int*)(0x42A20214UL)))
#define bM4_INTC_EIRQCR0_EFEN                     (*((volatile unsigned int*)(0x42A2021CUL)))
#define bM4_INTC_EIRQCR1_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20280UL)))
#define bM4_INTC_EIRQCR1_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20284UL)))
#define bM4_INTC_EIRQCR1_EISMPCLK0                (*((volatile unsigned int*)(0x42A20290UL)))
#define bM4_INTC_EIRQCR1_EISMPCLK1                (*((volatile unsigned int*)(0x42A20294UL)))
#define bM4_INTC_EIRQCR1_EFEN                     (*((volatile unsigned int*)(0x42A2029CUL)))
#define bM4_INTC_EIRQCR2_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20300UL)))
#define bM4_INTC_EIRQCR2_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20304UL)))
#define bM4_INTC_EIRQCR2_EISMPCLK0                (*((volatile unsigned int*)(0x42A20310UL)))
#define bM4_INTC_EIRQCR2_EISMPCLK1                (*((volatile unsigned int*)(0x42A20314UL)))
#define bM4_INTC_EIRQCR2_EFEN                     (*((volatile unsigned int*)(0x42A2031CUL)))
#define bM4_INTC_EIRQCR3_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20380UL)))
#define bM4_INTC_EIRQCR3_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20384UL)))
#define bM4_INTC_EIRQCR3_EISMPCLK0                (*((volatile unsigned int*)(0x42A20390UL)))
#define bM4_INTC_EIRQCR3_EISMPCLK1                (*((volatile unsigned int*)(0x42A20394UL)))
#define bM4_INTC_EIRQCR3_EFEN                     (*((volatile unsigned int*)(0x42A2039CUL)))
#define bM4_INTC_EIRQCR4_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20400UL)))
#define bM4_INTC_EIRQCR4_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20404UL)))
#define bM4_INTC_EIRQCR4_EISMPCLK0                (*((volatile unsigned int*)(0x42A20410UL)))
#define bM4_INTC_EIRQCR4_EISMPCLK1                (*((volatile unsigned int*)(0x42A20414UL)))
#define bM4_INTC_EIRQCR4_EFEN                     (*((volatile unsigned int*)(0x42A2041CUL)))
#define bM4_INTC_EIRQCR5_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20480UL)))
#define bM4_INTC_EIRQCR5_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20484UL)))
#define bM4_INTC_EIRQCR5_EISMPCLK0                (*((volatile unsigned int*)(0x42A20490UL)))
#define bM4_INTC_EIRQCR5_EISMPCLK1                (*((volatile unsigned int*)(0x42A20494UL)))
#define bM4_INTC_EIRQCR5_EFEN                     (*((volatile unsigned int*)(0x42A2049CUL)))
#define bM4_INTC_EIRQCR6_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20500UL)))
#define bM4_INTC_EIRQCR6_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20504UL)))
#define bM4_INTC_EIRQCR6_EISMPCLK0                (*((volatile unsigned int*)(0x42A20510UL)))
#define bM4_INTC_EIRQCR6_EISMPCLK1                (*((volatile unsigned int*)(0x42A20514UL)))
#define bM4_INTC_EIRQCR6_EFEN                     (*((volatile unsigned int*)(0x42A2051CUL)))
#define bM4_INTC_EIRQCR7_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20580UL)))
#define bM4_INTC_EIRQCR7_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20584UL)))
#define bM4_INTC_EIRQCR7_EISMPCLK0                (*((volatile unsigned int*)(0x42A20590UL)))
#define bM4_INTC_EIRQCR7_EISMPCLK1                (*((volatile unsigned int*)(0x42A20594UL)))
#define bM4_INTC_EIRQCR7_EFEN                     (*((volatile unsigned int*)(0x42A2059CUL)))
#define bM4_INTC_EIRQCR8_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20600UL)))
#define bM4_INTC_EIRQCR8_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20604UL)))
#define bM4_INTC_EIRQCR8_EISMPCLK0                (*((volatile unsigned int*)(0x42A20610UL)))
#define bM4_INTC_EIRQCR8_EISMPCLK1                (*((volatile unsigned int*)(0x42A20614UL)))
#define bM4_INTC_EIRQCR8_EFEN                     (*((volatile unsigned int*)(0x42A2061CUL)))
#define bM4_INTC_EIRQCR9_EIRQTRG0                 (*((volatile unsigned int*)(0x42A20680UL)))
#define bM4_INTC_EIRQCR9_EIRQTRG1                 (*((volatile unsigned int*)(0x42A20684UL)))
#define bM4_INTC_EIRQCR9_EISMPCLK0                (*((volatile unsigned int*)(0x42A20690UL)))
#define bM4_INTC_EIRQCR9_EISMPCLK1                (*((volatile unsigned int*)(0x42A20694UL)))
#define bM4_INTC_EIRQCR9_EFEN                     (*((volatile unsigned int*)(0x42A2069CUL)))
#define bM4_INTC_EIRQCR10_EIRQTRG0                (*((volatile unsigned int*)(0x42A20700UL)))
#define bM4_INTC_EIRQCR10_EIRQTRG1                (*((volatile unsigned int*)(0x42A20704UL)))
#define bM4_INTC_EIRQCR10_EISMPCLK0               (*((volatile unsigned int*)(0x42A20710UL)))
#define bM4_INTC_EIRQCR10_EISMPCLK1               (*((volatile unsigned int*)(0x42A20714UL)))
#define bM4_INTC_EIRQCR10_EFEN                    (*((volatile unsigned int*)(0x42A2071CUL)))
#define bM4_INTC_EIRQCR11_EIRQTRG0                (*((volatile unsigned int*)(0x42A20780UL)))
#define bM4_INTC_EIRQCR11_EIRQTRG1                (*((volatile unsigned int*)(0x42A20784UL)))
#define bM4_INTC_EIRQCR11_EISMPCLK0               (*((volatile unsigned int*)(0x42A20790UL)))
#define bM4_INTC_EIRQCR11_EISMPCLK1               (*((volatile unsigned int*)(0x42A20794UL)))
#define bM4_INTC_EIRQCR11_EFEN                    (*((volatile unsigned int*)(0x42A2079CUL)))
#define bM4_INTC_EIRQCR12_EIRQTRG0                (*((volatile unsigned int*)(0x42A20800UL)))
#define bM4_INTC_EIRQCR12_EIRQTRG1                (*((volatile unsigned int*)(0x42A20804UL)))
#define bM4_INTC_EIRQCR12_EISMPCLK0               (*((volatile unsigned int*)(0x42A20810UL)))
#define bM4_INTC_EIRQCR12_EISMPCLK1               (*((volatile unsigned int*)(0x42A20814UL)))
#define bM4_INTC_EIRQCR12_EFEN                    (*((volatile unsigned int*)(0x42A2081CUL)))
#define bM4_INTC_EIRQCR13_EIRQTRG0                (*((volatile unsigned int*)(0x42A20880UL)))
#define bM4_INTC_EIRQCR13_EIRQTRG1                (*((volatile unsigned int*)(0x42A20884UL)))
#define bM4_INTC_EIRQCR13_EISMPCLK0               (*((volatile unsigned int*)(0x42A20890UL)))
#define bM4_INTC_EIRQCR13_EISMPCLK1               (*((volatile unsigned int*)(0x42A20894UL)))
#define bM4_INTC_EIRQCR13_EFEN                    (*((volatile unsigned int*)(0x42A2089CUL)))
#define bM4_INTC_EIRQCR14_EIRQTRG0                (*((volatile unsigned int*)(0x42A20900UL)))
#define bM4_INTC_EIRQCR14_EIRQTRG1                (*((volatile unsigned int*)(0x42A20904UL)))
#define bM4_INTC_EIRQCR14_EISMPCLK0               (*((volatile unsigned int*)(0x42A20910UL)))
#define bM4_INTC_EIRQCR14_EISMPCLK1               (*((volatile unsigned int*)(0x42A20914UL)))
#define bM4_INTC_EIRQCR14_EFEN                    (*((volatile unsigned int*)(0x42A2091CUL)))
#define bM4_INTC_EIRQCR15_EIRQTRG0                (*((volatile unsigned int*)(0x42A20980UL)))
#define bM4_INTC_EIRQCR15_EIRQTRG1                (*((volatile unsigned int*)(0x42A20984UL)))
#define bM4_INTC_EIRQCR15_EISMPCLK0               (*((volatile unsigned int*)(0x42A20990UL)))
#define bM4_INTC_EIRQCR15_EISMPCLK1               (*((volatile unsigned int*)(0x42A20994UL)))
#define bM4_INTC_EIRQCR15_EFEN                    (*((volatile unsigned int*)(0x42A2099CUL)))
#define bM4_INTC_WUPEN_EIRQWUEN0                  (*((volatile unsigned int*)(0x42A20A00UL)))
#define bM4_INTC_WUPEN_EIRQWUEN1                  (*((volatile unsigned int*)(0x42A20A04UL)))
#define bM4_INTC_WUPEN_EIRQWUEN2                  (*((volatile unsigned int*)(0x42A20A08UL)))
#define bM4_INTC_WUPEN_EIRQWUEN3                  (*((volatile unsigned int*)(0x42A20A0CUL)))
#define bM4_INTC_WUPEN_EIRQWUEN4                  (*((volatile unsigned int*)(0x42A20A10UL)))
#define bM4_INTC_WUPEN_EIRQWUEN5                  (*((volatile unsigned int*)(0x42A20A14UL)))
#define bM4_INTC_WUPEN_EIRQWUEN6                  (*((volatile unsigned int*)(0x42A20A18UL)))
#define bM4_INTC_WUPEN_EIRQWUEN7                  (*((volatile unsigned int*)(0x42A20A1CUL)))
#define bM4_INTC_WUPEN_EIRQWUEN8                  (*((volatile unsigned int*)(0x42A20A20UL)))
#define bM4_INTC_WUPEN_EIRQWUEN9                  (*((volatile unsigned int*)(0x42A20A24UL)))
#define bM4_INTC_WUPEN_EIRQWUEN10                 (*((volatile unsigned int*)(0x42A20A28UL)))
#define bM4_INTC_WUPEN_EIRQWUEN11                 (*((volatile unsigned int*)(0x42A20A2CUL)))
#define bM4_INTC_WUPEN_EIRQWUEN12                 (*((volatile unsigned int*)(0x42A20A30UL)))
#define bM4_INTC_WUPEN_EIRQWUEN13                 (*((volatile unsigned int*)(0x42A20A34UL)))
#define bM4_INTC_WUPEN_EIRQWUEN14                 (*((volatile unsigned int*)(0x42A20A38UL)))
#define bM4_INTC_WUPEN_EIRQWUEN15                 (*((volatile unsigned int*)(0x42A20A3CUL)))
#define bM4_INTC_WUPEN_SWDTWUEN                   (*((volatile unsigned int*)(0x42A20A40UL)))
#define bM4_INTC_WUPEN_PVD1WUEN                   (*((volatile unsigned int*)(0x42A20A44UL)))
#define bM4_INTC_WUPEN_PVD2WUEN                   (*((volatile unsigned int*)(0x42A20A48UL)))
#define bM4_INTC_WUPEN_CMPI0WUEN                  (*((volatile unsigned int*)(0x42A20A4CUL)))
#define bM4_INTC_WUPEN_WKTMWUEN                   (*((volatile unsigned int*)(0x42A20A50UL)))
#define bM4_INTC_WUPEN_RTCALMWUEN                 (*((volatile unsigned int*)(0x42A20A54UL)))
#define bM4_INTC_WUPEN_RTCPRDWUEN                 (*((volatile unsigned int*)(0x42A20A58UL)))
#define bM4_INTC_WUPEN_TMR0WUEN                   (*((volatile unsigned int*)(0x42A20A5CUL)))
#define bM4_INTC_WUPEN_RXWUEN                     (*((volatile unsigned int*)(0x42A20A64UL)))
#define bM4_INTC_EIFR_EIFR0                       (*((volatile unsigned int*)(0x42A20A80UL)))
#define bM4_INTC_EIFR_EIFR1                       (*((volatile unsigned int*)(0x42A20A84UL)))
#define bM4_INTC_EIFR_EIFR2                       (*((volatile unsigned int*)(0x42A20A88UL)))
#define bM4_INTC_EIFR_EIFR3                       (*((volatile unsigned int*)(0x42A20A8CUL)))
#define bM4_INTC_EIFR_EIFR4                       (*((volatile unsigned int*)(0x42A20A90UL)))
#define bM4_INTC_EIFR_EIFR5                       (*((volatile unsigned int*)(0x42A20A94UL)))
#define bM4_INTC_EIFR_EIFR6                       (*((volatile unsigned int*)(0x42A20A98UL)))
#define bM4_INTC_EIFR_EIFR7                       (*((volatile unsigned int*)(0x42A20A9CUL)))
#define bM4_INTC_EIFR_EIFR8                       (*((volatile unsigned int*)(0x42A20AA0UL)))
#define bM4_INTC_EIFR_EIFR9                       (*((volatile unsigned int*)(0x42A20AA4UL)))
#define bM4_INTC_EIFR_EIFR10                      (*((volatile unsigned int*)(0x42A20AA8UL)))
#define bM4_INTC_EIFR_EIFR11                      (*((volatile unsigned int*)(0x42A20AACUL)))
#define bM4_INTC_EIFR_EIFR12                      (*((volatile unsigned int*)(0x42A20AB0UL)))
#define bM4_INTC_EIFR_EIFR13                      (*((volatile unsigned int*)(0x42A20AB4UL)))
#define bM4_INTC_EIFR_EIFR14                      (*((volatile unsigned int*)(0x42A20AB8UL)))
#define bM4_INTC_EIFR_EIFR15                      (*((volatile unsigned int*)(0x42A20ABCUL)))
#define bM4_INTC_EICFR_EICFR0                     (*((volatile unsigned int*)(0x42A20B00UL)))
#define bM4_INTC_EICFR_EICFR1                     (*((volatile unsigned int*)(0x42A20B04UL)))
#define bM4_INTC_EICFR_EICFR2                     (*((volatile unsigned int*)(0x42A20B08UL)))
#define bM4_INTC_EICFR_EICFR3                     (*((volatile unsigned int*)(0x42A20B0CUL)))
#define bM4_INTC_EICFR_EICFR4                     (*((volatile unsigned int*)(0x42A20B10UL)))
#define bM4_INTC_EICFR_EICFR5                     (*((volatile unsigned int*)(0x42A20B14UL)))
#define bM4_INTC_EICFR_EICFR6                     (*((volatile unsigned int*)(0x42A20B18UL)))
#define bM4_INTC_EICFR_EICFR7                     (*((volatile unsigned int*)(0x42A20B1CUL)))
#define bM4_INTC_EICFR_EICFR8                     (*((volatile unsigned int*)(0x42A20B20UL)))
#define bM4_INTC_EICFR_EICFR9                     (*((volatile unsigned int*)(0x42A20B24UL)))
#define bM4_INTC_EICFR_EICFR10                    (*((volatile unsigned int*)(0x42A20B28UL)))
#define bM4_INTC_EICFR_EICFR11                    (*((volatile unsigned int*)(0x42A20B2CUL)))
#define bM4_INTC_EICFR_EICFR12                    (*((volatile unsigned int*)(0x42A20B30UL)))
#define bM4_INTC_EICFR_EICFR13                    (*((volatile unsigned int*)(0x42A20B34UL)))
#define bM4_INTC_EICFR_EICFR14                    (*((volatile unsigned int*)(0x42A20B38UL)))
#define bM4_INTC_EICFR_EICFR15                    (*((volatile unsigned int*)(0x42A20B3CUL)))
#define bM4_INTC_SEL0_INTSEL0                     (*((volatile unsigned int*)(0x42A20B80UL)))
#define bM4_INTC_SEL0_INTSEL1                     (*((volatile unsigned int*)(0x42A20B84UL)))
#define bM4_INTC_SEL0_INTSEL2                     (*((volatile unsigned int*)(0x42A20B88UL)))
#define bM4_INTC_SEL0_INTSEL3                     (*((volatile unsigned int*)(0x42A20B8CUL)))
#define bM4_INTC_SEL0_INTSEL4                     (*((volatile unsigned int*)(0x42A20B90UL)))
#define bM4_INTC_SEL0_INTSEL5                     (*((volatile unsigned int*)(0x42A20B94UL)))
#define bM4_INTC_SEL0_INTSEL6                     (*((volatile unsigned int*)(0x42A20B98UL)))
#define bM4_INTC_SEL0_INTSEL7                     (*((volatile unsigned int*)(0x42A20B9CUL)))
#define bM4_INTC_SEL0_INTSEL8                     (*((volatile unsigned int*)(0x42A20BA0UL)))
#define bM4_INTC_SEL1_INTSEL0                     (*((volatile unsigned int*)(0x42A20C00UL)))
#define bM4_INTC_SEL1_INTSEL1                     (*((volatile unsigned int*)(0x42A20C04UL)))
#define bM4_INTC_SEL1_INTSEL2                     (*((volatile unsigned int*)(0x42A20C08UL)))
#define bM4_INTC_SEL1_INTSEL3                     (*((volatile unsigned int*)(0x42A20C0CUL)))
#define bM4_INTC_SEL1_INTSEL4                     (*((volatile unsigned int*)(0x42A20C10UL)))
#define bM4_INTC_SEL1_INTSEL5                     (*((volatile unsigned int*)(0x42A20C14UL)))
#define bM4_INTC_SEL1_INTSEL6                     (*((volatile unsigned int*)(0x42A20C18UL)))
#define bM4_INTC_SEL1_INTSEL7                     (*((volatile unsigned int*)(0x42A20C1CUL)))
#define bM4_INTC_SEL1_INTSEL8                     (*((volatile unsigned int*)(0x42A20C20UL)))
#define bM4_INTC_SEL2_INTSEL0                     (*((volatile unsigned int*)(0x42A20C80UL)))
#define bM4_INTC_SEL2_INTSEL1                     (*((volatile unsigned int*)(0x42A20C84UL)))
#define bM4_INTC_SEL2_INTSEL2                     (*((volatile unsigned int*)(0x42A20C88UL)))
#define bM4_INTC_SEL2_INTSEL3                     (*((volatile unsigned int*)(0x42A20C8CUL)))
#define bM4_INTC_SEL2_INTSEL4                     (*((volatile unsigned int*)(0x42A20C90UL)))
#define bM4_INTC_SEL2_INTSEL5                     (*((volatile unsigned int*)(0x42A20C94UL)))
#define bM4_INTC_SEL2_INTSEL6                     (*((volatile unsigned int*)(0x42A20C98UL)))
#define bM4_INTC_SEL2_INTSEL7                     (*((volatile unsigned int*)(0x42A20C9CUL)))
#define bM4_INTC_SEL2_INTSEL8                     (*((volatile unsigned int*)(0x42A20CA0UL)))
#define bM4_INTC_SEL3_INTSEL0                     (*((volatile unsigned int*)(0x42A20D00UL)))
#define bM4_INTC_SEL3_INTSEL1                     (*((volatile unsigned int*)(0x42A20D04UL)))
#define bM4_INTC_SEL3_INTSEL2                     (*((volatile unsigned int*)(0x42A20D08UL)))
#define bM4_INTC_SEL3_INTSEL3                     (*((volatile unsigned int*)(0x42A20D0CUL)))
#define bM4_INTC_SEL3_INTSEL4                     (*((volatile unsigned int*)(0x42A20D10UL)))
#define bM4_INTC_SEL3_INTSEL5                     (*((volatile unsigned int*)(0x42A20D14UL)))
#define bM4_INTC_SEL3_INTSEL6                     (*((volatile unsigned int*)(0x42A20D18UL)))
#define bM4_INTC_SEL3_INTSEL7                     (*((volatile unsigned int*)(0x42A20D1CUL)))
#define bM4_INTC_SEL3_INTSEL8                     (*((volatile unsigned int*)(0x42A20D20UL)))
#define bM4_INTC_SEL4_INTSEL0                     (*((volatile unsigned int*)(0x42A20D80UL)))
#define bM4_INTC_SEL4_INTSEL1                     (*((volatile unsigned int*)(0x42A20D84UL)))
#define bM4_INTC_SEL4_INTSEL2                     (*((volatile unsigned int*)(0x42A20D88UL)))
#define bM4_INTC_SEL4_INTSEL3                     (*((volatile unsigned int*)(0x42A20D8CUL)))
#define bM4_INTC_SEL4_INTSEL4                     (*((volatile unsigned int*)(0x42A20D90UL)))
#define bM4_INTC_SEL4_INTSEL5                     (*((volatile unsigned int*)(0x42A20D94UL)))
#define bM4_INTC_SEL4_INTSEL6                     (*((volatile unsigned int*)(0x42A20D98UL)))
#define bM4_INTC_SEL4_INTSEL7                     (*((volatile unsigned int*)(0x42A20D9CUL)))
#define bM4_INTC_SEL4_INTSEL8                     (*((volatile unsigned int*)(0x42A20DA0UL)))
#define bM4_INTC_SEL5_INTSEL0                     (*((volatile unsigned int*)(0x42A20E00UL)))
#define bM4_INTC_SEL5_INTSEL1                     (*((volatile unsigned int*)(0x42A20E04UL)))
#define bM4_INTC_SEL5_INTSEL2                     (*((volatile unsigned int*)(0x42A20E08UL)))
#define bM4_INTC_SEL5_INTSEL3                     (*((volatile unsigned int*)(0x42A20E0CUL)))
#define bM4_INTC_SEL5_INTSEL4                     (*((volatile unsigned int*)(0x42A20E10UL)))
#define bM4_INTC_SEL5_INTSEL5                     (*((volatile unsigned int*)(0x42A20E14UL)))
#define bM4_INTC_SEL5_INTSEL6                     (*((volatile unsigned int*)(0x42A20E18UL)))
#define bM4_INTC_SEL5_INTSEL7                     (*((volatile unsigned int*)(0x42A20E1CUL)))
#define bM4_INTC_SEL5_INTSEL8                     (*((volatile unsigned int*)(0x42A20E20UL)))
#define bM4_INTC_SEL6_INTSEL0                     (*((volatile unsigned int*)(0x42A20E80UL)))
#define bM4_INTC_SEL6_INTSEL1                     (*((volatile unsigned int*)(0x42A20E84UL)))
#define bM4_INTC_SEL6_INTSEL2                     (*((volatile unsigned int*)(0x42A20E88UL)))
#define bM4_INTC_SEL6_INTSEL3                     (*((volatile unsigned int*)(0x42A20E8CUL)))
#define bM4_INTC_SEL6_INTSEL4                     (*((volatile unsigned int*)(0x42A20E90UL)))
#define bM4_INTC_SEL6_INTSEL5                     (*((volatile unsigned int*)(0x42A20E94UL)))
#define bM4_INTC_SEL6_INTSEL6                     (*((volatile unsigned int*)(0x42A20E98UL)))
#define bM4_INTC_SEL6_INTSEL7                     (*((volatile unsigned int*)(0x42A20E9CUL)))
#define bM4_INTC_SEL6_INTSEL8                     (*((volatile unsigned int*)(0x42A20EA0UL)))
#define bM4_INTC_SEL7_INTSEL0                     (*((volatile unsigned int*)(0x42A20F00UL)))
#define bM4_INTC_SEL7_INTSEL1                     (*((volatile unsigned int*)(0x42A20F04UL)))
#define bM4_INTC_SEL7_INTSEL2                     (*((volatile unsigned int*)(0x42A20F08UL)))
#define bM4_INTC_SEL7_INTSEL3                     (*((volatile unsigned int*)(0x42A20F0CUL)))
#define bM4_INTC_SEL7_INTSEL4                     (*((volatile unsigned int*)(0x42A20F10UL)))
#define bM4_INTC_SEL7_INTSEL5                     (*((volatile unsigned int*)(0x42A20F14UL)))
#define bM4_INTC_SEL7_INTSEL6                     (*((volatile unsigned int*)(0x42A20F18UL)))
#define bM4_INTC_SEL7_INTSEL7                     (*((volatile unsigned int*)(0x42A20F1CUL)))
#define bM4_INTC_SEL7_INTSEL8                     (*((volatile unsigned int*)(0x42A20F20UL)))
#define bM4_INTC_SEL8_INTSEL0                     (*((volatile unsigned int*)(0x42A20F80UL)))
#define bM4_INTC_SEL8_INTSEL1                     (*((volatile unsigned int*)(0x42A20F84UL)))
#define bM4_INTC_SEL8_INTSEL2                     (*((volatile unsigned int*)(0x42A20F88UL)))
#define bM4_INTC_SEL8_INTSEL3                     (*((volatile unsigned int*)(0x42A20F8CUL)))
#define bM4_INTC_SEL8_INTSEL4                     (*((volatile unsigned int*)(0x42A20F90UL)))
#define bM4_INTC_SEL8_INTSEL5                     (*((volatile unsigned int*)(0x42A20F94UL)))
#define bM4_INTC_SEL8_INTSEL6                     (*((volatile unsigned int*)(0x42A20F98UL)))
#define bM4_INTC_SEL8_INTSEL7                     (*((volatile unsigned int*)(0x42A20F9CUL)))
#define bM4_INTC_SEL8_INTSEL8                     (*((volatile unsigned int*)(0x42A20FA0UL)))
#define bM4_INTC_SEL9_INTSEL0                     (*((volatile unsigned int*)(0x42A21000UL)))
#define bM4_INTC_SEL9_INTSEL1                     (*((volatile unsigned int*)(0x42A21004UL)))
#define bM4_INTC_SEL9_INTSEL2                     (*((volatile unsigned int*)(0x42A21008UL)))
#define bM4_INTC_SEL9_INTSEL3                     (*((volatile unsigned int*)(0x42A2100CUL)))
#define bM4_INTC_SEL9_INTSEL4                     (*((volatile unsigned int*)(0x42A21010UL)))
#define bM4_INTC_SEL9_INTSEL5                     (*((volatile unsigned int*)(0x42A21014UL)))
#define bM4_INTC_SEL9_INTSEL6                     (*((volatile unsigned int*)(0x42A21018UL)))
#define bM4_INTC_SEL9_INTSEL7                     (*((volatile unsigned int*)(0x42A2101CUL)))
#define bM4_INTC_SEL9_INTSEL8                     (*((volatile unsigned int*)(0x42A21020UL)))
#define bM4_INTC_SEL10_INTSEL0                    (*((volatile unsigned int*)(0x42A21080UL)))
#define bM4_INTC_SEL10_INTSEL1                    (*((volatile unsigned int*)(0x42A21084UL)))
#define bM4_INTC_SEL10_INTSEL2                    (*((volatile unsigned int*)(0x42A21088UL)))
#define bM4_INTC_SEL10_INTSEL3                    (*((volatile unsigned int*)(0x42A2108CUL)))
#define bM4_INTC_SEL10_INTSEL4                    (*((volatile unsigned int*)(0x42A21090UL)))
#define bM4_INTC_SEL10_INTSEL5                    (*((volatile unsigned int*)(0x42A21094UL)))
#define bM4_INTC_SEL10_INTSEL6                    (*((volatile unsigned int*)(0x42A21098UL)))
#define bM4_INTC_SEL10_INTSEL7                    (*((volatile unsigned int*)(0x42A2109CUL)))
#define bM4_INTC_SEL10_INTSEL8                    (*((volatile unsigned int*)(0x42A210A0UL)))
#define bM4_INTC_SEL11_INTSEL0                    (*((volatile unsigned int*)(0x42A21100UL)))
#define bM4_INTC_SEL11_INTSEL1                    (*((volatile unsigned int*)(0x42A21104UL)))
#define bM4_INTC_SEL11_INTSEL2                    (*((volatile unsigned int*)(0x42A21108UL)))
#define bM4_INTC_SEL11_INTSEL3                    (*((volatile unsigned int*)(0x42A2110CUL)))
#define bM4_INTC_SEL11_INTSEL4                    (*((volatile unsigned int*)(0x42A21110UL)))
#define bM4_INTC_SEL11_INTSEL5                    (*((volatile unsigned int*)(0x42A21114UL)))
#define bM4_INTC_SEL11_INTSEL6                    (*((volatile unsigned int*)(0x42A21118UL)))
#define bM4_INTC_SEL11_INTSEL7                    (*((volatile unsigned int*)(0x42A2111CUL)))
#define bM4_INTC_SEL11_INTSEL8                    (*((volatile unsigned int*)(0x42A21120UL)))
#define bM4_INTC_SEL12_INTSEL0                    (*((volatile unsigned int*)(0x42A21180UL)))
#define bM4_INTC_SEL12_INTSEL1                    (*((volatile unsigned int*)(0x42A21184UL)))
#define bM4_INTC_SEL12_INTSEL2                    (*((volatile unsigned int*)(0x42A21188UL)))
#define bM4_INTC_SEL12_INTSEL3                    (*((volatile unsigned int*)(0x42A2118CUL)))
#define bM4_INTC_SEL12_INTSEL4                    (*((volatile unsigned int*)(0x42A21190UL)))
#define bM4_INTC_SEL12_INTSEL5                    (*((volatile unsigned int*)(0x42A21194UL)))
#define bM4_INTC_SEL12_INTSEL6                    (*((volatile unsigned int*)(0x42A21198UL)))
#define bM4_INTC_SEL12_INTSEL7                    (*((volatile unsigned int*)(0x42A2119CUL)))
#define bM4_INTC_SEL12_INTSEL8                    (*((volatile unsigned int*)(0x42A211A0UL)))
#define bM4_INTC_SEL13_INTSEL0                    (*((volatile unsigned int*)(0x42A21200UL)))
#define bM4_INTC_SEL13_INTSEL1                    (*((volatile unsigned int*)(0x42A21204UL)))
#define bM4_INTC_SEL13_INTSEL2                    (*((volatile unsigned int*)(0x42A21208UL)))
#define bM4_INTC_SEL13_INTSEL3                    (*((volatile unsigned int*)(0x42A2120CUL)))
#define bM4_INTC_SEL13_INTSEL4                    (*((volatile unsigned int*)(0x42A21210UL)))
#define bM4_INTC_SEL13_INTSEL5                    (*((volatile unsigned int*)(0x42A21214UL)))
#define bM4_INTC_SEL13_INTSEL6                    (*((volatile unsigned int*)(0x42A21218UL)))
#define bM4_INTC_SEL13_INTSEL7                    (*((volatile unsigned int*)(0x42A2121CUL)))
#define bM4_INTC_SEL13_INTSEL8                    (*((volatile unsigned int*)(0x42A21220UL)))
#define bM4_INTC_SEL14_INTSEL0                    (*((volatile unsigned int*)(0x42A21280UL)))
#define bM4_INTC_SEL14_INTSEL1                    (*((volatile unsigned int*)(0x42A21284UL)))
#define bM4_INTC_SEL14_INTSEL2                    (*((volatile unsigned int*)(0x42A21288UL)))
#define bM4_INTC_SEL14_INTSEL3                    (*((volatile unsigned int*)(0x42A2128CUL)))
#define bM4_INTC_SEL14_INTSEL4                    (*((volatile unsigned int*)(0x42A21290UL)))
#define bM4_INTC_SEL14_INTSEL5                    (*((volatile unsigned int*)(0x42A21294UL)))
#define bM4_INTC_SEL14_INTSEL6                    (*((volatile unsigned int*)(0x42A21298UL)))
#define bM4_INTC_SEL14_INTSEL7                    (*((volatile unsigned int*)(0x42A2129CUL)))
#define bM4_INTC_SEL14_INTSEL8                    (*((volatile unsigned int*)(0x42A212A0UL)))
#define bM4_INTC_SEL15_INTSEL0                    (*((volatile unsigned int*)(0x42A21300UL)))
#define bM4_INTC_SEL15_INTSEL1                    (*((volatile unsigned int*)(0x42A21304UL)))
#define bM4_INTC_SEL15_INTSEL2                    (*((volatile unsigned int*)(0x42A21308UL)))
#define bM4_INTC_SEL15_INTSEL3                    (*((volatile unsigned int*)(0x42A2130CUL)))
#define bM4_INTC_SEL15_INTSEL4                    (*((volatile unsigned int*)(0x42A21310UL)))
#define bM4_INTC_SEL15_INTSEL5                    (*((volatile unsigned int*)(0x42A21314UL)))
#define bM4_INTC_SEL15_INTSEL6                    (*((volatile unsigned int*)(0x42A21318UL)))
#define bM4_INTC_SEL15_INTSEL7                    (*((volatile unsigned int*)(0x42A2131CUL)))
#define bM4_INTC_SEL15_INTSEL8                    (*((volatile unsigned int*)(0x42A21320UL)))
#define bM4_INTC_SEL16_INTSEL0                    (*((volatile unsigned int*)(0x42A21380UL)))
#define bM4_INTC_SEL16_INTSEL1                    (*((volatile unsigned int*)(0x42A21384UL)))
#define bM4_INTC_SEL16_INTSEL2                    (*((volatile unsigned int*)(0x42A21388UL)))
#define bM4_INTC_SEL16_INTSEL3                    (*((volatile unsigned int*)(0x42A2138CUL)))
#define bM4_INTC_SEL16_INTSEL4                    (*((volatile unsigned int*)(0x42A21390UL)))
#define bM4_INTC_SEL16_INTSEL5                    (*((volatile unsigned int*)(0x42A21394UL)))
#define bM4_INTC_SEL16_INTSEL6                    (*((volatile unsigned int*)(0x42A21398UL)))
#define bM4_INTC_SEL16_INTSEL7                    (*((volatile unsigned int*)(0x42A2139CUL)))
#define bM4_INTC_SEL16_INTSEL8                    (*((volatile unsigned int*)(0x42A213A0UL)))
#define bM4_INTC_SEL17_INTSEL0                    (*((volatile unsigned int*)(0x42A21400UL)))
#define bM4_INTC_SEL17_INTSEL1                    (*((volatile unsigned int*)(0x42A21404UL)))
#define bM4_INTC_SEL17_INTSEL2                    (*((volatile unsigned int*)(0x42A21408UL)))
#define bM4_INTC_SEL17_INTSEL3                    (*((volatile unsigned int*)(0x42A2140CUL)))
#define bM4_INTC_SEL17_INTSEL4                    (*((volatile unsigned int*)(0x42A21410UL)))
#define bM4_INTC_SEL17_INTSEL5                    (*((volatile unsigned int*)(0x42A21414UL)))
#define bM4_INTC_SEL17_INTSEL6                    (*((volatile unsigned int*)(0x42A21418UL)))
#define bM4_INTC_SEL17_INTSEL7                    (*((volatile unsigned int*)(0x42A2141CUL)))
#define bM4_INTC_SEL17_INTSEL8                    (*((volatile unsigned int*)(0x42A21420UL)))
#define bM4_INTC_SEL18_INTSEL0                    (*((volatile unsigned int*)(0x42A21480UL)))
#define bM4_INTC_SEL18_INTSEL1                    (*((volatile unsigned int*)(0x42A21484UL)))
#define bM4_INTC_SEL18_INTSEL2                    (*((volatile unsigned int*)(0x42A21488UL)))
#define bM4_INTC_SEL18_INTSEL3                    (*((volatile unsigned int*)(0x42A2148CUL)))
#define bM4_INTC_SEL18_INTSEL4                    (*((volatile unsigned int*)(0x42A21490UL)))
#define bM4_INTC_SEL18_INTSEL5                    (*((volatile unsigned int*)(0x42A21494UL)))
#define bM4_INTC_SEL18_INTSEL6                    (*((volatile unsigned int*)(0x42A21498UL)))
#define bM4_INTC_SEL18_INTSEL7                    (*((volatile unsigned int*)(0x42A2149CUL)))
#define bM4_INTC_SEL18_INTSEL8                    (*((volatile unsigned int*)(0x42A214A0UL)))
#define bM4_INTC_SEL19_INTSEL0                    (*((volatile unsigned int*)(0x42A21500UL)))
#define bM4_INTC_SEL19_INTSEL1                    (*((volatile unsigned int*)(0x42A21504UL)))
#define bM4_INTC_SEL19_INTSEL2                    (*((volatile unsigned int*)(0x42A21508UL)))
#define bM4_INTC_SEL19_INTSEL3                    (*((volatile unsigned int*)(0x42A2150CUL)))
#define bM4_INTC_SEL19_INTSEL4                    (*((volatile unsigned int*)(0x42A21510UL)))
#define bM4_INTC_SEL19_INTSEL5                    (*((volatile unsigned int*)(0x42A21514UL)))
#define bM4_INTC_SEL19_INTSEL6                    (*((volatile unsigned int*)(0x42A21518UL)))
#define bM4_INTC_SEL19_INTSEL7                    (*((volatile unsigned int*)(0x42A2151CUL)))
#define bM4_INTC_SEL19_INTSEL8                    (*((volatile unsigned int*)(0x42A21520UL)))
#define bM4_INTC_SEL20_INTSEL0                    (*((volatile unsigned int*)(0x42A21580UL)))
#define bM4_INTC_SEL20_INTSEL1                    (*((volatile unsigned int*)(0x42A21584UL)))
#define bM4_INTC_SEL20_INTSEL2                    (*((volatile unsigned int*)(0x42A21588UL)))
#define bM4_INTC_SEL20_INTSEL3                    (*((volatile unsigned int*)(0x42A2158CUL)))
#define bM4_INTC_SEL20_INTSEL4                    (*((volatile unsigned int*)(0x42A21590UL)))
#define bM4_INTC_SEL20_INTSEL5                    (*((volatile unsigned int*)(0x42A21594UL)))
#define bM4_INTC_SEL20_INTSEL6                    (*((volatile unsigned int*)(0x42A21598UL)))
#define bM4_INTC_SEL20_INTSEL7                    (*((volatile unsigned int*)(0x42A2159CUL)))
#define bM4_INTC_SEL20_INTSEL8                    (*((volatile unsigned int*)(0x42A215A0UL)))
#define bM4_INTC_SEL21_INTSEL0                    (*((volatile unsigned int*)(0x42A21600UL)))
#define bM4_INTC_SEL21_INTSEL1                    (*((volatile unsigned int*)(0x42A21604UL)))
#define bM4_INTC_SEL21_INTSEL2                    (*((volatile unsigned int*)(0x42A21608UL)))
#define bM4_INTC_SEL21_INTSEL3                    (*((volatile unsigned int*)(0x42A2160CUL)))
#define bM4_INTC_SEL21_INTSEL4                    (*((volatile unsigned int*)(0x42A21610UL)))
#define bM4_INTC_SEL21_INTSEL5                    (*((volatile unsigned int*)(0x42A21614UL)))
#define bM4_INTC_SEL21_INTSEL6                    (*((volatile unsigned int*)(0x42A21618UL)))
#define bM4_INTC_SEL21_INTSEL7                    (*((volatile unsigned int*)(0x42A2161CUL)))
#define bM4_INTC_SEL21_INTSEL8                    (*((volatile unsigned int*)(0x42A21620UL)))
#define bM4_INTC_SEL22_INTSEL0                    (*((volatile unsigned int*)(0x42A21680UL)))
#define bM4_INTC_SEL22_INTSEL1                    (*((volatile unsigned int*)(0x42A21684UL)))
#define bM4_INTC_SEL22_INTSEL2                    (*((volatile unsigned int*)(0x42A21688UL)))
#define bM4_INTC_SEL22_INTSEL3                    (*((volatile unsigned int*)(0x42A2168CUL)))
#define bM4_INTC_SEL22_INTSEL4                    (*((volatile unsigned int*)(0x42A21690UL)))
#define bM4_INTC_SEL22_INTSEL5                    (*((volatile unsigned int*)(0x42A21694UL)))
#define bM4_INTC_SEL22_INTSEL6                    (*((volatile unsigned int*)(0x42A21698UL)))
#define bM4_INTC_SEL22_INTSEL7                    (*((volatile unsigned int*)(0x42A2169CUL)))
#define bM4_INTC_SEL22_INTSEL8                    (*((volatile unsigned int*)(0x42A216A0UL)))
#define bM4_INTC_SEL23_INTSEL0                    (*((volatile unsigned int*)(0x42A21700UL)))
#define bM4_INTC_SEL23_INTSEL1                    (*((volatile unsigned int*)(0x42A21704UL)))
#define bM4_INTC_SEL23_INTSEL2                    (*((volatile unsigned int*)(0x42A21708UL)))
#define bM4_INTC_SEL23_INTSEL3                    (*((volatile unsigned int*)(0x42A2170CUL)))
#define bM4_INTC_SEL23_INTSEL4                    (*((volatile unsigned int*)(0x42A21710UL)))
#define bM4_INTC_SEL23_INTSEL5                    (*((volatile unsigned int*)(0x42A21714UL)))
#define bM4_INTC_SEL23_INTSEL6                    (*((volatile unsigned int*)(0x42A21718UL)))
#define bM4_INTC_SEL23_INTSEL7                    (*((volatile unsigned int*)(0x42A2171CUL)))
#define bM4_INTC_SEL23_INTSEL8                    (*((volatile unsigned int*)(0x42A21720UL)))
#define bM4_INTC_SEL24_INTSEL0                    (*((volatile unsigned int*)(0x42A21780UL)))
#define bM4_INTC_SEL24_INTSEL1                    (*((volatile unsigned int*)(0x42A21784UL)))
#define bM4_INTC_SEL24_INTSEL2                    (*((volatile unsigned int*)(0x42A21788UL)))
#define bM4_INTC_SEL24_INTSEL3                    (*((volatile unsigned int*)(0x42A2178CUL)))
#define bM4_INTC_SEL24_INTSEL4                    (*((volatile unsigned int*)(0x42A21790UL)))
#define bM4_INTC_SEL24_INTSEL5                    (*((volatile unsigned int*)(0x42A21794UL)))
#define bM4_INTC_SEL24_INTSEL6                    (*((volatile unsigned int*)(0x42A21798UL)))
#define bM4_INTC_SEL24_INTSEL7                    (*((volatile unsigned int*)(0x42A2179CUL)))
#define bM4_INTC_SEL24_INTSEL8                    (*((volatile unsigned int*)(0x42A217A0UL)))
#define bM4_INTC_SEL25_INTSEL0                    (*((volatile unsigned int*)(0x42A21800UL)))
#define bM4_INTC_SEL25_INTSEL1                    (*((volatile unsigned int*)(0x42A21804UL)))
#define bM4_INTC_SEL25_INTSEL2                    (*((volatile unsigned int*)(0x42A21808UL)))
#define bM4_INTC_SEL25_INTSEL3                    (*((volatile unsigned int*)(0x42A2180CUL)))
#define bM4_INTC_SEL25_INTSEL4                    (*((volatile unsigned int*)(0x42A21810UL)))
#define bM4_INTC_SEL25_INTSEL5                    (*((volatile unsigned int*)(0x42A21814UL)))
#define bM4_INTC_SEL25_INTSEL6                    (*((volatile unsigned int*)(0x42A21818UL)))
#define bM4_INTC_SEL25_INTSEL7                    (*((volatile unsigned int*)(0x42A2181CUL)))
#define bM4_INTC_SEL25_INTSEL8                    (*((volatile unsigned int*)(0x42A21820UL)))
#define bM4_INTC_SEL26_INTSEL0                    (*((volatile unsigned int*)(0x42A21880UL)))
#define bM4_INTC_SEL26_INTSEL1                    (*((volatile unsigned int*)(0x42A21884UL)))
#define bM4_INTC_SEL26_INTSEL2                    (*((volatile unsigned int*)(0x42A21888UL)))
#define bM4_INTC_SEL26_INTSEL3                    (*((volatile unsigned int*)(0x42A2188CUL)))
#define bM4_INTC_SEL26_INTSEL4                    (*((volatile unsigned int*)(0x42A21890UL)))
#define bM4_INTC_SEL26_INTSEL5                    (*((volatile unsigned int*)(0x42A21894UL)))
#define bM4_INTC_SEL26_INTSEL6                    (*((volatile unsigned int*)(0x42A21898UL)))
#define bM4_INTC_SEL26_INTSEL7                    (*((volatile unsigned int*)(0x42A2189CUL)))
#define bM4_INTC_SEL26_INTSEL8                    (*((volatile unsigned int*)(0x42A218A0UL)))
#define bM4_INTC_SEL27_INTSEL0                    (*((volatile unsigned int*)(0x42A21900UL)))
#define bM4_INTC_SEL27_INTSEL1                    (*((volatile unsigned int*)(0x42A21904UL)))
#define bM4_INTC_SEL27_INTSEL2                    (*((volatile unsigned int*)(0x42A21908UL)))
#define bM4_INTC_SEL27_INTSEL3                    (*((volatile unsigned int*)(0x42A2190CUL)))
#define bM4_INTC_SEL27_INTSEL4                    (*((volatile unsigned int*)(0x42A21910UL)))
#define bM4_INTC_SEL27_INTSEL5                    (*((volatile unsigned int*)(0x42A21914UL)))
#define bM4_INTC_SEL27_INTSEL6                    (*((volatile unsigned int*)(0x42A21918UL)))
#define bM4_INTC_SEL27_INTSEL7                    (*((volatile unsigned int*)(0x42A2191CUL)))
#define bM4_INTC_SEL27_INTSEL8                    (*((volatile unsigned int*)(0x42A21920UL)))
#define bM4_INTC_SEL28_INTSEL0                    (*((volatile unsigned int*)(0x42A21980UL)))
#define bM4_INTC_SEL28_INTSEL1                    (*((volatile unsigned int*)(0x42A21984UL)))
#define bM4_INTC_SEL28_INTSEL2                    (*((volatile unsigned int*)(0x42A21988UL)))
#define bM4_INTC_SEL28_INTSEL3                    (*((volatile unsigned int*)(0x42A2198CUL)))
#define bM4_INTC_SEL28_INTSEL4                    (*((volatile unsigned int*)(0x42A21990UL)))
#define bM4_INTC_SEL28_INTSEL5                    (*((volatile unsigned int*)(0x42A21994UL)))
#define bM4_INTC_SEL28_INTSEL6                    (*((volatile unsigned int*)(0x42A21998UL)))
#define bM4_INTC_SEL28_INTSEL7                    (*((volatile unsigned int*)(0x42A2199CUL)))
#define bM4_INTC_SEL28_INTSEL8                    (*((volatile unsigned int*)(0x42A219A0UL)))
#define bM4_INTC_SEL29_INTSEL0                    (*((volatile unsigned int*)(0x42A21A00UL)))
#define bM4_INTC_SEL29_INTSEL1                    (*((volatile unsigned int*)(0x42A21A04UL)))
#define bM4_INTC_SEL29_INTSEL2                    (*((volatile unsigned int*)(0x42A21A08UL)))
#define bM4_INTC_SEL29_INTSEL3                    (*((volatile unsigned int*)(0x42A21A0CUL)))
#define bM4_INTC_SEL29_INTSEL4                    (*((volatile unsigned int*)(0x42A21A10UL)))
#define bM4_INTC_SEL29_INTSEL5                    (*((volatile unsigned int*)(0x42A21A14UL)))
#define bM4_INTC_SEL29_INTSEL6                    (*((volatile unsigned int*)(0x42A21A18UL)))
#define bM4_INTC_SEL29_INTSEL7                    (*((volatile unsigned int*)(0x42A21A1CUL)))
#define bM4_INTC_SEL29_INTSEL8                    (*((volatile unsigned int*)(0x42A21A20UL)))
#define bM4_INTC_SEL30_INTSEL0                    (*((volatile unsigned int*)(0x42A21A80UL)))
#define bM4_INTC_SEL30_INTSEL1                    (*((volatile unsigned int*)(0x42A21A84UL)))
#define bM4_INTC_SEL30_INTSEL2                    (*((volatile unsigned int*)(0x42A21A88UL)))
#define bM4_INTC_SEL30_INTSEL3                    (*((volatile unsigned int*)(0x42A21A8CUL)))
#define bM4_INTC_SEL30_INTSEL4                    (*((volatile unsigned int*)(0x42A21A90UL)))
#define bM4_INTC_SEL30_INTSEL5                    (*((volatile unsigned int*)(0x42A21A94UL)))
#define bM4_INTC_SEL30_INTSEL6                    (*((volatile unsigned int*)(0x42A21A98UL)))
#define bM4_INTC_SEL30_INTSEL7                    (*((volatile unsigned int*)(0x42A21A9CUL)))
#define bM4_INTC_SEL30_INTSEL8                    (*((volatile unsigned int*)(0x42A21AA0UL)))
#define bM4_INTC_SEL31_INTSEL0                    (*((volatile unsigned int*)(0x42A21B00UL)))
#define bM4_INTC_SEL31_INTSEL1                    (*((volatile unsigned int*)(0x42A21B04UL)))
#define bM4_INTC_SEL31_INTSEL2                    (*((volatile unsigned int*)(0x42A21B08UL)))
#define bM4_INTC_SEL31_INTSEL3                    (*((volatile unsigned int*)(0x42A21B0CUL)))
#define bM4_INTC_SEL31_INTSEL4                    (*((volatile unsigned int*)(0x42A21B10UL)))
#define bM4_INTC_SEL31_INTSEL5                    (*((volatile unsigned int*)(0x42A21B14UL)))
#define bM4_INTC_SEL31_INTSEL6                    (*((volatile unsigned int*)(0x42A21B18UL)))
#define bM4_INTC_SEL31_INTSEL7                    (*((volatile unsigned int*)(0x42A21B1CUL)))
#define bM4_INTC_SEL31_INTSEL8                    (*((volatile unsigned int*)(0x42A21B20UL)))
#define bM4_INTC_SEL32_INTSEL0                    (*((volatile unsigned int*)(0x42A21B80UL)))
#define bM4_INTC_SEL32_INTSEL1                    (*((volatile unsigned int*)(0x42A21B84UL)))
#define bM4_INTC_SEL32_INTSEL2                    (*((volatile unsigned int*)(0x42A21B88UL)))
#define bM4_INTC_SEL32_INTSEL3                    (*((volatile unsigned int*)(0x42A21B8CUL)))
#define bM4_INTC_SEL32_INTSEL4                    (*((volatile unsigned int*)(0x42A21B90UL)))
#define bM4_INTC_SEL32_INTSEL5                    (*((volatile unsigned int*)(0x42A21B94UL)))
#define bM4_INTC_SEL32_INTSEL6                    (*((volatile unsigned int*)(0x42A21B98UL)))
#define bM4_INTC_SEL32_INTSEL7                    (*((volatile unsigned int*)(0x42A21B9CUL)))
#define bM4_INTC_SEL32_INTSEL8                    (*((volatile unsigned int*)(0x42A21BA0UL)))
#define bM4_INTC_SEL33_INTSEL0                    (*((volatile unsigned int*)(0x42A21C00UL)))
#define bM4_INTC_SEL33_INTSEL1                    (*((volatile unsigned int*)(0x42A21C04UL)))
#define bM4_INTC_SEL33_INTSEL2                    (*((volatile unsigned int*)(0x42A21C08UL)))
#define bM4_INTC_SEL33_INTSEL3                    (*((volatile unsigned int*)(0x42A21C0CUL)))
#define bM4_INTC_SEL33_INTSEL4                    (*((volatile unsigned int*)(0x42A21C10UL)))
#define bM4_INTC_SEL33_INTSEL5                    (*((volatile unsigned int*)(0x42A21C14UL)))
#define bM4_INTC_SEL33_INTSEL6                    (*((volatile unsigned int*)(0x42A21C18UL)))
#define bM4_INTC_SEL33_INTSEL7                    (*((volatile unsigned int*)(0x42A21C1CUL)))
#define bM4_INTC_SEL33_INTSEL8                    (*((volatile unsigned int*)(0x42A21C20UL)))
#define bM4_INTC_SEL34_INTSEL0                    (*((volatile unsigned int*)(0x42A21C80UL)))
#define bM4_INTC_SEL34_INTSEL1                    (*((volatile unsigned int*)(0x42A21C84UL)))
#define bM4_INTC_SEL34_INTSEL2                    (*((volatile unsigned int*)(0x42A21C88UL)))
#define bM4_INTC_SEL34_INTSEL3                    (*((volatile unsigned int*)(0x42A21C8CUL)))
#define bM4_INTC_SEL34_INTSEL4                    (*((volatile unsigned int*)(0x42A21C90UL)))
#define bM4_INTC_SEL34_INTSEL5                    (*((volatile unsigned int*)(0x42A21C94UL)))
#define bM4_INTC_SEL34_INTSEL6                    (*((volatile unsigned int*)(0x42A21C98UL)))
#define bM4_INTC_SEL34_INTSEL7                    (*((volatile unsigned int*)(0x42A21C9CUL)))
#define bM4_INTC_SEL34_INTSEL8                    (*((volatile unsigned int*)(0x42A21CA0UL)))
#define bM4_INTC_SEL35_INTSEL0                    (*((volatile unsigned int*)(0x42A21D00UL)))
#define bM4_INTC_SEL35_INTSEL1                    (*((volatile unsigned int*)(0x42A21D04UL)))
#define bM4_INTC_SEL35_INTSEL2                    (*((volatile unsigned int*)(0x42A21D08UL)))
#define bM4_INTC_SEL35_INTSEL3                    (*((volatile unsigned int*)(0x42A21D0CUL)))
#define bM4_INTC_SEL35_INTSEL4                    (*((volatile unsigned int*)(0x42A21D10UL)))
#define bM4_INTC_SEL35_INTSEL5                    (*((volatile unsigned int*)(0x42A21D14UL)))
#define bM4_INTC_SEL35_INTSEL6                    (*((volatile unsigned int*)(0x42A21D18UL)))
#define bM4_INTC_SEL35_INTSEL7                    (*((volatile unsigned int*)(0x42A21D1CUL)))
#define bM4_INTC_SEL35_INTSEL8                    (*((volatile unsigned int*)(0x42A21D20UL)))
#define bM4_INTC_SEL36_INTSEL0                    (*((volatile unsigned int*)(0x42A21D80UL)))
#define bM4_INTC_SEL36_INTSEL1                    (*((volatile unsigned int*)(0x42A21D84UL)))
#define bM4_INTC_SEL36_INTSEL2                    (*((volatile unsigned int*)(0x42A21D88UL)))
#define bM4_INTC_SEL36_INTSEL3                    (*((volatile unsigned int*)(0x42A21D8CUL)))
#define bM4_INTC_SEL36_INTSEL4                    (*((volatile unsigned int*)(0x42A21D90UL)))
#define bM4_INTC_SEL36_INTSEL5                    (*((volatile unsigned int*)(0x42A21D94UL)))
#define bM4_INTC_SEL36_INTSEL6                    (*((volatile unsigned int*)(0x42A21D98UL)))
#define bM4_INTC_SEL36_INTSEL7                    (*((volatile unsigned int*)(0x42A21D9CUL)))
#define bM4_INTC_SEL36_INTSEL8                    (*((volatile unsigned int*)(0x42A21DA0UL)))
#define bM4_INTC_SEL37_INTSEL0                    (*((volatile unsigned int*)(0x42A21E00UL)))
#define bM4_INTC_SEL37_INTSEL1                    (*((volatile unsigned int*)(0x42A21E04UL)))
#define bM4_INTC_SEL37_INTSEL2                    (*((volatile unsigned int*)(0x42A21E08UL)))
#define bM4_INTC_SEL37_INTSEL3                    (*((volatile unsigned int*)(0x42A21E0CUL)))
#define bM4_INTC_SEL37_INTSEL4                    (*((volatile unsigned int*)(0x42A21E10UL)))
#define bM4_INTC_SEL37_INTSEL5                    (*((volatile unsigned int*)(0x42A21E14UL)))
#define bM4_INTC_SEL37_INTSEL6                    (*((volatile unsigned int*)(0x42A21E18UL)))
#define bM4_INTC_SEL37_INTSEL7                    (*((volatile unsigned int*)(0x42A21E1CUL)))
#define bM4_INTC_SEL37_INTSEL8                    (*((volatile unsigned int*)(0x42A21E20UL)))
#define bM4_INTC_SEL38_INTSEL0                    (*((volatile unsigned int*)(0x42A21E80UL)))
#define bM4_INTC_SEL38_INTSEL1                    (*((volatile unsigned int*)(0x42A21E84UL)))
#define bM4_INTC_SEL38_INTSEL2                    (*((volatile unsigned int*)(0x42A21E88UL)))
#define bM4_INTC_SEL38_INTSEL3                    (*((volatile unsigned int*)(0x42A21E8CUL)))
#define bM4_INTC_SEL38_INTSEL4                    (*((volatile unsigned int*)(0x42A21E90UL)))
#define bM4_INTC_SEL38_INTSEL5                    (*((volatile unsigned int*)(0x42A21E94UL)))
#define bM4_INTC_SEL38_INTSEL6                    (*((volatile unsigned int*)(0x42A21E98UL)))
#define bM4_INTC_SEL38_INTSEL7                    (*((volatile unsigned int*)(0x42A21E9CUL)))
#define bM4_INTC_SEL38_INTSEL8                    (*((volatile unsigned int*)(0x42A21EA0UL)))
#define bM4_INTC_SEL39_INTSEL0                    (*((volatile unsigned int*)(0x42A21F00UL)))
#define bM4_INTC_SEL39_INTSEL1                    (*((volatile unsigned int*)(0x42A21F04UL)))
#define bM4_INTC_SEL39_INTSEL2                    (*((volatile unsigned int*)(0x42A21F08UL)))
#define bM4_INTC_SEL39_INTSEL3                    (*((volatile unsigned int*)(0x42A21F0CUL)))
#define bM4_INTC_SEL39_INTSEL4                    (*((volatile unsigned int*)(0x42A21F10UL)))
#define bM4_INTC_SEL39_INTSEL5                    (*((volatile unsigned int*)(0x42A21F14UL)))
#define bM4_INTC_SEL39_INTSEL6                    (*((volatile unsigned int*)(0x42A21F18UL)))
#define bM4_INTC_SEL39_INTSEL7                    (*((volatile unsigned int*)(0x42A21F1CUL)))
#define bM4_INTC_SEL39_INTSEL8                    (*((volatile unsigned int*)(0x42A21F20UL)))
#define bM4_INTC_SEL40_INTSEL0                    (*((volatile unsigned int*)(0x42A21F80UL)))
#define bM4_INTC_SEL40_INTSEL1                    (*((volatile unsigned int*)(0x42A21F84UL)))
#define bM4_INTC_SEL40_INTSEL2                    (*((volatile unsigned int*)(0x42A21F88UL)))
#define bM4_INTC_SEL40_INTSEL3                    (*((volatile unsigned int*)(0x42A21F8CUL)))
#define bM4_INTC_SEL40_INTSEL4                    (*((volatile unsigned int*)(0x42A21F90UL)))
#define bM4_INTC_SEL40_INTSEL5                    (*((volatile unsigned int*)(0x42A21F94UL)))
#define bM4_INTC_SEL40_INTSEL6                    (*((volatile unsigned int*)(0x42A21F98UL)))
#define bM4_INTC_SEL40_INTSEL7                    (*((volatile unsigned int*)(0x42A21F9CUL)))
#define bM4_INTC_SEL40_INTSEL8                    (*((volatile unsigned int*)(0x42A21FA0UL)))
#define bM4_INTC_SEL41_INTSEL0                    (*((volatile unsigned int*)(0x42A22000UL)))
#define bM4_INTC_SEL41_INTSEL1                    (*((volatile unsigned int*)(0x42A22004UL)))
#define bM4_INTC_SEL41_INTSEL2                    (*((volatile unsigned int*)(0x42A22008UL)))
#define bM4_INTC_SEL41_INTSEL3                    (*((volatile unsigned int*)(0x42A2200CUL)))
#define bM4_INTC_SEL41_INTSEL4                    (*((volatile unsigned int*)(0x42A22010UL)))
#define bM4_INTC_SEL41_INTSEL5                    (*((volatile unsigned int*)(0x42A22014UL)))
#define bM4_INTC_SEL41_INTSEL6                    (*((volatile unsigned int*)(0x42A22018UL)))
#define bM4_INTC_SEL41_INTSEL7                    (*((volatile unsigned int*)(0x42A2201CUL)))
#define bM4_INTC_SEL41_INTSEL8                    (*((volatile unsigned int*)(0x42A22020UL)))
#define bM4_INTC_SEL42_INTSEL0                    (*((volatile unsigned int*)(0x42A22080UL)))
#define bM4_INTC_SEL42_INTSEL1                    (*((volatile unsigned int*)(0x42A22084UL)))
#define bM4_INTC_SEL42_INTSEL2                    (*((volatile unsigned int*)(0x42A22088UL)))
#define bM4_INTC_SEL42_INTSEL3                    (*((volatile unsigned int*)(0x42A2208CUL)))
#define bM4_INTC_SEL42_INTSEL4                    (*((volatile unsigned int*)(0x42A22090UL)))
#define bM4_INTC_SEL42_INTSEL5                    (*((volatile unsigned int*)(0x42A22094UL)))
#define bM4_INTC_SEL42_INTSEL6                    (*((volatile unsigned int*)(0x42A22098UL)))
#define bM4_INTC_SEL42_INTSEL7                    (*((volatile unsigned int*)(0x42A2209CUL)))
#define bM4_INTC_SEL42_INTSEL8                    (*((volatile unsigned int*)(0x42A220A0UL)))
#define bM4_INTC_SEL43_INTSEL0                    (*((volatile unsigned int*)(0x42A22100UL)))
#define bM4_INTC_SEL43_INTSEL1                    (*((volatile unsigned int*)(0x42A22104UL)))
#define bM4_INTC_SEL43_INTSEL2                    (*((volatile unsigned int*)(0x42A22108UL)))
#define bM4_INTC_SEL43_INTSEL3                    (*((volatile unsigned int*)(0x42A2210CUL)))
#define bM4_INTC_SEL43_INTSEL4                    (*((volatile unsigned int*)(0x42A22110UL)))
#define bM4_INTC_SEL43_INTSEL5                    (*((volatile unsigned int*)(0x42A22114UL)))
#define bM4_INTC_SEL43_INTSEL6                    (*((volatile unsigned int*)(0x42A22118UL)))
#define bM4_INTC_SEL43_INTSEL7                    (*((volatile unsigned int*)(0x42A2211CUL)))
#define bM4_INTC_SEL43_INTSEL8                    (*((volatile unsigned int*)(0x42A22120UL)))
#define bM4_INTC_SEL44_INTSEL0                    (*((volatile unsigned int*)(0x42A22180UL)))
#define bM4_INTC_SEL44_INTSEL1                    (*((volatile unsigned int*)(0x42A22184UL)))
#define bM4_INTC_SEL44_INTSEL2                    (*((volatile unsigned int*)(0x42A22188UL)))
#define bM4_INTC_SEL44_INTSEL3                    (*((volatile unsigned int*)(0x42A2218CUL)))
#define bM4_INTC_SEL44_INTSEL4                    (*((volatile unsigned int*)(0x42A22190UL)))
#define bM4_INTC_SEL44_INTSEL5                    (*((volatile unsigned int*)(0x42A22194UL)))
#define bM4_INTC_SEL44_INTSEL6                    (*((volatile unsigned int*)(0x42A22198UL)))
#define bM4_INTC_SEL44_INTSEL7                    (*((volatile unsigned int*)(0x42A2219CUL)))
#define bM4_INTC_SEL44_INTSEL8                    (*((volatile unsigned int*)(0x42A221A0UL)))
#define bM4_INTC_SEL45_INTSEL0                    (*((volatile unsigned int*)(0x42A22200UL)))
#define bM4_INTC_SEL45_INTSEL1                    (*((volatile unsigned int*)(0x42A22204UL)))
#define bM4_INTC_SEL45_INTSEL2                    (*((volatile unsigned int*)(0x42A22208UL)))
#define bM4_INTC_SEL45_INTSEL3                    (*((volatile unsigned int*)(0x42A2220CUL)))
#define bM4_INTC_SEL45_INTSEL4                    (*((volatile unsigned int*)(0x42A22210UL)))
#define bM4_INTC_SEL45_INTSEL5                    (*((volatile unsigned int*)(0x42A22214UL)))
#define bM4_INTC_SEL45_INTSEL6                    (*((volatile unsigned int*)(0x42A22218UL)))
#define bM4_INTC_SEL45_INTSEL7                    (*((volatile unsigned int*)(0x42A2221CUL)))
#define bM4_INTC_SEL45_INTSEL8                    (*((volatile unsigned int*)(0x42A22220UL)))
#define bM4_INTC_SEL46_INTSEL0                    (*((volatile unsigned int*)(0x42A22280UL)))
#define bM4_INTC_SEL46_INTSEL1                    (*((volatile unsigned int*)(0x42A22284UL)))
#define bM4_INTC_SEL46_INTSEL2                    (*((volatile unsigned int*)(0x42A22288UL)))
#define bM4_INTC_SEL46_INTSEL3                    (*((volatile unsigned int*)(0x42A2228CUL)))
#define bM4_INTC_SEL46_INTSEL4                    (*((volatile unsigned int*)(0x42A22290UL)))
#define bM4_INTC_SEL46_INTSEL5                    (*((volatile unsigned int*)(0x42A22294UL)))
#define bM4_INTC_SEL46_INTSEL6                    (*((volatile unsigned int*)(0x42A22298UL)))
#define bM4_INTC_SEL46_INTSEL7                    (*((volatile unsigned int*)(0x42A2229CUL)))
#define bM4_INTC_SEL46_INTSEL8                    (*((volatile unsigned int*)(0x42A222A0UL)))
#define bM4_INTC_SEL47_INTSEL0                    (*((volatile unsigned int*)(0x42A22300UL)))
#define bM4_INTC_SEL47_INTSEL1                    (*((volatile unsigned int*)(0x42A22304UL)))
#define bM4_INTC_SEL47_INTSEL2                    (*((volatile unsigned int*)(0x42A22308UL)))
#define bM4_INTC_SEL47_INTSEL3                    (*((volatile unsigned int*)(0x42A2230CUL)))
#define bM4_INTC_SEL47_INTSEL4                    (*((volatile unsigned int*)(0x42A22310UL)))
#define bM4_INTC_SEL47_INTSEL5                    (*((volatile unsigned int*)(0x42A22314UL)))
#define bM4_INTC_SEL47_INTSEL6                    (*((volatile unsigned int*)(0x42A22318UL)))
#define bM4_INTC_SEL47_INTSEL7                    (*((volatile unsigned int*)(0x42A2231CUL)))
#define bM4_INTC_SEL47_INTSEL8                    (*((volatile unsigned int*)(0x42A22320UL)))
#define bM4_INTC_SEL48_INTSEL0                    (*((volatile unsigned int*)(0x42A22380UL)))
#define bM4_INTC_SEL48_INTSEL1                    (*((volatile unsigned int*)(0x42A22384UL)))
#define bM4_INTC_SEL48_INTSEL2                    (*((volatile unsigned int*)(0x42A22388UL)))
#define bM4_INTC_SEL48_INTSEL3                    (*((volatile unsigned int*)(0x42A2238CUL)))
#define bM4_INTC_SEL48_INTSEL4                    (*((volatile unsigned int*)(0x42A22390UL)))
#define bM4_INTC_SEL48_INTSEL5                    (*((volatile unsigned int*)(0x42A22394UL)))
#define bM4_INTC_SEL48_INTSEL6                    (*((volatile unsigned int*)(0x42A22398UL)))
#define bM4_INTC_SEL48_INTSEL7                    (*((volatile unsigned int*)(0x42A2239CUL)))
#define bM4_INTC_SEL48_INTSEL8                    (*((volatile unsigned int*)(0x42A223A0UL)))
#define bM4_INTC_SEL49_INTSEL0                    (*((volatile unsigned int*)(0x42A22400UL)))
#define bM4_INTC_SEL49_INTSEL1                    (*((volatile unsigned int*)(0x42A22404UL)))
#define bM4_INTC_SEL49_INTSEL2                    (*((volatile unsigned int*)(0x42A22408UL)))
#define bM4_INTC_SEL49_INTSEL3                    (*((volatile unsigned int*)(0x42A2240CUL)))
#define bM4_INTC_SEL49_INTSEL4                    (*((volatile unsigned int*)(0x42A22410UL)))
#define bM4_INTC_SEL49_INTSEL5                    (*((volatile unsigned int*)(0x42A22414UL)))
#define bM4_INTC_SEL49_INTSEL6                    (*((volatile unsigned int*)(0x42A22418UL)))
#define bM4_INTC_SEL49_INTSEL7                    (*((volatile unsigned int*)(0x42A2241CUL)))
#define bM4_INTC_SEL49_INTSEL8                    (*((volatile unsigned int*)(0x42A22420UL)))
#define bM4_INTC_SEL50_INTSEL0                    (*((volatile unsigned int*)(0x42A22480UL)))
#define bM4_INTC_SEL50_INTSEL1                    (*((volatile unsigned int*)(0x42A22484UL)))
#define bM4_INTC_SEL50_INTSEL2                    (*((volatile unsigned int*)(0x42A22488UL)))
#define bM4_INTC_SEL50_INTSEL3                    (*((volatile unsigned int*)(0x42A2248CUL)))
#define bM4_INTC_SEL50_INTSEL4                    (*((volatile unsigned int*)(0x42A22490UL)))
#define bM4_INTC_SEL50_INTSEL5                    (*((volatile unsigned int*)(0x42A22494UL)))
#define bM4_INTC_SEL50_INTSEL6                    (*((volatile unsigned int*)(0x42A22498UL)))
#define bM4_INTC_SEL50_INTSEL7                    (*((volatile unsigned int*)(0x42A2249CUL)))
#define bM4_INTC_SEL50_INTSEL8                    (*((volatile unsigned int*)(0x42A224A0UL)))
#define bM4_INTC_SEL51_INTSEL0                    (*((volatile unsigned int*)(0x42A22500UL)))
#define bM4_INTC_SEL51_INTSEL1                    (*((volatile unsigned int*)(0x42A22504UL)))
#define bM4_INTC_SEL51_INTSEL2                    (*((volatile unsigned int*)(0x42A22508UL)))
#define bM4_INTC_SEL51_INTSEL3                    (*((volatile unsigned int*)(0x42A2250CUL)))
#define bM4_INTC_SEL51_INTSEL4                    (*((volatile unsigned int*)(0x42A22510UL)))
#define bM4_INTC_SEL51_INTSEL5                    (*((volatile unsigned int*)(0x42A22514UL)))
#define bM4_INTC_SEL51_INTSEL6                    (*((volatile unsigned int*)(0x42A22518UL)))
#define bM4_INTC_SEL51_INTSEL7                    (*((volatile unsigned int*)(0x42A2251CUL)))
#define bM4_INTC_SEL51_INTSEL8                    (*((volatile unsigned int*)(0x42A22520UL)))
#define bM4_INTC_SEL52_INTSEL0                    (*((volatile unsigned int*)(0x42A22580UL)))
#define bM4_INTC_SEL52_INTSEL1                    (*((volatile unsigned int*)(0x42A22584UL)))
#define bM4_INTC_SEL52_INTSEL2                    (*((volatile unsigned int*)(0x42A22588UL)))
#define bM4_INTC_SEL52_INTSEL3                    (*((volatile unsigned int*)(0x42A2258CUL)))
#define bM4_INTC_SEL52_INTSEL4                    (*((volatile unsigned int*)(0x42A22590UL)))
#define bM4_INTC_SEL52_INTSEL5                    (*((volatile unsigned int*)(0x42A22594UL)))
#define bM4_INTC_SEL52_INTSEL6                    (*((volatile unsigned int*)(0x42A22598UL)))
#define bM4_INTC_SEL52_INTSEL7                    (*((volatile unsigned int*)(0x42A2259CUL)))
#define bM4_INTC_SEL52_INTSEL8                    (*((volatile unsigned int*)(0x42A225A0UL)))
#define bM4_INTC_SEL53_INTSEL0                    (*((volatile unsigned int*)(0x42A22600UL)))
#define bM4_INTC_SEL53_INTSEL1                    (*((volatile unsigned int*)(0x42A22604UL)))
#define bM4_INTC_SEL53_INTSEL2                    (*((volatile unsigned int*)(0x42A22608UL)))
#define bM4_INTC_SEL53_INTSEL3                    (*((volatile unsigned int*)(0x42A2260CUL)))
#define bM4_INTC_SEL53_INTSEL4                    (*((volatile unsigned int*)(0x42A22610UL)))
#define bM4_INTC_SEL53_INTSEL5                    (*((volatile unsigned int*)(0x42A22614UL)))
#define bM4_INTC_SEL53_INTSEL6                    (*((volatile unsigned int*)(0x42A22618UL)))
#define bM4_INTC_SEL53_INTSEL7                    (*((volatile unsigned int*)(0x42A2261CUL)))
#define bM4_INTC_SEL53_INTSEL8                    (*((volatile unsigned int*)(0x42A22620UL)))
#define bM4_INTC_SEL54_INTSEL0                    (*((volatile unsigned int*)(0x42A22680UL)))
#define bM4_INTC_SEL54_INTSEL1                    (*((volatile unsigned int*)(0x42A22684UL)))
#define bM4_INTC_SEL54_INTSEL2                    (*((volatile unsigned int*)(0x42A22688UL)))
#define bM4_INTC_SEL54_INTSEL3                    (*((volatile unsigned int*)(0x42A2268CUL)))
#define bM4_INTC_SEL54_INTSEL4                    (*((volatile unsigned int*)(0x42A22690UL)))
#define bM4_INTC_SEL54_INTSEL5                    (*((volatile unsigned int*)(0x42A22694UL)))
#define bM4_INTC_SEL54_INTSEL6                    (*((volatile unsigned int*)(0x42A22698UL)))
#define bM4_INTC_SEL54_INTSEL7                    (*((volatile unsigned int*)(0x42A2269CUL)))
#define bM4_INTC_SEL54_INTSEL8                    (*((volatile unsigned int*)(0x42A226A0UL)))
#define bM4_INTC_SEL55_INTSEL0                    (*((volatile unsigned int*)(0x42A22700UL)))
#define bM4_INTC_SEL55_INTSEL1                    (*((volatile unsigned int*)(0x42A22704UL)))
#define bM4_INTC_SEL55_INTSEL2                    (*((volatile unsigned int*)(0x42A22708UL)))
#define bM4_INTC_SEL55_INTSEL3                    (*((volatile unsigned int*)(0x42A2270CUL)))
#define bM4_INTC_SEL55_INTSEL4                    (*((volatile unsigned int*)(0x42A22710UL)))
#define bM4_INTC_SEL55_INTSEL5                    (*((volatile unsigned int*)(0x42A22714UL)))
#define bM4_INTC_SEL55_INTSEL6                    (*((volatile unsigned int*)(0x42A22718UL)))
#define bM4_INTC_SEL55_INTSEL7                    (*((volatile unsigned int*)(0x42A2271CUL)))
#define bM4_INTC_SEL55_INTSEL8                    (*((volatile unsigned int*)(0x42A22720UL)))
#define bM4_INTC_SEL56_INTSEL0                    (*((volatile unsigned int*)(0x42A22780UL)))
#define bM4_INTC_SEL56_INTSEL1                    (*((volatile unsigned int*)(0x42A22784UL)))
#define bM4_INTC_SEL56_INTSEL2                    (*((volatile unsigned int*)(0x42A22788UL)))
#define bM4_INTC_SEL56_INTSEL3                    (*((volatile unsigned int*)(0x42A2278CUL)))
#define bM4_INTC_SEL56_INTSEL4                    (*((volatile unsigned int*)(0x42A22790UL)))
#define bM4_INTC_SEL56_INTSEL5                    (*((volatile unsigned int*)(0x42A22794UL)))
#define bM4_INTC_SEL56_INTSEL6                    (*((volatile unsigned int*)(0x42A22798UL)))
#define bM4_INTC_SEL56_INTSEL7                    (*((volatile unsigned int*)(0x42A2279CUL)))
#define bM4_INTC_SEL56_INTSEL8                    (*((volatile unsigned int*)(0x42A227A0UL)))
#define bM4_INTC_SEL57_INTSEL0                    (*((volatile unsigned int*)(0x42A22800UL)))
#define bM4_INTC_SEL57_INTSEL1                    (*((volatile unsigned int*)(0x42A22804UL)))
#define bM4_INTC_SEL57_INTSEL2                    (*((volatile unsigned int*)(0x42A22808UL)))
#define bM4_INTC_SEL57_INTSEL3                    (*((volatile unsigned int*)(0x42A2280CUL)))
#define bM4_INTC_SEL57_INTSEL4                    (*((volatile unsigned int*)(0x42A22810UL)))
#define bM4_INTC_SEL57_INTSEL5                    (*((volatile unsigned int*)(0x42A22814UL)))
#define bM4_INTC_SEL57_INTSEL6                    (*((volatile unsigned int*)(0x42A22818UL)))
#define bM4_INTC_SEL57_INTSEL7                    (*((volatile unsigned int*)(0x42A2281CUL)))
#define bM4_INTC_SEL57_INTSEL8                    (*((volatile unsigned int*)(0x42A22820UL)))
#define bM4_INTC_SEL58_INTSEL0                    (*((volatile unsigned int*)(0x42A22880UL)))
#define bM4_INTC_SEL58_INTSEL1                    (*((volatile unsigned int*)(0x42A22884UL)))
#define bM4_INTC_SEL58_INTSEL2                    (*((volatile unsigned int*)(0x42A22888UL)))
#define bM4_INTC_SEL58_INTSEL3                    (*((volatile unsigned int*)(0x42A2288CUL)))
#define bM4_INTC_SEL58_INTSEL4                    (*((volatile unsigned int*)(0x42A22890UL)))
#define bM4_INTC_SEL58_INTSEL5                    (*((volatile unsigned int*)(0x42A22894UL)))
#define bM4_INTC_SEL58_INTSEL6                    (*((volatile unsigned int*)(0x42A22898UL)))
#define bM4_INTC_SEL58_INTSEL7                    (*((volatile unsigned int*)(0x42A2289CUL)))
#define bM4_INTC_SEL58_INTSEL8                    (*((volatile unsigned int*)(0x42A228A0UL)))
#define bM4_INTC_SEL59_INTSEL0                    (*((volatile unsigned int*)(0x42A22900UL)))
#define bM4_INTC_SEL59_INTSEL1                    (*((volatile unsigned int*)(0x42A22904UL)))
#define bM4_INTC_SEL59_INTSEL2                    (*((volatile unsigned int*)(0x42A22908UL)))
#define bM4_INTC_SEL59_INTSEL3                    (*((volatile unsigned int*)(0x42A2290CUL)))
#define bM4_INTC_SEL59_INTSEL4                    (*((volatile unsigned int*)(0x42A22910UL)))
#define bM4_INTC_SEL59_INTSEL5                    (*((volatile unsigned int*)(0x42A22914UL)))
#define bM4_INTC_SEL59_INTSEL6                    (*((volatile unsigned int*)(0x42A22918UL)))
#define bM4_INTC_SEL59_INTSEL7                    (*((volatile unsigned int*)(0x42A2291CUL)))
#define bM4_INTC_SEL59_INTSEL8                    (*((volatile unsigned int*)(0x42A22920UL)))
#define bM4_INTC_SEL60_INTSEL0                    (*((volatile unsigned int*)(0x42A22980UL)))
#define bM4_INTC_SEL60_INTSEL1                    (*((volatile unsigned int*)(0x42A22984UL)))
#define bM4_INTC_SEL60_INTSEL2                    (*((volatile unsigned int*)(0x42A22988UL)))
#define bM4_INTC_SEL60_INTSEL3                    (*((volatile unsigned int*)(0x42A2298CUL)))
#define bM4_INTC_SEL60_INTSEL4                    (*((volatile unsigned int*)(0x42A22990UL)))
#define bM4_INTC_SEL60_INTSEL5                    (*((volatile unsigned int*)(0x42A22994UL)))
#define bM4_INTC_SEL60_INTSEL6                    (*((volatile unsigned int*)(0x42A22998UL)))
#define bM4_INTC_SEL60_INTSEL7                    (*((volatile unsigned int*)(0x42A2299CUL)))
#define bM4_INTC_SEL60_INTSEL8                    (*((volatile unsigned int*)(0x42A229A0UL)))
#define bM4_INTC_SEL61_INTSEL0                    (*((volatile unsigned int*)(0x42A22A00UL)))
#define bM4_INTC_SEL61_INTSEL1                    (*((volatile unsigned int*)(0x42A22A04UL)))
#define bM4_INTC_SEL61_INTSEL2                    (*((volatile unsigned int*)(0x42A22A08UL)))
#define bM4_INTC_SEL61_INTSEL3                    (*((volatile unsigned int*)(0x42A22A0CUL)))
#define bM4_INTC_SEL61_INTSEL4                    (*((volatile unsigned int*)(0x42A22A10UL)))
#define bM4_INTC_SEL61_INTSEL5                    (*((volatile unsigned int*)(0x42A22A14UL)))
#define bM4_INTC_SEL61_INTSEL6                    (*((volatile unsigned int*)(0x42A22A18UL)))
#define bM4_INTC_SEL61_INTSEL7                    (*((volatile unsigned int*)(0x42A22A1CUL)))
#define bM4_INTC_SEL61_INTSEL8                    (*((volatile unsigned int*)(0x42A22A20UL)))
#define bM4_INTC_SEL62_INTSEL0                    (*((volatile unsigned int*)(0x42A22A80UL)))
#define bM4_INTC_SEL62_INTSEL1                    (*((volatile unsigned int*)(0x42A22A84UL)))
#define bM4_INTC_SEL62_INTSEL2                    (*((volatile unsigned int*)(0x42A22A88UL)))
#define bM4_INTC_SEL62_INTSEL3                    (*((volatile unsigned int*)(0x42A22A8CUL)))
#define bM4_INTC_SEL62_INTSEL4                    (*((volatile unsigned int*)(0x42A22A90UL)))
#define bM4_INTC_SEL62_INTSEL5                    (*((volatile unsigned int*)(0x42A22A94UL)))
#define bM4_INTC_SEL62_INTSEL6                    (*((volatile unsigned int*)(0x42A22A98UL)))
#define bM4_INTC_SEL62_INTSEL7                    (*((volatile unsigned int*)(0x42A22A9CUL)))
#define bM4_INTC_SEL62_INTSEL8                    (*((volatile unsigned int*)(0x42A22AA0UL)))
#define bM4_INTC_SEL63_INTSEL0                    (*((volatile unsigned int*)(0x42A22B00UL)))
#define bM4_INTC_SEL63_INTSEL1                    (*((volatile unsigned int*)(0x42A22B04UL)))
#define bM4_INTC_SEL63_INTSEL2                    (*((volatile unsigned int*)(0x42A22B08UL)))
#define bM4_INTC_SEL63_INTSEL3                    (*((volatile unsigned int*)(0x42A22B0CUL)))
#define bM4_INTC_SEL63_INTSEL4                    (*((volatile unsigned int*)(0x42A22B10UL)))
#define bM4_INTC_SEL63_INTSEL5                    (*((volatile unsigned int*)(0x42A22B14UL)))
#define bM4_INTC_SEL63_INTSEL6                    (*((volatile unsigned int*)(0x42A22B18UL)))
#define bM4_INTC_SEL63_INTSEL7                    (*((volatile unsigned int*)(0x42A22B1CUL)))
#define bM4_INTC_SEL63_INTSEL8                    (*((volatile unsigned int*)(0x42A22B20UL)))
#define bM4_INTC_SEL64_INTSEL0                    (*((volatile unsigned int*)(0x42A22B80UL)))
#define bM4_INTC_SEL64_INTSEL1                    (*((volatile unsigned int*)(0x42A22B84UL)))
#define bM4_INTC_SEL64_INTSEL2                    (*((volatile unsigned int*)(0x42A22B88UL)))
#define bM4_INTC_SEL64_INTSEL3                    (*((volatile unsigned int*)(0x42A22B8CUL)))
#define bM4_INTC_SEL64_INTSEL4                    (*((volatile unsigned int*)(0x42A22B90UL)))
#define bM4_INTC_SEL64_INTSEL5                    (*((volatile unsigned int*)(0x42A22B94UL)))
#define bM4_INTC_SEL64_INTSEL6                    (*((volatile unsigned int*)(0x42A22B98UL)))
#define bM4_INTC_SEL64_INTSEL7                    (*((volatile unsigned int*)(0x42A22B9CUL)))
#define bM4_INTC_SEL64_INTSEL8                    (*((volatile unsigned int*)(0x42A22BA0UL)))
#define bM4_INTC_SEL65_INTSEL0                    (*((volatile unsigned int*)(0x42A22C00UL)))
#define bM4_INTC_SEL65_INTSEL1                    (*((volatile unsigned int*)(0x42A22C04UL)))
#define bM4_INTC_SEL65_INTSEL2                    (*((volatile unsigned int*)(0x42A22C08UL)))
#define bM4_INTC_SEL65_INTSEL3                    (*((volatile unsigned int*)(0x42A22C0CUL)))
#define bM4_INTC_SEL65_INTSEL4                    (*((volatile unsigned int*)(0x42A22C10UL)))
#define bM4_INTC_SEL65_INTSEL5                    (*((volatile unsigned int*)(0x42A22C14UL)))
#define bM4_INTC_SEL65_INTSEL6                    (*((volatile unsigned int*)(0x42A22C18UL)))
#define bM4_INTC_SEL65_INTSEL7                    (*((volatile unsigned int*)(0x42A22C1CUL)))
#define bM4_INTC_SEL65_INTSEL8                    (*((volatile unsigned int*)(0x42A22C20UL)))
#define bM4_INTC_SEL66_INTSEL0                    (*((volatile unsigned int*)(0x42A22C80UL)))
#define bM4_INTC_SEL66_INTSEL1                    (*((volatile unsigned int*)(0x42A22C84UL)))
#define bM4_INTC_SEL66_INTSEL2                    (*((volatile unsigned int*)(0x42A22C88UL)))
#define bM4_INTC_SEL66_INTSEL3                    (*((volatile unsigned int*)(0x42A22C8CUL)))
#define bM4_INTC_SEL66_INTSEL4                    (*((volatile unsigned int*)(0x42A22C90UL)))
#define bM4_INTC_SEL66_INTSEL5                    (*((volatile unsigned int*)(0x42A22C94UL)))
#define bM4_INTC_SEL66_INTSEL6                    (*((volatile unsigned int*)(0x42A22C98UL)))
#define bM4_INTC_SEL66_INTSEL7                    (*((volatile unsigned int*)(0x42A22C9CUL)))
#define bM4_INTC_SEL66_INTSEL8                    (*((volatile unsigned int*)(0x42A22CA0UL)))
#define bM4_INTC_SEL67_INTSEL0                    (*((volatile unsigned int*)(0x42A22D00UL)))
#define bM4_INTC_SEL67_INTSEL1                    (*((volatile unsigned int*)(0x42A22D04UL)))
#define bM4_INTC_SEL67_INTSEL2                    (*((volatile unsigned int*)(0x42A22D08UL)))
#define bM4_INTC_SEL67_INTSEL3                    (*((volatile unsigned int*)(0x42A22D0CUL)))
#define bM4_INTC_SEL67_INTSEL4                    (*((volatile unsigned int*)(0x42A22D10UL)))
#define bM4_INTC_SEL67_INTSEL5                    (*((volatile unsigned int*)(0x42A22D14UL)))
#define bM4_INTC_SEL67_INTSEL6                    (*((volatile unsigned int*)(0x42A22D18UL)))
#define bM4_INTC_SEL67_INTSEL7                    (*((volatile unsigned int*)(0x42A22D1CUL)))
#define bM4_INTC_SEL67_INTSEL8                    (*((volatile unsigned int*)(0x42A22D20UL)))
#define bM4_INTC_SEL68_INTSEL0                    (*((volatile unsigned int*)(0x42A22D80UL)))
#define bM4_INTC_SEL68_INTSEL1                    (*((volatile unsigned int*)(0x42A22D84UL)))
#define bM4_INTC_SEL68_INTSEL2                    (*((volatile unsigned int*)(0x42A22D88UL)))
#define bM4_INTC_SEL68_INTSEL3                    (*((volatile unsigned int*)(0x42A22D8CUL)))
#define bM4_INTC_SEL68_INTSEL4                    (*((volatile unsigned int*)(0x42A22D90UL)))
#define bM4_INTC_SEL68_INTSEL5                    (*((volatile unsigned int*)(0x42A22D94UL)))
#define bM4_INTC_SEL68_INTSEL6                    (*((volatile unsigned int*)(0x42A22D98UL)))
#define bM4_INTC_SEL68_INTSEL7                    (*((volatile unsigned int*)(0x42A22D9CUL)))
#define bM4_INTC_SEL68_INTSEL8                    (*((volatile unsigned int*)(0x42A22DA0UL)))
#define bM4_INTC_SEL69_INTSEL0                    (*((volatile unsigned int*)(0x42A22E00UL)))
#define bM4_INTC_SEL69_INTSEL1                    (*((volatile unsigned int*)(0x42A22E04UL)))
#define bM4_INTC_SEL69_INTSEL2                    (*((volatile unsigned int*)(0x42A22E08UL)))
#define bM4_INTC_SEL69_INTSEL3                    (*((volatile unsigned int*)(0x42A22E0CUL)))
#define bM4_INTC_SEL69_INTSEL4                    (*((volatile unsigned int*)(0x42A22E10UL)))
#define bM4_INTC_SEL69_INTSEL5                    (*((volatile unsigned int*)(0x42A22E14UL)))
#define bM4_INTC_SEL69_INTSEL6                    (*((volatile unsigned int*)(0x42A22E18UL)))
#define bM4_INTC_SEL69_INTSEL7                    (*((volatile unsigned int*)(0x42A22E1CUL)))
#define bM4_INTC_SEL69_INTSEL8                    (*((volatile unsigned int*)(0x42A22E20UL)))
#define bM4_INTC_SEL70_INTSEL0                    (*((volatile unsigned int*)(0x42A22E80UL)))
#define bM4_INTC_SEL70_INTSEL1                    (*((volatile unsigned int*)(0x42A22E84UL)))
#define bM4_INTC_SEL70_INTSEL2                    (*((volatile unsigned int*)(0x42A22E88UL)))
#define bM4_INTC_SEL70_INTSEL3                    (*((volatile unsigned int*)(0x42A22E8CUL)))
#define bM4_INTC_SEL70_INTSEL4                    (*((volatile unsigned int*)(0x42A22E90UL)))
#define bM4_INTC_SEL70_INTSEL5                    (*((volatile unsigned int*)(0x42A22E94UL)))
#define bM4_INTC_SEL70_INTSEL6                    (*((volatile unsigned int*)(0x42A22E98UL)))
#define bM4_INTC_SEL70_INTSEL7                    (*((volatile unsigned int*)(0x42A22E9CUL)))
#define bM4_INTC_SEL70_INTSEL8                    (*((volatile unsigned int*)(0x42A22EA0UL)))
#define bM4_INTC_SEL71_INTSEL0                    (*((volatile unsigned int*)(0x42A22F00UL)))
#define bM4_INTC_SEL71_INTSEL1                    (*((volatile unsigned int*)(0x42A22F04UL)))
#define bM4_INTC_SEL71_INTSEL2                    (*((volatile unsigned int*)(0x42A22F08UL)))
#define bM4_INTC_SEL71_INTSEL3                    (*((volatile unsigned int*)(0x42A22F0CUL)))
#define bM4_INTC_SEL71_INTSEL4                    (*((volatile unsigned int*)(0x42A22F10UL)))
#define bM4_INTC_SEL71_INTSEL5                    (*((volatile unsigned int*)(0x42A22F14UL)))
#define bM4_INTC_SEL71_INTSEL6                    (*((volatile unsigned int*)(0x42A22F18UL)))
#define bM4_INTC_SEL71_INTSEL7                    (*((volatile unsigned int*)(0x42A22F1CUL)))
#define bM4_INTC_SEL71_INTSEL8                    (*((volatile unsigned int*)(0x42A22F20UL)))
#define bM4_INTC_SEL72_INTSEL0                    (*((volatile unsigned int*)(0x42A22F80UL)))
#define bM4_INTC_SEL72_INTSEL1                    (*((volatile unsigned int*)(0x42A22F84UL)))
#define bM4_INTC_SEL72_INTSEL2                    (*((volatile unsigned int*)(0x42A22F88UL)))
#define bM4_INTC_SEL72_INTSEL3                    (*((volatile unsigned int*)(0x42A22F8CUL)))
#define bM4_INTC_SEL72_INTSEL4                    (*((volatile unsigned int*)(0x42A22F90UL)))
#define bM4_INTC_SEL72_INTSEL5                    (*((volatile unsigned int*)(0x42A22F94UL)))
#define bM4_INTC_SEL72_INTSEL6                    (*((volatile unsigned int*)(0x42A22F98UL)))
#define bM4_INTC_SEL72_INTSEL7                    (*((volatile unsigned int*)(0x42A22F9CUL)))
#define bM4_INTC_SEL72_INTSEL8                    (*((volatile unsigned int*)(0x42A22FA0UL)))
#define bM4_INTC_SEL73_INTSEL0                    (*((volatile unsigned int*)(0x42A23000UL)))
#define bM4_INTC_SEL73_INTSEL1                    (*((volatile unsigned int*)(0x42A23004UL)))
#define bM4_INTC_SEL73_INTSEL2                    (*((volatile unsigned int*)(0x42A23008UL)))
#define bM4_INTC_SEL73_INTSEL3                    (*((volatile unsigned int*)(0x42A2300CUL)))
#define bM4_INTC_SEL73_INTSEL4                    (*((volatile unsigned int*)(0x42A23010UL)))
#define bM4_INTC_SEL73_INTSEL5                    (*((volatile unsigned int*)(0x42A23014UL)))
#define bM4_INTC_SEL73_INTSEL6                    (*((volatile unsigned int*)(0x42A23018UL)))
#define bM4_INTC_SEL73_INTSEL7                    (*((volatile unsigned int*)(0x42A2301CUL)))
#define bM4_INTC_SEL73_INTSEL8                    (*((volatile unsigned int*)(0x42A23020UL)))
#define bM4_INTC_SEL74_INTSEL0                    (*((volatile unsigned int*)(0x42A23080UL)))
#define bM4_INTC_SEL74_INTSEL1                    (*((volatile unsigned int*)(0x42A23084UL)))
#define bM4_INTC_SEL74_INTSEL2                    (*((volatile unsigned int*)(0x42A23088UL)))
#define bM4_INTC_SEL74_INTSEL3                    (*((volatile unsigned int*)(0x42A2308CUL)))
#define bM4_INTC_SEL74_INTSEL4                    (*((volatile unsigned int*)(0x42A23090UL)))
#define bM4_INTC_SEL74_INTSEL5                    (*((volatile unsigned int*)(0x42A23094UL)))
#define bM4_INTC_SEL74_INTSEL6                    (*((volatile unsigned int*)(0x42A23098UL)))
#define bM4_INTC_SEL74_INTSEL7                    (*((volatile unsigned int*)(0x42A2309CUL)))
#define bM4_INTC_SEL74_INTSEL8                    (*((volatile unsigned int*)(0x42A230A0UL)))
#define bM4_INTC_SEL75_INTSEL0                    (*((volatile unsigned int*)(0x42A23100UL)))
#define bM4_INTC_SEL75_INTSEL1                    (*((volatile unsigned int*)(0x42A23104UL)))
#define bM4_INTC_SEL75_INTSEL2                    (*((volatile unsigned int*)(0x42A23108UL)))
#define bM4_INTC_SEL75_INTSEL3                    (*((volatile unsigned int*)(0x42A2310CUL)))
#define bM4_INTC_SEL75_INTSEL4                    (*((volatile unsigned int*)(0x42A23110UL)))
#define bM4_INTC_SEL75_INTSEL5                    (*((volatile unsigned int*)(0x42A23114UL)))
#define bM4_INTC_SEL75_INTSEL6                    (*((volatile unsigned int*)(0x42A23118UL)))
#define bM4_INTC_SEL75_INTSEL7                    (*((volatile unsigned int*)(0x42A2311CUL)))
#define bM4_INTC_SEL75_INTSEL8                    (*((volatile unsigned int*)(0x42A23120UL)))
#define bM4_INTC_SEL76_INTSEL0                    (*((volatile unsigned int*)(0x42A23180UL)))
#define bM4_INTC_SEL76_INTSEL1                    (*((volatile unsigned int*)(0x42A23184UL)))
#define bM4_INTC_SEL76_INTSEL2                    (*((volatile unsigned int*)(0x42A23188UL)))
#define bM4_INTC_SEL76_INTSEL3                    (*((volatile unsigned int*)(0x42A2318CUL)))
#define bM4_INTC_SEL76_INTSEL4                    (*((volatile unsigned int*)(0x42A23190UL)))
#define bM4_INTC_SEL76_INTSEL5                    (*((volatile unsigned int*)(0x42A23194UL)))
#define bM4_INTC_SEL76_INTSEL6                    (*((volatile unsigned int*)(0x42A23198UL)))
#define bM4_INTC_SEL76_INTSEL7                    (*((volatile unsigned int*)(0x42A2319CUL)))
#define bM4_INTC_SEL76_INTSEL8                    (*((volatile unsigned int*)(0x42A231A0UL)))
#define bM4_INTC_SEL77_INTSEL0                    (*((volatile unsigned int*)(0x42A23200UL)))
#define bM4_INTC_SEL77_INTSEL1                    (*((volatile unsigned int*)(0x42A23204UL)))
#define bM4_INTC_SEL77_INTSEL2                    (*((volatile unsigned int*)(0x42A23208UL)))
#define bM4_INTC_SEL77_INTSEL3                    (*((volatile unsigned int*)(0x42A2320CUL)))
#define bM4_INTC_SEL77_INTSEL4                    (*((volatile unsigned int*)(0x42A23210UL)))
#define bM4_INTC_SEL77_INTSEL5                    (*((volatile unsigned int*)(0x42A23214UL)))
#define bM4_INTC_SEL77_INTSEL6                    (*((volatile unsigned int*)(0x42A23218UL)))
#define bM4_INTC_SEL77_INTSEL7                    (*((volatile unsigned int*)(0x42A2321CUL)))
#define bM4_INTC_SEL77_INTSEL8                    (*((volatile unsigned int*)(0x42A23220UL)))
#define bM4_INTC_SEL78_INTSEL0                    (*((volatile unsigned int*)(0x42A23280UL)))
#define bM4_INTC_SEL78_INTSEL1                    (*((volatile unsigned int*)(0x42A23284UL)))
#define bM4_INTC_SEL78_INTSEL2                    (*((volatile unsigned int*)(0x42A23288UL)))
#define bM4_INTC_SEL78_INTSEL3                    (*((volatile unsigned int*)(0x42A2328CUL)))
#define bM4_INTC_SEL78_INTSEL4                    (*((volatile unsigned int*)(0x42A23290UL)))
#define bM4_INTC_SEL78_INTSEL5                    (*((volatile unsigned int*)(0x42A23294UL)))
#define bM4_INTC_SEL78_INTSEL6                    (*((volatile unsigned int*)(0x42A23298UL)))
#define bM4_INTC_SEL78_INTSEL7                    (*((volatile unsigned int*)(0x42A2329CUL)))
#define bM4_INTC_SEL78_INTSEL8                    (*((volatile unsigned int*)(0x42A232A0UL)))
#define bM4_INTC_SEL79_INTSEL0                    (*((volatile unsigned int*)(0x42A23300UL)))
#define bM4_INTC_SEL79_INTSEL1                    (*((volatile unsigned int*)(0x42A23304UL)))
#define bM4_INTC_SEL79_INTSEL2                    (*((volatile unsigned int*)(0x42A23308UL)))
#define bM4_INTC_SEL79_INTSEL3                    (*((volatile unsigned int*)(0x42A2330CUL)))
#define bM4_INTC_SEL79_INTSEL4                    (*((volatile unsigned int*)(0x42A23310UL)))
#define bM4_INTC_SEL79_INTSEL5                    (*((volatile unsigned int*)(0x42A23314UL)))
#define bM4_INTC_SEL79_INTSEL6                    (*((volatile unsigned int*)(0x42A23318UL)))
#define bM4_INTC_SEL79_INTSEL7                    (*((volatile unsigned int*)(0x42A2331CUL)))
#define bM4_INTC_SEL79_INTSEL8                    (*((volatile unsigned int*)(0x42A23320UL)))
#define bM4_INTC_SEL80_INTSEL0                    (*((volatile unsigned int*)(0x42A23380UL)))
#define bM4_INTC_SEL80_INTSEL1                    (*((volatile unsigned int*)(0x42A23384UL)))
#define bM4_INTC_SEL80_INTSEL2                    (*((volatile unsigned int*)(0x42A23388UL)))
#define bM4_INTC_SEL80_INTSEL3                    (*((volatile unsigned int*)(0x42A2338CUL)))
#define bM4_INTC_SEL80_INTSEL4                    (*((volatile unsigned int*)(0x42A23390UL)))
#define bM4_INTC_SEL80_INTSEL5                    (*((volatile unsigned int*)(0x42A23394UL)))
#define bM4_INTC_SEL80_INTSEL6                    (*((volatile unsigned int*)(0x42A23398UL)))
#define bM4_INTC_SEL80_INTSEL7                    (*((volatile unsigned int*)(0x42A2339CUL)))
#define bM4_INTC_SEL80_INTSEL8                    (*((volatile unsigned int*)(0x42A233A0UL)))
#define bM4_INTC_SEL81_INTSEL0                    (*((volatile unsigned int*)(0x42A23400UL)))
#define bM4_INTC_SEL81_INTSEL1                    (*((volatile unsigned int*)(0x42A23404UL)))
#define bM4_INTC_SEL81_INTSEL2                    (*((volatile unsigned int*)(0x42A23408UL)))
#define bM4_INTC_SEL81_INTSEL3                    (*((volatile unsigned int*)(0x42A2340CUL)))
#define bM4_INTC_SEL81_INTSEL4                    (*((volatile unsigned int*)(0x42A23410UL)))
#define bM4_INTC_SEL81_INTSEL5                    (*((volatile unsigned int*)(0x42A23414UL)))
#define bM4_INTC_SEL81_INTSEL6                    (*((volatile unsigned int*)(0x42A23418UL)))
#define bM4_INTC_SEL81_INTSEL7                    (*((volatile unsigned int*)(0x42A2341CUL)))
#define bM4_INTC_SEL81_INTSEL8                    (*((volatile unsigned int*)(0x42A23420UL)))
#define bM4_INTC_SEL82_INTSEL0                    (*((volatile unsigned int*)(0x42A23480UL)))
#define bM4_INTC_SEL82_INTSEL1                    (*((volatile unsigned int*)(0x42A23484UL)))
#define bM4_INTC_SEL82_INTSEL2                    (*((volatile unsigned int*)(0x42A23488UL)))
#define bM4_INTC_SEL82_INTSEL3                    (*((volatile unsigned int*)(0x42A2348CUL)))
#define bM4_INTC_SEL82_INTSEL4                    (*((volatile unsigned int*)(0x42A23490UL)))
#define bM4_INTC_SEL82_INTSEL5                    (*((volatile unsigned int*)(0x42A23494UL)))
#define bM4_INTC_SEL82_INTSEL6                    (*((volatile unsigned int*)(0x42A23498UL)))
#define bM4_INTC_SEL82_INTSEL7                    (*((volatile unsigned int*)(0x42A2349CUL)))
#define bM4_INTC_SEL82_INTSEL8                    (*((volatile unsigned int*)(0x42A234A0UL)))
#define bM4_INTC_SEL83_INTSEL0                    (*((volatile unsigned int*)(0x42A23500UL)))
#define bM4_INTC_SEL83_INTSEL1                    (*((volatile unsigned int*)(0x42A23504UL)))
#define bM4_INTC_SEL83_INTSEL2                    (*((volatile unsigned int*)(0x42A23508UL)))
#define bM4_INTC_SEL83_INTSEL3                    (*((volatile unsigned int*)(0x42A2350CUL)))
#define bM4_INTC_SEL83_INTSEL4                    (*((volatile unsigned int*)(0x42A23510UL)))
#define bM4_INTC_SEL83_INTSEL5                    (*((volatile unsigned int*)(0x42A23514UL)))
#define bM4_INTC_SEL83_INTSEL6                    (*((volatile unsigned int*)(0x42A23518UL)))
#define bM4_INTC_SEL83_INTSEL7                    (*((volatile unsigned int*)(0x42A2351CUL)))
#define bM4_INTC_SEL83_INTSEL8                    (*((volatile unsigned int*)(0x42A23520UL)))
#define bM4_INTC_SEL84_INTSEL0                    (*((volatile unsigned int*)(0x42A23580UL)))
#define bM4_INTC_SEL84_INTSEL1                    (*((volatile unsigned int*)(0x42A23584UL)))
#define bM4_INTC_SEL84_INTSEL2                    (*((volatile unsigned int*)(0x42A23588UL)))
#define bM4_INTC_SEL84_INTSEL3                    (*((volatile unsigned int*)(0x42A2358CUL)))
#define bM4_INTC_SEL84_INTSEL4                    (*((volatile unsigned int*)(0x42A23590UL)))
#define bM4_INTC_SEL84_INTSEL5                    (*((volatile unsigned int*)(0x42A23594UL)))
#define bM4_INTC_SEL84_INTSEL6                    (*((volatile unsigned int*)(0x42A23598UL)))
#define bM4_INTC_SEL84_INTSEL7                    (*((volatile unsigned int*)(0x42A2359CUL)))
#define bM4_INTC_SEL84_INTSEL8                    (*((volatile unsigned int*)(0x42A235A0UL)))
#define bM4_INTC_SEL85_INTSEL0                    (*((volatile unsigned int*)(0x42A23600UL)))
#define bM4_INTC_SEL85_INTSEL1                    (*((volatile unsigned int*)(0x42A23604UL)))
#define bM4_INTC_SEL85_INTSEL2                    (*((volatile unsigned int*)(0x42A23608UL)))
#define bM4_INTC_SEL85_INTSEL3                    (*((volatile unsigned int*)(0x42A2360CUL)))
#define bM4_INTC_SEL85_INTSEL4                    (*((volatile unsigned int*)(0x42A23610UL)))
#define bM4_INTC_SEL85_INTSEL5                    (*((volatile unsigned int*)(0x42A23614UL)))
#define bM4_INTC_SEL85_INTSEL6                    (*((volatile unsigned int*)(0x42A23618UL)))
#define bM4_INTC_SEL85_INTSEL7                    (*((volatile unsigned int*)(0x42A2361CUL)))
#define bM4_INTC_SEL85_INTSEL8                    (*((volatile unsigned int*)(0x42A23620UL)))
#define bM4_INTC_SEL86_INTSEL0                    (*((volatile unsigned int*)(0x42A23680UL)))
#define bM4_INTC_SEL86_INTSEL1                    (*((volatile unsigned int*)(0x42A23684UL)))
#define bM4_INTC_SEL86_INTSEL2                    (*((volatile unsigned int*)(0x42A23688UL)))
#define bM4_INTC_SEL86_INTSEL3                    (*((volatile unsigned int*)(0x42A2368CUL)))
#define bM4_INTC_SEL86_INTSEL4                    (*((volatile unsigned int*)(0x42A23690UL)))
#define bM4_INTC_SEL86_INTSEL5                    (*((volatile unsigned int*)(0x42A23694UL)))
#define bM4_INTC_SEL86_INTSEL6                    (*((volatile unsigned int*)(0x42A23698UL)))
#define bM4_INTC_SEL86_INTSEL7                    (*((volatile unsigned int*)(0x42A2369CUL)))
#define bM4_INTC_SEL86_INTSEL8                    (*((volatile unsigned int*)(0x42A236A0UL)))
#define bM4_INTC_SEL87_INTSEL0                    (*((volatile unsigned int*)(0x42A23700UL)))
#define bM4_INTC_SEL87_INTSEL1                    (*((volatile unsigned int*)(0x42A23704UL)))
#define bM4_INTC_SEL87_INTSEL2                    (*((volatile unsigned int*)(0x42A23708UL)))
#define bM4_INTC_SEL87_INTSEL3                    (*((volatile unsigned int*)(0x42A2370CUL)))
#define bM4_INTC_SEL87_INTSEL4                    (*((volatile unsigned int*)(0x42A23710UL)))
#define bM4_INTC_SEL87_INTSEL5                    (*((volatile unsigned int*)(0x42A23714UL)))
#define bM4_INTC_SEL87_INTSEL6                    (*((volatile unsigned int*)(0x42A23718UL)))
#define bM4_INTC_SEL87_INTSEL7                    (*((volatile unsigned int*)(0x42A2371CUL)))
#define bM4_INTC_SEL87_INTSEL8                    (*((volatile unsigned int*)(0x42A23720UL)))
#define bM4_INTC_SEL88_INTSEL0                    (*((volatile unsigned int*)(0x42A23780UL)))
#define bM4_INTC_SEL88_INTSEL1                    (*((volatile unsigned int*)(0x42A23784UL)))
#define bM4_INTC_SEL88_INTSEL2                    (*((volatile unsigned int*)(0x42A23788UL)))
#define bM4_INTC_SEL88_INTSEL3                    (*((volatile unsigned int*)(0x42A2378CUL)))
#define bM4_INTC_SEL88_INTSEL4                    (*((volatile unsigned int*)(0x42A23790UL)))
#define bM4_INTC_SEL88_INTSEL5                    (*((volatile unsigned int*)(0x42A23794UL)))
#define bM4_INTC_SEL88_INTSEL6                    (*((volatile unsigned int*)(0x42A23798UL)))
#define bM4_INTC_SEL88_INTSEL7                    (*((volatile unsigned int*)(0x42A2379CUL)))
#define bM4_INTC_SEL88_INTSEL8                    (*((volatile unsigned int*)(0x42A237A0UL)))
#define bM4_INTC_SEL89_INTSEL0                    (*((volatile unsigned int*)(0x42A23800UL)))
#define bM4_INTC_SEL89_INTSEL1                    (*((volatile unsigned int*)(0x42A23804UL)))
#define bM4_INTC_SEL89_INTSEL2                    (*((volatile unsigned int*)(0x42A23808UL)))
#define bM4_INTC_SEL89_INTSEL3                    (*((volatile unsigned int*)(0x42A2380CUL)))
#define bM4_INTC_SEL89_INTSEL4                    (*((volatile unsigned int*)(0x42A23810UL)))
#define bM4_INTC_SEL89_INTSEL5                    (*((volatile unsigned int*)(0x42A23814UL)))
#define bM4_INTC_SEL89_INTSEL6                    (*((volatile unsigned int*)(0x42A23818UL)))
#define bM4_INTC_SEL89_INTSEL7                    (*((volatile unsigned int*)(0x42A2381CUL)))
#define bM4_INTC_SEL89_INTSEL8                    (*((volatile unsigned int*)(0x42A23820UL)))
#define bM4_INTC_SEL90_INTSEL0                    (*((volatile unsigned int*)(0x42A23880UL)))
#define bM4_INTC_SEL90_INTSEL1                    (*((volatile unsigned int*)(0x42A23884UL)))
#define bM4_INTC_SEL90_INTSEL2                    (*((volatile unsigned int*)(0x42A23888UL)))
#define bM4_INTC_SEL90_INTSEL3                    (*((volatile unsigned int*)(0x42A2388CUL)))
#define bM4_INTC_SEL90_INTSEL4                    (*((volatile unsigned int*)(0x42A23890UL)))
#define bM4_INTC_SEL90_INTSEL5                    (*((volatile unsigned int*)(0x42A23894UL)))
#define bM4_INTC_SEL90_INTSEL6                    (*((volatile unsigned int*)(0x42A23898UL)))
#define bM4_INTC_SEL90_INTSEL7                    (*((volatile unsigned int*)(0x42A2389CUL)))
#define bM4_INTC_SEL90_INTSEL8                    (*((volatile unsigned int*)(0x42A238A0UL)))
#define bM4_INTC_SEL91_INTSEL0                    (*((volatile unsigned int*)(0x42A23900UL)))
#define bM4_INTC_SEL91_INTSEL1                    (*((volatile unsigned int*)(0x42A23904UL)))
#define bM4_INTC_SEL91_INTSEL2                    (*((volatile unsigned int*)(0x42A23908UL)))
#define bM4_INTC_SEL91_INTSEL3                    (*((volatile unsigned int*)(0x42A2390CUL)))
#define bM4_INTC_SEL91_INTSEL4                    (*((volatile unsigned int*)(0x42A23910UL)))
#define bM4_INTC_SEL91_INTSEL5                    (*((volatile unsigned int*)(0x42A23914UL)))
#define bM4_INTC_SEL91_INTSEL6                    (*((volatile unsigned int*)(0x42A23918UL)))
#define bM4_INTC_SEL91_INTSEL7                    (*((volatile unsigned int*)(0x42A2391CUL)))
#define bM4_INTC_SEL91_INTSEL8                    (*((volatile unsigned int*)(0x42A23920UL)))
#define bM4_INTC_SEL92_INTSEL0                    (*((volatile unsigned int*)(0x42A23980UL)))
#define bM4_INTC_SEL92_INTSEL1                    (*((volatile unsigned int*)(0x42A23984UL)))
#define bM4_INTC_SEL92_INTSEL2                    (*((volatile unsigned int*)(0x42A23988UL)))
#define bM4_INTC_SEL92_INTSEL3                    (*((volatile unsigned int*)(0x42A2398CUL)))
#define bM4_INTC_SEL92_INTSEL4                    (*((volatile unsigned int*)(0x42A23990UL)))
#define bM4_INTC_SEL92_INTSEL5                    (*((volatile unsigned int*)(0x42A23994UL)))
#define bM4_INTC_SEL92_INTSEL6                    (*((volatile unsigned int*)(0x42A23998UL)))
#define bM4_INTC_SEL92_INTSEL7                    (*((volatile unsigned int*)(0x42A2399CUL)))
#define bM4_INTC_SEL92_INTSEL8                    (*((volatile unsigned int*)(0x42A239A0UL)))
#define bM4_INTC_SEL93_INTSEL0                    (*((volatile unsigned int*)(0x42A23A00UL)))
#define bM4_INTC_SEL93_INTSEL1                    (*((volatile unsigned int*)(0x42A23A04UL)))
#define bM4_INTC_SEL93_INTSEL2                    (*((volatile unsigned int*)(0x42A23A08UL)))
#define bM4_INTC_SEL93_INTSEL3                    (*((volatile unsigned int*)(0x42A23A0CUL)))
#define bM4_INTC_SEL93_INTSEL4                    (*((volatile unsigned int*)(0x42A23A10UL)))
#define bM4_INTC_SEL93_INTSEL5                    (*((volatile unsigned int*)(0x42A23A14UL)))
#define bM4_INTC_SEL93_INTSEL6                    (*((volatile unsigned int*)(0x42A23A18UL)))
#define bM4_INTC_SEL93_INTSEL7                    (*((volatile unsigned int*)(0x42A23A1CUL)))
#define bM4_INTC_SEL93_INTSEL8                    (*((volatile unsigned int*)(0x42A23A20UL)))
#define bM4_INTC_SEL94_INTSEL0                    (*((volatile unsigned int*)(0x42A23A80UL)))
#define bM4_INTC_SEL94_INTSEL1                    (*((volatile unsigned int*)(0x42A23A84UL)))
#define bM4_INTC_SEL94_INTSEL2                    (*((volatile unsigned int*)(0x42A23A88UL)))
#define bM4_INTC_SEL94_INTSEL3                    (*((volatile unsigned int*)(0x42A23A8CUL)))
#define bM4_INTC_SEL94_INTSEL4                    (*((volatile unsigned int*)(0x42A23A90UL)))
#define bM4_INTC_SEL94_INTSEL5                    (*((volatile unsigned int*)(0x42A23A94UL)))
#define bM4_INTC_SEL94_INTSEL6                    (*((volatile unsigned int*)(0x42A23A98UL)))
#define bM4_INTC_SEL94_INTSEL7                    (*((volatile unsigned int*)(0x42A23A9CUL)))
#define bM4_INTC_SEL94_INTSEL8                    (*((volatile unsigned int*)(0x42A23AA0UL)))
#define bM4_INTC_SEL95_INTSEL0                    (*((volatile unsigned int*)(0x42A23B00UL)))
#define bM4_INTC_SEL95_INTSEL1                    (*((volatile unsigned int*)(0x42A23B04UL)))
#define bM4_INTC_SEL95_INTSEL2                    (*((volatile unsigned int*)(0x42A23B08UL)))
#define bM4_INTC_SEL95_INTSEL3                    (*((volatile unsigned int*)(0x42A23B0CUL)))
#define bM4_INTC_SEL95_INTSEL4                    (*((volatile unsigned int*)(0x42A23B10UL)))
#define bM4_INTC_SEL95_INTSEL5                    (*((volatile unsigned int*)(0x42A23B14UL)))
#define bM4_INTC_SEL95_INTSEL6                    (*((volatile unsigned int*)(0x42A23B18UL)))
#define bM4_INTC_SEL95_INTSEL7                    (*((volatile unsigned int*)(0x42A23B1CUL)))
#define bM4_INTC_SEL95_INTSEL8                    (*((volatile unsigned int*)(0x42A23B20UL)))
#define bM4_INTC_SEL96_INTSEL0                    (*((volatile unsigned int*)(0x42A23B80UL)))
#define bM4_INTC_SEL96_INTSEL1                    (*((volatile unsigned int*)(0x42A23B84UL)))
#define bM4_INTC_SEL96_INTSEL2                    (*((volatile unsigned int*)(0x42A23B88UL)))
#define bM4_INTC_SEL96_INTSEL3                    (*((volatile unsigned int*)(0x42A23B8CUL)))
#define bM4_INTC_SEL96_INTSEL4                    (*((volatile unsigned int*)(0x42A23B90UL)))
#define bM4_INTC_SEL96_INTSEL5                    (*((volatile unsigned int*)(0x42A23B94UL)))
#define bM4_INTC_SEL96_INTSEL6                    (*((volatile unsigned int*)(0x42A23B98UL)))
#define bM4_INTC_SEL96_INTSEL7                    (*((volatile unsigned int*)(0x42A23B9CUL)))
#define bM4_INTC_SEL96_INTSEL8                    (*((volatile unsigned int*)(0x42A23BA0UL)))
#define bM4_INTC_SEL97_INTSEL0                    (*((volatile unsigned int*)(0x42A23C00UL)))
#define bM4_INTC_SEL97_INTSEL1                    (*((volatile unsigned int*)(0x42A23C04UL)))
#define bM4_INTC_SEL97_INTSEL2                    (*((volatile unsigned int*)(0x42A23C08UL)))
#define bM4_INTC_SEL97_INTSEL3                    (*((volatile unsigned int*)(0x42A23C0CUL)))
#define bM4_INTC_SEL97_INTSEL4                    (*((volatile unsigned int*)(0x42A23C10UL)))
#define bM4_INTC_SEL97_INTSEL5                    (*((volatile unsigned int*)(0x42A23C14UL)))
#define bM4_INTC_SEL97_INTSEL6                    (*((volatile unsigned int*)(0x42A23C18UL)))
#define bM4_INTC_SEL97_INTSEL7                    (*((volatile unsigned int*)(0x42A23C1CUL)))
#define bM4_INTC_SEL97_INTSEL8                    (*((volatile unsigned int*)(0x42A23C20UL)))
#define bM4_INTC_SEL98_INTSEL0                    (*((volatile unsigned int*)(0x42A23C80UL)))
#define bM4_INTC_SEL98_INTSEL1                    (*((volatile unsigned int*)(0x42A23C84UL)))
#define bM4_INTC_SEL98_INTSEL2                    (*((volatile unsigned int*)(0x42A23C88UL)))
#define bM4_INTC_SEL98_INTSEL3                    (*((volatile unsigned int*)(0x42A23C8CUL)))
#define bM4_INTC_SEL98_INTSEL4                    (*((volatile unsigned int*)(0x42A23C90UL)))
#define bM4_INTC_SEL98_INTSEL5                    (*((volatile unsigned int*)(0x42A23C94UL)))
#define bM4_INTC_SEL98_INTSEL6                    (*((volatile unsigned int*)(0x42A23C98UL)))
#define bM4_INTC_SEL98_INTSEL7                    (*((volatile unsigned int*)(0x42A23C9CUL)))
#define bM4_INTC_SEL98_INTSEL8                    (*((volatile unsigned int*)(0x42A23CA0UL)))
#define bM4_INTC_SEL99_INTSEL0                    (*((volatile unsigned int*)(0x42A23D00UL)))
#define bM4_INTC_SEL99_INTSEL1                    (*((volatile unsigned int*)(0x42A23D04UL)))
#define bM4_INTC_SEL99_INTSEL2                    (*((volatile unsigned int*)(0x42A23D08UL)))
#define bM4_INTC_SEL99_INTSEL3                    (*((volatile unsigned int*)(0x42A23D0CUL)))
#define bM4_INTC_SEL99_INTSEL4                    (*((volatile unsigned int*)(0x42A23D10UL)))
#define bM4_INTC_SEL99_INTSEL5                    (*((volatile unsigned int*)(0x42A23D14UL)))
#define bM4_INTC_SEL99_INTSEL6                    (*((volatile unsigned int*)(0x42A23D18UL)))
#define bM4_INTC_SEL99_INTSEL7                    (*((volatile unsigned int*)(0x42A23D1CUL)))
#define bM4_INTC_SEL99_INTSEL8                    (*((volatile unsigned int*)(0x42A23D20UL)))
#define bM4_INTC_SEL100_INTSEL0                   (*((volatile unsigned int*)(0x42A23D80UL)))
#define bM4_INTC_SEL100_INTSEL1                   (*((volatile unsigned int*)(0x42A23D84UL)))
#define bM4_INTC_SEL100_INTSEL2                   (*((volatile unsigned int*)(0x42A23D88UL)))
#define bM4_INTC_SEL100_INTSEL3                   (*((volatile unsigned int*)(0x42A23D8CUL)))
#define bM4_INTC_SEL100_INTSEL4                   (*((volatile unsigned int*)(0x42A23D90UL)))
#define bM4_INTC_SEL100_INTSEL5                   (*((volatile unsigned int*)(0x42A23D94UL)))
#define bM4_INTC_SEL100_INTSEL6                   (*((volatile unsigned int*)(0x42A23D98UL)))
#define bM4_INTC_SEL100_INTSEL7                   (*((volatile unsigned int*)(0x42A23D9CUL)))
#define bM4_INTC_SEL100_INTSEL8                   (*((volatile unsigned int*)(0x42A23DA0UL)))
#define bM4_INTC_SEL101_INTSEL0                   (*((volatile unsigned int*)(0x42A23E00UL)))
#define bM4_INTC_SEL101_INTSEL1                   (*((volatile unsigned int*)(0x42A23E04UL)))
#define bM4_INTC_SEL101_INTSEL2                   (*((volatile unsigned int*)(0x42A23E08UL)))
#define bM4_INTC_SEL101_INTSEL3                   (*((volatile unsigned int*)(0x42A23E0CUL)))
#define bM4_INTC_SEL101_INTSEL4                   (*((volatile unsigned int*)(0x42A23E10UL)))
#define bM4_INTC_SEL101_INTSEL5                   (*((volatile unsigned int*)(0x42A23E14UL)))
#define bM4_INTC_SEL101_INTSEL6                   (*((volatile unsigned int*)(0x42A23E18UL)))
#define bM4_INTC_SEL101_INTSEL7                   (*((volatile unsigned int*)(0x42A23E1CUL)))
#define bM4_INTC_SEL101_INTSEL8                   (*((volatile unsigned int*)(0x42A23E20UL)))
#define bM4_INTC_SEL102_INTSEL0                   (*((volatile unsigned int*)(0x42A23E80UL)))
#define bM4_INTC_SEL102_INTSEL1                   (*((volatile unsigned int*)(0x42A23E84UL)))
#define bM4_INTC_SEL102_INTSEL2                   (*((volatile unsigned int*)(0x42A23E88UL)))
#define bM4_INTC_SEL102_INTSEL3                   (*((volatile unsigned int*)(0x42A23E8CUL)))
#define bM4_INTC_SEL102_INTSEL4                   (*((volatile unsigned int*)(0x42A23E90UL)))
#define bM4_INTC_SEL102_INTSEL5                   (*((volatile unsigned int*)(0x42A23E94UL)))
#define bM4_INTC_SEL102_INTSEL6                   (*((volatile unsigned int*)(0x42A23E98UL)))
#define bM4_INTC_SEL102_INTSEL7                   (*((volatile unsigned int*)(0x42A23E9CUL)))
#define bM4_INTC_SEL102_INTSEL8                   (*((volatile unsigned int*)(0x42A23EA0UL)))
#define bM4_INTC_SEL103_INTSEL0                   (*((volatile unsigned int*)(0x42A23F00UL)))
#define bM4_INTC_SEL103_INTSEL1                   (*((volatile unsigned int*)(0x42A23F04UL)))
#define bM4_INTC_SEL103_INTSEL2                   (*((volatile unsigned int*)(0x42A23F08UL)))
#define bM4_INTC_SEL103_INTSEL3                   (*((volatile unsigned int*)(0x42A23F0CUL)))
#define bM4_INTC_SEL103_INTSEL4                   (*((volatile unsigned int*)(0x42A23F10UL)))
#define bM4_INTC_SEL103_INTSEL5                   (*((volatile unsigned int*)(0x42A23F14UL)))
#define bM4_INTC_SEL103_INTSEL6                   (*((volatile unsigned int*)(0x42A23F18UL)))
#define bM4_INTC_SEL103_INTSEL7                   (*((volatile unsigned int*)(0x42A23F1CUL)))
#define bM4_INTC_SEL103_INTSEL8                   (*((volatile unsigned int*)(0x42A23F20UL)))
#define bM4_INTC_SEL104_INTSEL0                   (*((volatile unsigned int*)(0x42A23F80UL)))
#define bM4_INTC_SEL104_INTSEL1                   (*((volatile unsigned int*)(0x42A23F84UL)))
#define bM4_INTC_SEL104_INTSEL2                   (*((volatile unsigned int*)(0x42A23F88UL)))
#define bM4_INTC_SEL104_INTSEL3                   (*((volatile unsigned int*)(0x42A23F8CUL)))
#define bM4_INTC_SEL104_INTSEL4                   (*((volatile unsigned int*)(0x42A23F90UL)))
#define bM4_INTC_SEL104_INTSEL5                   (*((volatile unsigned int*)(0x42A23F94UL)))
#define bM4_INTC_SEL104_INTSEL6                   (*((volatile unsigned int*)(0x42A23F98UL)))
#define bM4_INTC_SEL104_INTSEL7                   (*((volatile unsigned int*)(0x42A23F9CUL)))
#define bM4_INTC_SEL104_INTSEL8                   (*((volatile unsigned int*)(0x42A23FA0UL)))
#define bM4_INTC_SEL105_INTSEL0                   (*((volatile unsigned int*)(0x42A24000UL)))
#define bM4_INTC_SEL105_INTSEL1                   (*((volatile unsigned int*)(0x42A24004UL)))
#define bM4_INTC_SEL105_INTSEL2                   (*((volatile unsigned int*)(0x42A24008UL)))
#define bM4_INTC_SEL105_INTSEL3                   (*((volatile unsigned int*)(0x42A2400CUL)))
#define bM4_INTC_SEL105_INTSEL4                   (*((volatile unsigned int*)(0x42A24010UL)))
#define bM4_INTC_SEL105_INTSEL5                   (*((volatile unsigned int*)(0x42A24014UL)))
#define bM4_INTC_SEL105_INTSEL6                   (*((volatile unsigned int*)(0x42A24018UL)))
#define bM4_INTC_SEL105_INTSEL7                   (*((volatile unsigned int*)(0x42A2401CUL)))
#define bM4_INTC_SEL105_INTSEL8                   (*((volatile unsigned int*)(0x42A24020UL)))
#define bM4_INTC_SEL106_INTSEL0                   (*((volatile unsigned int*)(0x42A24080UL)))
#define bM4_INTC_SEL106_INTSEL1                   (*((volatile unsigned int*)(0x42A24084UL)))
#define bM4_INTC_SEL106_INTSEL2                   (*((volatile unsigned int*)(0x42A24088UL)))
#define bM4_INTC_SEL106_INTSEL3                   (*((volatile unsigned int*)(0x42A2408CUL)))
#define bM4_INTC_SEL106_INTSEL4                   (*((volatile unsigned int*)(0x42A24090UL)))
#define bM4_INTC_SEL106_INTSEL5                   (*((volatile unsigned int*)(0x42A24094UL)))
#define bM4_INTC_SEL106_INTSEL6                   (*((volatile unsigned int*)(0x42A24098UL)))
#define bM4_INTC_SEL106_INTSEL7                   (*((volatile unsigned int*)(0x42A2409CUL)))
#define bM4_INTC_SEL106_INTSEL8                   (*((volatile unsigned int*)(0x42A240A0UL)))
#define bM4_INTC_SEL107_INTSEL0                   (*((volatile unsigned int*)(0x42A24100UL)))
#define bM4_INTC_SEL107_INTSEL1                   (*((volatile unsigned int*)(0x42A24104UL)))
#define bM4_INTC_SEL107_INTSEL2                   (*((volatile unsigned int*)(0x42A24108UL)))
#define bM4_INTC_SEL107_INTSEL3                   (*((volatile unsigned int*)(0x42A2410CUL)))
#define bM4_INTC_SEL107_INTSEL4                   (*((volatile unsigned int*)(0x42A24110UL)))
#define bM4_INTC_SEL107_INTSEL5                   (*((volatile unsigned int*)(0x42A24114UL)))
#define bM4_INTC_SEL107_INTSEL6                   (*((volatile unsigned int*)(0x42A24118UL)))
#define bM4_INTC_SEL107_INTSEL7                   (*((volatile unsigned int*)(0x42A2411CUL)))
#define bM4_INTC_SEL107_INTSEL8                   (*((volatile unsigned int*)(0x42A24120UL)))
#define bM4_INTC_SEL108_INTSEL0                   (*((volatile unsigned int*)(0x42A24180UL)))
#define bM4_INTC_SEL108_INTSEL1                   (*((volatile unsigned int*)(0x42A24184UL)))
#define bM4_INTC_SEL108_INTSEL2                   (*((volatile unsigned int*)(0x42A24188UL)))
#define bM4_INTC_SEL108_INTSEL3                   (*((volatile unsigned int*)(0x42A2418CUL)))
#define bM4_INTC_SEL108_INTSEL4                   (*((volatile unsigned int*)(0x42A24190UL)))
#define bM4_INTC_SEL108_INTSEL5                   (*((volatile unsigned int*)(0x42A24194UL)))
#define bM4_INTC_SEL108_INTSEL6                   (*((volatile unsigned int*)(0x42A24198UL)))
#define bM4_INTC_SEL108_INTSEL7                   (*((volatile unsigned int*)(0x42A2419CUL)))
#define bM4_INTC_SEL108_INTSEL8                   (*((volatile unsigned int*)(0x42A241A0UL)))
#define bM4_INTC_SEL109_INTSEL0                   (*((volatile unsigned int*)(0x42A24200UL)))
#define bM4_INTC_SEL109_INTSEL1                   (*((volatile unsigned int*)(0x42A24204UL)))
#define bM4_INTC_SEL109_INTSEL2                   (*((volatile unsigned int*)(0x42A24208UL)))
#define bM4_INTC_SEL109_INTSEL3                   (*((volatile unsigned int*)(0x42A2420CUL)))
#define bM4_INTC_SEL109_INTSEL4                   (*((volatile unsigned int*)(0x42A24210UL)))
#define bM4_INTC_SEL109_INTSEL5                   (*((volatile unsigned int*)(0x42A24214UL)))
#define bM4_INTC_SEL109_INTSEL6                   (*((volatile unsigned int*)(0x42A24218UL)))
#define bM4_INTC_SEL109_INTSEL7                   (*((volatile unsigned int*)(0x42A2421CUL)))
#define bM4_INTC_SEL109_INTSEL8                   (*((volatile unsigned int*)(0x42A24220UL)))
#define bM4_INTC_SEL110_INTSEL0                   (*((volatile unsigned int*)(0x42A24280UL)))
#define bM4_INTC_SEL110_INTSEL1                   (*((volatile unsigned int*)(0x42A24284UL)))
#define bM4_INTC_SEL110_INTSEL2                   (*((volatile unsigned int*)(0x42A24288UL)))
#define bM4_INTC_SEL110_INTSEL3                   (*((volatile unsigned int*)(0x42A2428CUL)))
#define bM4_INTC_SEL110_INTSEL4                   (*((volatile unsigned int*)(0x42A24290UL)))
#define bM4_INTC_SEL110_INTSEL5                   (*((volatile unsigned int*)(0x42A24294UL)))
#define bM4_INTC_SEL110_INTSEL6                   (*((volatile unsigned int*)(0x42A24298UL)))
#define bM4_INTC_SEL110_INTSEL7                   (*((volatile unsigned int*)(0x42A2429CUL)))
#define bM4_INTC_SEL110_INTSEL8                   (*((volatile unsigned int*)(0x42A242A0UL)))
#define bM4_INTC_SEL111_INTSEL0                   (*((volatile unsigned int*)(0x42A24300UL)))
#define bM4_INTC_SEL111_INTSEL1                   (*((volatile unsigned int*)(0x42A24304UL)))
#define bM4_INTC_SEL111_INTSEL2                   (*((volatile unsigned int*)(0x42A24308UL)))
#define bM4_INTC_SEL111_INTSEL3                   (*((volatile unsigned int*)(0x42A2430CUL)))
#define bM4_INTC_SEL111_INTSEL4                   (*((volatile unsigned int*)(0x42A24310UL)))
#define bM4_INTC_SEL111_INTSEL5                   (*((volatile unsigned int*)(0x42A24314UL)))
#define bM4_INTC_SEL111_INTSEL6                   (*((volatile unsigned int*)(0x42A24318UL)))
#define bM4_INTC_SEL111_INTSEL7                   (*((volatile unsigned int*)(0x42A2431CUL)))
#define bM4_INTC_SEL111_INTSEL8                   (*((volatile unsigned int*)(0x42A24320UL)))
#define bM4_INTC_SEL112_INTSEL0                   (*((volatile unsigned int*)(0x42A24380UL)))
#define bM4_INTC_SEL112_INTSEL1                   (*((volatile unsigned int*)(0x42A24384UL)))
#define bM4_INTC_SEL112_INTSEL2                   (*((volatile unsigned int*)(0x42A24388UL)))
#define bM4_INTC_SEL112_INTSEL3                   (*((volatile unsigned int*)(0x42A2438CUL)))
#define bM4_INTC_SEL112_INTSEL4                   (*((volatile unsigned int*)(0x42A24390UL)))
#define bM4_INTC_SEL112_INTSEL5                   (*((volatile unsigned int*)(0x42A24394UL)))
#define bM4_INTC_SEL112_INTSEL6                   (*((volatile unsigned int*)(0x42A24398UL)))
#define bM4_INTC_SEL112_INTSEL7                   (*((volatile unsigned int*)(0x42A2439CUL)))
#define bM4_INTC_SEL112_INTSEL8                   (*((volatile unsigned int*)(0x42A243A0UL)))
#define bM4_INTC_SEL113_INTSEL0                   (*((volatile unsigned int*)(0x42A24400UL)))
#define bM4_INTC_SEL113_INTSEL1                   (*((volatile unsigned int*)(0x42A24404UL)))
#define bM4_INTC_SEL113_INTSEL2                   (*((volatile unsigned int*)(0x42A24408UL)))
#define bM4_INTC_SEL113_INTSEL3                   (*((volatile unsigned int*)(0x42A2440CUL)))
#define bM4_INTC_SEL113_INTSEL4                   (*((volatile unsigned int*)(0x42A24410UL)))
#define bM4_INTC_SEL113_INTSEL5                   (*((volatile unsigned int*)(0x42A24414UL)))
#define bM4_INTC_SEL113_INTSEL6                   (*((volatile unsigned int*)(0x42A24418UL)))
#define bM4_INTC_SEL113_INTSEL7                   (*((volatile unsigned int*)(0x42A2441CUL)))
#define bM4_INTC_SEL113_INTSEL8                   (*((volatile unsigned int*)(0x42A24420UL)))
#define bM4_INTC_SEL114_INTSEL0                   (*((volatile unsigned int*)(0x42A24480UL)))
#define bM4_INTC_SEL114_INTSEL1                   (*((volatile unsigned int*)(0x42A24484UL)))
#define bM4_INTC_SEL114_INTSEL2                   (*((volatile unsigned int*)(0x42A24488UL)))
#define bM4_INTC_SEL114_INTSEL3                   (*((volatile unsigned int*)(0x42A2448CUL)))
#define bM4_INTC_SEL114_INTSEL4                   (*((volatile unsigned int*)(0x42A24490UL)))
#define bM4_INTC_SEL114_INTSEL5                   (*((volatile unsigned int*)(0x42A24494UL)))
#define bM4_INTC_SEL114_INTSEL6                   (*((volatile unsigned int*)(0x42A24498UL)))
#define bM4_INTC_SEL114_INTSEL7                   (*((volatile unsigned int*)(0x42A2449CUL)))
#define bM4_INTC_SEL114_INTSEL8                   (*((volatile unsigned int*)(0x42A244A0UL)))
#define bM4_INTC_SEL115_INTSEL0                   (*((volatile unsigned int*)(0x42A24500UL)))
#define bM4_INTC_SEL115_INTSEL1                   (*((volatile unsigned int*)(0x42A24504UL)))
#define bM4_INTC_SEL115_INTSEL2                   (*((volatile unsigned int*)(0x42A24508UL)))
#define bM4_INTC_SEL115_INTSEL3                   (*((volatile unsigned int*)(0x42A2450CUL)))
#define bM4_INTC_SEL115_INTSEL4                   (*((volatile unsigned int*)(0x42A24510UL)))
#define bM4_INTC_SEL115_INTSEL5                   (*((volatile unsigned int*)(0x42A24514UL)))
#define bM4_INTC_SEL115_INTSEL6                   (*((volatile unsigned int*)(0x42A24518UL)))
#define bM4_INTC_SEL115_INTSEL7                   (*((volatile unsigned int*)(0x42A2451CUL)))
#define bM4_INTC_SEL115_INTSEL8                   (*((volatile unsigned int*)(0x42A24520UL)))
#define bM4_INTC_SEL116_INTSEL0                   (*((volatile unsigned int*)(0x42A24580UL)))
#define bM4_INTC_SEL116_INTSEL1                   (*((volatile unsigned int*)(0x42A24584UL)))
#define bM4_INTC_SEL116_INTSEL2                   (*((volatile unsigned int*)(0x42A24588UL)))
#define bM4_INTC_SEL116_INTSEL3                   (*((volatile unsigned int*)(0x42A2458CUL)))
#define bM4_INTC_SEL116_INTSEL4                   (*((volatile unsigned int*)(0x42A24590UL)))
#define bM4_INTC_SEL116_INTSEL5                   (*((volatile unsigned int*)(0x42A24594UL)))
#define bM4_INTC_SEL116_INTSEL6                   (*((volatile unsigned int*)(0x42A24598UL)))
#define bM4_INTC_SEL116_INTSEL7                   (*((volatile unsigned int*)(0x42A2459CUL)))
#define bM4_INTC_SEL116_INTSEL8                   (*((volatile unsigned int*)(0x42A245A0UL)))
#define bM4_INTC_SEL117_INTSEL0                   (*((volatile unsigned int*)(0x42A24600UL)))
#define bM4_INTC_SEL117_INTSEL1                   (*((volatile unsigned int*)(0x42A24604UL)))
#define bM4_INTC_SEL117_INTSEL2                   (*((volatile unsigned int*)(0x42A24608UL)))
#define bM4_INTC_SEL117_INTSEL3                   (*((volatile unsigned int*)(0x42A2460CUL)))
#define bM4_INTC_SEL117_INTSEL4                   (*((volatile unsigned int*)(0x42A24610UL)))
#define bM4_INTC_SEL117_INTSEL5                   (*((volatile unsigned int*)(0x42A24614UL)))
#define bM4_INTC_SEL117_INTSEL6                   (*((volatile unsigned int*)(0x42A24618UL)))
#define bM4_INTC_SEL117_INTSEL7                   (*((volatile unsigned int*)(0x42A2461CUL)))
#define bM4_INTC_SEL117_INTSEL8                   (*((volatile unsigned int*)(0x42A24620UL)))
#define bM4_INTC_SEL118_INTSEL0                   (*((volatile unsigned int*)(0x42A24680UL)))
#define bM4_INTC_SEL118_INTSEL1                   (*((volatile unsigned int*)(0x42A24684UL)))
#define bM4_INTC_SEL118_INTSEL2                   (*((volatile unsigned int*)(0x42A24688UL)))
#define bM4_INTC_SEL118_INTSEL3                   (*((volatile unsigned int*)(0x42A2468CUL)))
#define bM4_INTC_SEL118_INTSEL4                   (*((volatile unsigned int*)(0x42A24690UL)))
#define bM4_INTC_SEL118_INTSEL5                   (*((volatile unsigned int*)(0x42A24694UL)))
#define bM4_INTC_SEL118_INTSEL6                   (*((volatile unsigned int*)(0x42A24698UL)))
#define bM4_INTC_SEL118_INTSEL7                   (*((volatile unsigned int*)(0x42A2469CUL)))
#define bM4_INTC_SEL118_INTSEL8                   (*((volatile unsigned int*)(0x42A246A0UL)))
#define bM4_INTC_SEL119_INTSEL0                   (*((volatile unsigned int*)(0x42A24700UL)))
#define bM4_INTC_SEL119_INTSEL1                   (*((volatile unsigned int*)(0x42A24704UL)))
#define bM4_INTC_SEL119_INTSEL2                   (*((volatile unsigned int*)(0x42A24708UL)))
#define bM4_INTC_SEL119_INTSEL3                   (*((volatile unsigned int*)(0x42A2470CUL)))
#define bM4_INTC_SEL119_INTSEL4                   (*((volatile unsigned int*)(0x42A24710UL)))
#define bM4_INTC_SEL119_INTSEL5                   (*((volatile unsigned int*)(0x42A24714UL)))
#define bM4_INTC_SEL119_INTSEL6                   (*((volatile unsigned int*)(0x42A24718UL)))
#define bM4_INTC_SEL119_INTSEL7                   (*((volatile unsigned int*)(0x42A2471CUL)))
#define bM4_INTC_SEL119_INTSEL8                   (*((volatile unsigned int*)(0x42A24720UL)))
#define bM4_INTC_SEL120_INTSEL0                   (*((volatile unsigned int*)(0x42A24780UL)))
#define bM4_INTC_SEL120_INTSEL1                   (*((volatile unsigned int*)(0x42A24784UL)))
#define bM4_INTC_SEL120_INTSEL2                   (*((volatile unsigned int*)(0x42A24788UL)))
#define bM4_INTC_SEL120_INTSEL3                   (*((volatile unsigned int*)(0x42A2478CUL)))
#define bM4_INTC_SEL120_INTSEL4                   (*((volatile unsigned int*)(0x42A24790UL)))
#define bM4_INTC_SEL120_INTSEL5                   (*((volatile unsigned int*)(0x42A24794UL)))
#define bM4_INTC_SEL120_INTSEL6                   (*((volatile unsigned int*)(0x42A24798UL)))
#define bM4_INTC_SEL120_INTSEL7                   (*((volatile unsigned int*)(0x42A2479CUL)))
#define bM4_INTC_SEL120_INTSEL8                   (*((volatile unsigned int*)(0x42A247A0UL)))
#define bM4_INTC_SEL121_INTSEL0                   (*((volatile unsigned int*)(0x42A24800UL)))
#define bM4_INTC_SEL121_INTSEL1                   (*((volatile unsigned int*)(0x42A24804UL)))
#define bM4_INTC_SEL121_INTSEL2                   (*((volatile unsigned int*)(0x42A24808UL)))
#define bM4_INTC_SEL121_INTSEL3                   (*((volatile unsigned int*)(0x42A2480CUL)))
#define bM4_INTC_SEL121_INTSEL4                   (*((volatile unsigned int*)(0x42A24810UL)))
#define bM4_INTC_SEL121_INTSEL5                   (*((volatile unsigned int*)(0x42A24814UL)))
#define bM4_INTC_SEL121_INTSEL6                   (*((volatile unsigned int*)(0x42A24818UL)))
#define bM4_INTC_SEL121_INTSEL7                   (*((volatile unsigned int*)(0x42A2481CUL)))
#define bM4_INTC_SEL121_INTSEL8                   (*((volatile unsigned int*)(0x42A24820UL)))
#define bM4_INTC_SEL122_INTSEL0                   (*((volatile unsigned int*)(0x42A24880UL)))
#define bM4_INTC_SEL122_INTSEL1                   (*((volatile unsigned int*)(0x42A24884UL)))
#define bM4_INTC_SEL122_INTSEL2                   (*((volatile unsigned int*)(0x42A24888UL)))
#define bM4_INTC_SEL122_INTSEL3                   (*((volatile unsigned int*)(0x42A2488CUL)))
#define bM4_INTC_SEL122_INTSEL4                   (*((volatile unsigned int*)(0x42A24890UL)))
#define bM4_INTC_SEL122_INTSEL5                   (*((volatile unsigned int*)(0x42A24894UL)))
#define bM4_INTC_SEL122_INTSEL6                   (*((volatile unsigned int*)(0x42A24898UL)))
#define bM4_INTC_SEL122_INTSEL7                   (*((volatile unsigned int*)(0x42A2489CUL)))
#define bM4_INTC_SEL122_INTSEL8                   (*((volatile unsigned int*)(0x42A248A0UL)))
#define bM4_INTC_SEL123_INTSEL0                   (*((volatile unsigned int*)(0x42A24900UL)))
#define bM4_INTC_SEL123_INTSEL1                   (*((volatile unsigned int*)(0x42A24904UL)))
#define bM4_INTC_SEL123_INTSEL2                   (*((volatile unsigned int*)(0x42A24908UL)))
#define bM4_INTC_SEL123_INTSEL3                   (*((volatile unsigned int*)(0x42A2490CUL)))
#define bM4_INTC_SEL123_INTSEL4                   (*((volatile unsigned int*)(0x42A24910UL)))
#define bM4_INTC_SEL123_INTSEL5                   (*((volatile unsigned int*)(0x42A24914UL)))
#define bM4_INTC_SEL123_INTSEL6                   (*((volatile unsigned int*)(0x42A24918UL)))
#define bM4_INTC_SEL123_INTSEL7                   (*((volatile unsigned int*)(0x42A2491CUL)))
#define bM4_INTC_SEL123_INTSEL8                   (*((volatile unsigned int*)(0x42A24920UL)))
#define bM4_INTC_SEL124_INTSEL0                   (*((volatile unsigned int*)(0x42A24980UL)))
#define bM4_INTC_SEL124_INTSEL1                   (*((volatile unsigned int*)(0x42A24984UL)))
#define bM4_INTC_SEL124_INTSEL2                   (*((volatile unsigned int*)(0x42A24988UL)))
#define bM4_INTC_SEL124_INTSEL3                   (*((volatile unsigned int*)(0x42A2498CUL)))
#define bM4_INTC_SEL124_INTSEL4                   (*((volatile unsigned int*)(0x42A24990UL)))
#define bM4_INTC_SEL124_INTSEL5                   (*((volatile unsigned int*)(0x42A24994UL)))
#define bM4_INTC_SEL124_INTSEL6                   (*((volatile unsigned int*)(0x42A24998UL)))
#define bM4_INTC_SEL124_INTSEL7                   (*((volatile unsigned int*)(0x42A2499CUL)))
#define bM4_INTC_SEL124_INTSEL8                   (*((volatile unsigned int*)(0x42A249A0UL)))
#define bM4_INTC_SEL125_INTSEL0                   (*((volatile unsigned int*)(0x42A24A00UL)))
#define bM4_INTC_SEL125_INTSEL1                   (*((volatile unsigned int*)(0x42A24A04UL)))
#define bM4_INTC_SEL125_INTSEL2                   (*((volatile unsigned int*)(0x42A24A08UL)))
#define bM4_INTC_SEL125_INTSEL3                   (*((volatile unsigned int*)(0x42A24A0CUL)))
#define bM4_INTC_SEL125_INTSEL4                   (*((volatile unsigned int*)(0x42A24A10UL)))
#define bM4_INTC_SEL125_INTSEL5                   (*((volatile unsigned int*)(0x42A24A14UL)))
#define bM4_INTC_SEL125_INTSEL6                   (*((volatile unsigned int*)(0x42A24A18UL)))
#define bM4_INTC_SEL125_INTSEL7                   (*((volatile unsigned int*)(0x42A24A1CUL)))
#define bM4_INTC_SEL125_INTSEL8                   (*((volatile unsigned int*)(0x42A24A20UL)))
#define bM4_INTC_SEL126_INTSEL0                   (*((volatile unsigned int*)(0x42A24A80UL)))
#define bM4_INTC_SEL126_INTSEL1                   (*((volatile unsigned int*)(0x42A24A84UL)))
#define bM4_INTC_SEL126_INTSEL2                   (*((volatile unsigned int*)(0x42A24A88UL)))
#define bM4_INTC_SEL126_INTSEL3                   (*((volatile unsigned int*)(0x42A24A8CUL)))
#define bM4_INTC_SEL126_INTSEL4                   (*((volatile unsigned int*)(0x42A24A90UL)))
#define bM4_INTC_SEL126_INTSEL5                   (*((volatile unsigned int*)(0x42A24A94UL)))
#define bM4_INTC_SEL126_INTSEL6                   (*((volatile unsigned int*)(0x42A24A98UL)))
#define bM4_INTC_SEL126_INTSEL7                   (*((volatile unsigned int*)(0x42A24A9CUL)))
#define bM4_INTC_SEL126_INTSEL8                   (*((volatile unsigned int*)(0x42A24AA0UL)))
#define bM4_INTC_SEL127_INTSEL0                   (*((volatile unsigned int*)(0x42A24B00UL)))
#define bM4_INTC_SEL127_INTSEL1                   (*((volatile unsigned int*)(0x42A24B04UL)))
#define bM4_INTC_SEL127_INTSEL2                   (*((volatile unsigned int*)(0x42A24B08UL)))
#define bM4_INTC_SEL127_INTSEL3                   (*((volatile unsigned int*)(0x42A24B0CUL)))
#define bM4_INTC_SEL127_INTSEL4                   (*((volatile unsigned int*)(0x42A24B10UL)))
#define bM4_INTC_SEL127_INTSEL5                   (*((volatile unsigned int*)(0x42A24B14UL)))
#define bM4_INTC_SEL127_INTSEL6                   (*((volatile unsigned int*)(0x42A24B18UL)))
#define bM4_INTC_SEL127_INTSEL7                   (*((volatile unsigned int*)(0x42A24B1CUL)))
#define bM4_INTC_SEL127_INTSEL8                   (*((volatile unsigned int*)(0x42A24B20UL)))
#define bM4_INTC_VSSEL128_VSEL0                   (*((volatile unsigned int*)(0x42A24B80UL)))
#define bM4_INTC_VSSEL128_VSEL1                   (*((volatile unsigned int*)(0x42A24B84UL)))
#define bM4_INTC_VSSEL128_VSEL2                   (*((volatile unsigned int*)(0x42A24B88UL)))
#define bM4_INTC_VSSEL128_VSEL3                   (*((volatile unsigned int*)(0x42A24B8CUL)))
#define bM4_INTC_VSSEL128_VSEL4                   (*((volatile unsigned int*)(0x42A24B90UL)))
#define bM4_INTC_VSSEL128_VSEL5                   (*((volatile unsigned int*)(0x42A24B94UL)))
#define bM4_INTC_VSSEL128_VSEL6                   (*((volatile unsigned int*)(0x42A24B98UL)))
#define bM4_INTC_VSSEL128_VSEL7                   (*((volatile unsigned int*)(0x42A24B9CUL)))
#define bM4_INTC_VSSEL128_VSEL8                   (*((volatile unsigned int*)(0x42A24BA0UL)))
#define bM4_INTC_VSSEL128_VSEL9                   (*((volatile unsigned int*)(0x42A24BA4UL)))
#define bM4_INTC_VSSEL128_VSEL10                  (*((volatile unsigned int*)(0x42A24BA8UL)))
#define bM4_INTC_VSSEL128_VSEL11                  (*((volatile unsigned int*)(0x42A24BACUL)))
#define bM4_INTC_VSSEL128_VSEL12                  (*((volatile unsigned int*)(0x42A24BB0UL)))
#define bM4_INTC_VSSEL128_VSEL13                  (*((volatile unsigned int*)(0x42A24BB4UL)))
#define bM4_INTC_VSSEL128_VSEL14                  (*((volatile unsigned int*)(0x42A24BB8UL)))
#define bM4_INTC_VSSEL128_VSEL15                  (*((volatile unsigned int*)(0x42A24BBCUL)))
#define bM4_INTC_VSSEL128_VSEL16                  (*((volatile unsigned int*)(0x42A24BC0UL)))
#define bM4_INTC_VSSEL128_VSEL17                  (*((volatile unsigned int*)(0x42A24BC4UL)))
#define bM4_INTC_VSSEL128_VSEL18                  (*((volatile unsigned int*)(0x42A24BC8UL)))
#define bM4_INTC_VSSEL128_VSEL19                  (*((volatile unsigned int*)(0x42A24BCCUL)))
#define bM4_INTC_VSSEL128_VSEL20                  (*((volatile unsigned int*)(0x42A24BD0UL)))
#define bM4_INTC_VSSEL128_VSEL21                  (*((volatile unsigned int*)(0x42A24BD4UL)))
#define bM4_INTC_VSSEL128_VSEL22                  (*((volatile unsigned int*)(0x42A24BD8UL)))
#define bM4_INTC_VSSEL128_VSEL23                  (*((volatile unsigned int*)(0x42A24BDCUL)))
#define bM4_INTC_VSSEL128_VSEL24                  (*((volatile unsigned int*)(0x42A24BE0UL)))
#define bM4_INTC_VSSEL128_VSEL25                  (*((volatile unsigned int*)(0x42A24BE4UL)))
#define bM4_INTC_VSSEL128_VSEL26                  (*((volatile unsigned int*)(0x42A24BE8UL)))
#define bM4_INTC_VSSEL128_VSEL27                  (*((volatile unsigned int*)(0x42A24BECUL)))
#define bM4_INTC_VSSEL128_VSEL28                  (*((volatile unsigned int*)(0x42A24BF0UL)))
#define bM4_INTC_VSSEL128_VSEL29                  (*((volatile unsigned int*)(0x42A24BF4UL)))
#define bM4_INTC_VSSEL128_VSEL30                  (*((volatile unsigned int*)(0x42A24BF8UL)))
#define bM4_INTC_VSSEL128_VSEL31                  (*((volatile unsigned int*)(0x42A24BFCUL)))
#define bM4_INTC_VSSEL129_VSEL0                   (*((volatile unsigned int*)(0x42A24C00UL)))
#define bM4_INTC_VSSEL129_VSEL1                   (*((volatile unsigned int*)(0x42A24C04UL)))
#define bM4_INTC_VSSEL129_VSEL2                   (*((volatile unsigned int*)(0x42A24C08UL)))
#define bM4_INTC_VSSEL129_VSEL3                   (*((volatile unsigned int*)(0x42A24C0CUL)))
#define bM4_INTC_VSSEL129_VSEL4                   (*((volatile unsigned int*)(0x42A24C10UL)))
#define bM4_INTC_VSSEL129_VSEL5                   (*((volatile unsigned int*)(0x42A24C14UL)))
#define bM4_INTC_VSSEL129_VSEL6                   (*((volatile unsigned int*)(0x42A24C18UL)))
#define bM4_INTC_VSSEL129_VSEL7                   (*((volatile unsigned int*)(0x42A24C1CUL)))
#define bM4_INTC_VSSEL129_VSEL8                   (*((volatile unsigned int*)(0x42A24C20UL)))
#define bM4_INTC_VSSEL129_VSEL9                   (*((volatile unsigned int*)(0x42A24C24UL)))
#define bM4_INTC_VSSEL129_VSEL10                  (*((volatile unsigned int*)(0x42A24C28UL)))
#define bM4_INTC_VSSEL129_VSEL11                  (*((volatile unsigned int*)(0x42A24C2CUL)))
#define bM4_INTC_VSSEL129_VSEL12                  (*((volatile unsigned int*)(0x42A24C30UL)))
#define bM4_INTC_VSSEL129_VSEL13                  (*((volatile unsigned int*)(0x42A24C34UL)))
#define bM4_INTC_VSSEL129_VSEL14                  (*((volatile unsigned int*)(0x42A24C38UL)))
#define bM4_INTC_VSSEL129_VSEL15                  (*((volatile unsigned int*)(0x42A24C3CUL)))
#define bM4_INTC_VSSEL129_VSEL16                  (*((volatile unsigned int*)(0x42A24C40UL)))
#define bM4_INTC_VSSEL129_VSEL17                  (*((volatile unsigned int*)(0x42A24C44UL)))
#define bM4_INTC_VSSEL129_VSEL18                  (*((volatile unsigned int*)(0x42A24C48UL)))
#define bM4_INTC_VSSEL129_VSEL19                  (*((volatile unsigned int*)(0x42A24C4CUL)))
#define bM4_INTC_VSSEL129_VSEL20                  (*((volatile unsigned int*)(0x42A24C50UL)))
#define bM4_INTC_VSSEL129_VSEL21                  (*((volatile unsigned int*)(0x42A24C54UL)))
#define bM4_INTC_VSSEL129_VSEL22                  (*((volatile unsigned int*)(0x42A24C58UL)))
#define bM4_INTC_VSSEL129_VSEL23                  (*((volatile unsigned int*)(0x42A24C5CUL)))
#define bM4_INTC_VSSEL129_VSEL24                  (*((volatile unsigned int*)(0x42A24C60UL)))
#define bM4_INTC_VSSEL129_VSEL25                  (*((volatile unsigned int*)(0x42A24C64UL)))
#define bM4_INTC_VSSEL129_VSEL26                  (*((volatile unsigned int*)(0x42A24C68UL)))
#define bM4_INTC_VSSEL129_VSEL27                  (*((volatile unsigned int*)(0x42A24C6CUL)))
#define bM4_INTC_VSSEL129_VSEL28                  (*((volatile unsigned int*)(0x42A24C70UL)))
#define bM4_INTC_VSSEL129_VSEL29                  (*((volatile unsigned int*)(0x42A24C74UL)))
#define bM4_INTC_VSSEL129_VSEL30                  (*((volatile unsigned int*)(0x42A24C78UL)))
#define bM4_INTC_VSSEL129_VSEL31                  (*((volatile unsigned int*)(0x42A24C7CUL)))
#define bM4_INTC_VSSEL130_VSEL0                   (*((volatile unsigned int*)(0x42A24C80UL)))
#define bM4_INTC_VSSEL130_VSEL1                   (*((volatile unsigned int*)(0x42A24C84UL)))
#define bM4_INTC_VSSEL130_VSEL2                   (*((volatile unsigned int*)(0x42A24C88UL)))
#define bM4_INTC_VSSEL130_VSEL3                   (*((volatile unsigned int*)(0x42A24C8CUL)))
#define bM4_INTC_VSSEL130_VSEL4                   (*((volatile unsigned int*)(0x42A24C90UL)))
#define bM4_INTC_VSSEL130_VSEL5                   (*((volatile unsigned int*)(0x42A24C94UL)))
#define bM4_INTC_VSSEL130_VSEL6                   (*((volatile unsigned int*)(0x42A24C98UL)))
#define bM4_INTC_VSSEL130_VSEL7                   (*((volatile unsigned int*)(0x42A24C9CUL)))
#define bM4_INTC_VSSEL130_VSEL8                   (*((volatile unsigned int*)(0x42A24CA0UL)))
#define bM4_INTC_VSSEL130_VSEL9                   (*((volatile unsigned int*)(0x42A24CA4UL)))
#define bM4_INTC_VSSEL130_VSEL10                  (*((volatile unsigned int*)(0x42A24CA8UL)))
#define bM4_INTC_VSSEL130_VSEL11                  (*((volatile unsigned int*)(0x42A24CACUL)))
#define bM4_INTC_VSSEL130_VSEL12                  (*((volatile unsigned int*)(0x42A24CB0UL)))
#define bM4_INTC_VSSEL130_VSEL13                  (*((volatile unsigned int*)(0x42A24CB4UL)))
#define bM4_INTC_VSSEL130_VSEL14                  (*((volatile unsigned int*)(0x42A24CB8UL)))
#define bM4_INTC_VSSEL130_VSEL15                  (*((volatile unsigned int*)(0x42A24CBCUL)))
#define bM4_INTC_VSSEL130_VSEL16                  (*((volatile unsigned int*)(0x42A24CC0UL)))
#define bM4_INTC_VSSEL130_VSEL17                  (*((volatile unsigned int*)(0x42A24CC4UL)))
#define bM4_INTC_VSSEL130_VSEL18                  (*((volatile unsigned int*)(0x42A24CC8UL)))
#define bM4_INTC_VSSEL130_VSEL19                  (*((volatile unsigned int*)(0x42A24CCCUL)))
#define bM4_INTC_VSSEL130_VSEL20                  (*((volatile unsigned int*)(0x42A24CD0UL)))
#define bM4_INTC_VSSEL130_VSEL21                  (*((volatile unsigned int*)(0x42A24CD4UL)))
#define bM4_INTC_VSSEL130_VSEL22                  (*((volatile unsigned int*)(0x42A24CD8UL)))
#define bM4_INTC_VSSEL130_VSEL23                  (*((volatile unsigned int*)(0x42A24CDCUL)))
#define bM4_INTC_VSSEL130_VSEL24                  (*((volatile unsigned int*)(0x42A24CE0UL)))
#define bM4_INTC_VSSEL130_VSEL25                  (*((volatile unsigned int*)(0x42A24CE4UL)))
#define bM4_INTC_VSSEL130_VSEL26                  (*((volatile unsigned int*)(0x42A24CE8UL)))
#define bM4_INTC_VSSEL130_VSEL27                  (*((volatile unsigned int*)(0x42A24CECUL)))
#define bM4_INTC_VSSEL130_VSEL28                  (*((volatile unsigned int*)(0x42A24CF0UL)))
#define bM4_INTC_VSSEL130_VSEL29                  (*((volatile unsigned int*)(0x42A24CF4UL)))
#define bM4_INTC_VSSEL130_VSEL30                  (*((volatile unsigned int*)(0x42A24CF8UL)))
#define bM4_INTC_VSSEL130_VSEL31                  (*((volatile unsigned int*)(0x42A24CFCUL)))
#define bM4_INTC_VSSEL131_VSEL0                   (*((volatile unsigned int*)(0x42A24D00UL)))
#define bM4_INTC_VSSEL131_VSEL1                   (*((volatile unsigned int*)(0x42A24D04UL)))
#define bM4_INTC_VSSEL131_VSEL2                   (*((volatile unsigned int*)(0x42A24D08UL)))
#define bM4_INTC_VSSEL131_VSEL3                   (*((volatile unsigned int*)(0x42A24D0CUL)))
#define bM4_INTC_VSSEL131_VSEL4                   (*((volatile unsigned int*)(0x42A24D10UL)))
#define bM4_INTC_VSSEL131_VSEL5                   (*((volatile unsigned int*)(0x42A24D14UL)))
#define bM4_INTC_VSSEL131_VSEL6                   (*((volatile unsigned int*)(0x42A24D18UL)))
#define bM4_INTC_VSSEL131_VSEL7                   (*((volatile unsigned int*)(0x42A24D1CUL)))
#define bM4_INTC_VSSEL131_VSEL8                   (*((volatile unsigned int*)(0x42A24D20UL)))
#define bM4_INTC_VSSEL131_VSEL9                   (*((volatile unsigned int*)(0x42A24D24UL)))
#define bM4_INTC_VSSEL131_VSEL10                  (*((volatile unsigned int*)(0x42A24D28UL)))
#define bM4_INTC_VSSEL131_VSEL11                  (*((volatile unsigned int*)(0x42A24D2CUL)))
#define bM4_INTC_VSSEL131_VSEL12                  (*((volatile unsigned int*)(0x42A24D30UL)))
#define bM4_INTC_VSSEL131_VSEL13                  (*((volatile unsigned int*)(0x42A24D34UL)))
#define bM4_INTC_VSSEL131_VSEL14                  (*((volatile unsigned int*)(0x42A24D38UL)))
#define bM4_INTC_VSSEL131_VSEL15                  (*((volatile unsigned int*)(0x42A24D3CUL)))
#define bM4_INTC_VSSEL131_VSEL16                  (*((volatile unsigned int*)(0x42A24D40UL)))
#define bM4_INTC_VSSEL131_VSEL17                  (*((volatile unsigned int*)(0x42A24D44UL)))
#define bM4_INTC_VSSEL131_VSEL18                  (*((volatile unsigned int*)(0x42A24D48UL)))
#define bM4_INTC_VSSEL131_VSEL19                  (*((volatile unsigned int*)(0x42A24D4CUL)))
#define bM4_INTC_VSSEL131_VSEL20                  (*((volatile unsigned int*)(0x42A24D50UL)))
#define bM4_INTC_VSSEL131_VSEL21                  (*((volatile unsigned int*)(0x42A24D54UL)))
#define bM4_INTC_VSSEL131_VSEL22                  (*((volatile unsigned int*)(0x42A24D58UL)))
#define bM4_INTC_VSSEL131_VSEL23                  (*((volatile unsigned int*)(0x42A24D5CUL)))
#define bM4_INTC_VSSEL131_VSEL24                  (*((volatile unsigned int*)(0x42A24D60UL)))
#define bM4_INTC_VSSEL131_VSEL25                  (*((volatile unsigned int*)(0x42A24D64UL)))
#define bM4_INTC_VSSEL131_VSEL26                  (*((volatile unsigned int*)(0x42A24D68UL)))
#define bM4_INTC_VSSEL131_VSEL27                  (*((volatile unsigned int*)(0x42A24D6CUL)))
#define bM4_INTC_VSSEL131_VSEL28                  (*((volatile unsigned int*)(0x42A24D70UL)))
#define bM4_INTC_VSSEL131_VSEL29                  (*((volatile unsigned int*)(0x42A24D74UL)))
#define bM4_INTC_VSSEL131_VSEL30                  (*((volatile unsigned int*)(0x42A24D78UL)))
#define bM4_INTC_VSSEL131_VSEL31                  (*((volatile unsigned int*)(0x42A24D7CUL)))
#define bM4_INTC_VSSEL132_VSEL0                   (*((volatile unsigned int*)(0x42A24D80UL)))
#define bM4_INTC_VSSEL132_VSEL1                   (*((volatile unsigned int*)(0x42A24D84UL)))
#define bM4_INTC_VSSEL132_VSEL2                   (*((volatile unsigned int*)(0x42A24D88UL)))
#define bM4_INTC_VSSEL132_VSEL3                   (*((volatile unsigned int*)(0x42A24D8CUL)))
#define bM4_INTC_VSSEL132_VSEL4                   (*((volatile unsigned int*)(0x42A24D90UL)))
#define bM4_INTC_VSSEL132_VSEL5                   (*((volatile unsigned int*)(0x42A24D94UL)))
#define bM4_INTC_VSSEL132_VSEL6                   (*((volatile unsigned int*)(0x42A24D98UL)))
#define bM4_INTC_VSSEL132_VSEL7                   (*((volatile unsigned int*)(0x42A24D9CUL)))
#define bM4_INTC_VSSEL132_VSEL8                   (*((volatile unsigned int*)(0x42A24DA0UL)))
#define bM4_INTC_VSSEL132_VSEL9                   (*((volatile unsigned int*)(0x42A24DA4UL)))
#define bM4_INTC_VSSEL132_VSEL10                  (*((volatile unsigned int*)(0x42A24DA8UL)))
#define bM4_INTC_VSSEL132_VSEL11                  (*((volatile unsigned int*)(0x42A24DACUL)))
#define bM4_INTC_VSSEL132_VSEL12                  (*((volatile unsigned int*)(0x42A24DB0UL)))
#define bM4_INTC_VSSEL132_VSEL13                  (*((volatile unsigned int*)(0x42A24DB4UL)))
#define bM4_INTC_VSSEL132_VSEL14                  (*((volatile unsigned int*)(0x42A24DB8UL)))
#define bM4_INTC_VSSEL132_VSEL15                  (*((volatile unsigned int*)(0x42A24DBCUL)))
#define bM4_INTC_VSSEL132_VSEL16                  (*((volatile unsigned int*)(0x42A24DC0UL)))
#define bM4_INTC_VSSEL132_VSEL17                  (*((volatile unsigned int*)(0x42A24DC4UL)))
#define bM4_INTC_VSSEL132_VSEL18                  (*((volatile unsigned int*)(0x42A24DC8UL)))
#define bM4_INTC_VSSEL132_VSEL19                  (*((volatile unsigned int*)(0x42A24DCCUL)))
#define bM4_INTC_VSSEL132_VSEL20                  (*((volatile unsigned int*)(0x42A24DD0UL)))
#define bM4_INTC_VSSEL132_VSEL21                  (*((volatile unsigned int*)(0x42A24DD4UL)))
#define bM4_INTC_VSSEL132_VSEL22                  (*((volatile unsigned int*)(0x42A24DD8UL)))
#define bM4_INTC_VSSEL132_VSEL23                  (*((volatile unsigned int*)(0x42A24DDCUL)))
#define bM4_INTC_VSSEL132_VSEL24                  (*((volatile unsigned int*)(0x42A24DE0UL)))
#define bM4_INTC_VSSEL132_VSEL25                  (*((volatile unsigned int*)(0x42A24DE4UL)))
#define bM4_INTC_VSSEL132_VSEL26                  (*((volatile unsigned int*)(0x42A24DE8UL)))
#define bM4_INTC_VSSEL132_VSEL27                  (*((volatile unsigned int*)(0x42A24DECUL)))
#define bM4_INTC_VSSEL132_VSEL28                  (*((volatile unsigned int*)(0x42A24DF0UL)))
#define bM4_INTC_VSSEL132_VSEL29                  (*((volatile unsigned int*)(0x42A24DF4UL)))
#define bM4_INTC_VSSEL132_VSEL30                  (*((volatile unsigned int*)(0x42A24DF8UL)))
#define bM4_INTC_VSSEL132_VSEL31                  (*((volatile unsigned int*)(0x42A24DFCUL)))
#define bM4_INTC_VSSEL133_VSEL0                   (*((volatile unsigned int*)(0x42A24E00UL)))
#define bM4_INTC_VSSEL133_VSEL1                   (*((volatile unsigned int*)(0x42A24E04UL)))
#define bM4_INTC_VSSEL133_VSEL2                   (*((volatile unsigned int*)(0x42A24E08UL)))
#define bM4_INTC_VSSEL133_VSEL3                   (*((volatile unsigned int*)(0x42A24E0CUL)))
#define bM4_INTC_VSSEL133_VSEL4                   (*((volatile unsigned int*)(0x42A24E10UL)))
#define bM4_INTC_VSSEL133_VSEL5                   (*((volatile unsigned int*)(0x42A24E14UL)))
#define bM4_INTC_VSSEL133_VSEL6                   (*((volatile unsigned int*)(0x42A24E18UL)))
#define bM4_INTC_VSSEL133_VSEL7                   (*((volatile unsigned int*)(0x42A24E1CUL)))
#define bM4_INTC_VSSEL133_VSEL8                   (*((volatile unsigned int*)(0x42A24E20UL)))
#define bM4_INTC_VSSEL133_VSEL9                   (*((volatile unsigned int*)(0x42A24E24UL)))
#define bM4_INTC_VSSEL133_VSEL10                  (*((volatile unsigned int*)(0x42A24E28UL)))
#define bM4_INTC_VSSEL133_VSEL11                  (*((volatile unsigned int*)(0x42A24E2CUL)))
#define bM4_INTC_VSSEL133_VSEL12                  (*((volatile unsigned int*)(0x42A24E30UL)))
#define bM4_INTC_VSSEL133_VSEL13                  (*((volatile unsigned int*)(0x42A24E34UL)))
#define bM4_INTC_VSSEL133_VSEL14                  (*((volatile unsigned int*)(0x42A24E38UL)))
#define bM4_INTC_VSSEL133_VSEL15                  (*((volatile unsigned int*)(0x42A24E3CUL)))
#define bM4_INTC_VSSEL133_VSEL16                  (*((volatile unsigned int*)(0x42A24E40UL)))
#define bM4_INTC_VSSEL133_VSEL17                  (*((volatile unsigned int*)(0x42A24E44UL)))
#define bM4_INTC_VSSEL133_VSEL18                  (*((volatile unsigned int*)(0x42A24E48UL)))
#define bM4_INTC_VSSEL133_VSEL19                  (*((volatile unsigned int*)(0x42A24E4CUL)))
#define bM4_INTC_VSSEL133_VSEL20                  (*((volatile unsigned int*)(0x42A24E50UL)))
#define bM4_INTC_VSSEL133_VSEL21                  (*((volatile unsigned int*)(0x42A24E54UL)))
#define bM4_INTC_VSSEL133_VSEL22                  (*((volatile unsigned int*)(0x42A24E58UL)))
#define bM4_INTC_VSSEL133_VSEL23                  (*((volatile unsigned int*)(0x42A24E5CUL)))
#define bM4_INTC_VSSEL133_VSEL24                  (*((volatile unsigned int*)(0x42A24E60UL)))
#define bM4_INTC_VSSEL133_VSEL25                  (*((volatile unsigned int*)(0x42A24E64UL)))
#define bM4_INTC_VSSEL133_VSEL26                  (*((volatile unsigned int*)(0x42A24E68UL)))
#define bM4_INTC_VSSEL133_VSEL27                  (*((volatile unsigned int*)(0x42A24E6CUL)))
#define bM4_INTC_VSSEL133_VSEL28                  (*((volatile unsigned int*)(0x42A24E70UL)))
#define bM4_INTC_VSSEL133_VSEL29                  (*((volatile unsigned int*)(0x42A24E74UL)))
#define bM4_INTC_VSSEL133_VSEL30                  (*((volatile unsigned int*)(0x42A24E78UL)))
#define bM4_INTC_VSSEL133_VSEL31                  (*((volatile unsigned int*)(0x42A24E7CUL)))
#define bM4_INTC_VSSEL134_VSEL0                   (*((volatile unsigned int*)(0x42A24E80UL)))
#define bM4_INTC_VSSEL134_VSEL1                   (*((volatile unsigned int*)(0x42A24E84UL)))
#define bM4_INTC_VSSEL134_VSEL2                   (*((volatile unsigned int*)(0x42A24E88UL)))
#define bM4_INTC_VSSEL134_VSEL3                   (*((volatile unsigned int*)(0x42A24E8CUL)))
#define bM4_INTC_VSSEL134_VSEL4                   (*((volatile unsigned int*)(0x42A24E90UL)))
#define bM4_INTC_VSSEL134_VSEL5                   (*((volatile unsigned int*)(0x42A24E94UL)))
#define bM4_INTC_VSSEL134_VSEL6                   (*((volatile unsigned int*)(0x42A24E98UL)))
#define bM4_INTC_VSSEL134_VSEL7                   (*((volatile unsigned int*)(0x42A24E9CUL)))
#define bM4_INTC_VSSEL134_VSEL8                   (*((volatile unsigned int*)(0x42A24EA0UL)))
#define bM4_INTC_VSSEL134_VSEL9                   (*((volatile unsigned int*)(0x42A24EA4UL)))
#define bM4_INTC_VSSEL134_VSEL10                  (*((volatile unsigned int*)(0x42A24EA8UL)))
#define bM4_INTC_VSSEL134_VSEL11                  (*((volatile unsigned int*)(0x42A24EACUL)))
#define bM4_INTC_VSSEL134_VSEL12                  (*((volatile unsigned int*)(0x42A24EB0UL)))
#define bM4_INTC_VSSEL134_VSEL13                  (*((volatile unsigned int*)(0x42A24EB4UL)))
#define bM4_INTC_VSSEL134_VSEL14                  (*((volatile unsigned int*)(0x42A24EB8UL)))
#define bM4_INTC_VSSEL134_VSEL15                  (*((volatile unsigned int*)(0x42A24EBCUL)))
#define bM4_INTC_VSSEL134_VSEL16                  (*((volatile unsigned int*)(0x42A24EC0UL)))
#define bM4_INTC_VSSEL134_VSEL17                  (*((volatile unsigned int*)(0x42A24EC4UL)))
#define bM4_INTC_VSSEL134_VSEL18                  (*((volatile unsigned int*)(0x42A24EC8UL)))
#define bM4_INTC_VSSEL134_VSEL19                  (*((volatile unsigned int*)(0x42A24ECCUL)))
#define bM4_INTC_VSSEL134_VSEL20                  (*((volatile unsigned int*)(0x42A24ED0UL)))
#define bM4_INTC_VSSEL134_VSEL21                  (*((volatile unsigned int*)(0x42A24ED4UL)))
#define bM4_INTC_VSSEL134_VSEL22                  (*((volatile unsigned int*)(0x42A24ED8UL)))
#define bM4_INTC_VSSEL134_VSEL23                  (*((volatile unsigned int*)(0x42A24EDCUL)))
#define bM4_INTC_VSSEL134_VSEL24                  (*((volatile unsigned int*)(0x42A24EE0UL)))
#define bM4_INTC_VSSEL134_VSEL25                  (*((volatile unsigned int*)(0x42A24EE4UL)))
#define bM4_INTC_VSSEL134_VSEL26                  (*((volatile unsigned int*)(0x42A24EE8UL)))
#define bM4_INTC_VSSEL134_VSEL27                  (*((volatile unsigned int*)(0x42A24EECUL)))
#define bM4_INTC_VSSEL134_VSEL28                  (*((volatile unsigned int*)(0x42A24EF0UL)))
#define bM4_INTC_VSSEL134_VSEL29                  (*((volatile unsigned int*)(0x42A24EF4UL)))
#define bM4_INTC_VSSEL134_VSEL30                  (*((volatile unsigned int*)(0x42A24EF8UL)))
#define bM4_INTC_VSSEL134_VSEL31                  (*((volatile unsigned int*)(0x42A24EFCUL)))
#define bM4_INTC_VSSEL135_VSEL0                   (*((volatile unsigned int*)(0x42A24F00UL)))
#define bM4_INTC_VSSEL135_VSEL1                   (*((volatile unsigned int*)(0x42A24F04UL)))
#define bM4_INTC_VSSEL135_VSEL2                   (*((volatile unsigned int*)(0x42A24F08UL)))
#define bM4_INTC_VSSEL135_VSEL3                   (*((volatile unsigned int*)(0x42A24F0CUL)))
#define bM4_INTC_VSSEL135_VSEL4                   (*((volatile unsigned int*)(0x42A24F10UL)))
#define bM4_INTC_VSSEL135_VSEL5                   (*((volatile unsigned int*)(0x42A24F14UL)))
#define bM4_INTC_VSSEL135_VSEL6                   (*((volatile unsigned int*)(0x42A24F18UL)))
#define bM4_INTC_VSSEL135_VSEL7                   (*((volatile unsigned int*)(0x42A24F1CUL)))
#define bM4_INTC_VSSEL135_VSEL8                   (*((volatile unsigned int*)(0x42A24F20UL)))
#define bM4_INTC_VSSEL135_VSEL9                   (*((volatile unsigned int*)(0x42A24F24UL)))
#define bM4_INTC_VSSEL135_VSEL10                  (*((volatile unsigned int*)(0x42A24F28UL)))
#define bM4_INTC_VSSEL135_VSEL11                  (*((volatile unsigned int*)(0x42A24F2CUL)))
#define bM4_INTC_VSSEL135_VSEL12                  (*((volatile unsigned int*)(0x42A24F30UL)))
#define bM4_INTC_VSSEL135_VSEL13                  (*((volatile unsigned int*)(0x42A24F34UL)))
#define bM4_INTC_VSSEL135_VSEL14                  (*((volatile unsigned int*)(0x42A24F38UL)))
#define bM4_INTC_VSSEL135_VSEL15                  (*((volatile unsigned int*)(0x42A24F3CUL)))
#define bM4_INTC_VSSEL135_VSEL16                  (*((volatile unsigned int*)(0x42A24F40UL)))
#define bM4_INTC_VSSEL135_VSEL17                  (*((volatile unsigned int*)(0x42A24F44UL)))
#define bM4_INTC_VSSEL135_VSEL18                  (*((volatile unsigned int*)(0x42A24F48UL)))
#define bM4_INTC_VSSEL135_VSEL19                  (*((volatile unsigned int*)(0x42A24F4CUL)))
#define bM4_INTC_VSSEL135_VSEL20                  (*((volatile unsigned int*)(0x42A24F50UL)))
#define bM4_INTC_VSSEL135_VSEL21                  (*((volatile unsigned int*)(0x42A24F54UL)))
#define bM4_INTC_VSSEL135_VSEL22                  (*((volatile unsigned int*)(0x42A24F58UL)))
#define bM4_INTC_VSSEL135_VSEL23                  (*((volatile unsigned int*)(0x42A24F5CUL)))
#define bM4_INTC_VSSEL135_VSEL24                  (*((volatile unsigned int*)(0x42A24F60UL)))
#define bM4_INTC_VSSEL135_VSEL25                  (*((volatile unsigned int*)(0x42A24F64UL)))
#define bM4_INTC_VSSEL135_VSEL26                  (*((volatile unsigned int*)(0x42A24F68UL)))
#define bM4_INTC_VSSEL135_VSEL27                  (*((volatile unsigned int*)(0x42A24F6CUL)))
#define bM4_INTC_VSSEL135_VSEL28                  (*((volatile unsigned int*)(0x42A24F70UL)))
#define bM4_INTC_VSSEL135_VSEL29                  (*((volatile unsigned int*)(0x42A24F74UL)))
#define bM4_INTC_VSSEL135_VSEL30                  (*((volatile unsigned int*)(0x42A24F78UL)))
#define bM4_INTC_VSSEL135_VSEL31                  (*((volatile unsigned int*)(0x42A24F7CUL)))
#define bM4_INTC_VSSEL136_VSEL0                   (*((volatile unsigned int*)(0x42A24F80UL)))
#define bM4_INTC_VSSEL136_VSEL1                   (*((volatile unsigned int*)(0x42A24F84UL)))
#define bM4_INTC_VSSEL136_VSEL2                   (*((volatile unsigned int*)(0x42A24F88UL)))
#define bM4_INTC_VSSEL136_VSEL3                   (*((volatile unsigned int*)(0x42A24F8CUL)))
#define bM4_INTC_VSSEL136_VSEL4                   (*((volatile unsigned int*)(0x42A24F90UL)))
#define bM4_INTC_VSSEL136_VSEL5                   (*((volatile unsigned int*)(0x42A24F94UL)))
#define bM4_INTC_VSSEL136_VSEL6                   (*((volatile unsigned int*)(0x42A24F98UL)))
#define bM4_INTC_VSSEL136_VSEL7                   (*((volatile unsigned int*)(0x42A24F9CUL)))
#define bM4_INTC_VSSEL136_VSEL8                   (*((volatile unsigned int*)(0x42A24FA0UL)))
#define bM4_INTC_VSSEL136_VSEL9                   (*((volatile unsigned int*)(0x42A24FA4UL)))
#define bM4_INTC_VSSEL136_VSEL10                  (*((volatile unsigned int*)(0x42A24FA8UL)))
#define bM4_INTC_VSSEL136_VSEL11                  (*((volatile unsigned int*)(0x42A24FACUL)))
#define bM4_INTC_VSSEL136_VSEL12                  (*((volatile unsigned int*)(0x42A24FB0UL)))
#define bM4_INTC_VSSEL136_VSEL13                  (*((volatile unsigned int*)(0x42A24FB4UL)))
#define bM4_INTC_VSSEL136_VSEL14                  (*((volatile unsigned int*)(0x42A24FB8UL)))
#define bM4_INTC_VSSEL136_VSEL15                  (*((volatile unsigned int*)(0x42A24FBCUL)))
#define bM4_INTC_VSSEL136_VSEL16                  (*((volatile unsigned int*)(0x42A24FC0UL)))
#define bM4_INTC_VSSEL136_VSEL17                  (*((volatile unsigned int*)(0x42A24FC4UL)))
#define bM4_INTC_VSSEL136_VSEL18                  (*((volatile unsigned int*)(0x42A24FC8UL)))
#define bM4_INTC_VSSEL136_VSEL19                  (*((volatile unsigned int*)(0x42A24FCCUL)))
#define bM4_INTC_VSSEL136_VSEL20                  (*((volatile unsigned int*)(0x42A24FD0UL)))
#define bM4_INTC_VSSEL136_VSEL21                  (*((volatile unsigned int*)(0x42A24FD4UL)))
#define bM4_INTC_VSSEL136_VSEL22                  (*((volatile unsigned int*)(0x42A24FD8UL)))
#define bM4_INTC_VSSEL136_VSEL23                  (*((volatile unsigned int*)(0x42A24FDCUL)))
#define bM4_INTC_VSSEL136_VSEL24                  (*((volatile unsigned int*)(0x42A24FE0UL)))
#define bM4_INTC_VSSEL136_VSEL25                  (*((volatile unsigned int*)(0x42A24FE4UL)))
#define bM4_INTC_VSSEL136_VSEL26                  (*((volatile unsigned int*)(0x42A24FE8UL)))
#define bM4_INTC_VSSEL136_VSEL27                  (*((volatile unsigned int*)(0x42A24FECUL)))
#define bM4_INTC_VSSEL136_VSEL28                  (*((volatile unsigned int*)(0x42A24FF0UL)))
#define bM4_INTC_VSSEL136_VSEL29                  (*((volatile unsigned int*)(0x42A24FF4UL)))
#define bM4_INTC_VSSEL136_VSEL30                  (*((volatile unsigned int*)(0x42A24FF8UL)))
#define bM4_INTC_VSSEL136_VSEL31                  (*((volatile unsigned int*)(0x42A24FFCUL)))
#define bM4_INTC_VSSEL137_VSEL0                   (*((volatile unsigned int*)(0x42A25000UL)))
#define bM4_INTC_VSSEL137_VSEL1                   (*((volatile unsigned int*)(0x42A25004UL)))
#define bM4_INTC_VSSEL137_VSEL2                   (*((volatile unsigned int*)(0x42A25008UL)))
#define bM4_INTC_VSSEL137_VSEL3                   (*((volatile unsigned int*)(0x42A2500CUL)))
#define bM4_INTC_VSSEL137_VSEL4                   (*((volatile unsigned int*)(0x42A25010UL)))
#define bM4_INTC_VSSEL137_VSEL5                   (*((volatile unsigned int*)(0x42A25014UL)))
#define bM4_INTC_VSSEL137_VSEL6                   (*((volatile unsigned int*)(0x42A25018UL)))
#define bM4_INTC_VSSEL137_VSEL7                   (*((volatile unsigned int*)(0x42A2501CUL)))
#define bM4_INTC_VSSEL137_VSEL8                   (*((volatile unsigned int*)(0x42A25020UL)))
#define bM4_INTC_VSSEL137_VSEL9                   (*((volatile unsigned int*)(0x42A25024UL)))
#define bM4_INTC_VSSEL137_VSEL10                  (*((volatile unsigned int*)(0x42A25028UL)))
#define bM4_INTC_VSSEL137_VSEL11                  (*((volatile unsigned int*)(0x42A2502CUL)))
#define bM4_INTC_VSSEL137_VSEL12                  (*((volatile unsigned int*)(0x42A25030UL)))
#define bM4_INTC_VSSEL137_VSEL13                  (*((volatile unsigned int*)(0x42A25034UL)))
#define bM4_INTC_VSSEL137_VSEL14                  (*((volatile unsigned int*)(0x42A25038UL)))
#define bM4_INTC_VSSEL137_VSEL15                  (*((volatile unsigned int*)(0x42A2503CUL)))
#define bM4_INTC_VSSEL137_VSEL16                  (*((volatile unsigned int*)(0x42A25040UL)))
#define bM4_INTC_VSSEL137_VSEL17                  (*((volatile unsigned int*)(0x42A25044UL)))
#define bM4_INTC_VSSEL137_VSEL18                  (*((volatile unsigned int*)(0x42A25048UL)))
#define bM4_INTC_VSSEL137_VSEL19                  (*((volatile unsigned int*)(0x42A2504CUL)))
#define bM4_INTC_VSSEL137_VSEL20                  (*((volatile unsigned int*)(0x42A25050UL)))
#define bM4_INTC_VSSEL137_VSEL21                  (*((volatile unsigned int*)(0x42A25054UL)))
#define bM4_INTC_VSSEL137_VSEL22                  (*((volatile unsigned int*)(0x42A25058UL)))
#define bM4_INTC_VSSEL137_VSEL23                  (*((volatile unsigned int*)(0x42A2505CUL)))
#define bM4_INTC_VSSEL137_VSEL24                  (*((volatile unsigned int*)(0x42A25060UL)))
#define bM4_INTC_VSSEL137_VSEL25                  (*((volatile unsigned int*)(0x42A25064UL)))
#define bM4_INTC_VSSEL137_VSEL26                  (*((volatile unsigned int*)(0x42A25068UL)))
#define bM4_INTC_VSSEL137_VSEL27                  (*((volatile unsigned int*)(0x42A2506CUL)))
#define bM4_INTC_VSSEL137_VSEL28                  (*((volatile unsigned int*)(0x42A25070UL)))
#define bM4_INTC_VSSEL137_VSEL29                  (*((volatile unsigned int*)(0x42A25074UL)))
#define bM4_INTC_VSSEL137_VSEL30                  (*((volatile unsigned int*)(0x42A25078UL)))
#define bM4_INTC_VSSEL137_VSEL31                  (*((volatile unsigned int*)(0x42A2507CUL)))
#define bM4_INTC_VSSEL138_VSEL0                   (*((volatile unsigned int*)(0x42A25080UL)))
#define bM4_INTC_VSSEL138_VSEL1                   (*((volatile unsigned int*)(0x42A25084UL)))
#define bM4_INTC_VSSEL138_VSEL2                   (*((volatile unsigned int*)(0x42A25088UL)))
#define bM4_INTC_VSSEL138_VSEL3                   (*((volatile unsigned int*)(0x42A2508CUL)))
#define bM4_INTC_VSSEL138_VSEL4                   (*((volatile unsigned int*)(0x42A25090UL)))
#define bM4_INTC_VSSEL138_VSEL5                   (*((volatile unsigned int*)(0x42A25094UL)))
#define bM4_INTC_VSSEL138_VSEL6                   (*((volatile unsigned int*)(0x42A25098UL)))
#define bM4_INTC_VSSEL138_VSEL7                   (*((volatile unsigned int*)(0x42A2509CUL)))
#define bM4_INTC_VSSEL138_VSEL8                   (*((volatile unsigned int*)(0x42A250A0UL)))
#define bM4_INTC_VSSEL138_VSEL9                   (*((volatile unsigned int*)(0x42A250A4UL)))
#define bM4_INTC_VSSEL138_VSEL10                  (*((volatile unsigned int*)(0x42A250A8UL)))
#define bM4_INTC_VSSEL138_VSEL11                  (*((volatile unsigned int*)(0x42A250ACUL)))
#define bM4_INTC_VSSEL138_VSEL12                  (*((volatile unsigned int*)(0x42A250B0UL)))
#define bM4_INTC_VSSEL138_VSEL13                  (*((volatile unsigned int*)(0x42A250B4UL)))
#define bM4_INTC_VSSEL138_VSEL14                  (*((volatile unsigned int*)(0x42A250B8UL)))
#define bM4_INTC_VSSEL138_VSEL15                  (*((volatile unsigned int*)(0x42A250BCUL)))
#define bM4_INTC_VSSEL138_VSEL16                  (*((volatile unsigned int*)(0x42A250C0UL)))
#define bM4_INTC_VSSEL138_VSEL17                  (*((volatile unsigned int*)(0x42A250C4UL)))
#define bM4_INTC_VSSEL138_VSEL18                  (*((volatile unsigned int*)(0x42A250C8UL)))
#define bM4_INTC_VSSEL138_VSEL19                  (*((volatile unsigned int*)(0x42A250CCUL)))
#define bM4_INTC_VSSEL138_VSEL20                  (*((volatile unsigned int*)(0x42A250D0UL)))
#define bM4_INTC_VSSEL138_VSEL21                  (*((volatile unsigned int*)(0x42A250D4UL)))
#define bM4_INTC_VSSEL138_VSEL22                  (*((volatile unsigned int*)(0x42A250D8UL)))
#define bM4_INTC_VSSEL138_VSEL23                  (*((volatile unsigned int*)(0x42A250DCUL)))
#define bM4_INTC_VSSEL138_VSEL24                  (*((volatile unsigned int*)(0x42A250E0UL)))
#define bM4_INTC_VSSEL138_VSEL25                  (*((volatile unsigned int*)(0x42A250E4UL)))
#define bM4_INTC_VSSEL138_VSEL26                  (*((volatile unsigned int*)(0x42A250E8UL)))
#define bM4_INTC_VSSEL138_VSEL27                  (*((volatile unsigned int*)(0x42A250ECUL)))
#define bM4_INTC_VSSEL138_VSEL28                  (*((volatile unsigned int*)(0x42A250F0UL)))
#define bM4_INTC_VSSEL138_VSEL29                  (*((volatile unsigned int*)(0x42A250F4UL)))
#define bM4_INTC_VSSEL138_VSEL30                  (*((volatile unsigned int*)(0x42A250F8UL)))
#define bM4_INTC_VSSEL138_VSEL31                  (*((volatile unsigned int*)(0x42A250FCUL)))
#define bM4_INTC_VSSEL139_VSEL0                   (*((volatile unsigned int*)(0x42A25100UL)))
#define bM4_INTC_VSSEL139_VSEL1                   (*((volatile unsigned int*)(0x42A25104UL)))
#define bM4_INTC_VSSEL139_VSEL2                   (*((volatile unsigned int*)(0x42A25108UL)))
#define bM4_INTC_VSSEL139_VSEL3                   (*((volatile unsigned int*)(0x42A2510CUL)))
#define bM4_INTC_VSSEL139_VSEL4                   (*((volatile unsigned int*)(0x42A25110UL)))
#define bM4_INTC_VSSEL139_VSEL5                   (*((volatile unsigned int*)(0x42A25114UL)))
#define bM4_INTC_VSSEL139_VSEL6                   (*((volatile unsigned int*)(0x42A25118UL)))
#define bM4_INTC_VSSEL139_VSEL7                   (*((volatile unsigned int*)(0x42A2511CUL)))
#define bM4_INTC_VSSEL139_VSEL8                   (*((volatile unsigned int*)(0x42A25120UL)))
#define bM4_INTC_VSSEL139_VSEL9                   (*((volatile unsigned int*)(0x42A25124UL)))
#define bM4_INTC_VSSEL139_VSEL10                  (*((volatile unsigned int*)(0x42A25128UL)))
#define bM4_INTC_VSSEL139_VSEL11                  (*((volatile unsigned int*)(0x42A2512CUL)))
#define bM4_INTC_VSSEL139_VSEL12                  (*((volatile unsigned int*)(0x42A25130UL)))
#define bM4_INTC_VSSEL139_VSEL13                  (*((volatile unsigned int*)(0x42A25134UL)))
#define bM4_INTC_VSSEL139_VSEL14                  (*((volatile unsigned int*)(0x42A25138UL)))
#define bM4_INTC_VSSEL139_VSEL15                  (*((volatile unsigned int*)(0x42A2513CUL)))
#define bM4_INTC_VSSEL139_VSEL16                  (*((volatile unsigned int*)(0x42A25140UL)))
#define bM4_INTC_VSSEL139_VSEL17                  (*((volatile unsigned int*)(0x42A25144UL)))
#define bM4_INTC_VSSEL139_VSEL18                  (*((volatile unsigned int*)(0x42A25148UL)))
#define bM4_INTC_VSSEL139_VSEL19                  (*((volatile unsigned int*)(0x42A2514CUL)))
#define bM4_INTC_VSSEL139_VSEL20                  (*((volatile unsigned int*)(0x42A25150UL)))
#define bM4_INTC_VSSEL139_VSEL21                  (*((volatile unsigned int*)(0x42A25154UL)))
#define bM4_INTC_VSSEL139_VSEL22                  (*((volatile unsigned int*)(0x42A25158UL)))
#define bM4_INTC_VSSEL139_VSEL23                  (*((volatile unsigned int*)(0x42A2515CUL)))
#define bM4_INTC_VSSEL139_VSEL24                  (*((volatile unsigned int*)(0x42A25160UL)))
#define bM4_INTC_VSSEL139_VSEL25                  (*((volatile unsigned int*)(0x42A25164UL)))
#define bM4_INTC_VSSEL139_VSEL26                  (*((volatile unsigned int*)(0x42A25168UL)))
#define bM4_INTC_VSSEL139_VSEL27                  (*((volatile unsigned int*)(0x42A2516CUL)))
#define bM4_INTC_VSSEL139_VSEL28                  (*((volatile unsigned int*)(0x42A25170UL)))
#define bM4_INTC_VSSEL139_VSEL29                  (*((volatile unsigned int*)(0x42A25174UL)))
#define bM4_INTC_VSSEL139_VSEL30                  (*((volatile unsigned int*)(0x42A25178UL)))
#define bM4_INTC_VSSEL139_VSEL31                  (*((volatile unsigned int*)(0x42A2517CUL)))
#define bM4_INTC_VSSEL140_VSEL0                   (*((volatile unsigned int*)(0x42A25180UL)))
#define bM4_INTC_VSSEL140_VSEL1                   (*((volatile unsigned int*)(0x42A25184UL)))
#define bM4_INTC_VSSEL140_VSEL2                   (*((volatile unsigned int*)(0x42A25188UL)))
#define bM4_INTC_VSSEL140_VSEL3                   (*((volatile unsigned int*)(0x42A2518CUL)))
#define bM4_INTC_VSSEL140_VSEL4                   (*((volatile unsigned int*)(0x42A25190UL)))
#define bM4_INTC_VSSEL140_VSEL5                   (*((volatile unsigned int*)(0x42A25194UL)))
#define bM4_INTC_VSSEL140_VSEL6                   (*((volatile unsigned int*)(0x42A25198UL)))
#define bM4_INTC_VSSEL140_VSEL7                   (*((volatile unsigned int*)(0x42A2519CUL)))
#define bM4_INTC_VSSEL140_VSEL8                   (*((volatile unsigned int*)(0x42A251A0UL)))
#define bM4_INTC_VSSEL140_VSEL9                   (*((volatile unsigned int*)(0x42A251A4UL)))
#define bM4_INTC_VSSEL140_VSEL10                  (*((volatile unsigned int*)(0x42A251A8UL)))
#define bM4_INTC_VSSEL140_VSEL11                  (*((volatile unsigned int*)(0x42A251ACUL)))
#define bM4_INTC_VSSEL140_VSEL12                  (*((volatile unsigned int*)(0x42A251B0UL)))
#define bM4_INTC_VSSEL140_VSEL13                  (*((volatile unsigned int*)(0x42A251B4UL)))
#define bM4_INTC_VSSEL140_VSEL14                  (*((volatile unsigned int*)(0x42A251B8UL)))
#define bM4_INTC_VSSEL140_VSEL15                  (*((volatile unsigned int*)(0x42A251BCUL)))
#define bM4_INTC_VSSEL140_VSEL16                  (*((volatile unsigned int*)(0x42A251C0UL)))
#define bM4_INTC_VSSEL140_VSEL17                  (*((volatile unsigned int*)(0x42A251C4UL)))
#define bM4_INTC_VSSEL140_VSEL18                  (*((volatile unsigned int*)(0x42A251C8UL)))
#define bM4_INTC_VSSEL140_VSEL19                  (*((volatile unsigned int*)(0x42A251CCUL)))
#define bM4_INTC_VSSEL140_VSEL20                  (*((volatile unsigned int*)(0x42A251D0UL)))
#define bM4_INTC_VSSEL140_VSEL21                  (*((volatile unsigned int*)(0x42A251D4UL)))
#define bM4_INTC_VSSEL140_VSEL22                  (*((volatile unsigned int*)(0x42A251D8UL)))
#define bM4_INTC_VSSEL140_VSEL23                  (*((volatile unsigned int*)(0x42A251DCUL)))
#define bM4_INTC_VSSEL140_VSEL24                  (*((volatile unsigned int*)(0x42A251E0UL)))
#define bM4_INTC_VSSEL140_VSEL25                  (*((volatile unsigned int*)(0x42A251E4UL)))
#define bM4_INTC_VSSEL140_VSEL26                  (*((volatile unsigned int*)(0x42A251E8UL)))
#define bM4_INTC_VSSEL140_VSEL27                  (*((volatile unsigned int*)(0x42A251ECUL)))
#define bM4_INTC_VSSEL140_VSEL28                  (*((volatile unsigned int*)(0x42A251F0UL)))
#define bM4_INTC_VSSEL140_VSEL29                  (*((volatile unsigned int*)(0x42A251F4UL)))
#define bM4_INTC_VSSEL140_VSEL30                  (*((volatile unsigned int*)(0x42A251F8UL)))
#define bM4_INTC_VSSEL140_VSEL31                  (*((volatile unsigned int*)(0x42A251FCUL)))
#define bM4_INTC_VSSEL141_VSEL0                   (*((volatile unsigned int*)(0x42A25200UL)))
#define bM4_INTC_VSSEL141_VSEL1                   (*((volatile unsigned int*)(0x42A25204UL)))
#define bM4_INTC_VSSEL141_VSEL2                   (*((volatile unsigned int*)(0x42A25208UL)))
#define bM4_INTC_VSSEL141_VSEL3                   (*((volatile unsigned int*)(0x42A2520CUL)))
#define bM4_INTC_VSSEL141_VSEL4                   (*((volatile unsigned int*)(0x42A25210UL)))
#define bM4_INTC_VSSEL141_VSEL5                   (*((volatile unsigned int*)(0x42A25214UL)))
#define bM4_INTC_VSSEL141_VSEL6                   (*((volatile unsigned int*)(0x42A25218UL)))
#define bM4_INTC_VSSEL141_VSEL7                   (*((volatile unsigned int*)(0x42A2521CUL)))
#define bM4_INTC_VSSEL141_VSEL8                   (*((volatile unsigned int*)(0x42A25220UL)))
#define bM4_INTC_VSSEL141_VSEL9                   (*((volatile unsigned int*)(0x42A25224UL)))
#define bM4_INTC_VSSEL141_VSEL10                  (*((volatile unsigned int*)(0x42A25228UL)))
#define bM4_INTC_VSSEL141_VSEL11                  (*((volatile unsigned int*)(0x42A2522CUL)))
#define bM4_INTC_VSSEL141_VSEL12                  (*((volatile unsigned int*)(0x42A25230UL)))
#define bM4_INTC_VSSEL141_VSEL13                  (*((volatile unsigned int*)(0x42A25234UL)))
#define bM4_INTC_VSSEL141_VSEL14                  (*((volatile unsigned int*)(0x42A25238UL)))
#define bM4_INTC_VSSEL141_VSEL15                  (*((volatile unsigned int*)(0x42A2523CUL)))
#define bM4_INTC_VSSEL141_VSEL16                  (*((volatile unsigned int*)(0x42A25240UL)))
#define bM4_INTC_VSSEL141_VSEL17                  (*((volatile unsigned int*)(0x42A25244UL)))
#define bM4_INTC_VSSEL141_VSEL18                  (*((volatile unsigned int*)(0x42A25248UL)))
#define bM4_INTC_VSSEL141_VSEL19                  (*((volatile unsigned int*)(0x42A2524CUL)))
#define bM4_INTC_VSSEL141_VSEL20                  (*((volatile unsigned int*)(0x42A25250UL)))
#define bM4_INTC_VSSEL141_VSEL21                  (*((volatile unsigned int*)(0x42A25254UL)))
#define bM4_INTC_VSSEL141_VSEL22                  (*((volatile unsigned int*)(0x42A25258UL)))
#define bM4_INTC_VSSEL141_VSEL23                  (*((volatile unsigned int*)(0x42A2525CUL)))
#define bM4_INTC_VSSEL141_VSEL24                  (*((volatile unsigned int*)(0x42A25260UL)))
#define bM4_INTC_VSSEL141_VSEL25                  (*((volatile unsigned int*)(0x42A25264UL)))
#define bM4_INTC_VSSEL141_VSEL26                  (*((volatile unsigned int*)(0x42A25268UL)))
#define bM4_INTC_VSSEL141_VSEL27                  (*((volatile unsigned int*)(0x42A2526CUL)))
#define bM4_INTC_VSSEL141_VSEL28                  (*((volatile unsigned int*)(0x42A25270UL)))
#define bM4_INTC_VSSEL141_VSEL29                  (*((volatile unsigned int*)(0x42A25274UL)))
#define bM4_INTC_VSSEL141_VSEL30                  (*((volatile unsigned int*)(0x42A25278UL)))
#define bM4_INTC_VSSEL141_VSEL31                  (*((volatile unsigned int*)(0x42A2527CUL)))
#define bM4_INTC_VSSEL142_VSEL0                   (*((volatile unsigned int*)(0x42A25280UL)))
#define bM4_INTC_VSSEL142_VSEL1                   (*((volatile unsigned int*)(0x42A25284UL)))
#define bM4_INTC_VSSEL142_VSEL2                   (*((volatile unsigned int*)(0x42A25288UL)))
#define bM4_INTC_VSSEL142_VSEL3                   (*((volatile unsigned int*)(0x42A2528CUL)))
#define bM4_INTC_VSSEL142_VSEL4                   (*((volatile unsigned int*)(0x42A25290UL)))
#define bM4_INTC_VSSEL142_VSEL5                   (*((volatile unsigned int*)(0x42A25294UL)))
#define bM4_INTC_VSSEL142_VSEL6                   (*((volatile unsigned int*)(0x42A25298UL)))
#define bM4_INTC_VSSEL142_VSEL7                   (*((volatile unsigned int*)(0x42A2529CUL)))
#define bM4_INTC_VSSEL142_VSEL8                   (*((volatile unsigned int*)(0x42A252A0UL)))
#define bM4_INTC_VSSEL142_VSEL9                   (*((volatile unsigned int*)(0x42A252A4UL)))
#define bM4_INTC_VSSEL142_VSEL10                  (*((volatile unsigned int*)(0x42A252A8UL)))
#define bM4_INTC_VSSEL142_VSEL11                  (*((volatile unsigned int*)(0x42A252ACUL)))
#define bM4_INTC_VSSEL142_VSEL12                  (*((volatile unsigned int*)(0x42A252B0UL)))
#define bM4_INTC_VSSEL142_VSEL13                  (*((volatile unsigned int*)(0x42A252B4UL)))
#define bM4_INTC_VSSEL142_VSEL14                  (*((volatile unsigned int*)(0x42A252B8UL)))
#define bM4_INTC_VSSEL142_VSEL15                  (*((volatile unsigned int*)(0x42A252BCUL)))
#define bM4_INTC_VSSEL142_VSEL16                  (*((volatile unsigned int*)(0x42A252C0UL)))
#define bM4_INTC_VSSEL142_VSEL17                  (*((volatile unsigned int*)(0x42A252C4UL)))
#define bM4_INTC_VSSEL142_VSEL18                  (*((volatile unsigned int*)(0x42A252C8UL)))
#define bM4_INTC_VSSEL142_VSEL19                  (*((volatile unsigned int*)(0x42A252CCUL)))
#define bM4_INTC_VSSEL142_VSEL20                  (*((volatile unsigned int*)(0x42A252D0UL)))
#define bM4_INTC_VSSEL142_VSEL21                  (*((volatile unsigned int*)(0x42A252D4UL)))
#define bM4_INTC_VSSEL142_VSEL22                  (*((volatile unsigned int*)(0x42A252D8UL)))
#define bM4_INTC_VSSEL142_VSEL23                  (*((volatile unsigned int*)(0x42A252DCUL)))
#define bM4_INTC_VSSEL142_VSEL24                  (*((volatile unsigned int*)(0x42A252E0UL)))
#define bM4_INTC_VSSEL142_VSEL25                  (*((volatile unsigned int*)(0x42A252E4UL)))
#define bM4_INTC_VSSEL142_VSEL26                  (*((volatile unsigned int*)(0x42A252E8UL)))
#define bM4_INTC_VSSEL142_VSEL27                  (*((volatile unsigned int*)(0x42A252ECUL)))
#define bM4_INTC_VSSEL142_VSEL28                  (*((volatile unsigned int*)(0x42A252F0UL)))
#define bM4_INTC_VSSEL142_VSEL29                  (*((volatile unsigned int*)(0x42A252F4UL)))
#define bM4_INTC_VSSEL142_VSEL30                  (*((volatile unsigned int*)(0x42A252F8UL)))
#define bM4_INTC_VSSEL142_VSEL31                  (*((volatile unsigned int*)(0x42A252FCUL)))
#define bM4_INTC_VSSEL143_VSEL0                   (*((volatile unsigned int*)(0x42A25300UL)))
#define bM4_INTC_VSSEL143_VSEL1                   (*((volatile unsigned int*)(0x42A25304UL)))
#define bM4_INTC_VSSEL143_VSEL2                   (*((volatile unsigned int*)(0x42A25308UL)))
#define bM4_INTC_VSSEL143_VSEL3                   (*((volatile unsigned int*)(0x42A2530CUL)))
#define bM4_INTC_VSSEL143_VSEL4                   (*((volatile unsigned int*)(0x42A25310UL)))
#define bM4_INTC_VSSEL143_VSEL5                   (*((volatile unsigned int*)(0x42A25314UL)))
#define bM4_INTC_VSSEL143_VSEL6                   (*((volatile unsigned int*)(0x42A25318UL)))
#define bM4_INTC_VSSEL143_VSEL7                   (*((volatile unsigned int*)(0x42A2531CUL)))
#define bM4_INTC_VSSEL143_VSEL8                   (*((volatile unsigned int*)(0x42A25320UL)))
#define bM4_INTC_VSSEL143_VSEL9                   (*((volatile unsigned int*)(0x42A25324UL)))
#define bM4_INTC_VSSEL143_VSEL10                  (*((volatile unsigned int*)(0x42A25328UL)))
#define bM4_INTC_VSSEL143_VSEL11                  (*((volatile unsigned int*)(0x42A2532CUL)))
#define bM4_INTC_VSSEL143_VSEL12                  (*((volatile unsigned int*)(0x42A25330UL)))
#define bM4_INTC_VSSEL143_VSEL13                  (*((volatile unsigned int*)(0x42A25334UL)))
#define bM4_INTC_VSSEL143_VSEL14                  (*((volatile unsigned int*)(0x42A25338UL)))
#define bM4_INTC_VSSEL143_VSEL15                  (*((volatile unsigned int*)(0x42A2533CUL)))
#define bM4_INTC_VSSEL143_VSEL16                  (*((volatile unsigned int*)(0x42A25340UL)))
#define bM4_INTC_VSSEL143_VSEL17                  (*((volatile unsigned int*)(0x42A25344UL)))
#define bM4_INTC_VSSEL143_VSEL18                  (*((volatile unsigned int*)(0x42A25348UL)))
#define bM4_INTC_VSSEL143_VSEL19                  (*((volatile unsigned int*)(0x42A2534CUL)))
#define bM4_INTC_VSSEL143_VSEL20                  (*((volatile unsigned int*)(0x42A25350UL)))
#define bM4_INTC_VSSEL143_VSEL21                  (*((volatile unsigned int*)(0x42A25354UL)))
#define bM4_INTC_VSSEL143_VSEL22                  (*((volatile unsigned int*)(0x42A25358UL)))
#define bM4_INTC_VSSEL143_VSEL23                  (*((volatile unsigned int*)(0x42A2535CUL)))
#define bM4_INTC_VSSEL143_VSEL24                  (*((volatile unsigned int*)(0x42A25360UL)))
#define bM4_INTC_VSSEL143_VSEL25                  (*((volatile unsigned int*)(0x42A25364UL)))
#define bM4_INTC_VSSEL143_VSEL26                  (*((volatile unsigned int*)(0x42A25368UL)))
#define bM4_INTC_VSSEL143_VSEL27                  (*((volatile unsigned int*)(0x42A2536CUL)))
#define bM4_INTC_VSSEL143_VSEL28                  (*((volatile unsigned int*)(0x42A25370UL)))
#define bM4_INTC_VSSEL143_VSEL29                  (*((volatile unsigned int*)(0x42A25374UL)))
#define bM4_INTC_VSSEL143_VSEL30                  (*((volatile unsigned int*)(0x42A25378UL)))
#define bM4_INTC_VSSEL143_VSEL31                  (*((volatile unsigned int*)(0x42A2537CUL)))
#define bM4_INTC_SWIER_SWIE0                      (*((volatile unsigned int*)(0x42A25380UL)))
#define bM4_INTC_SWIER_SWIE1                      (*((volatile unsigned int*)(0x42A25384UL)))
#define bM4_INTC_SWIER_SWIE2                      (*((volatile unsigned int*)(0x42A25388UL)))
#define bM4_INTC_SWIER_SWIE3                      (*((volatile unsigned int*)(0x42A2538CUL)))
#define bM4_INTC_SWIER_SWIE4                      (*((volatile unsigned int*)(0x42A25390UL)))
#define bM4_INTC_SWIER_SWIE5                      (*((volatile unsigned int*)(0x42A25394UL)))
#define bM4_INTC_SWIER_SWIE6                      (*((volatile unsigned int*)(0x42A25398UL)))
#define bM4_INTC_SWIER_SWIE7                      (*((volatile unsigned int*)(0x42A2539CUL)))
#define bM4_INTC_SWIER_SWIE8                      (*((volatile unsigned int*)(0x42A253A0UL)))
#define bM4_INTC_SWIER_SWIE9                      (*((volatile unsigned int*)(0x42A253A4UL)))
#define bM4_INTC_SWIER_SWIE10                     (*((volatile unsigned int*)(0x42A253A8UL)))
#define bM4_INTC_SWIER_SWIE11                     (*((volatile unsigned int*)(0x42A253ACUL)))
#define bM4_INTC_SWIER_SWIE12                     (*((volatile unsigned int*)(0x42A253B0UL)))
#define bM4_INTC_SWIER_SWIE13                     (*((volatile unsigned int*)(0x42A253B4UL)))
#define bM4_INTC_SWIER_SWIE14                     (*((volatile unsigned int*)(0x42A253B8UL)))
#define bM4_INTC_SWIER_SWIE15                     (*((volatile unsigned int*)(0x42A253BCUL)))
#define bM4_INTC_SWIER_SWIE16                     (*((volatile unsigned int*)(0x42A253C0UL)))
#define bM4_INTC_SWIER_SWIE17                     (*((volatile unsigned int*)(0x42A253C4UL)))
#define bM4_INTC_SWIER_SWIE18                     (*((volatile unsigned int*)(0x42A253C8UL)))
#define bM4_INTC_SWIER_SWIE19                     (*((volatile unsigned int*)(0x42A253CCUL)))
#define bM4_INTC_SWIER_SWIE20                     (*((volatile unsigned int*)(0x42A253D0UL)))
#define bM4_INTC_SWIER_SWIE21                     (*((volatile unsigned int*)(0x42A253D4UL)))
#define bM4_INTC_SWIER_SWIE22                     (*((volatile unsigned int*)(0x42A253D8UL)))
#define bM4_INTC_SWIER_SWIE23                     (*((volatile unsigned int*)(0x42A253DCUL)))
#define bM4_INTC_SWIER_SWIE24                     (*((volatile unsigned int*)(0x42A253E0UL)))
#define bM4_INTC_SWIER_SWIE25                     (*((volatile unsigned int*)(0x42A253E4UL)))
#define bM4_INTC_SWIER_SWIE26                     (*((volatile unsigned int*)(0x42A253E8UL)))
#define bM4_INTC_SWIER_SWIE27                     (*((volatile unsigned int*)(0x42A253ECUL)))
#define bM4_INTC_SWIER_SWIE28                     (*((volatile unsigned int*)(0x42A253F0UL)))
#define bM4_INTC_SWIER_SWIE29                     (*((volatile unsigned int*)(0x42A253F4UL)))
#define bM4_INTC_SWIER_SWIE30                     (*((volatile unsigned int*)(0x42A253F8UL)))
#define bM4_INTC_SWIER_SWIE31                     (*((volatile unsigned int*)(0x42A253FCUL)))
#define bM4_INTC_EVTER_EVTE0                      (*((volatile unsigned int*)(0x42A25400UL)))
#define bM4_INTC_EVTER_EVTE1                      (*((volatile unsigned int*)(0x42A25404UL)))
#define bM4_INTC_EVTER_EVTE2                      (*((volatile unsigned int*)(0x42A25408UL)))
#define bM4_INTC_EVTER_EVTE3                      (*((volatile unsigned int*)(0x42A2540CUL)))
#define bM4_INTC_EVTER_EVTE4                      (*((volatile unsigned int*)(0x42A25410UL)))
#define bM4_INTC_EVTER_EVTE5                      (*((volatile unsigned int*)(0x42A25414UL)))
#define bM4_INTC_EVTER_EVTE6                      (*((volatile unsigned int*)(0x42A25418UL)))
#define bM4_INTC_EVTER_EVTE7                      (*((volatile unsigned int*)(0x42A2541CUL)))
#define bM4_INTC_EVTER_EVTE8                      (*((volatile unsigned int*)(0x42A25420UL)))
#define bM4_INTC_EVTER_EVTE9                      (*((volatile unsigned int*)(0x42A25424UL)))
#define bM4_INTC_EVTER_EVTE10                     (*((volatile unsigned int*)(0x42A25428UL)))
#define bM4_INTC_EVTER_EVTE11                     (*((volatile unsigned int*)(0x42A2542CUL)))
#define bM4_INTC_EVTER_EVTE12                     (*((volatile unsigned int*)(0x42A25430UL)))
#define bM4_INTC_EVTER_EVTE13                     (*((volatile unsigned int*)(0x42A25434UL)))
#define bM4_INTC_EVTER_EVTE14                     (*((volatile unsigned int*)(0x42A25438UL)))
#define bM4_INTC_EVTER_EVTE15                     (*((volatile unsigned int*)(0x42A2543CUL)))
#define bM4_INTC_EVTER_EVTE16                     (*((volatile unsigned int*)(0x42A25440UL)))
#define bM4_INTC_EVTER_EVTE17                     (*((volatile unsigned int*)(0x42A25444UL)))
#define bM4_INTC_EVTER_EVTE18                     (*((volatile unsigned int*)(0x42A25448UL)))
#define bM4_INTC_EVTER_EVTE19                     (*((volatile unsigned int*)(0x42A2544CUL)))
#define bM4_INTC_EVTER_EVTE20                     (*((volatile unsigned int*)(0x42A25450UL)))
#define bM4_INTC_EVTER_EVTE21                     (*((volatile unsigned int*)(0x42A25454UL)))
#define bM4_INTC_EVTER_EVTE22                     (*((volatile unsigned int*)(0x42A25458UL)))
#define bM4_INTC_EVTER_EVTE23                     (*((volatile unsigned int*)(0x42A2545CUL)))
#define bM4_INTC_EVTER_EVTE24                     (*((volatile unsigned int*)(0x42A25460UL)))
#define bM4_INTC_EVTER_EVTE25                     (*((volatile unsigned int*)(0x42A25464UL)))
#define bM4_INTC_EVTER_EVTE26                     (*((volatile unsigned int*)(0x42A25468UL)))
#define bM4_INTC_EVTER_EVTE27                     (*((volatile unsigned int*)(0x42A2546CUL)))
#define bM4_INTC_EVTER_EVTE28                     (*((volatile unsigned int*)(0x42A25470UL)))
#define bM4_INTC_EVTER_EVTE29                     (*((volatile unsigned int*)(0x42A25474UL)))
#define bM4_INTC_EVTER_EVTE30                     (*((volatile unsigned int*)(0x42A25478UL)))
#define bM4_INTC_EVTER_EVTE31                     (*((volatile unsigned int*)(0x42A2547CUL)))
#define bM4_INTC_IER_IER0                         (*((volatile unsigned int*)(0x42A25480UL)))
#define bM4_INTC_IER_IER1                         (*((volatile unsigned int*)(0x42A25484UL)))
#define bM4_INTC_IER_IER2                         (*((volatile unsigned int*)(0x42A25488UL)))
#define bM4_INTC_IER_IER3                         (*((volatile unsigned int*)(0x42A2548CUL)))
#define bM4_INTC_IER_IER4                         (*((volatile unsigned int*)(0x42A25490UL)))
#define bM4_INTC_IER_IER5                         (*((volatile unsigned int*)(0x42A25494UL)))
#define bM4_INTC_IER_IER6                         (*((volatile unsigned int*)(0x42A25498UL)))
#define bM4_INTC_IER_IER7                         (*((volatile unsigned int*)(0x42A2549CUL)))
#define bM4_INTC_IER_IER8                         (*((volatile unsigned int*)(0x42A254A0UL)))
#define bM4_INTC_IER_IER9                         (*((volatile unsigned int*)(0x42A254A4UL)))
#define bM4_INTC_IER_IER10                        (*((volatile unsigned int*)(0x42A254A8UL)))
#define bM4_INTC_IER_IER11                        (*((volatile unsigned int*)(0x42A254ACUL)))
#define bM4_INTC_IER_IER12                        (*((volatile unsigned int*)(0x42A254B0UL)))
#define bM4_INTC_IER_IER13                        (*((volatile unsigned int*)(0x42A254B4UL)))
#define bM4_INTC_IER_IER14                        (*((volatile unsigned int*)(0x42A254B8UL)))
#define bM4_INTC_IER_IER15                        (*((volatile unsigned int*)(0x42A254BCUL)))
#define bM4_INTC_IER_IER16                        (*((volatile unsigned int*)(0x42A254C0UL)))
#define bM4_INTC_IER_IER17                        (*((volatile unsigned int*)(0x42A254C4UL)))
#define bM4_INTC_IER_IER18                        (*((volatile unsigned int*)(0x42A254C8UL)))
#define bM4_INTC_IER_IER19                        (*((volatile unsigned int*)(0x42A254CCUL)))
#define bM4_INTC_IER_IER20                        (*((volatile unsigned int*)(0x42A254D0UL)))
#define bM4_INTC_IER_IER21                        (*((volatile unsigned int*)(0x42A254D4UL)))
#define bM4_INTC_IER_IER22                        (*((volatile unsigned int*)(0x42A254D8UL)))
#define bM4_INTC_IER_IER23                        (*((volatile unsigned int*)(0x42A254DCUL)))
#define bM4_INTC_IER_IER24                        (*((volatile unsigned int*)(0x42A254E0UL)))
#define bM4_INTC_IER_IER25                        (*((volatile unsigned int*)(0x42A254E4UL)))
#define bM4_INTC_IER_IER26                        (*((volatile unsigned int*)(0x42A254E8UL)))
#define bM4_INTC_IER_IER27                        (*((volatile unsigned int*)(0x42A254ECUL)))
#define bM4_INTC_IER_IER28                        (*((volatile unsigned int*)(0x42A254F0UL)))
#define bM4_INTC_IER_IER29                        (*((volatile unsigned int*)(0x42A254F4UL)))
#define bM4_INTC_IER_IER30                        (*((volatile unsigned int*)(0x42A254F8UL)))
#define bM4_INTC_IER_IER31                        (*((volatile unsigned int*)(0x42A254FCUL)))
#define bM4_KEYSCAN_SCR_KEYINSEL0                 (*((volatile unsigned int*)(0x42A18000UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL1                 (*((volatile unsigned int*)(0x42A18004UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL2                 (*((volatile unsigned int*)(0x42A18008UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL3                 (*((volatile unsigned int*)(0x42A1800CUL)))
#define bM4_KEYSCAN_SCR_KEYINSEL4                 (*((volatile unsigned int*)(0x42A18010UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL5                 (*((volatile unsigned int*)(0x42A18014UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL6                 (*((volatile unsigned int*)(0x42A18018UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL7                 (*((volatile unsigned int*)(0x42A1801CUL)))
#define bM4_KEYSCAN_SCR_KEYINSEL8                 (*((volatile unsigned int*)(0x42A18020UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL9                 (*((volatile unsigned int*)(0x42A18024UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL10                (*((volatile unsigned int*)(0x42A18028UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL11                (*((volatile unsigned int*)(0x42A1802CUL)))
#define bM4_KEYSCAN_SCR_KEYINSEL12                (*((volatile unsigned int*)(0x42A18030UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL13                (*((volatile unsigned int*)(0x42A18034UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL14                (*((volatile unsigned int*)(0x42A18038UL)))
#define bM4_KEYSCAN_SCR_KEYINSEL15                (*((volatile unsigned int*)(0x42A1803CUL)))
#define bM4_KEYSCAN_SCR_KEYOUTSEL0                (*((volatile unsigned int*)(0x42A18040UL)))
#define bM4_KEYSCAN_SCR_KEYOUTSEL1                (*((volatile unsigned int*)(0x42A18044UL)))
#define bM4_KEYSCAN_SCR_KEYOUTSEL2                (*((volatile unsigned int*)(0x42A18048UL)))
#define bM4_KEYSCAN_SCR_CKSEL0                    (*((volatile unsigned int*)(0x42A18050UL)))
#define bM4_KEYSCAN_SCR_CKSEL1                    (*((volatile unsigned int*)(0x42A18054UL)))
#define bM4_KEYSCAN_SCR_T_LLEVEL0                 (*((volatile unsigned int*)(0x42A18060UL)))
#define bM4_KEYSCAN_SCR_T_LLEVEL1                 (*((volatile unsigned int*)(0x42A18064UL)))
#define bM4_KEYSCAN_SCR_T_LLEVEL2                 (*((volatile unsigned int*)(0x42A18068UL)))
#define bM4_KEYSCAN_SCR_T_LLEVEL3                 (*((volatile unsigned int*)(0x42A1806CUL)))
#define bM4_KEYSCAN_SCR_T_LLEVEL4                 (*((volatile unsigned int*)(0x42A18070UL)))
#define bM4_KEYSCAN_SCR_T_HIZ0                    (*((volatile unsigned int*)(0x42A18074UL)))
#define bM4_KEYSCAN_SCR_T_HIZ1                    (*((volatile unsigned int*)(0x42A18078UL)))
#define bM4_KEYSCAN_SCR_T_HIZ2                    (*((volatile unsigned int*)(0x42A1807CUL)))
#define bM4_KEYSCAN_SER_SEN                       (*((volatile unsigned int*)(0x42A18080UL)))
#define bM4_KEYSCAN_SSR_INDEX0                    (*((volatile unsigned int*)(0x42A18100UL)))
#define bM4_KEYSCAN_SSR_INDEX1                    (*((volatile unsigned int*)(0x42A18104UL)))
#define bM4_KEYSCAN_SSR_INDEX2                    (*((volatile unsigned int*)(0x42A18108UL)))
#define bM4_MPU_RGD0_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00000UL)))
#define bM4_MPU_RGD0_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00004UL)))
#define bM4_MPU_RGD0_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00008UL)))
#define bM4_MPU_RGD0_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0000CUL)))
#define bM4_MPU_RGD0_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00010UL)))
#define bM4_MPU_RGD0_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00014UL)))
#define bM4_MPU_RGD0_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00018UL)))
#define bM4_MPU_RGD0_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0001CUL)))
#define bM4_MPU_RGD0_MPURGADDR3                   (*((volatile unsigned int*)(0x42A00020UL)))
#define bM4_MPU_RGD0_MPURGADDR4                   (*((volatile unsigned int*)(0x42A00024UL)))
#define bM4_MPU_RGD0_MPURGADDR5                   (*((volatile unsigned int*)(0x42A00028UL)))
#define bM4_MPU_RGD0_MPURGADDR6                   (*((volatile unsigned int*)(0x42A0002CUL)))
#define bM4_MPU_RGD0_MPURGADDR7                   (*((volatile unsigned int*)(0x42A00030UL)))
#define bM4_MPU_RGD0_MPURGADDR8                   (*((volatile unsigned int*)(0x42A00034UL)))
#define bM4_MPU_RGD0_MPURGADDR9                   (*((volatile unsigned int*)(0x42A00038UL)))
#define bM4_MPU_RGD0_MPURGADDR10                  (*((volatile unsigned int*)(0x42A0003CUL)))
#define bM4_MPU_RGD0_MPURGADDR11                  (*((volatile unsigned int*)(0x42A00040UL)))
#define bM4_MPU_RGD0_MPURGADDR12                  (*((volatile unsigned int*)(0x42A00044UL)))
#define bM4_MPU_RGD0_MPURGADDR13                  (*((volatile unsigned int*)(0x42A00048UL)))
#define bM4_MPU_RGD0_MPURGADDR14                  (*((volatile unsigned int*)(0x42A0004CUL)))
#define bM4_MPU_RGD0_MPURGADDR15                  (*((volatile unsigned int*)(0x42A00050UL)))
#define bM4_MPU_RGD0_MPURGADDR16                  (*((volatile unsigned int*)(0x42A00054UL)))
#define bM4_MPU_RGD0_MPURGADDR17                  (*((volatile unsigned int*)(0x42A00058UL)))
#define bM4_MPU_RGD0_MPURGADDR18                  (*((volatile unsigned int*)(0x42A0005CUL)))
#define bM4_MPU_RGD0_MPURGADDR19                  (*((volatile unsigned int*)(0x42A00060UL)))
#define bM4_MPU_RGD0_MPURGADDR20                  (*((volatile unsigned int*)(0x42A00064UL)))
#define bM4_MPU_RGD0_MPURGADDR21                  (*((volatile unsigned int*)(0x42A00068UL)))
#define bM4_MPU_RGD0_MPURGADDR22                  (*((volatile unsigned int*)(0x42A0006CUL)))
#define bM4_MPU_RGD0_MPURGADDR23                  (*((volatile unsigned int*)(0x42A00070UL)))
#define bM4_MPU_RGD0_MPURGADDR24                  (*((volatile unsigned int*)(0x42A00074UL)))
#define bM4_MPU_RGD0_MPURGADDR25                  (*((volatile unsigned int*)(0x42A00078UL)))
#define bM4_MPU_RGD0_MPURGADDR26                  (*((volatile unsigned int*)(0x42A0007CUL)))
#define bM4_MPU_RGD1_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00080UL)))
#define bM4_MPU_RGD1_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00084UL)))
#define bM4_MPU_RGD1_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00088UL)))
#define bM4_MPU_RGD1_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0008CUL)))
#define bM4_MPU_RGD1_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00090UL)))
#define bM4_MPU_RGD1_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00094UL)))
#define bM4_MPU_RGD1_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00098UL)))
#define bM4_MPU_RGD1_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0009CUL)))
#define bM4_MPU_RGD1_MPURGADDR3                   (*((volatile unsigned int*)(0x42A000A0UL)))
#define bM4_MPU_RGD1_MPURGADDR4                   (*((volatile unsigned int*)(0x42A000A4UL)))
#define bM4_MPU_RGD1_MPURGADDR5                   (*((volatile unsigned int*)(0x42A000A8UL)))
#define bM4_MPU_RGD1_MPURGADDR6                   (*((volatile unsigned int*)(0x42A000ACUL)))
#define bM4_MPU_RGD1_MPURGADDR7                   (*((volatile unsigned int*)(0x42A000B0UL)))
#define bM4_MPU_RGD1_MPURGADDR8                   (*((volatile unsigned int*)(0x42A000B4UL)))
#define bM4_MPU_RGD1_MPURGADDR9                   (*((volatile unsigned int*)(0x42A000B8UL)))
#define bM4_MPU_RGD1_MPURGADDR10                  (*((volatile unsigned int*)(0x42A000BCUL)))
#define bM4_MPU_RGD1_MPURGADDR11                  (*((volatile unsigned int*)(0x42A000C0UL)))
#define bM4_MPU_RGD1_MPURGADDR12                  (*((volatile unsigned int*)(0x42A000C4UL)))
#define bM4_MPU_RGD1_MPURGADDR13                  (*((volatile unsigned int*)(0x42A000C8UL)))
#define bM4_MPU_RGD1_MPURGADDR14                  (*((volatile unsigned int*)(0x42A000CCUL)))
#define bM4_MPU_RGD1_MPURGADDR15                  (*((volatile unsigned int*)(0x42A000D0UL)))
#define bM4_MPU_RGD1_MPURGADDR16                  (*((volatile unsigned int*)(0x42A000D4UL)))
#define bM4_MPU_RGD1_MPURGADDR17                  (*((volatile unsigned int*)(0x42A000D8UL)))
#define bM4_MPU_RGD1_MPURGADDR18                  (*((volatile unsigned int*)(0x42A000DCUL)))
#define bM4_MPU_RGD1_MPURGADDR19                  (*((volatile unsigned int*)(0x42A000E0UL)))
#define bM4_MPU_RGD1_MPURGADDR20                  (*((volatile unsigned int*)(0x42A000E4UL)))
#define bM4_MPU_RGD1_MPURGADDR21                  (*((volatile unsigned int*)(0x42A000E8UL)))
#define bM4_MPU_RGD1_MPURGADDR22                  (*((volatile unsigned int*)(0x42A000ECUL)))
#define bM4_MPU_RGD1_MPURGADDR23                  (*((volatile unsigned int*)(0x42A000F0UL)))
#define bM4_MPU_RGD1_MPURGADDR24                  (*((volatile unsigned int*)(0x42A000F4UL)))
#define bM4_MPU_RGD1_MPURGADDR25                  (*((volatile unsigned int*)(0x42A000F8UL)))
#define bM4_MPU_RGD1_MPURGADDR26                  (*((volatile unsigned int*)(0x42A000FCUL)))
#define bM4_MPU_RGD2_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00100UL)))
#define bM4_MPU_RGD2_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00104UL)))
#define bM4_MPU_RGD2_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00108UL)))
#define bM4_MPU_RGD2_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0010CUL)))
#define bM4_MPU_RGD2_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00110UL)))
#define bM4_MPU_RGD2_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00114UL)))
#define bM4_MPU_RGD2_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00118UL)))
#define bM4_MPU_RGD2_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0011CUL)))
#define bM4_MPU_RGD2_MPURGADDR3                   (*((volatile unsigned int*)(0x42A00120UL)))
#define bM4_MPU_RGD2_MPURGADDR4                   (*((volatile unsigned int*)(0x42A00124UL)))
#define bM4_MPU_RGD2_MPURGADDR5                   (*((volatile unsigned int*)(0x42A00128UL)))
#define bM4_MPU_RGD2_MPURGADDR6                   (*((volatile unsigned int*)(0x42A0012CUL)))
#define bM4_MPU_RGD2_MPURGADDR7                   (*((volatile unsigned int*)(0x42A00130UL)))
#define bM4_MPU_RGD2_MPURGADDR8                   (*((volatile unsigned int*)(0x42A00134UL)))
#define bM4_MPU_RGD2_MPURGADDR9                   (*((volatile unsigned int*)(0x42A00138UL)))
#define bM4_MPU_RGD2_MPURGADDR10                  (*((volatile unsigned int*)(0x42A0013CUL)))
#define bM4_MPU_RGD2_MPURGADDR11                  (*((volatile unsigned int*)(0x42A00140UL)))
#define bM4_MPU_RGD2_MPURGADDR12                  (*((volatile unsigned int*)(0x42A00144UL)))
#define bM4_MPU_RGD2_MPURGADDR13                  (*((volatile unsigned int*)(0x42A00148UL)))
#define bM4_MPU_RGD2_MPURGADDR14                  (*((volatile unsigned int*)(0x42A0014CUL)))
#define bM4_MPU_RGD2_MPURGADDR15                  (*((volatile unsigned int*)(0x42A00150UL)))
#define bM4_MPU_RGD2_MPURGADDR16                  (*((volatile unsigned int*)(0x42A00154UL)))
#define bM4_MPU_RGD2_MPURGADDR17                  (*((volatile unsigned int*)(0x42A00158UL)))
#define bM4_MPU_RGD2_MPURGADDR18                  (*((volatile unsigned int*)(0x42A0015CUL)))
#define bM4_MPU_RGD2_MPURGADDR19                  (*((volatile unsigned int*)(0x42A00160UL)))
#define bM4_MPU_RGD2_MPURGADDR20                  (*((volatile unsigned int*)(0x42A00164UL)))
#define bM4_MPU_RGD2_MPURGADDR21                  (*((volatile unsigned int*)(0x42A00168UL)))
#define bM4_MPU_RGD2_MPURGADDR22                  (*((volatile unsigned int*)(0x42A0016CUL)))
#define bM4_MPU_RGD2_MPURGADDR23                  (*((volatile unsigned int*)(0x42A00170UL)))
#define bM4_MPU_RGD2_MPURGADDR24                  (*((volatile unsigned int*)(0x42A00174UL)))
#define bM4_MPU_RGD2_MPURGADDR25                  (*((volatile unsigned int*)(0x42A00178UL)))
#define bM4_MPU_RGD2_MPURGADDR26                  (*((volatile unsigned int*)(0x42A0017CUL)))
#define bM4_MPU_RGD3_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00180UL)))
#define bM4_MPU_RGD3_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00184UL)))
#define bM4_MPU_RGD3_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00188UL)))
#define bM4_MPU_RGD3_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0018CUL)))
#define bM4_MPU_RGD3_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00190UL)))
#define bM4_MPU_RGD3_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00194UL)))
#define bM4_MPU_RGD3_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00198UL)))
#define bM4_MPU_RGD3_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0019CUL)))
#define bM4_MPU_RGD3_MPURGADDR3                   (*((volatile unsigned int*)(0x42A001A0UL)))
#define bM4_MPU_RGD3_MPURGADDR4                   (*((volatile unsigned int*)(0x42A001A4UL)))
#define bM4_MPU_RGD3_MPURGADDR5                   (*((volatile unsigned int*)(0x42A001A8UL)))
#define bM4_MPU_RGD3_MPURGADDR6                   (*((volatile unsigned int*)(0x42A001ACUL)))
#define bM4_MPU_RGD3_MPURGADDR7                   (*((volatile unsigned int*)(0x42A001B0UL)))
#define bM4_MPU_RGD3_MPURGADDR8                   (*((volatile unsigned int*)(0x42A001B4UL)))
#define bM4_MPU_RGD3_MPURGADDR9                   (*((volatile unsigned int*)(0x42A001B8UL)))
#define bM4_MPU_RGD3_MPURGADDR10                  (*((volatile unsigned int*)(0x42A001BCUL)))
#define bM4_MPU_RGD3_MPURGADDR11                  (*((volatile unsigned int*)(0x42A001C0UL)))
#define bM4_MPU_RGD3_MPURGADDR12                  (*((volatile unsigned int*)(0x42A001C4UL)))
#define bM4_MPU_RGD3_MPURGADDR13                  (*((volatile unsigned int*)(0x42A001C8UL)))
#define bM4_MPU_RGD3_MPURGADDR14                  (*((volatile unsigned int*)(0x42A001CCUL)))
#define bM4_MPU_RGD3_MPURGADDR15                  (*((volatile unsigned int*)(0x42A001D0UL)))
#define bM4_MPU_RGD3_MPURGADDR16                  (*((volatile unsigned int*)(0x42A001D4UL)))
#define bM4_MPU_RGD3_MPURGADDR17                  (*((volatile unsigned int*)(0x42A001D8UL)))
#define bM4_MPU_RGD3_MPURGADDR18                  (*((volatile unsigned int*)(0x42A001DCUL)))
#define bM4_MPU_RGD3_MPURGADDR19                  (*((volatile unsigned int*)(0x42A001E0UL)))
#define bM4_MPU_RGD3_MPURGADDR20                  (*((volatile unsigned int*)(0x42A001E4UL)))
#define bM4_MPU_RGD3_MPURGADDR21                  (*((volatile unsigned int*)(0x42A001E8UL)))
#define bM4_MPU_RGD3_MPURGADDR22                  (*((volatile unsigned int*)(0x42A001ECUL)))
#define bM4_MPU_RGD3_MPURGADDR23                  (*((volatile unsigned int*)(0x42A001F0UL)))
#define bM4_MPU_RGD3_MPURGADDR24                  (*((volatile unsigned int*)(0x42A001F4UL)))
#define bM4_MPU_RGD3_MPURGADDR25                  (*((volatile unsigned int*)(0x42A001F8UL)))
#define bM4_MPU_RGD3_MPURGADDR26                  (*((volatile unsigned int*)(0x42A001FCUL)))
#define bM4_MPU_RGD4_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00200UL)))
#define bM4_MPU_RGD4_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00204UL)))
#define bM4_MPU_RGD4_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00208UL)))
#define bM4_MPU_RGD4_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0020CUL)))
#define bM4_MPU_RGD4_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00210UL)))
#define bM4_MPU_RGD4_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00214UL)))
#define bM4_MPU_RGD4_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00218UL)))
#define bM4_MPU_RGD4_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0021CUL)))
#define bM4_MPU_RGD4_MPURGADDR3                   (*((volatile unsigned int*)(0x42A00220UL)))
#define bM4_MPU_RGD4_MPURGADDR4                   (*((volatile unsigned int*)(0x42A00224UL)))
#define bM4_MPU_RGD4_MPURGADDR5                   (*((volatile unsigned int*)(0x42A00228UL)))
#define bM4_MPU_RGD4_MPURGADDR6                   (*((volatile unsigned int*)(0x42A0022CUL)))
#define bM4_MPU_RGD4_MPURGADDR7                   (*((volatile unsigned int*)(0x42A00230UL)))
#define bM4_MPU_RGD4_MPURGADDR8                   (*((volatile unsigned int*)(0x42A00234UL)))
#define bM4_MPU_RGD4_MPURGADDR9                   (*((volatile unsigned int*)(0x42A00238UL)))
#define bM4_MPU_RGD4_MPURGADDR10                  (*((volatile unsigned int*)(0x42A0023CUL)))
#define bM4_MPU_RGD4_MPURGADDR11                  (*((volatile unsigned int*)(0x42A00240UL)))
#define bM4_MPU_RGD4_MPURGADDR12                  (*((volatile unsigned int*)(0x42A00244UL)))
#define bM4_MPU_RGD4_MPURGADDR13                  (*((volatile unsigned int*)(0x42A00248UL)))
#define bM4_MPU_RGD4_MPURGADDR14                  (*((volatile unsigned int*)(0x42A0024CUL)))
#define bM4_MPU_RGD4_MPURGADDR15                  (*((volatile unsigned int*)(0x42A00250UL)))
#define bM4_MPU_RGD4_MPURGADDR16                  (*((volatile unsigned int*)(0x42A00254UL)))
#define bM4_MPU_RGD4_MPURGADDR17                  (*((volatile unsigned int*)(0x42A00258UL)))
#define bM4_MPU_RGD4_MPURGADDR18                  (*((volatile unsigned int*)(0x42A0025CUL)))
#define bM4_MPU_RGD4_MPURGADDR19                  (*((volatile unsigned int*)(0x42A00260UL)))
#define bM4_MPU_RGD4_MPURGADDR20                  (*((volatile unsigned int*)(0x42A00264UL)))
#define bM4_MPU_RGD4_MPURGADDR21                  (*((volatile unsigned int*)(0x42A00268UL)))
#define bM4_MPU_RGD4_MPURGADDR22                  (*((volatile unsigned int*)(0x42A0026CUL)))
#define bM4_MPU_RGD4_MPURGADDR23                  (*((volatile unsigned int*)(0x42A00270UL)))
#define bM4_MPU_RGD4_MPURGADDR24                  (*((volatile unsigned int*)(0x42A00274UL)))
#define bM4_MPU_RGD4_MPURGADDR25                  (*((volatile unsigned int*)(0x42A00278UL)))
#define bM4_MPU_RGD4_MPURGADDR26                  (*((volatile unsigned int*)(0x42A0027CUL)))
#define bM4_MPU_RGD5_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00280UL)))
#define bM4_MPU_RGD5_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00284UL)))
#define bM4_MPU_RGD5_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00288UL)))
#define bM4_MPU_RGD5_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0028CUL)))
#define bM4_MPU_RGD5_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00290UL)))
#define bM4_MPU_RGD5_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00294UL)))
#define bM4_MPU_RGD5_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00298UL)))
#define bM4_MPU_RGD5_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0029CUL)))
#define bM4_MPU_RGD5_MPURGADDR3                   (*((volatile unsigned int*)(0x42A002A0UL)))
#define bM4_MPU_RGD5_MPURGADDR4                   (*((volatile unsigned int*)(0x42A002A4UL)))
#define bM4_MPU_RGD5_MPURGADDR5                   (*((volatile unsigned int*)(0x42A002A8UL)))
#define bM4_MPU_RGD5_MPURGADDR6                   (*((volatile unsigned int*)(0x42A002ACUL)))
#define bM4_MPU_RGD5_MPURGADDR7                   (*((volatile unsigned int*)(0x42A002B0UL)))
#define bM4_MPU_RGD5_MPURGADDR8                   (*((volatile unsigned int*)(0x42A002B4UL)))
#define bM4_MPU_RGD5_MPURGADDR9                   (*((volatile unsigned int*)(0x42A002B8UL)))
#define bM4_MPU_RGD5_MPURGADDR10                  (*((volatile unsigned int*)(0x42A002BCUL)))
#define bM4_MPU_RGD5_MPURGADDR11                  (*((volatile unsigned int*)(0x42A002C0UL)))
#define bM4_MPU_RGD5_MPURGADDR12                  (*((volatile unsigned int*)(0x42A002C4UL)))
#define bM4_MPU_RGD5_MPURGADDR13                  (*((volatile unsigned int*)(0x42A002C8UL)))
#define bM4_MPU_RGD5_MPURGADDR14                  (*((volatile unsigned int*)(0x42A002CCUL)))
#define bM4_MPU_RGD5_MPURGADDR15                  (*((volatile unsigned int*)(0x42A002D0UL)))
#define bM4_MPU_RGD5_MPURGADDR16                  (*((volatile unsigned int*)(0x42A002D4UL)))
#define bM4_MPU_RGD5_MPURGADDR17                  (*((volatile unsigned int*)(0x42A002D8UL)))
#define bM4_MPU_RGD5_MPURGADDR18                  (*((volatile unsigned int*)(0x42A002DCUL)))
#define bM4_MPU_RGD5_MPURGADDR19                  (*((volatile unsigned int*)(0x42A002E0UL)))
#define bM4_MPU_RGD5_MPURGADDR20                  (*((volatile unsigned int*)(0x42A002E4UL)))
#define bM4_MPU_RGD5_MPURGADDR21                  (*((volatile unsigned int*)(0x42A002E8UL)))
#define bM4_MPU_RGD5_MPURGADDR22                  (*((volatile unsigned int*)(0x42A002ECUL)))
#define bM4_MPU_RGD5_MPURGADDR23                  (*((volatile unsigned int*)(0x42A002F0UL)))
#define bM4_MPU_RGD5_MPURGADDR24                  (*((volatile unsigned int*)(0x42A002F4UL)))
#define bM4_MPU_RGD5_MPURGADDR25                  (*((volatile unsigned int*)(0x42A002F8UL)))
#define bM4_MPU_RGD5_MPURGADDR26                  (*((volatile unsigned int*)(0x42A002FCUL)))
#define bM4_MPU_RGD6_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00300UL)))
#define bM4_MPU_RGD6_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00304UL)))
#define bM4_MPU_RGD6_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00308UL)))
#define bM4_MPU_RGD6_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0030CUL)))
#define bM4_MPU_RGD6_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00310UL)))
#define bM4_MPU_RGD6_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00314UL)))
#define bM4_MPU_RGD6_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00318UL)))
#define bM4_MPU_RGD6_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0031CUL)))
#define bM4_MPU_RGD6_MPURGADDR3                   (*((volatile unsigned int*)(0x42A00320UL)))
#define bM4_MPU_RGD6_MPURGADDR4                   (*((volatile unsigned int*)(0x42A00324UL)))
#define bM4_MPU_RGD6_MPURGADDR5                   (*((volatile unsigned int*)(0x42A00328UL)))
#define bM4_MPU_RGD6_MPURGADDR6                   (*((volatile unsigned int*)(0x42A0032CUL)))
#define bM4_MPU_RGD6_MPURGADDR7                   (*((volatile unsigned int*)(0x42A00330UL)))
#define bM4_MPU_RGD6_MPURGADDR8                   (*((volatile unsigned int*)(0x42A00334UL)))
#define bM4_MPU_RGD6_MPURGADDR9                   (*((volatile unsigned int*)(0x42A00338UL)))
#define bM4_MPU_RGD6_MPURGADDR10                  (*((volatile unsigned int*)(0x42A0033CUL)))
#define bM4_MPU_RGD6_MPURGADDR11                  (*((volatile unsigned int*)(0x42A00340UL)))
#define bM4_MPU_RGD6_MPURGADDR12                  (*((volatile unsigned int*)(0x42A00344UL)))
#define bM4_MPU_RGD6_MPURGADDR13                  (*((volatile unsigned int*)(0x42A00348UL)))
#define bM4_MPU_RGD6_MPURGADDR14                  (*((volatile unsigned int*)(0x42A0034CUL)))
#define bM4_MPU_RGD6_MPURGADDR15                  (*((volatile unsigned int*)(0x42A00350UL)))
#define bM4_MPU_RGD6_MPURGADDR16                  (*((volatile unsigned int*)(0x42A00354UL)))
#define bM4_MPU_RGD6_MPURGADDR17                  (*((volatile unsigned int*)(0x42A00358UL)))
#define bM4_MPU_RGD6_MPURGADDR18                  (*((volatile unsigned int*)(0x42A0035CUL)))
#define bM4_MPU_RGD6_MPURGADDR19                  (*((volatile unsigned int*)(0x42A00360UL)))
#define bM4_MPU_RGD6_MPURGADDR20                  (*((volatile unsigned int*)(0x42A00364UL)))
#define bM4_MPU_RGD6_MPURGADDR21                  (*((volatile unsigned int*)(0x42A00368UL)))
#define bM4_MPU_RGD6_MPURGADDR22                  (*((volatile unsigned int*)(0x42A0036CUL)))
#define bM4_MPU_RGD6_MPURGADDR23                  (*((volatile unsigned int*)(0x42A00370UL)))
#define bM4_MPU_RGD6_MPURGADDR24                  (*((volatile unsigned int*)(0x42A00374UL)))
#define bM4_MPU_RGD6_MPURGADDR25                  (*((volatile unsigned int*)(0x42A00378UL)))
#define bM4_MPU_RGD6_MPURGADDR26                  (*((volatile unsigned int*)(0x42A0037CUL)))
#define bM4_MPU_RGD7_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00380UL)))
#define bM4_MPU_RGD7_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00384UL)))
#define bM4_MPU_RGD7_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00388UL)))
#define bM4_MPU_RGD7_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0038CUL)))
#define bM4_MPU_RGD7_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00390UL)))
#define bM4_MPU_RGD7_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00394UL)))
#define bM4_MPU_RGD7_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00398UL)))
#define bM4_MPU_RGD7_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0039CUL)))
#define bM4_MPU_RGD7_MPURGADDR3                   (*((volatile unsigned int*)(0x42A003A0UL)))
#define bM4_MPU_RGD7_MPURGADDR4                   (*((volatile unsigned int*)(0x42A003A4UL)))
#define bM4_MPU_RGD7_MPURGADDR5                   (*((volatile unsigned int*)(0x42A003A8UL)))
#define bM4_MPU_RGD7_MPURGADDR6                   (*((volatile unsigned int*)(0x42A003ACUL)))
#define bM4_MPU_RGD7_MPURGADDR7                   (*((volatile unsigned int*)(0x42A003B0UL)))
#define bM4_MPU_RGD7_MPURGADDR8                   (*((volatile unsigned int*)(0x42A003B4UL)))
#define bM4_MPU_RGD7_MPURGADDR9                   (*((volatile unsigned int*)(0x42A003B8UL)))
#define bM4_MPU_RGD7_MPURGADDR10                  (*((volatile unsigned int*)(0x42A003BCUL)))
#define bM4_MPU_RGD7_MPURGADDR11                  (*((volatile unsigned int*)(0x42A003C0UL)))
#define bM4_MPU_RGD7_MPURGADDR12                  (*((volatile unsigned int*)(0x42A003C4UL)))
#define bM4_MPU_RGD7_MPURGADDR13                  (*((volatile unsigned int*)(0x42A003C8UL)))
#define bM4_MPU_RGD7_MPURGADDR14                  (*((volatile unsigned int*)(0x42A003CCUL)))
#define bM4_MPU_RGD7_MPURGADDR15                  (*((volatile unsigned int*)(0x42A003D0UL)))
#define bM4_MPU_RGD7_MPURGADDR16                  (*((volatile unsigned int*)(0x42A003D4UL)))
#define bM4_MPU_RGD7_MPURGADDR17                  (*((volatile unsigned int*)(0x42A003D8UL)))
#define bM4_MPU_RGD7_MPURGADDR18                  (*((volatile unsigned int*)(0x42A003DCUL)))
#define bM4_MPU_RGD7_MPURGADDR19                  (*((volatile unsigned int*)(0x42A003E0UL)))
#define bM4_MPU_RGD7_MPURGADDR20                  (*((volatile unsigned int*)(0x42A003E4UL)))
#define bM4_MPU_RGD7_MPURGADDR21                  (*((volatile unsigned int*)(0x42A003E8UL)))
#define bM4_MPU_RGD7_MPURGADDR22                  (*((volatile unsigned int*)(0x42A003ECUL)))
#define bM4_MPU_RGD7_MPURGADDR23                  (*((volatile unsigned int*)(0x42A003F0UL)))
#define bM4_MPU_RGD7_MPURGADDR24                  (*((volatile unsigned int*)(0x42A003F4UL)))
#define bM4_MPU_RGD7_MPURGADDR25                  (*((volatile unsigned int*)(0x42A003F8UL)))
#define bM4_MPU_RGD7_MPURGADDR26                  (*((volatile unsigned int*)(0x42A003FCUL)))
#define bM4_MPU_RGD8_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00400UL)))
#define bM4_MPU_RGD8_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00404UL)))
#define bM4_MPU_RGD8_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00408UL)))
#define bM4_MPU_RGD8_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0040CUL)))
#define bM4_MPU_RGD8_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00410UL)))
#define bM4_MPU_RGD8_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00414UL)))
#define bM4_MPU_RGD8_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00418UL)))
#define bM4_MPU_RGD8_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0041CUL)))
#define bM4_MPU_RGD8_MPURGADDR3                   (*((volatile unsigned int*)(0x42A00420UL)))
#define bM4_MPU_RGD8_MPURGADDR4                   (*((volatile unsigned int*)(0x42A00424UL)))
#define bM4_MPU_RGD8_MPURGADDR5                   (*((volatile unsigned int*)(0x42A00428UL)))
#define bM4_MPU_RGD8_MPURGADDR6                   (*((volatile unsigned int*)(0x42A0042CUL)))
#define bM4_MPU_RGD8_MPURGADDR7                   (*((volatile unsigned int*)(0x42A00430UL)))
#define bM4_MPU_RGD8_MPURGADDR8                   (*((volatile unsigned int*)(0x42A00434UL)))
#define bM4_MPU_RGD8_MPURGADDR9                   (*((volatile unsigned int*)(0x42A00438UL)))
#define bM4_MPU_RGD8_MPURGADDR10                  (*((volatile unsigned int*)(0x42A0043CUL)))
#define bM4_MPU_RGD8_MPURGADDR11                  (*((volatile unsigned int*)(0x42A00440UL)))
#define bM4_MPU_RGD8_MPURGADDR12                  (*((volatile unsigned int*)(0x42A00444UL)))
#define bM4_MPU_RGD8_MPURGADDR13                  (*((volatile unsigned int*)(0x42A00448UL)))
#define bM4_MPU_RGD8_MPURGADDR14                  (*((volatile unsigned int*)(0x42A0044CUL)))
#define bM4_MPU_RGD8_MPURGADDR15                  (*((volatile unsigned int*)(0x42A00450UL)))
#define bM4_MPU_RGD8_MPURGADDR16                  (*((volatile unsigned int*)(0x42A00454UL)))
#define bM4_MPU_RGD8_MPURGADDR17                  (*((volatile unsigned int*)(0x42A00458UL)))
#define bM4_MPU_RGD8_MPURGADDR18                  (*((volatile unsigned int*)(0x42A0045CUL)))
#define bM4_MPU_RGD8_MPURGADDR19                  (*((volatile unsigned int*)(0x42A00460UL)))
#define bM4_MPU_RGD8_MPURGADDR20                  (*((volatile unsigned int*)(0x42A00464UL)))
#define bM4_MPU_RGD8_MPURGADDR21                  (*((volatile unsigned int*)(0x42A00468UL)))
#define bM4_MPU_RGD8_MPURGADDR22                  (*((volatile unsigned int*)(0x42A0046CUL)))
#define bM4_MPU_RGD8_MPURGADDR23                  (*((volatile unsigned int*)(0x42A00470UL)))
#define bM4_MPU_RGD8_MPURGADDR24                  (*((volatile unsigned int*)(0x42A00474UL)))
#define bM4_MPU_RGD8_MPURGADDR25                  (*((volatile unsigned int*)(0x42A00478UL)))
#define bM4_MPU_RGD8_MPURGADDR26                  (*((volatile unsigned int*)(0x42A0047CUL)))
#define bM4_MPU_RGD9_MPURGSIZE0                   (*((volatile unsigned int*)(0x42A00480UL)))
#define bM4_MPU_RGD9_MPURGSIZE1                   (*((volatile unsigned int*)(0x42A00484UL)))
#define bM4_MPU_RGD9_MPURGSIZE2                   (*((volatile unsigned int*)(0x42A00488UL)))
#define bM4_MPU_RGD9_MPURGSIZE3                   (*((volatile unsigned int*)(0x42A0048CUL)))
#define bM4_MPU_RGD9_MPURGSIZE4                   (*((volatile unsigned int*)(0x42A00490UL)))
#define bM4_MPU_RGD9_MPURGADDR0                   (*((volatile unsigned int*)(0x42A00494UL)))
#define bM4_MPU_RGD9_MPURGADDR1                   (*((volatile unsigned int*)(0x42A00498UL)))
#define bM4_MPU_RGD9_MPURGADDR2                   (*((volatile unsigned int*)(0x42A0049CUL)))
#define bM4_MPU_RGD9_MPURGADDR3                   (*((volatile unsigned int*)(0x42A004A0UL)))
#define bM4_MPU_RGD9_MPURGADDR4                   (*((volatile unsigned int*)(0x42A004A4UL)))
#define bM4_MPU_RGD9_MPURGADDR5                   (*((volatile unsigned int*)(0x42A004A8UL)))
#define bM4_MPU_RGD9_MPURGADDR6                   (*((volatile unsigned int*)(0x42A004ACUL)))
#define bM4_MPU_RGD9_MPURGADDR7                   (*((volatile unsigned int*)(0x42A004B0UL)))
#define bM4_MPU_RGD9_MPURGADDR8                   (*((volatile unsigned int*)(0x42A004B4UL)))
#define bM4_MPU_RGD9_MPURGADDR9                   (*((volatile unsigned int*)(0x42A004B8UL)))
#define bM4_MPU_RGD9_MPURGADDR10                  (*((volatile unsigned int*)(0x42A004BCUL)))
#define bM4_MPU_RGD9_MPURGADDR11                  (*((volatile unsigned int*)(0x42A004C0UL)))
#define bM4_MPU_RGD9_MPURGADDR12                  (*((volatile unsigned int*)(0x42A004C4UL)))
#define bM4_MPU_RGD9_MPURGADDR13                  (*((volatile unsigned int*)(0x42A004C8UL)))
#define bM4_MPU_RGD9_MPURGADDR14                  (*((volatile unsigned int*)(0x42A004CCUL)))
#define bM4_MPU_RGD9_MPURGADDR15                  (*((volatile unsigned int*)(0x42A004D0UL)))
#define bM4_MPU_RGD9_MPURGADDR16                  (*((volatile unsigned int*)(0x42A004D4UL)))
#define bM4_MPU_RGD9_MPURGADDR17                  (*((volatile unsigned int*)(0x42A004D8UL)))
#define bM4_MPU_RGD9_MPURGADDR18                  (*((volatile unsigned int*)(0x42A004DCUL)))
#define bM4_MPU_RGD9_MPURGADDR19                  (*((volatile unsigned int*)(0x42A004E0UL)))
#define bM4_MPU_RGD9_MPURGADDR20                  (*((volatile unsigned int*)(0x42A004E4UL)))
#define bM4_MPU_RGD9_MPURGADDR21                  (*((volatile unsigned int*)(0x42A004E8UL)))
#define bM4_MPU_RGD9_MPURGADDR22                  (*((volatile unsigned int*)(0x42A004ECUL)))
#define bM4_MPU_RGD9_MPURGADDR23                  (*((volatile unsigned int*)(0x42A004F0UL)))
#define bM4_MPU_RGD9_MPURGADDR24                  (*((volatile unsigned int*)(0x42A004F4UL)))
#define bM4_MPU_RGD9_MPURGADDR25                  (*((volatile unsigned int*)(0x42A004F8UL)))
#define bM4_MPU_RGD9_MPURGADDR26                  (*((volatile unsigned int*)(0x42A004FCUL)))
#define bM4_MPU_RGD10_MPURGSIZE0                  (*((volatile unsigned int*)(0x42A00500UL)))
#define bM4_MPU_RGD10_MPURGSIZE1                  (*((volatile unsigned int*)(0x42A00504UL)))
#define bM4_MPU_RGD10_MPURGSIZE2                  (*((volatile unsigned int*)(0x42A00508UL)))
#define bM4_MPU_RGD10_MPURGSIZE3                  (*((volatile unsigned int*)(0x42A0050CUL)))
#define bM4_MPU_RGD10_MPURGSIZE4                  (*((volatile unsigned int*)(0x42A00510UL)))
#define bM4_MPU_RGD10_MPURGADDR0                  (*((volatile unsigned int*)(0x42A00514UL)))
#define bM4_MPU_RGD10_MPURGADDR1                  (*((volatile unsigned int*)(0x42A00518UL)))
#define bM4_MPU_RGD10_MPURGADDR2                  (*((volatile unsigned int*)(0x42A0051CUL)))
#define bM4_MPU_RGD10_MPURGADDR3                  (*((volatile unsigned int*)(0x42A00520UL)))
#define bM4_MPU_RGD10_MPURGADDR4                  (*((volatile unsigned int*)(0x42A00524UL)))
#define bM4_MPU_RGD10_MPURGADDR5                  (*((volatile unsigned int*)(0x42A00528UL)))
#define bM4_MPU_RGD10_MPURGADDR6                  (*((volatile unsigned int*)(0x42A0052CUL)))
#define bM4_MPU_RGD10_MPURGADDR7                  (*((volatile unsigned int*)(0x42A00530UL)))
#define bM4_MPU_RGD10_MPURGADDR8                  (*((volatile unsigned int*)(0x42A00534UL)))
#define bM4_MPU_RGD10_MPURGADDR9                  (*((volatile unsigned int*)(0x42A00538UL)))
#define bM4_MPU_RGD10_MPURGADDR10                 (*((volatile unsigned int*)(0x42A0053CUL)))
#define bM4_MPU_RGD10_MPURGADDR11                 (*((volatile unsigned int*)(0x42A00540UL)))
#define bM4_MPU_RGD10_MPURGADDR12                 (*((volatile unsigned int*)(0x42A00544UL)))
#define bM4_MPU_RGD10_MPURGADDR13                 (*((volatile unsigned int*)(0x42A00548UL)))
#define bM4_MPU_RGD10_MPURGADDR14                 (*((volatile unsigned int*)(0x42A0054CUL)))
#define bM4_MPU_RGD10_MPURGADDR15                 (*((volatile unsigned int*)(0x42A00550UL)))
#define bM4_MPU_RGD10_MPURGADDR16                 (*((volatile unsigned int*)(0x42A00554UL)))
#define bM4_MPU_RGD10_MPURGADDR17                 (*((volatile unsigned int*)(0x42A00558UL)))
#define bM4_MPU_RGD10_MPURGADDR18                 (*((volatile unsigned int*)(0x42A0055CUL)))
#define bM4_MPU_RGD10_MPURGADDR19                 (*((volatile unsigned int*)(0x42A00560UL)))
#define bM4_MPU_RGD10_MPURGADDR20                 (*((volatile unsigned int*)(0x42A00564UL)))
#define bM4_MPU_RGD10_MPURGADDR21                 (*((volatile unsigned int*)(0x42A00568UL)))
#define bM4_MPU_RGD10_MPURGADDR22                 (*((volatile unsigned int*)(0x42A0056CUL)))
#define bM4_MPU_RGD10_MPURGADDR23                 (*((volatile unsigned int*)(0x42A00570UL)))
#define bM4_MPU_RGD10_MPURGADDR24                 (*((volatile unsigned int*)(0x42A00574UL)))
#define bM4_MPU_RGD10_MPURGADDR25                 (*((volatile unsigned int*)(0x42A00578UL)))
#define bM4_MPU_RGD10_MPURGADDR26                 (*((volatile unsigned int*)(0x42A0057CUL)))
#define bM4_MPU_RGD11_MPURGSIZE0                  (*((volatile unsigned int*)(0x42A00580UL)))
#define bM4_MPU_RGD11_MPURGSIZE1                  (*((volatile unsigned int*)(0x42A00584UL)))
#define bM4_MPU_RGD11_MPURGSIZE2                  (*((volatile unsigned int*)(0x42A00588UL)))
#define bM4_MPU_RGD11_MPURGSIZE3                  (*((volatile unsigned int*)(0x42A0058CUL)))
#define bM4_MPU_RGD11_MPURGSIZE4                  (*((volatile unsigned int*)(0x42A00590UL)))
#define bM4_MPU_RGD11_MPURGADDR0                  (*((volatile unsigned int*)(0x42A00594UL)))
#define bM4_MPU_RGD11_MPURGADDR1                  (*((volatile unsigned int*)(0x42A00598UL)))
#define bM4_MPU_RGD11_MPURGADDR2                  (*((volatile unsigned int*)(0x42A0059CUL)))
#define bM4_MPU_RGD11_MPURGADDR3                  (*((volatile unsigned int*)(0x42A005A0UL)))
#define bM4_MPU_RGD11_MPURGADDR4                  (*((volatile unsigned int*)(0x42A005A4UL)))
#define bM4_MPU_RGD11_MPURGADDR5                  (*((volatile unsigned int*)(0x42A005A8UL)))
#define bM4_MPU_RGD11_MPURGADDR6                  (*((volatile unsigned int*)(0x42A005ACUL)))
#define bM4_MPU_RGD11_MPURGADDR7                  (*((volatile unsigned int*)(0x42A005B0UL)))
#define bM4_MPU_RGD11_MPURGADDR8                  (*((volatile unsigned int*)(0x42A005B4UL)))
#define bM4_MPU_RGD11_MPURGADDR9                  (*((volatile unsigned int*)(0x42A005B8UL)))
#define bM4_MPU_RGD11_MPURGADDR10                 (*((volatile unsigned int*)(0x42A005BCUL)))
#define bM4_MPU_RGD11_MPURGADDR11                 (*((volatile unsigned int*)(0x42A005C0UL)))
#define bM4_MPU_RGD11_MPURGADDR12                 (*((volatile unsigned int*)(0x42A005C4UL)))
#define bM4_MPU_RGD11_MPURGADDR13                 (*((volatile unsigned int*)(0x42A005C8UL)))
#define bM4_MPU_RGD11_MPURGADDR14                 (*((volatile unsigned int*)(0x42A005CCUL)))
#define bM4_MPU_RGD11_MPURGADDR15                 (*((volatile unsigned int*)(0x42A005D0UL)))
#define bM4_MPU_RGD11_MPURGADDR16                 (*((volatile unsigned int*)(0x42A005D4UL)))
#define bM4_MPU_RGD11_MPURGADDR17                 (*((volatile unsigned int*)(0x42A005D8UL)))
#define bM4_MPU_RGD11_MPURGADDR18                 (*((volatile unsigned int*)(0x42A005DCUL)))
#define bM4_MPU_RGD11_MPURGADDR19                 (*((volatile unsigned int*)(0x42A005E0UL)))
#define bM4_MPU_RGD11_MPURGADDR20                 (*((volatile unsigned int*)(0x42A005E4UL)))
#define bM4_MPU_RGD11_MPURGADDR21                 (*((volatile unsigned int*)(0x42A005E8UL)))
#define bM4_MPU_RGD11_MPURGADDR22                 (*((volatile unsigned int*)(0x42A005ECUL)))
#define bM4_MPU_RGD11_MPURGADDR23                 (*((volatile unsigned int*)(0x42A005F0UL)))
#define bM4_MPU_RGD11_MPURGADDR24                 (*((volatile unsigned int*)(0x42A005F4UL)))
#define bM4_MPU_RGD11_MPURGADDR25                 (*((volatile unsigned int*)(0x42A005F8UL)))
#define bM4_MPU_RGD11_MPURGADDR26                 (*((volatile unsigned int*)(0x42A005FCUL)))
#define bM4_MPU_RGD12_MPURGSIZE0                  (*((volatile unsigned int*)(0x42A00600UL)))
#define bM4_MPU_RGD12_MPURGSIZE1                  (*((volatile unsigned int*)(0x42A00604UL)))
#define bM4_MPU_RGD12_MPURGSIZE2                  (*((volatile unsigned int*)(0x42A00608UL)))
#define bM4_MPU_RGD12_MPURGSIZE3                  (*((volatile unsigned int*)(0x42A0060CUL)))
#define bM4_MPU_RGD12_MPURGSIZE4                  (*((volatile unsigned int*)(0x42A00610UL)))
#define bM4_MPU_RGD12_MPURGADDR0                  (*((volatile unsigned int*)(0x42A00614UL)))
#define bM4_MPU_RGD12_MPURGADDR1                  (*((volatile unsigned int*)(0x42A00618UL)))
#define bM4_MPU_RGD12_MPURGADDR2                  (*((volatile unsigned int*)(0x42A0061CUL)))
#define bM4_MPU_RGD12_MPURGADDR3                  (*((volatile unsigned int*)(0x42A00620UL)))
#define bM4_MPU_RGD12_MPURGADDR4                  (*((volatile unsigned int*)(0x42A00624UL)))
#define bM4_MPU_RGD12_MPURGADDR5                  (*((volatile unsigned int*)(0x42A00628UL)))
#define bM4_MPU_RGD12_MPURGADDR6                  (*((volatile unsigned int*)(0x42A0062CUL)))
#define bM4_MPU_RGD12_MPURGADDR7                  (*((volatile unsigned int*)(0x42A00630UL)))
#define bM4_MPU_RGD12_MPURGADDR8                  (*((volatile unsigned int*)(0x42A00634UL)))
#define bM4_MPU_RGD12_MPURGADDR9                  (*((volatile unsigned int*)(0x42A00638UL)))
#define bM4_MPU_RGD12_MPURGADDR10                 (*((volatile unsigned int*)(0x42A0063CUL)))
#define bM4_MPU_RGD12_MPURGADDR11                 (*((volatile unsigned int*)(0x42A00640UL)))
#define bM4_MPU_RGD12_MPURGADDR12                 (*((volatile unsigned int*)(0x42A00644UL)))
#define bM4_MPU_RGD12_MPURGADDR13                 (*((volatile unsigned int*)(0x42A00648UL)))
#define bM4_MPU_RGD12_MPURGADDR14                 (*((volatile unsigned int*)(0x42A0064CUL)))
#define bM4_MPU_RGD12_MPURGADDR15                 (*((volatile unsigned int*)(0x42A00650UL)))
#define bM4_MPU_RGD12_MPURGADDR16                 (*((volatile unsigned int*)(0x42A00654UL)))
#define bM4_MPU_RGD12_MPURGADDR17                 (*((volatile unsigned int*)(0x42A00658UL)))
#define bM4_MPU_RGD12_MPURGADDR18                 (*((volatile unsigned int*)(0x42A0065CUL)))
#define bM4_MPU_RGD12_MPURGADDR19                 (*((volatile unsigned int*)(0x42A00660UL)))
#define bM4_MPU_RGD12_MPURGADDR20                 (*((volatile unsigned int*)(0x42A00664UL)))
#define bM4_MPU_RGD12_MPURGADDR21                 (*((volatile unsigned int*)(0x42A00668UL)))
#define bM4_MPU_RGD12_MPURGADDR22                 (*((volatile unsigned int*)(0x42A0066CUL)))
#define bM4_MPU_RGD12_MPURGADDR23                 (*((volatile unsigned int*)(0x42A00670UL)))
#define bM4_MPU_RGD12_MPURGADDR24                 (*((volatile unsigned int*)(0x42A00674UL)))
#define bM4_MPU_RGD12_MPURGADDR25                 (*((volatile unsigned int*)(0x42A00678UL)))
#define bM4_MPU_RGD12_MPURGADDR26                 (*((volatile unsigned int*)(0x42A0067CUL)))
#define bM4_MPU_RGD13_MPURGSIZE0                  (*((volatile unsigned int*)(0x42A00680UL)))
#define bM4_MPU_RGD13_MPURGSIZE1                  (*((volatile unsigned int*)(0x42A00684UL)))
#define bM4_MPU_RGD13_MPURGSIZE2                  (*((volatile unsigned int*)(0x42A00688UL)))
#define bM4_MPU_RGD13_MPURGSIZE3                  (*((volatile unsigned int*)(0x42A0068CUL)))
#define bM4_MPU_RGD13_MPURGSIZE4                  (*((volatile unsigned int*)(0x42A00690UL)))
#define bM4_MPU_RGD13_MPURGADDR0                  (*((volatile unsigned int*)(0x42A00694UL)))
#define bM4_MPU_RGD13_MPURGADDR1                  (*((volatile unsigned int*)(0x42A00698UL)))
#define bM4_MPU_RGD13_MPURGADDR2                  (*((volatile unsigned int*)(0x42A0069CUL)))
#define bM4_MPU_RGD13_MPURGADDR3                  (*((volatile unsigned int*)(0x42A006A0UL)))
#define bM4_MPU_RGD13_MPURGADDR4                  (*((volatile unsigned int*)(0x42A006A4UL)))
#define bM4_MPU_RGD13_MPURGADDR5                  (*((volatile unsigned int*)(0x42A006A8UL)))
#define bM4_MPU_RGD13_MPURGADDR6                  (*((volatile unsigned int*)(0x42A006ACUL)))
#define bM4_MPU_RGD13_MPURGADDR7                  (*((volatile unsigned int*)(0x42A006B0UL)))
#define bM4_MPU_RGD13_MPURGADDR8                  (*((volatile unsigned int*)(0x42A006B4UL)))
#define bM4_MPU_RGD13_MPURGADDR9                  (*((volatile unsigned int*)(0x42A006B8UL)))
#define bM4_MPU_RGD13_MPURGADDR10                 (*((volatile unsigned int*)(0x42A006BCUL)))
#define bM4_MPU_RGD13_MPURGADDR11                 (*((volatile unsigned int*)(0x42A006C0UL)))
#define bM4_MPU_RGD13_MPURGADDR12                 (*((volatile unsigned int*)(0x42A006C4UL)))
#define bM4_MPU_RGD13_MPURGADDR13                 (*((volatile unsigned int*)(0x42A006C8UL)))
#define bM4_MPU_RGD13_MPURGADDR14                 (*((volatile unsigned int*)(0x42A006CCUL)))
#define bM4_MPU_RGD13_MPURGADDR15                 (*((volatile unsigned int*)(0x42A006D0UL)))
#define bM4_MPU_RGD13_MPURGADDR16                 (*((volatile unsigned int*)(0x42A006D4UL)))
#define bM4_MPU_RGD13_MPURGADDR17                 (*((volatile unsigned int*)(0x42A006D8UL)))
#define bM4_MPU_RGD13_MPURGADDR18                 (*((volatile unsigned int*)(0x42A006DCUL)))
#define bM4_MPU_RGD13_MPURGADDR19                 (*((volatile unsigned int*)(0x42A006E0UL)))
#define bM4_MPU_RGD13_MPURGADDR20                 (*((volatile unsigned int*)(0x42A006E4UL)))
#define bM4_MPU_RGD13_MPURGADDR21                 (*((volatile unsigned int*)(0x42A006E8UL)))
#define bM4_MPU_RGD13_MPURGADDR22                 (*((volatile unsigned int*)(0x42A006ECUL)))
#define bM4_MPU_RGD13_MPURGADDR23                 (*((volatile unsigned int*)(0x42A006F0UL)))
#define bM4_MPU_RGD13_MPURGADDR24                 (*((volatile unsigned int*)(0x42A006F4UL)))
#define bM4_MPU_RGD13_MPURGADDR25                 (*((volatile unsigned int*)(0x42A006F8UL)))
#define bM4_MPU_RGD13_MPURGADDR26                 (*((volatile unsigned int*)(0x42A006FCUL)))
#define bM4_MPU_RGD14_MPURGSIZE0                  (*((volatile unsigned int*)(0x42A00700UL)))
#define bM4_MPU_RGD14_MPURGSIZE1                  (*((volatile unsigned int*)(0x42A00704UL)))
#define bM4_MPU_RGD14_MPURGSIZE2                  (*((volatile unsigned int*)(0x42A00708UL)))
#define bM4_MPU_RGD14_MPURGSIZE3                  (*((volatile unsigned int*)(0x42A0070CUL)))
#define bM4_MPU_RGD14_MPURGSIZE4                  (*((volatile unsigned int*)(0x42A00710UL)))
#define bM4_MPU_RGD14_MPURGADDR0                  (*((volatile unsigned int*)(0x42A00714UL)))
#define bM4_MPU_RGD14_MPURGADDR1                  (*((volatile unsigned int*)(0x42A00718UL)))
#define bM4_MPU_RGD14_MPURGADDR2                  (*((volatile unsigned int*)(0x42A0071CUL)))
#define bM4_MPU_RGD14_MPURGADDR3                  (*((volatile unsigned int*)(0x42A00720UL)))
#define bM4_MPU_RGD14_MPURGADDR4                  (*((volatile unsigned int*)(0x42A00724UL)))
#define bM4_MPU_RGD14_MPURGADDR5                  (*((volatile unsigned int*)(0x42A00728UL)))
#define bM4_MPU_RGD14_MPURGADDR6                  (*((volatile unsigned int*)(0x42A0072CUL)))
#define bM4_MPU_RGD14_MPURGADDR7                  (*((volatile unsigned int*)(0x42A00730UL)))
#define bM4_MPU_RGD14_MPURGADDR8                  (*((volatile unsigned int*)(0x42A00734UL)))
#define bM4_MPU_RGD14_MPURGADDR9                  (*((volatile unsigned int*)(0x42A00738UL)))
#define bM4_MPU_RGD14_MPURGADDR10                 (*((volatile unsigned int*)(0x42A0073CUL)))
#define bM4_MPU_RGD14_MPURGADDR11                 (*((volatile unsigned int*)(0x42A00740UL)))
#define bM4_MPU_RGD14_MPURGADDR12                 (*((volatile unsigned int*)(0x42A00744UL)))
#define bM4_MPU_RGD14_MPURGADDR13                 (*((volatile unsigned int*)(0x42A00748UL)))
#define bM4_MPU_RGD14_MPURGADDR14                 (*((volatile unsigned int*)(0x42A0074CUL)))
#define bM4_MPU_RGD14_MPURGADDR15                 (*((volatile unsigned int*)(0x42A00750UL)))
#define bM4_MPU_RGD14_MPURGADDR16                 (*((volatile unsigned int*)(0x42A00754UL)))
#define bM4_MPU_RGD14_MPURGADDR17                 (*((volatile unsigned int*)(0x42A00758UL)))
#define bM4_MPU_RGD14_MPURGADDR18                 (*((volatile unsigned int*)(0x42A0075CUL)))
#define bM4_MPU_RGD14_MPURGADDR19                 (*((volatile unsigned int*)(0x42A00760UL)))
#define bM4_MPU_RGD14_MPURGADDR20                 (*((volatile unsigned int*)(0x42A00764UL)))
#define bM4_MPU_RGD14_MPURGADDR21                 (*((volatile unsigned int*)(0x42A00768UL)))
#define bM4_MPU_RGD14_MPURGADDR22                 (*((volatile unsigned int*)(0x42A0076CUL)))
#define bM4_MPU_RGD14_MPURGADDR23                 (*((volatile unsigned int*)(0x42A00770UL)))
#define bM4_MPU_RGD14_MPURGADDR24                 (*((volatile unsigned int*)(0x42A00774UL)))
#define bM4_MPU_RGD14_MPURGADDR25                 (*((volatile unsigned int*)(0x42A00778UL)))
#define bM4_MPU_RGD14_MPURGADDR26                 (*((volatile unsigned int*)(0x42A0077CUL)))
#define bM4_MPU_RGD15_MPURGSIZE0                  (*((volatile unsigned int*)(0x42A00780UL)))
#define bM4_MPU_RGD15_MPURGSIZE1                  (*((volatile unsigned int*)(0x42A00784UL)))
#define bM4_MPU_RGD15_MPURGSIZE2                  (*((volatile unsigned int*)(0x42A00788UL)))
#define bM4_MPU_RGD15_MPURGSIZE3                  (*((volatile unsigned int*)(0x42A0078CUL)))
#define bM4_MPU_RGD15_MPURGSIZE4                  (*((volatile unsigned int*)(0x42A00790UL)))
#define bM4_MPU_RGD15_MPURGADDR0                  (*((volatile unsigned int*)(0x42A00794UL)))
#define bM4_MPU_RGD15_MPURGADDR1                  (*((volatile unsigned int*)(0x42A00798UL)))
#define bM4_MPU_RGD15_MPURGADDR2                  (*((volatile unsigned int*)(0x42A0079CUL)))
#define bM4_MPU_RGD15_MPURGADDR3                  (*((volatile unsigned int*)(0x42A007A0UL)))
#define bM4_MPU_RGD15_MPURGADDR4                  (*((volatile unsigned int*)(0x42A007A4UL)))
#define bM4_MPU_RGD15_MPURGADDR5                  (*((volatile unsigned int*)(0x42A007A8UL)))
#define bM4_MPU_RGD15_MPURGADDR6                  (*((volatile unsigned int*)(0x42A007ACUL)))
#define bM4_MPU_RGD15_MPURGADDR7                  (*((volatile unsigned int*)(0x42A007B0UL)))
#define bM4_MPU_RGD15_MPURGADDR8                  (*((volatile unsigned int*)(0x42A007B4UL)))
#define bM4_MPU_RGD15_MPURGADDR9                  (*((volatile unsigned int*)(0x42A007B8UL)))
#define bM4_MPU_RGD15_MPURGADDR10                 (*((volatile unsigned int*)(0x42A007BCUL)))
#define bM4_MPU_RGD15_MPURGADDR11                 (*((volatile unsigned int*)(0x42A007C0UL)))
#define bM4_MPU_RGD15_MPURGADDR12                 (*((volatile unsigned int*)(0x42A007C4UL)))
#define bM4_MPU_RGD15_MPURGADDR13                 (*((volatile unsigned int*)(0x42A007C8UL)))
#define bM4_MPU_RGD15_MPURGADDR14                 (*((volatile unsigned int*)(0x42A007CCUL)))
#define bM4_MPU_RGD15_MPURGADDR15                 (*((volatile unsigned int*)(0x42A007D0UL)))
#define bM4_MPU_RGD15_MPURGADDR16                 (*((volatile unsigned int*)(0x42A007D4UL)))
#define bM4_MPU_RGD15_MPURGADDR17                 (*((volatile unsigned int*)(0x42A007D8UL)))
#define bM4_MPU_RGD15_MPURGADDR18                 (*((volatile unsigned int*)(0x42A007DCUL)))
#define bM4_MPU_RGD15_MPURGADDR19                 (*((volatile unsigned int*)(0x42A007E0UL)))
#define bM4_MPU_RGD15_MPURGADDR20                 (*((volatile unsigned int*)(0x42A007E4UL)))
#define bM4_MPU_RGD15_MPURGADDR21                 (*((volatile unsigned int*)(0x42A007E8UL)))
#define bM4_MPU_RGD15_MPURGADDR22                 (*((volatile unsigned int*)(0x42A007ECUL)))
#define bM4_MPU_RGD15_MPURGADDR23                 (*((volatile unsigned int*)(0x42A007F0UL)))
#define bM4_MPU_RGD15_MPURGADDR24                 (*((volatile unsigned int*)(0x42A007F4UL)))
#define bM4_MPU_RGD15_MPURGADDR25                 (*((volatile unsigned int*)(0x42A007F8UL)))
#define bM4_MPU_RGD15_MPURGADDR26                 (*((volatile unsigned int*)(0x42A007FCUL)))
#define bM4_MPU_RGCR0_S2RG0RP                     (*((volatile unsigned int*)(0x42A00800UL)))
#define bM4_MPU_RGCR0_S2RG0WP                     (*((volatile unsigned int*)(0x42A00804UL)))
#define bM4_MPU_RGCR0_S2RG0E                      (*((volatile unsigned int*)(0x42A0081CUL)))
#define bM4_MPU_RGCR0_S1RG0RP                     (*((volatile unsigned int*)(0x42A00820UL)))
#define bM4_MPU_RGCR0_S1RG0WP                     (*((volatile unsigned int*)(0x42A00824UL)))
#define bM4_MPU_RGCR0_S1RG0E                      (*((volatile unsigned int*)(0x42A0083CUL)))
#define bM4_MPU_RGCR0_FRG0RP                      (*((volatile unsigned int*)(0x42A00840UL)))
#define bM4_MPU_RGCR0_FRG0WP                      (*((volatile unsigned int*)(0x42A00844UL)))
#define bM4_MPU_RGCR0_FRG0E                       (*((volatile unsigned int*)(0x42A0085CUL)))
#define bM4_MPU_RGCR1_S2RG1RP                     (*((volatile unsigned int*)(0x42A00880UL)))
#define bM4_MPU_RGCR1_S2RG1WP                     (*((volatile unsigned int*)(0x42A00884UL)))
#define bM4_MPU_RGCR1_S2RG1E                      (*((volatile unsigned int*)(0x42A0089CUL)))
#define bM4_MPU_RGCR1_S1RG1RP                     (*((volatile unsigned int*)(0x42A008A0UL)))
#define bM4_MPU_RGCR1_S1RG1WP                     (*((volatile unsigned int*)(0x42A008A4UL)))
#define bM4_MPU_RGCR1_S1RG1E                      (*((volatile unsigned int*)(0x42A008BCUL)))
#define bM4_MPU_RGCR1_FRG1RP                      (*((volatile unsigned int*)(0x42A008C0UL)))
#define bM4_MPU_RGCR1_FRG1WP                      (*((volatile unsigned int*)(0x42A008C4UL)))
#define bM4_MPU_RGCR1_FRG1E                       (*((volatile unsigned int*)(0x42A008DCUL)))
#define bM4_MPU_RGCR2_S2RG2RP                     (*((volatile unsigned int*)(0x42A00900UL)))
#define bM4_MPU_RGCR2_S2RG2WP                     (*((volatile unsigned int*)(0x42A00904UL)))
#define bM4_MPU_RGCR2_S2RG2E                      (*((volatile unsigned int*)(0x42A0091CUL)))
#define bM4_MPU_RGCR2_S1RG2RP                     (*((volatile unsigned int*)(0x42A00920UL)))
#define bM4_MPU_RGCR2_S1RG2WP                     (*((volatile unsigned int*)(0x42A00924UL)))
#define bM4_MPU_RGCR2_S1RG2E                      (*((volatile unsigned int*)(0x42A0093CUL)))
#define bM4_MPU_RGCR2_FRG2RP                      (*((volatile unsigned int*)(0x42A00940UL)))
#define bM4_MPU_RGCR2_FRG2WP                      (*((volatile unsigned int*)(0x42A00944UL)))
#define bM4_MPU_RGCR2_FRG2E                       (*((volatile unsigned int*)(0x42A0095CUL)))
#define bM4_MPU_RGCR3_S2RG3RP                     (*((volatile unsigned int*)(0x42A00980UL)))
#define bM4_MPU_RGCR3_S2RG3WP                     (*((volatile unsigned int*)(0x42A00984UL)))
#define bM4_MPU_RGCR3_S2RG3E                      (*((volatile unsigned int*)(0x42A0099CUL)))
#define bM4_MPU_RGCR3_S1RG3RP                     (*((volatile unsigned int*)(0x42A009A0UL)))
#define bM4_MPU_RGCR3_S1RG3WP                     (*((volatile unsigned int*)(0x42A009A4UL)))
#define bM4_MPU_RGCR3_S1RG3E                      (*((volatile unsigned int*)(0x42A009BCUL)))
#define bM4_MPU_RGCR3_FRG3RP                      (*((volatile unsigned int*)(0x42A009C0UL)))
#define bM4_MPU_RGCR3_FRG3WP                      (*((volatile unsigned int*)(0x42A009C4UL)))
#define bM4_MPU_RGCR3_FRG3E                       (*((volatile unsigned int*)(0x42A009DCUL)))
#define bM4_MPU_RGCR4_S2RG4RP                     (*((volatile unsigned int*)(0x42A00A00UL)))
#define bM4_MPU_RGCR4_S2RG4WP                     (*((volatile unsigned int*)(0x42A00A04UL)))
#define bM4_MPU_RGCR4_S2RG4E                      (*((volatile unsigned int*)(0x42A00A1CUL)))
#define bM4_MPU_RGCR4_S1RG4RP                     (*((volatile unsigned int*)(0x42A00A20UL)))
#define bM4_MPU_RGCR4_S1RG4WP                     (*((volatile unsigned int*)(0x42A00A24UL)))
#define bM4_MPU_RGCR4_S1RG4E                      (*((volatile unsigned int*)(0x42A00A3CUL)))
#define bM4_MPU_RGCR4_FRG4RP                      (*((volatile unsigned int*)(0x42A00A40UL)))
#define bM4_MPU_RGCR4_FRG4WP                      (*((volatile unsigned int*)(0x42A00A44UL)))
#define bM4_MPU_RGCR4_FRG4E                       (*((volatile unsigned int*)(0x42A00A5CUL)))
#define bM4_MPU_RGCR5_S2RG5RP                     (*((volatile unsigned int*)(0x42A00A80UL)))
#define bM4_MPU_RGCR5_S2RG5WP                     (*((volatile unsigned int*)(0x42A00A84UL)))
#define bM4_MPU_RGCR5_S2RG5E                      (*((volatile unsigned int*)(0x42A00A9CUL)))
#define bM4_MPU_RGCR5_S1RG5RP                     (*((volatile unsigned int*)(0x42A00AA0UL)))
#define bM4_MPU_RGCR5_S1RG5WP                     (*((volatile unsigned int*)(0x42A00AA4UL)))
#define bM4_MPU_RGCR5_S1RG5E                      (*((volatile unsigned int*)(0x42A00ABCUL)))
#define bM4_MPU_RGCR5_FRG5RP                      (*((volatile unsigned int*)(0x42A00AC0UL)))
#define bM4_MPU_RGCR5_FRG5WP                      (*((volatile unsigned int*)(0x42A00AC4UL)))
#define bM4_MPU_RGCR5_FRG5E                       (*((volatile unsigned int*)(0x42A00ADCUL)))
#define bM4_MPU_RGCR6_S2RG6RP                     (*((volatile unsigned int*)(0x42A00B00UL)))
#define bM4_MPU_RGCR6_S2RG6WP                     (*((volatile unsigned int*)(0x42A00B04UL)))
#define bM4_MPU_RGCR6_S2RG6E                      (*((volatile unsigned int*)(0x42A00B1CUL)))
#define bM4_MPU_RGCR6_S1RG6RP                     (*((volatile unsigned int*)(0x42A00B20UL)))
#define bM4_MPU_RGCR6_S1RG6WP                     (*((volatile unsigned int*)(0x42A00B24UL)))
#define bM4_MPU_RGCR6_S1RG6E                      (*((volatile unsigned int*)(0x42A00B3CUL)))
#define bM4_MPU_RGCR6_FRG6RP                      (*((volatile unsigned int*)(0x42A00B40UL)))
#define bM4_MPU_RGCR6_FRG6WP                      (*((volatile unsigned int*)(0x42A00B44UL)))
#define bM4_MPU_RGCR6_FRG6E                       (*((volatile unsigned int*)(0x42A00B5CUL)))
#define bM4_MPU_RGCR7_S2RG7RP                     (*((volatile unsigned int*)(0x42A00B80UL)))
#define bM4_MPU_RGCR7_S2RG7WP                     (*((volatile unsigned int*)(0x42A00B84UL)))
#define bM4_MPU_RGCR7_S2RG7E                      (*((volatile unsigned int*)(0x42A00B9CUL)))
#define bM4_MPU_RGCR7_S1RG7RP                     (*((volatile unsigned int*)(0x42A00BA0UL)))
#define bM4_MPU_RGCR7_S1RG7WP                     (*((volatile unsigned int*)(0x42A00BA4UL)))
#define bM4_MPU_RGCR7_S1RG7E                      (*((volatile unsigned int*)(0x42A00BBCUL)))
#define bM4_MPU_RGCR7_FRG7RP                      (*((volatile unsigned int*)(0x42A00BC0UL)))
#define bM4_MPU_RGCR7_FRG7WP                      (*((volatile unsigned int*)(0x42A00BC4UL)))
#define bM4_MPU_RGCR7_FRG7E                       (*((volatile unsigned int*)(0x42A00BDCUL)))
#define bM4_MPU_RGCR8_S2RG8RP                     (*((volatile unsigned int*)(0x42A00C00UL)))
#define bM4_MPU_RGCR8_S2RG8WP                     (*((volatile unsigned int*)(0x42A00C04UL)))
#define bM4_MPU_RGCR8_S2RG8E                      (*((volatile unsigned int*)(0x42A00C1CUL)))
#define bM4_MPU_RGCR8_S1RG8RP                     (*((volatile unsigned int*)(0x42A00C20UL)))
#define bM4_MPU_RGCR8_S1RG8WP                     (*((volatile unsigned int*)(0x42A00C24UL)))
#define bM4_MPU_RGCR8_S1RG8E                      (*((volatile unsigned int*)(0x42A00C3CUL)))
#define bM4_MPU_RGCR9_S2RG9RP                     (*((volatile unsigned int*)(0x42A00C80UL)))
#define bM4_MPU_RGCR9_S2RG9WP                     (*((volatile unsigned int*)(0x42A00C84UL)))
#define bM4_MPU_RGCR9_S2RG9E                      (*((volatile unsigned int*)(0x42A00C9CUL)))
#define bM4_MPU_RGCR9_S1RG9RP                     (*((volatile unsigned int*)(0x42A00CA0UL)))
#define bM4_MPU_RGCR9_S1RG9WP                     (*((volatile unsigned int*)(0x42A00CA4UL)))
#define bM4_MPU_RGCR9_S1RG9E                      (*((volatile unsigned int*)(0x42A00CBCUL)))
#define bM4_MPU_RGCR10_S2RG10RP                   (*((volatile unsigned int*)(0x42A00D00UL)))
#define bM4_MPU_RGCR10_S2RG10WP                   (*((volatile unsigned int*)(0x42A00D04UL)))
#define bM4_MPU_RGCR10_S2RG10E                    (*((volatile unsigned int*)(0x42A00D1CUL)))
#define bM4_MPU_RGCR10_S1RG10RP                   (*((volatile unsigned int*)(0x42A00D20UL)))
#define bM4_MPU_RGCR10_S1RG10WP                   (*((volatile unsigned int*)(0x42A00D24UL)))
#define bM4_MPU_RGCR10_S1RG10E                    (*((volatile unsigned int*)(0x42A00D3CUL)))
#define bM4_MPU_RGCR11_S2RG11RP                   (*((volatile unsigned int*)(0x42A00D80UL)))
#define bM4_MPU_RGCR11_S2RG11WP                   (*((volatile unsigned int*)(0x42A00D84UL)))
#define bM4_MPU_RGCR11_S2RG11E                    (*((volatile unsigned int*)(0x42A00D9CUL)))
#define bM4_MPU_RGCR11_S1RG11RP                   (*((volatile unsigned int*)(0x42A00DA0UL)))
#define bM4_MPU_RGCR11_S1RG11WP                   (*((volatile unsigned int*)(0x42A00DA4UL)))
#define bM4_MPU_RGCR11_S1RG11E                    (*((volatile unsigned int*)(0x42A00DBCUL)))
#define bM4_MPU_RGCR12_S2RG12RP                   (*((volatile unsigned int*)(0x42A00E00UL)))
#define bM4_MPU_RGCR12_S2RG12WP                   (*((volatile unsigned int*)(0x42A00E04UL)))
#define bM4_MPU_RGCR12_S2RG12E                    (*((volatile unsigned int*)(0x42A00E1CUL)))
#define bM4_MPU_RGCR12_S1RG12RP                   (*((volatile unsigned int*)(0x42A00E20UL)))
#define bM4_MPU_RGCR12_S1RG12WP                   (*((volatile unsigned int*)(0x42A00E24UL)))
#define bM4_MPU_RGCR12_S1RG12E                    (*((volatile unsigned int*)(0x42A00E3CUL)))
#define bM4_MPU_RGCR13_S2RG13RP                   (*((volatile unsigned int*)(0x42A00E80UL)))
#define bM4_MPU_RGCR13_S2RG13WP                   (*((volatile unsigned int*)(0x42A00E84UL)))
#define bM4_MPU_RGCR13_S2RG13E                    (*((volatile unsigned int*)(0x42A00E9CUL)))
#define bM4_MPU_RGCR13_S1RG13RP                   (*((volatile unsigned int*)(0x42A00EA0UL)))
#define bM4_MPU_RGCR13_S1RG13WP                   (*((volatile unsigned int*)(0x42A00EA4UL)))
#define bM4_MPU_RGCR13_S1RG13E                    (*((volatile unsigned int*)(0x42A00EBCUL)))
#define bM4_MPU_RGCR14_S2RG14RP                   (*((volatile unsigned int*)(0x42A00F00UL)))
#define bM4_MPU_RGCR14_S2RG14WP                   (*((volatile unsigned int*)(0x42A00F04UL)))
#define bM4_MPU_RGCR14_S2RG14E                    (*((volatile unsigned int*)(0x42A00F1CUL)))
#define bM4_MPU_RGCR14_S1RG14RP                   (*((volatile unsigned int*)(0x42A00F20UL)))
#define bM4_MPU_RGCR14_S1RG14WP                   (*((volatile unsigned int*)(0x42A00F24UL)))
#define bM4_MPU_RGCR14_S1RG14E                    (*((volatile unsigned int*)(0x42A00F3CUL)))
#define bM4_MPU_RGCR15_S2RG15RP                   (*((volatile unsigned int*)(0x42A00F80UL)))
#define bM4_MPU_RGCR15_S2RG15WP                   (*((volatile unsigned int*)(0x42A00F84UL)))
#define bM4_MPU_RGCR15_S2RG15E                    (*((volatile unsigned int*)(0x42A00F9CUL)))
#define bM4_MPU_RGCR15_S1RG15RP                   (*((volatile unsigned int*)(0x42A00FA0UL)))
#define bM4_MPU_RGCR15_S1RG15WP                   (*((volatile unsigned int*)(0x42A00FA4UL)))
#define bM4_MPU_RGCR15_S1RG15E                    (*((volatile unsigned int*)(0x42A00FBCUL)))
#define bM4_MPU_CR_SMPU2BRP                       (*((volatile unsigned int*)(0x42A01000UL)))
#define bM4_MPU_CR_SMPU2BWP                       (*((volatile unsigned int*)(0x42A01004UL)))
#define bM4_MPU_CR_SMPU2ACT0                      (*((volatile unsigned int*)(0x42A01008UL)))
#define bM4_MPU_CR_SMPU2ACT1                      (*((volatile unsigned int*)(0x42A0100CUL)))
#define bM4_MPU_CR_SMPU2E                         (*((volatile unsigned int*)(0x42A0101CUL)))
#define bM4_MPU_CR_SMPU1BRP                       (*((volatile unsigned int*)(0x42A01020UL)))
#define bM4_MPU_CR_SMPU1BWP                       (*((volatile unsigned int*)(0x42A01024UL)))
#define bM4_MPU_CR_SMPU1ACT0                      (*((volatile unsigned int*)(0x42A01028UL)))
#define bM4_MPU_CR_SMPU1ACT1                      (*((volatile unsigned int*)(0x42A0102CUL)))
#define bM4_MPU_CR_SMPU1E                         (*((volatile unsigned int*)(0x42A0103CUL)))
#define bM4_MPU_CR_FMPUBRP                        (*((volatile unsigned int*)(0x42A01040UL)))
#define bM4_MPU_CR_FMPUBWP                        (*((volatile unsigned int*)(0x42A01044UL)))
#define bM4_MPU_CR_FMPUACT0                       (*((volatile unsigned int*)(0x42A01048UL)))
#define bM4_MPU_CR_FMPUACT1                       (*((volatile unsigned int*)(0x42A0104CUL)))
#define bM4_MPU_CR_FMPUE                          (*((volatile unsigned int*)(0x42A0105CUL)))
#define bM4_MPU_SR_SMPU2EAF                       (*((volatile unsigned int*)(0x42A01080UL)))
#define bM4_MPU_SR_SMPU1EAF                       (*((volatile unsigned int*)(0x42A010A0UL)))
#define bM4_MPU_SR_FMPUEAF                        (*((volatile unsigned int*)(0x42A010C0UL)))
#define bM4_MPU_ECLR_SMPU2ECLR                    (*((volatile unsigned int*)(0x42A01100UL)))
#define bM4_MPU_ECLR_SMPU1ECLR                    (*((volatile unsigned int*)(0x42A01120UL)))
#define bM4_MPU_ECLR_FMPUECLR                     (*((volatile unsigned int*)(0x42A01140UL)))
#define bM4_MPU_WP_MPUWE                          (*((volatile unsigned int*)(0x42A01180UL)))
#define bM4_MPU_WP_WKEY0                          (*((volatile unsigned int*)(0x42A01184UL)))
#define bM4_MPU_WP_WKEY1                          (*((volatile unsigned int*)(0x42A01188UL)))
#define bM4_MPU_WP_WKEY2                          (*((volatile unsigned int*)(0x42A0118CUL)))
#define bM4_MPU_WP_WKEY3                          (*((volatile unsigned int*)(0x42A01190UL)))
#define bM4_MPU_WP_WKEY4                          (*((volatile unsigned int*)(0x42A01194UL)))
#define bM4_MPU_WP_WKEY5                          (*((volatile unsigned int*)(0x42A01198UL)))
#define bM4_MPU_WP_WKEY6                          (*((volatile unsigned int*)(0x42A0119CUL)))
#define bM4_MPU_WP_WKEY7                          (*((volatile unsigned int*)(0x42A011A0UL)))
#define bM4_MPU_WP_WKEY8                          (*((volatile unsigned int*)(0x42A011A4UL)))
#define bM4_MPU_WP_WKEY9                          (*((volatile unsigned int*)(0x42A011A8UL)))
#define bM4_MPU_WP_WKEY10                         (*((volatile unsigned int*)(0x42A011ACUL)))
#define bM4_MPU_WP_WKEY11                         (*((volatile unsigned int*)(0x42A011B0UL)))
#define bM4_MPU_WP_WKEY12                         (*((volatile unsigned int*)(0x42A011B4UL)))
#define bM4_MPU_WP_WKEY13                         (*((volatile unsigned int*)(0x42A011B8UL)))
#define bM4_MPU_WP_WKEY14                         (*((volatile unsigned int*)(0x42A011BCUL)))
#define bM4_MSTP_FCG0_SRAMH                       (*((volatile unsigned int*)(0x42900000UL)))
#define bM4_MSTP_FCG0_SRAM12                      (*((volatile unsigned int*)(0x42900010UL)))
#define bM4_MSTP_FCG0_SRAM3                       (*((volatile unsigned int*)(0x42900020UL)))
#define bM4_MSTP_FCG0_SRAMRET                     (*((volatile unsigned int*)(0x42900028UL)))
#define bM4_MSTP_FCG0_DMA1                        (*((volatile unsigned int*)(0x42900038UL)))
#define bM4_MSTP_FCG0_DMA2                        (*((volatile unsigned int*)(0x4290003CUL)))
#define bM4_MSTP_FCG0_FCM                         (*((volatile unsigned int*)(0x42900040UL)))
#define bM4_MSTP_FCG0_AOS                         (*((volatile unsigned int*)(0x42900044UL)))
#define bM4_MSTP_FCG0_AES                         (*((volatile unsigned int*)(0x42900050UL)))
#define bM4_MSTP_FCG0_HASH                        (*((volatile unsigned int*)(0x42900054UL)))
#define bM4_MSTP_FCG0_TRNG                        (*((volatile unsigned int*)(0x42900058UL)))
#define bM4_MSTP_FCG0_CRC                         (*((volatile unsigned int*)(0x4290005CUL)))
#define bM4_MSTP_FCG0_DCU1                        (*((volatile unsigned int*)(0x42900060UL)))
#define bM4_MSTP_FCG0_DCU2                        (*((volatile unsigned int*)(0x42900064UL)))
#define bM4_MSTP_FCG0_DCU3                        (*((volatile unsigned int*)(0x42900068UL)))
#define bM4_MSTP_FCG0_DCU4                        (*((volatile unsigned int*)(0x4290006CUL)))
#define bM4_MSTP_FCG0_KEY                         (*((volatile unsigned int*)(0x4290007CUL)))
#define bM4_MSTP_FCG1_CAN                         (*((volatile unsigned int*)(0x42900080UL)))
#define bM4_MSTP_FCG1_QSPI                        (*((volatile unsigned int*)(0x4290008CUL)))
#define bM4_MSTP_FCG1_IIC1                        (*((volatile unsigned int*)(0x42900090UL)))
#define bM4_MSTP_FCG1_IIC2                        (*((volatile unsigned int*)(0x42900094UL)))
#define bM4_MSTP_FCG1_IIC3                        (*((volatile unsigned int*)(0x42900098UL)))
#define bM4_MSTP_FCG1_USBFS                       (*((volatile unsigned int*)(0x429000A0UL)))
#define bM4_MSTP_FCG1_SDIOC1                      (*((volatile unsigned int*)(0x429000A8UL)))
#define bM4_MSTP_FCG1_SDIOC2                      (*((volatile unsigned int*)(0x429000ACUL)))
#define bM4_MSTP_FCG1_I2S1                        (*((volatile unsigned int*)(0x429000B0UL)))
#define bM4_MSTP_FCG1_I2S2                        (*((volatile unsigned int*)(0x429000B4UL)))
#define bM4_MSTP_FCG1_I2S3                        (*((volatile unsigned int*)(0x429000B8UL)))
#define bM4_MSTP_FCG1_I2S4                        (*((volatile unsigned int*)(0x429000BCUL)))
#define bM4_MSTP_FCG1_SPI1                        (*((volatile unsigned int*)(0x429000C0UL)))
#define bM4_MSTP_FCG1_SPI2                        (*((volatile unsigned int*)(0x429000C4UL)))
#define bM4_MSTP_FCG1_SPI3                        (*((volatile unsigned int*)(0x429000C8UL)))
#define bM4_MSTP_FCG1_SPI4                        (*((volatile unsigned int*)(0x429000CCUL)))
#define bM4_MSTP_FCG1_USART1                      (*((volatile unsigned int*)(0x429000E0UL)))
#define bM4_MSTP_FCG1_USART2                      (*((volatile unsigned int*)(0x429000E4UL)))
#define bM4_MSTP_FCG1_USART3                      (*((volatile unsigned int*)(0x429000E8UL)))
#define bM4_MSTP_FCG1_USART4                      (*((volatile unsigned int*)(0x429000ECUL)))
#define bM4_MSTP_FCG2_TIMER0_1                    (*((volatile unsigned int*)(0x42900100UL)))
#define bM4_MSTP_FCG2_TIMER0_2                    (*((volatile unsigned int*)(0x42900104UL)))
#define bM4_MSTP_FCG2_TIMERA_1                    (*((volatile unsigned int*)(0x42900108UL)))
#define bM4_MSTP_FCG2_TIMERA_2                    (*((volatile unsigned int*)(0x4290010CUL)))
#define bM4_MSTP_FCG2_TIMERA_3                    (*((volatile unsigned int*)(0x42900110UL)))
#define bM4_MSTP_FCG2_TIMERA_4                    (*((volatile unsigned int*)(0x42900114UL)))
#define bM4_MSTP_FCG2_TIMERA_5                    (*((volatile unsigned int*)(0x42900118UL)))
#define bM4_MSTP_FCG2_TIMERA_6                    (*((volatile unsigned int*)(0x4290011CUL)))
#define bM4_MSTP_FCG2_TIMER4_1                    (*((volatile unsigned int*)(0x42900120UL)))
#define bM4_MSTP_FCG2_TIMER4_2                    (*((volatile unsigned int*)(0x42900124UL)))
#define bM4_MSTP_FCG2_TIMER4_3                    (*((volatile unsigned int*)(0x42900128UL)))
#define bM4_MSTP_FCG2_EMB                         (*((volatile unsigned int*)(0x4290013CUL)))
#define bM4_MSTP_FCG2_TIMER6_1                    (*((volatile unsigned int*)(0x42900140UL)))
#define bM4_MSTP_FCG2_TIMER6_2                    (*((volatile unsigned int*)(0x42900144UL)))
#define bM4_MSTP_FCG2_TIMER6_3                    (*((volatile unsigned int*)(0x42900148UL)))
#define bM4_MSTP_FCG3_ADC1                        (*((volatile unsigned int*)(0x42900180UL)))
#define bM4_MSTP_FCG3_ADC2                        (*((volatile unsigned int*)(0x42900184UL)))
#define bM4_MSTP_FCG3_CMP                         (*((volatile unsigned int*)(0x429001A0UL)))
#define bM4_MSTP_FCG3_OTS                         (*((volatile unsigned int*)(0x429001B0UL)))
#define bM4_MSTP_FCG0PC_PRT0                      (*((volatile unsigned int*)(0x42900200UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE0                 (*((volatile unsigned int*)(0x42900240UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE1                 (*((volatile unsigned int*)(0x42900244UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE2                 (*((volatile unsigned int*)(0x42900248UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE3                 (*((volatile unsigned int*)(0x4290024CUL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE4                 (*((volatile unsigned int*)(0x42900250UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE5                 (*((volatile unsigned int*)(0x42900254UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE6                 (*((volatile unsigned int*)(0x42900258UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE7                 (*((volatile unsigned int*)(0x4290025CUL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE8                 (*((volatile unsigned int*)(0x42900260UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE9                 (*((volatile unsigned int*)(0x42900264UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE10                (*((volatile unsigned int*)(0x42900268UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE11                (*((volatile unsigned int*)(0x4290026CUL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE12                (*((volatile unsigned int*)(0x42900270UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE13                (*((volatile unsigned int*)(0x42900274UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE14                (*((volatile unsigned int*)(0x42900278UL)))
#define bM4_MSTP_FCG0PC_FCG0PCWE15                (*((volatile unsigned int*)(0x4290027CUL)))
#define bM4_OTS_CTL_OTSST                         (*((volatile unsigned int*)(0x42948000UL)))
#define bM4_OTS_CTL_OTSCK                         (*((volatile unsigned int*)(0x42948004UL)))
#define bM4_OTS_CTL_OTSIE                         (*((volatile unsigned int*)(0x42948008UL)))
#define bM4_OTS_CTL_TSSTP                         (*((volatile unsigned int*)(0x4294800CUL)))
#define bM4_OTS_LPR_TSOFS0                        (*((volatile unsigned int*)(0x42948100UL)))
#define bM4_OTS_LPR_TSOFS1                        (*((volatile unsigned int*)(0x42948104UL)))
#define bM4_OTS_LPR_TSOFS2                        (*((volatile unsigned int*)(0x42948108UL)))
#define bM4_OTS_LPR_TSOFS3                        (*((volatile unsigned int*)(0x4294810CUL)))
#define bM4_OTS_LPR_TSOFS4                        (*((volatile unsigned int*)(0x42948110UL)))
#define bM4_OTS_LPR_TSOFS5                        (*((volatile unsigned int*)(0x42948114UL)))
#define bM4_OTS_LPR_TSOFS6                        (*((volatile unsigned int*)(0x42948118UL)))
#define bM4_OTS_LPR_TSOFS7                        (*((volatile unsigned int*)(0x4294811CUL)))
#define bM4_OTS_LPR_TSSLP0                        (*((volatile unsigned int*)(0x42948120UL)))
#define bM4_OTS_LPR_TSSLP1                        (*((volatile unsigned int*)(0x42948124UL)))
#define bM4_OTS_LPR_TSSLP2                        (*((volatile unsigned int*)(0x42948128UL)))
#define bM4_OTS_LPR_TSSLP3                        (*((volatile unsigned int*)(0x4294812CUL)))
#define bM4_OTS_LPR_TSSLP4                        (*((volatile unsigned int*)(0x42948130UL)))
#define bM4_OTS_LPR_TSSLP5                        (*((volatile unsigned int*)(0x42948134UL)))
#define bM4_OTS_LPR_TSSLP6                        (*((volatile unsigned int*)(0x42948138UL)))
#define bM4_OTS_LPR_TSSLP7                        (*((volatile unsigned int*)(0x4294813CUL)))
#define bM4_OTS_LPR_TSSLP8                        (*((volatile unsigned int*)(0x42948140UL)))
#define bM4_OTS_LPR_TSSLP9                        (*((volatile unsigned int*)(0x42948144UL)))
#define bM4_OTS_LPR_TSSLP10                       (*((volatile unsigned int*)(0x42948148UL)))
#define bM4_OTS_LPR_TSSLP11                       (*((volatile unsigned int*)(0x4294814CUL)))
#define bM4_OTS_LPR_TSSLP12                       (*((volatile unsigned int*)(0x42948150UL)))
#define bM4_OTS_LPR_TSSLP13                       (*((volatile unsigned int*)(0x42948154UL)))
#define bM4_OTS_LPR_TSSLP14                       (*((volatile unsigned int*)(0x42948158UL)))
#define bM4_OTS_LPR_TSSLP15                       (*((volatile unsigned int*)(0x4294815CUL)))
#define bM4_OTS_LPR_TSSLP16                       (*((volatile unsigned int*)(0x42948160UL)))
#define bM4_OTS_LPR_TSSLP17                       (*((volatile unsigned int*)(0x42948164UL)))
#define bM4_OTS_LPR_TSSLP18                       (*((volatile unsigned int*)(0x42948168UL)))
#define bM4_OTS_LPR_TSSLP19                       (*((volatile unsigned int*)(0x4294816CUL)))
#define bM4_OTS_LPR_TSSLP20                       (*((volatile unsigned int*)(0x42948170UL)))
#define bM4_OTS_LPR_TSSLP21                       (*((volatile unsigned int*)(0x42948174UL)))
#define bM4_OTS_LPR_TSSLP22                       (*((volatile unsigned int*)(0x42948178UL)))
#define bM4_OTS_LPR_TSSLP23                       (*((volatile unsigned int*)(0x4294817CUL)))
#define bM4_PERIC_USBFS_SYCTLREG_DFB              (*((volatile unsigned int*)(0x42AA8000UL)))
#define bM4_PERIC_USBFS_SYCTLREG_SOFEN            (*((volatile unsigned int*)(0x42AA8004UL)))
#define bM4_PERIC_SDIOC_SYCTLREG_SELMMC1          (*((volatile unsigned int*)(0x42AA8084UL)))
#define bM4_PERIC_SDIOC_SYCTLREG_SELMMC2          (*((volatile unsigned int*)(0x42AA808CUL)))
#define bM4_PORT_PIDRA_PIN00                      (*((volatile unsigned int*)(0x42A70000UL)))
#define bM4_PORT_PIDRA_PIN01                      (*((volatile unsigned int*)(0x42A70004UL)))
#define bM4_PORT_PIDRA_PIN02                      (*((volatile unsigned int*)(0x42A70008UL)))
#define bM4_PORT_PIDRA_PIN03                      (*((volatile unsigned int*)(0x42A7000CUL)))
#define bM4_PORT_PIDRA_PIN04                      (*((volatile unsigned int*)(0x42A70010UL)))
#define bM4_PORT_PIDRA_PIN05                      (*((volatile unsigned int*)(0x42A70014UL)))
#define bM4_PORT_PIDRA_PIN06                      (*((volatile unsigned int*)(0x42A70018UL)))
#define bM4_PORT_PIDRA_PIN07                      (*((volatile unsigned int*)(0x42A7001CUL)))
#define bM4_PORT_PIDRA_PIN08                      (*((volatile unsigned int*)(0x42A70020UL)))
#define bM4_PORT_PIDRA_PIN09                      (*((volatile unsigned int*)(0x42A70024UL)))
#define bM4_PORT_PIDRA_PIN10                      (*((volatile unsigned int*)(0x42A70028UL)))
#define bM4_PORT_PIDRA_PIN11                      (*((volatile unsigned int*)(0x42A7002CUL)))
#define bM4_PORT_PIDRA_PIN12                      (*((volatile unsigned int*)(0x42A70030UL)))
#define bM4_PORT_PIDRA_PIN13                      (*((volatile unsigned int*)(0x42A70034UL)))
#define bM4_PORT_PIDRA_PIN14                      (*((volatile unsigned int*)(0x42A70038UL)))
#define bM4_PORT_PIDRA_PIN15                      (*((volatile unsigned int*)(0x42A7003CUL)))
#define bM4_PORT_PODRA_POUT00                     (*((volatile unsigned int*)(0x42A70080UL)))
#define bM4_PORT_PODRA_POUT01                     (*((volatile unsigned int*)(0x42A70084UL)))
#define bM4_PORT_PODRA_POUT02                     (*((volatile unsigned int*)(0x42A70088UL)))
#define bM4_PORT_PODRA_POUT03                     (*((volatile unsigned int*)(0x42A7008CUL)))
#define bM4_PORT_PODRA_POUT04                     (*((volatile unsigned int*)(0x42A70090UL)))
#define bM4_PORT_PODRA_POUT05                     (*((volatile unsigned int*)(0x42A70094UL)))
#define bM4_PORT_PODRA_POUT06                     (*((volatile unsigned int*)(0x42A70098UL)))
#define bM4_PORT_PODRA_POUT07                     (*((volatile unsigned int*)(0x42A7009CUL)))
#define bM4_PORT_PODRA_POUT08                     (*((volatile unsigned int*)(0x42A700A0UL)))
#define bM4_PORT_PODRA_POUT09                     (*((volatile unsigned int*)(0x42A700A4UL)))
#define bM4_PORT_PODRA_POUT10                     (*((volatile unsigned int*)(0x42A700A8UL)))
#define bM4_PORT_PODRA_POUT11                     (*((volatile unsigned int*)(0x42A700ACUL)))
#define bM4_PORT_PODRA_POUT12                     (*((volatile unsigned int*)(0x42A700B0UL)))
#define bM4_PORT_PODRA_POUT13                     (*((volatile unsigned int*)(0x42A700B4UL)))
#define bM4_PORT_PODRA_POUT14                     (*((volatile unsigned int*)(0x42A700B8UL)))
#define bM4_PORT_PODRA_POUT15                     (*((volatile unsigned int*)(0x42A700BCUL)))
#define bM4_PORT_POERA_POUTE00                    (*((volatile unsigned int*)(0x42A700C0UL)))
#define bM4_PORT_POERA_POUTE01                    (*((volatile unsigned int*)(0x42A700C4UL)))
#define bM4_PORT_POERA_POUTE02                    (*((volatile unsigned int*)(0x42A700C8UL)))
#define bM4_PORT_POERA_POUTE03                    (*((volatile unsigned int*)(0x42A700CCUL)))
#define bM4_PORT_POERA_POUTE04                    (*((volatile unsigned int*)(0x42A700D0UL)))
#define bM4_PORT_POERA_POUTE05                    (*((volatile unsigned int*)(0x42A700D4UL)))
#define bM4_PORT_POERA_POUTE06                    (*((volatile unsigned int*)(0x42A700D8UL)))
#define bM4_PORT_POERA_POUTE07                    (*((volatile unsigned int*)(0x42A700DCUL)))
#define bM4_PORT_POERA_POUTE08                    (*((volatile unsigned int*)(0x42A700E0UL)))
#define bM4_PORT_POERA_POUTE09                    (*((volatile unsigned int*)(0x42A700E4UL)))
#define bM4_PORT_POERA_POUTE10                    (*((volatile unsigned int*)(0x42A700E8UL)))
#define bM4_PORT_POERA_POUTE11                    (*((volatile unsigned int*)(0x42A700ECUL)))
#define bM4_PORT_POERA_POUTE12                    (*((volatile unsigned int*)(0x42A700F0UL)))
#define bM4_PORT_POERA_POUTE13                    (*((volatile unsigned int*)(0x42A700F4UL)))
#define bM4_PORT_POERA_POUTE14                    (*((volatile unsigned int*)(0x42A700F8UL)))
#define bM4_PORT_POERA_POUTE15                    (*((volatile unsigned int*)(0x42A700FCUL)))
#define bM4_PORT_POSRA_POS00                      (*((volatile unsigned int*)(0x42A70100UL)))
#define bM4_PORT_POSRA_POS01                      (*((volatile unsigned int*)(0x42A70104UL)))
#define bM4_PORT_POSRA_POS02                      (*((volatile unsigned int*)(0x42A70108UL)))
#define bM4_PORT_POSRA_POS03                      (*((volatile unsigned int*)(0x42A7010CUL)))
#define bM4_PORT_POSRA_POS04                      (*((volatile unsigned int*)(0x42A70110UL)))
#define bM4_PORT_POSRA_POS05                      (*((volatile unsigned int*)(0x42A70114UL)))
#define bM4_PORT_POSRA_POS06                      (*((volatile unsigned int*)(0x42A70118UL)))
#define bM4_PORT_POSRA_POS07                      (*((volatile unsigned int*)(0x42A7011CUL)))
#define bM4_PORT_POSRA_POS08                      (*((volatile unsigned int*)(0x42A70120UL)))
#define bM4_PORT_POSRA_POS09                      (*((volatile unsigned int*)(0x42A70124UL)))
#define bM4_PORT_POSRA_POS10                      (*((volatile unsigned int*)(0x42A70128UL)))
#define bM4_PORT_POSRA_POS11                      (*((volatile unsigned int*)(0x42A7012CUL)))
#define bM4_PORT_POSRA_POS12                      (*((volatile unsigned int*)(0x42A70130UL)))
#define bM4_PORT_POSRA_POS13                      (*((volatile unsigned int*)(0x42A70134UL)))
#define bM4_PORT_POSRA_POS14                      (*((volatile unsigned int*)(0x42A70138UL)))
#define bM4_PORT_POSRA_POS15                      (*((volatile unsigned int*)(0x42A7013CUL)))
#define bM4_PORT_PORRA_POR00                      (*((volatile unsigned int*)(0x42A70140UL)))
#define bM4_PORT_PORRA_POR01                      (*((volatile unsigned int*)(0x42A70144UL)))
#define bM4_PORT_PORRA_POR02                      (*((volatile unsigned int*)(0x42A70148UL)))
#define bM4_PORT_PORRA_POR03                      (*((volatile unsigned int*)(0x42A7014CUL)))
#define bM4_PORT_PORRA_POR04                      (*((volatile unsigned int*)(0x42A70150UL)))
#define bM4_PORT_PORRA_POR05                      (*((volatile unsigned int*)(0x42A70154UL)))
#define bM4_PORT_PORRA_POR06                      (*((volatile unsigned int*)(0x42A70158UL)))
#define bM4_PORT_PORRA_POR07                      (*((volatile unsigned int*)(0x42A7015CUL)))
#define bM4_PORT_PORRA_POR08                      (*((volatile unsigned int*)(0x42A70160UL)))
#define bM4_PORT_PORRA_POR09                      (*((volatile unsigned int*)(0x42A70164UL)))
#define bM4_PORT_PORRA_POR10                      (*((volatile unsigned int*)(0x42A70168UL)))
#define bM4_PORT_PORRA_POR11                      (*((volatile unsigned int*)(0x42A7016CUL)))
#define bM4_PORT_PORRA_POR12                      (*((volatile unsigned int*)(0x42A70170UL)))
#define bM4_PORT_PORRA_POR13                      (*((volatile unsigned int*)(0x42A70174UL)))
#define bM4_PORT_PORRA_POR14                      (*((volatile unsigned int*)(0x42A70178UL)))
#define bM4_PORT_PORRA_POR15                      (*((volatile unsigned int*)(0x42A7017CUL)))
#define bM4_PORT_POTRA_POT00                      (*((volatile unsigned int*)(0x42A70180UL)))
#define bM4_PORT_POTRA_POT01                      (*((volatile unsigned int*)(0x42A70184UL)))
#define bM4_PORT_POTRA_POT02                      (*((volatile unsigned int*)(0x42A70188UL)))
#define bM4_PORT_POTRA_POT03                      (*((volatile unsigned int*)(0x42A7018CUL)))
#define bM4_PORT_POTRA_POT04                      (*((volatile unsigned int*)(0x42A70190UL)))
#define bM4_PORT_POTRA_POT05                      (*((volatile unsigned int*)(0x42A70194UL)))
#define bM4_PORT_POTRA_POT06                      (*((volatile unsigned int*)(0x42A70198UL)))
#define bM4_PORT_POTRA_POT07                      (*((volatile unsigned int*)(0x42A7019CUL)))
#define bM4_PORT_POTRA_POT08                      (*((volatile unsigned int*)(0x42A701A0UL)))
#define bM4_PORT_POTRA_POT09                      (*((volatile unsigned int*)(0x42A701A4UL)))
#define bM4_PORT_POTRA_POT10                      (*((volatile unsigned int*)(0x42A701A8UL)))
#define bM4_PORT_POTRA_POT11                      (*((volatile unsigned int*)(0x42A701ACUL)))
#define bM4_PORT_POTRA_POT12                      (*((volatile unsigned int*)(0x42A701B0UL)))
#define bM4_PORT_POTRA_POT13                      (*((volatile unsigned int*)(0x42A701B4UL)))
#define bM4_PORT_POTRA_POT14                      (*((volatile unsigned int*)(0x42A701B8UL)))
#define bM4_PORT_POTRA_POT15                      (*((volatile unsigned int*)(0x42A701BCUL)))
#define bM4_PORT_PIDRB_PIN00                      (*((volatile unsigned int*)(0x42A70200UL)))
#define bM4_PORT_PIDRB_PIN01                      (*((volatile unsigned int*)(0x42A70204UL)))
#define bM4_PORT_PIDRB_PIN02                      (*((volatile unsigned int*)(0x42A70208UL)))
#define bM4_PORT_PIDRB_PIN03                      (*((volatile unsigned int*)(0x42A7020CUL)))
#define bM4_PORT_PIDRB_PIN04                      (*((volatile unsigned int*)(0x42A70210UL)))
#define bM4_PORT_PIDRB_PIN05                      (*((volatile unsigned int*)(0x42A70214UL)))
#define bM4_PORT_PIDRB_PIN06                      (*((volatile unsigned int*)(0x42A70218UL)))
#define bM4_PORT_PIDRB_PIN07                      (*((volatile unsigned int*)(0x42A7021CUL)))
#define bM4_PORT_PIDRB_PIN08                      (*((volatile unsigned int*)(0x42A70220UL)))
#define bM4_PORT_PIDRB_PIN09                      (*((volatile unsigned int*)(0x42A70224UL)))
#define bM4_PORT_PIDRB_PIN10                      (*((volatile unsigned int*)(0x42A70228UL)))
#define bM4_PORT_PIDRB_PIN11                      (*((volatile unsigned int*)(0x42A7022CUL)))
#define bM4_PORT_PIDRB_PIN12                      (*((volatile unsigned int*)(0x42A70230UL)))
#define bM4_PORT_PIDRB_PIN13                      (*((volatile unsigned int*)(0x42A70234UL)))
#define bM4_PORT_PIDRB_PIN14                      (*((volatile unsigned int*)(0x42A70238UL)))
#define bM4_PORT_PIDRB_PIN15                      (*((volatile unsigned int*)(0x42A7023CUL)))
#define bM4_PORT_PODRB_POUT00                     (*((volatile unsigned int*)(0x42A70280UL)))
#define bM4_PORT_PODRB_POUT01                     (*((volatile unsigned int*)(0x42A70284UL)))
#define bM4_PORT_PODRB_POUT02                     (*((volatile unsigned int*)(0x42A70288UL)))
#define bM4_PORT_PODRB_POUT03                     (*((volatile unsigned int*)(0x42A7028CUL)))
#define bM4_PORT_PODRB_POUT04                     (*((volatile unsigned int*)(0x42A70290UL)))
#define bM4_PORT_PODRB_POUT05                     (*((volatile unsigned int*)(0x42A70294UL)))
#define bM4_PORT_PODRB_POUT06                     (*((volatile unsigned int*)(0x42A70298UL)))
#define bM4_PORT_PODRB_POUT07                     (*((volatile unsigned int*)(0x42A7029CUL)))
#define bM4_PORT_PODRB_POUT08                     (*((volatile unsigned int*)(0x42A702A0UL)))
#define bM4_PORT_PODRB_POUT09                     (*((volatile unsigned int*)(0x42A702A4UL)))
#define bM4_PORT_PODRB_POUT10                     (*((volatile unsigned int*)(0x42A702A8UL)))
#define bM4_PORT_PODRB_POUT11                     (*((volatile unsigned int*)(0x42A702ACUL)))
#define bM4_PORT_PODRB_POUT12                     (*((volatile unsigned int*)(0x42A702B0UL)))
#define bM4_PORT_PODRB_POUT13                     (*((volatile unsigned int*)(0x42A702B4UL)))
#define bM4_PORT_PODRB_POUT14                     (*((volatile unsigned int*)(0x42A702B8UL)))
#define bM4_PORT_PODRB_POUT15                     (*((volatile unsigned int*)(0x42A702BCUL)))
#define bM4_PORT_POERB_POUTE00                    (*((volatile unsigned int*)(0x42A702C0UL)))
#define bM4_PORT_POERB_POUTE01                    (*((volatile unsigned int*)(0x42A702C4UL)))
#define bM4_PORT_POERB_POUTE02                    (*((volatile unsigned int*)(0x42A702C8UL)))
#define bM4_PORT_POERB_POUTE03                    (*((volatile unsigned int*)(0x42A702CCUL)))
#define bM4_PORT_POERB_POUTE04                    (*((volatile unsigned int*)(0x42A702D0UL)))
#define bM4_PORT_POERB_POUTE05                    (*((volatile unsigned int*)(0x42A702D4UL)))
#define bM4_PORT_POERB_POUTE06                    (*((volatile unsigned int*)(0x42A702D8UL)))
#define bM4_PORT_POERB_POUTE07                    (*((volatile unsigned int*)(0x42A702DCUL)))
#define bM4_PORT_POERB_POUTE08                    (*((volatile unsigned int*)(0x42A702E0UL)))
#define bM4_PORT_POERB_POUTE09                    (*((volatile unsigned int*)(0x42A702E4UL)))
#define bM4_PORT_POERB_POUTE10                    (*((volatile unsigned int*)(0x42A702E8UL)))
#define bM4_PORT_POERB_POUTE11                    (*((volatile unsigned int*)(0x42A702ECUL)))
#define bM4_PORT_POERB_POUTE12                    (*((volatile unsigned int*)(0x42A702F0UL)))
#define bM4_PORT_POERB_POUTE13                    (*((volatile unsigned int*)(0x42A702F4UL)))
#define bM4_PORT_POERB_POUTE14                    (*((volatile unsigned int*)(0x42A702F8UL)))
#define bM4_PORT_POERB_POUTE15                    (*((volatile unsigned int*)(0x42A702FCUL)))
#define bM4_PORT_POSRB_POS00                      (*((volatile unsigned int*)(0x42A70300UL)))
#define bM4_PORT_POSRB_POS01                      (*((volatile unsigned int*)(0x42A70304UL)))
#define bM4_PORT_POSRB_POS02                      (*((volatile unsigned int*)(0x42A70308UL)))
#define bM4_PORT_POSRB_POS03                      (*((volatile unsigned int*)(0x42A7030CUL)))
#define bM4_PORT_POSRB_POS04                      (*((volatile unsigned int*)(0x42A70310UL)))
#define bM4_PORT_POSRB_POS05                      (*((volatile unsigned int*)(0x42A70314UL)))
#define bM4_PORT_POSRB_POS06                      (*((volatile unsigned int*)(0x42A70318UL)))
#define bM4_PORT_POSRB_POS07                      (*((volatile unsigned int*)(0x42A7031CUL)))
#define bM4_PORT_POSRB_POS08                      (*((volatile unsigned int*)(0x42A70320UL)))
#define bM4_PORT_POSRB_POS09                      (*((volatile unsigned int*)(0x42A70324UL)))
#define bM4_PORT_POSRB_POS10                      (*((volatile unsigned int*)(0x42A70328UL)))
#define bM4_PORT_POSRB_POS11                      (*((volatile unsigned int*)(0x42A7032CUL)))
#define bM4_PORT_POSRB_POS12                      (*((volatile unsigned int*)(0x42A70330UL)))
#define bM4_PORT_POSRB_POS13                      (*((volatile unsigned int*)(0x42A70334UL)))
#define bM4_PORT_POSRB_POS14                      (*((volatile unsigned int*)(0x42A70338UL)))
#define bM4_PORT_POSRB_POS15                      (*((volatile unsigned int*)(0x42A7033CUL)))
#define bM4_PORT_PORRB_POR00                      (*((volatile unsigned int*)(0x42A70340UL)))
#define bM4_PORT_PORRB_POR01                      (*((volatile unsigned int*)(0x42A70344UL)))
#define bM4_PORT_PORRB_POR02                      (*((volatile unsigned int*)(0x42A70348UL)))
#define bM4_PORT_PORRB_POR03                      (*((volatile unsigned int*)(0x42A7034CUL)))
#define bM4_PORT_PORRB_POR04                      (*((volatile unsigned int*)(0x42A70350UL)))
#define bM4_PORT_PORRB_POR05                      (*((volatile unsigned int*)(0x42A70354UL)))
#define bM4_PORT_PORRB_POR06                      (*((volatile unsigned int*)(0x42A70358UL)))
#define bM4_PORT_PORRB_POR07                      (*((volatile unsigned int*)(0x42A7035CUL)))
#define bM4_PORT_PORRB_POR08                      (*((volatile unsigned int*)(0x42A70360UL)))
#define bM4_PORT_PORRB_POR09                      (*((volatile unsigned int*)(0x42A70364UL)))
#define bM4_PORT_PORRB_POR10                      (*((volatile unsigned int*)(0x42A70368UL)))
#define bM4_PORT_PORRB_POR11                      (*((volatile unsigned int*)(0x42A7036CUL)))
#define bM4_PORT_PORRB_POR12                      (*((volatile unsigned int*)(0x42A70370UL)))
#define bM4_PORT_PORRB_POR13                      (*((volatile unsigned int*)(0x42A70374UL)))
#define bM4_PORT_PORRB_POR14                      (*((volatile unsigned int*)(0x42A70378UL)))
#define bM4_PORT_PORRB_POR15                      (*((volatile unsigned int*)(0x42A7037CUL)))
#define bM4_PORT_POTRB_POT00                      (*((volatile unsigned int*)(0x42A70380UL)))
#define bM4_PORT_POTRB_POT01                      (*((volatile unsigned int*)(0x42A70384UL)))
#define bM4_PORT_POTRB_POT02                      (*((volatile unsigned int*)(0x42A70388UL)))
#define bM4_PORT_POTRB_POT03                      (*((volatile unsigned int*)(0x42A7038CUL)))
#define bM4_PORT_POTRB_POT04                      (*((volatile unsigned int*)(0x42A70390UL)))
#define bM4_PORT_POTRB_POT05                      (*((volatile unsigned int*)(0x42A70394UL)))
#define bM4_PORT_POTRB_POT06                      (*((volatile unsigned int*)(0x42A70398UL)))
#define bM4_PORT_POTRB_POT07                      (*((volatile unsigned int*)(0x42A7039CUL)))
#define bM4_PORT_POTRB_POT08                      (*((volatile unsigned int*)(0x42A703A0UL)))
#define bM4_PORT_POTRB_POT09                      (*((volatile unsigned int*)(0x42A703A4UL)))
#define bM4_PORT_POTRB_POT10                      (*((volatile unsigned int*)(0x42A703A8UL)))
#define bM4_PORT_POTRB_POT11                      (*((volatile unsigned int*)(0x42A703ACUL)))
#define bM4_PORT_POTRB_POT12                      (*((volatile unsigned int*)(0x42A703B0UL)))
#define bM4_PORT_POTRB_POT13                      (*((volatile unsigned int*)(0x42A703B4UL)))
#define bM4_PORT_POTRB_POT14                      (*((volatile unsigned int*)(0x42A703B8UL)))
#define bM4_PORT_POTRB_POT15                      (*((volatile unsigned int*)(0x42A703BCUL)))
#define bM4_PORT_PIDRC_PIN00                      (*((volatile unsigned int*)(0x42A70400UL)))
#define bM4_PORT_PIDRC_PIN01                      (*((volatile unsigned int*)(0x42A70404UL)))
#define bM4_PORT_PIDRC_PIN02                      (*((volatile unsigned int*)(0x42A70408UL)))
#define bM4_PORT_PIDRC_PIN03                      (*((volatile unsigned int*)(0x42A7040CUL)))
#define bM4_PORT_PIDRC_PIN04                      (*((volatile unsigned int*)(0x42A70410UL)))
#define bM4_PORT_PIDRC_PIN05                      (*((volatile unsigned int*)(0x42A70414UL)))
#define bM4_PORT_PIDRC_PIN06                      (*((volatile unsigned int*)(0x42A70418UL)))
#define bM4_PORT_PIDRC_PIN07                      (*((volatile unsigned int*)(0x42A7041CUL)))
#define bM4_PORT_PIDRC_PIN08                      (*((volatile unsigned int*)(0x42A70420UL)))
#define bM4_PORT_PIDRC_PIN09                      (*((volatile unsigned int*)(0x42A70424UL)))
#define bM4_PORT_PIDRC_PIN10                      (*((volatile unsigned int*)(0x42A70428UL)))
#define bM4_PORT_PIDRC_PIN11                      (*((volatile unsigned int*)(0x42A7042CUL)))
#define bM4_PORT_PIDRC_PIN12                      (*((volatile unsigned int*)(0x42A70430UL)))
#define bM4_PORT_PIDRC_PIN13                      (*((volatile unsigned int*)(0x42A70434UL)))
#define bM4_PORT_PIDRC_PIN14                      (*((volatile unsigned int*)(0x42A70438UL)))
#define bM4_PORT_PIDRC_PIN15                      (*((volatile unsigned int*)(0x42A7043CUL)))
#define bM4_PORT_PODRC_POUT00                     (*((volatile unsigned int*)(0x42A70480UL)))
#define bM4_PORT_PODRC_POUT01                     (*((volatile unsigned int*)(0x42A70484UL)))
#define bM4_PORT_PODRC_POUT02                     (*((volatile unsigned int*)(0x42A70488UL)))
#define bM4_PORT_PODRC_POUT03                     (*((volatile unsigned int*)(0x42A7048CUL)))
#define bM4_PORT_PODRC_POUT04                     (*((volatile unsigned int*)(0x42A70490UL)))
#define bM4_PORT_PODRC_POUT05                     (*((volatile unsigned int*)(0x42A70494UL)))
#define bM4_PORT_PODRC_POUT06                     (*((volatile unsigned int*)(0x42A70498UL)))
#define bM4_PORT_PODRC_POUT07                     (*((volatile unsigned int*)(0x42A7049CUL)))
#define bM4_PORT_PODRC_POUT08                     (*((volatile unsigned int*)(0x42A704A0UL)))
#define bM4_PORT_PODRC_POUT09                     (*((volatile unsigned int*)(0x42A704A4UL)))
#define bM4_PORT_PODRC_POUT10                     (*((volatile unsigned int*)(0x42A704A8UL)))
#define bM4_PORT_PODRC_POUT11                     (*((volatile unsigned int*)(0x42A704ACUL)))
#define bM4_PORT_PODRC_POUT12                     (*((volatile unsigned int*)(0x42A704B0UL)))
#define bM4_PORT_PODRC_POUT13                     (*((volatile unsigned int*)(0x42A704B4UL)))
#define bM4_PORT_PODRC_POUT14                     (*((volatile unsigned int*)(0x42A704B8UL)))
#define bM4_PORT_PODRC_POUT15                     (*((volatile unsigned int*)(0x42A704BCUL)))
#define bM4_PORT_POERC_POUTE00                    (*((volatile unsigned int*)(0x42A704C0UL)))
#define bM4_PORT_POERC_POUTE01                    (*((volatile unsigned int*)(0x42A704C4UL)))
#define bM4_PORT_POERC_POUTE02                    (*((volatile unsigned int*)(0x42A704C8UL)))
#define bM4_PORT_POERC_POUTE03                    (*((volatile unsigned int*)(0x42A704CCUL)))
#define bM4_PORT_POERC_POUTE04                    (*((volatile unsigned int*)(0x42A704D0UL)))
#define bM4_PORT_POERC_POUTE05                    (*((volatile unsigned int*)(0x42A704D4UL)))
#define bM4_PORT_POERC_POUTE06                    (*((volatile unsigned int*)(0x42A704D8UL)))
#define bM4_PORT_POERC_POUTE07                    (*((volatile unsigned int*)(0x42A704DCUL)))
#define bM4_PORT_POERC_POUTE08                    (*((volatile unsigned int*)(0x42A704E0UL)))
#define bM4_PORT_POERC_POUTE09                    (*((volatile unsigned int*)(0x42A704E4UL)))
#define bM4_PORT_POERC_POUTE10                    (*((volatile unsigned int*)(0x42A704E8UL)))
#define bM4_PORT_POERC_POUTE11                    (*((volatile unsigned int*)(0x42A704ECUL)))
#define bM4_PORT_POERC_POUTE12                    (*((volatile unsigned int*)(0x42A704F0UL)))
#define bM4_PORT_POERC_POUTE13                    (*((volatile unsigned int*)(0x42A704F4UL)))
#define bM4_PORT_POERC_POUTE14                    (*((volatile unsigned int*)(0x42A704F8UL)))
#define bM4_PORT_POERC_POUTE15                    (*((volatile unsigned int*)(0x42A704FCUL)))
#define bM4_PORT_POSRC_POS00                      (*((volatile unsigned int*)(0x42A70500UL)))
#define bM4_PORT_POSRC_POS01                      (*((volatile unsigned int*)(0x42A70504UL)))
#define bM4_PORT_POSRC_POS02                      (*((volatile unsigned int*)(0x42A70508UL)))
#define bM4_PORT_POSRC_POS03                      (*((volatile unsigned int*)(0x42A7050CUL)))
#define bM4_PORT_POSRC_POS04                      (*((volatile unsigned int*)(0x42A70510UL)))
#define bM4_PORT_POSRC_POS05                      (*((volatile unsigned int*)(0x42A70514UL)))
#define bM4_PORT_POSRC_POS06                      (*((volatile unsigned int*)(0x42A70518UL)))
#define bM4_PORT_POSRC_POS07                      (*((volatile unsigned int*)(0x42A7051CUL)))
#define bM4_PORT_POSRC_POS08                      (*((volatile unsigned int*)(0x42A70520UL)))
#define bM4_PORT_POSRC_POS09                      (*((volatile unsigned int*)(0x42A70524UL)))
#define bM4_PORT_POSRC_POS10                      (*((volatile unsigned int*)(0x42A70528UL)))
#define bM4_PORT_POSRC_POS11                      (*((volatile unsigned int*)(0x42A7052CUL)))
#define bM4_PORT_POSRC_POS12                      (*((volatile unsigned int*)(0x42A70530UL)))
#define bM4_PORT_POSRC_POS13                      (*((volatile unsigned int*)(0x42A70534UL)))
#define bM4_PORT_POSRC_POS14                      (*((volatile unsigned int*)(0x42A70538UL)))
#define bM4_PORT_POSRC_POS15                      (*((volatile unsigned int*)(0x42A7053CUL)))
#define bM4_PORT_PORRC_POR00                      (*((volatile unsigned int*)(0x42A70540UL)))
#define bM4_PORT_PORRC_POR01                      (*((volatile unsigned int*)(0x42A70544UL)))
#define bM4_PORT_PORRC_POR02                      (*((volatile unsigned int*)(0x42A70548UL)))
#define bM4_PORT_PORRC_POR03                      (*((volatile unsigned int*)(0x42A7054CUL)))
#define bM4_PORT_PORRC_POR04                      (*((volatile unsigned int*)(0x42A70550UL)))
#define bM4_PORT_PORRC_POR05                      (*((volatile unsigned int*)(0x42A70554UL)))
#define bM4_PORT_PORRC_POR06                      (*((volatile unsigned int*)(0x42A70558UL)))
#define bM4_PORT_PORRC_POR07                      (*((volatile unsigned int*)(0x42A7055CUL)))
#define bM4_PORT_PORRC_POR08                      (*((volatile unsigned int*)(0x42A70560UL)))
#define bM4_PORT_PORRC_POR09                      (*((volatile unsigned int*)(0x42A70564UL)))
#define bM4_PORT_PORRC_POR10                      (*((volatile unsigned int*)(0x42A70568UL)))
#define bM4_PORT_PORRC_POR11                      (*((volatile unsigned int*)(0x42A7056CUL)))
#define bM4_PORT_PORRC_POR12                      (*((volatile unsigned int*)(0x42A70570UL)))
#define bM4_PORT_PORRC_POR13                      (*((volatile unsigned int*)(0x42A70574UL)))
#define bM4_PORT_PORRC_POR14                      (*((volatile unsigned int*)(0x42A70578UL)))
#define bM4_PORT_PORRC_POR15                      (*((volatile unsigned int*)(0x42A7057CUL)))
#define bM4_PORT_POTRC_POT00                      (*((volatile unsigned int*)(0x42A70580UL)))
#define bM4_PORT_POTRC_POT01                      (*((volatile unsigned int*)(0x42A70584UL)))
#define bM4_PORT_POTRC_POT02                      (*((volatile unsigned int*)(0x42A70588UL)))
#define bM4_PORT_POTRC_POT03                      (*((volatile unsigned int*)(0x42A7058CUL)))
#define bM4_PORT_POTRC_POT04                      (*((volatile unsigned int*)(0x42A70590UL)))
#define bM4_PORT_POTRC_POT05                      (*((volatile unsigned int*)(0x42A70594UL)))
#define bM4_PORT_POTRC_POT06                      (*((volatile unsigned int*)(0x42A70598UL)))
#define bM4_PORT_POTRC_POT07                      (*((volatile unsigned int*)(0x42A7059CUL)))
#define bM4_PORT_POTRC_POT08                      (*((volatile unsigned int*)(0x42A705A0UL)))
#define bM4_PORT_POTRC_POT09                      (*((volatile unsigned int*)(0x42A705A4UL)))
#define bM4_PORT_POTRC_POT10                      (*((volatile unsigned int*)(0x42A705A8UL)))
#define bM4_PORT_POTRC_POT11                      (*((volatile unsigned int*)(0x42A705ACUL)))
#define bM4_PORT_POTRC_POT12                      (*((volatile unsigned int*)(0x42A705B0UL)))
#define bM4_PORT_POTRC_POT13                      (*((volatile unsigned int*)(0x42A705B4UL)))
#define bM4_PORT_POTRC_POT14                      (*((volatile unsigned int*)(0x42A705B8UL)))
#define bM4_PORT_POTRC_POT15                      (*((volatile unsigned int*)(0x42A705BCUL)))
#define bM4_PORT_PIDRD_PIN00                      (*((volatile unsigned int*)(0x42A70600UL)))
#define bM4_PORT_PIDRD_PIN01                      (*((volatile unsigned int*)(0x42A70604UL)))
#define bM4_PORT_PIDRD_PIN02                      (*((volatile unsigned int*)(0x42A70608UL)))
#define bM4_PORT_PIDRD_PIN03                      (*((volatile unsigned int*)(0x42A7060CUL)))
#define bM4_PORT_PIDRD_PIN04                      (*((volatile unsigned int*)(0x42A70610UL)))
#define bM4_PORT_PIDRD_PIN05                      (*((volatile unsigned int*)(0x42A70614UL)))
#define bM4_PORT_PIDRD_PIN06                      (*((volatile unsigned int*)(0x42A70618UL)))
#define bM4_PORT_PIDRD_PIN07                      (*((volatile unsigned int*)(0x42A7061CUL)))
#define bM4_PORT_PIDRD_PIN08                      (*((volatile unsigned int*)(0x42A70620UL)))
#define bM4_PORT_PIDRD_PIN09                      (*((volatile unsigned int*)(0x42A70624UL)))
#define bM4_PORT_PIDRD_PIN10                      (*((volatile unsigned int*)(0x42A70628UL)))
#define bM4_PORT_PIDRD_PIN11                      (*((volatile unsigned int*)(0x42A7062CUL)))
#define bM4_PORT_PIDRD_PIN12                      (*((volatile unsigned int*)(0x42A70630UL)))
#define bM4_PORT_PIDRD_PIN13                      (*((volatile unsigned int*)(0x42A70634UL)))
#define bM4_PORT_PIDRD_PIN14                      (*((volatile unsigned int*)(0x42A70638UL)))
#define bM4_PORT_PIDRD_PIN15                      (*((volatile unsigned int*)(0x42A7063CUL)))
#define bM4_PORT_PODRD_POUT00                     (*((volatile unsigned int*)(0x42A70680UL)))
#define bM4_PORT_PODRD_POUT01                     (*((volatile unsigned int*)(0x42A70684UL)))
#define bM4_PORT_PODRD_POUT02                     (*((volatile unsigned int*)(0x42A70688UL)))
#define bM4_PORT_PODRD_POUT03                     (*((volatile unsigned int*)(0x42A7068CUL)))
#define bM4_PORT_PODRD_POUT04                     (*((volatile unsigned int*)(0x42A70690UL)))
#define bM4_PORT_PODRD_POUT05                     (*((volatile unsigned int*)(0x42A70694UL)))
#define bM4_PORT_PODRD_POUT06                     (*((volatile unsigned int*)(0x42A70698UL)))
#define bM4_PORT_PODRD_POUT07                     (*((volatile unsigned int*)(0x42A7069CUL)))
#define bM4_PORT_PODRD_POUT08                     (*((volatile unsigned int*)(0x42A706A0UL)))
#define bM4_PORT_PODRD_POUT09                     (*((volatile unsigned int*)(0x42A706A4UL)))
#define bM4_PORT_PODRD_POUT10                     (*((volatile unsigned int*)(0x42A706A8UL)))
#define bM4_PORT_PODRD_POUT11                     (*((volatile unsigned int*)(0x42A706ACUL)))
#define bM4_PORT_PODRD_POUT12                     (*((volatile unsigned int*)(0x42A706B0UL)))
#define bM4_PORT_PODRD_POUT13                     (*((volatile unsigned int*)(0x42A706B4UL)))
#define bM4_PORT_PODRD_POUT14                     (*((volatile unsigned int*)(0x42A706B8UL)))
#define bM4_PORT_PODRD_POUT15                     (*((volatile unsigned int*)(0x42A706BCUL)))
#define bM4_PORT_POERD_POUTE00                    (*((volatile unsigned int*)(0x42A706C0UL)))
#define bM4_PORT_POERD_POUTE01                    (*((volatile unsigned int*)(0x42A706C4UL)))
#define bM4_PORT_POERD_POUTE02                    (*((volatile unsigned int*)(0x42A706C8UL)))
#define bM4_PORT_POERD_POUTE03                    (*((volatile unsigned int*)(0x42A706CCUL)))
#define bM4_PORT_POERD_POUTE04                    (*((volatile unsigned int*)(0x42A706D0UL)))
#define bM4_PORT_POERD_POUTE05                    (*((volatile unsigned int*)(0x42A706D4UL)))
#define bM4_PORT_POERD_POUTE06                    (*((volatile unsigned int*)(0x42A706D8UL)))
#define bM4_PORT_POERD_POUTE07                    (*((volatile unsigned int*)(0x42A706DCUL)))
#define bM4_PORT_POERD_POUTE08                    (*((volatile unsigned int*)(0x42A706E0UL)))
#define bM4_PORT_POERD_POUTE09                    (*((volatile unsigned int*)(0x42A706E4UL)))
#define bM4_PORT_POERD_POUTE10                    (*((volatile unsigned int*)(0x42A706E8UL)))
#define bM4_PORT_POERD_POUTE11                    (*((volatile unsigned int*)(0x42A706ECUL)))
#define bM4_PORT_POERD_POUTE12                    (*((volatile unsigned int*)(0x42A706F0UL)))
#define bM4_PORT_POERD_POUTE13                    (*((volatile unsigned int*)(0x42A706F4UL)))
#define bM4_PORT_POERD_POUTE14                    (*((volatile unsigned int*)(0x42A706F8UL)))
#define bM4_PORT_POERD_POUTE15                    (*((volatile unsigned int*)(0x42A706FCUL)))
#define bM4_PORT_POSRD_POS00                      (*((volatile unsigned int*)(0x42A70700UL)))
#define bM4_PORT_POSRD_POS01                      (*((volatile unsigned int*)(0x42A70704UL)))
#define bM4_PORT_POSRD_POS02                      (*((volatile unsigned int*)(0x42A70708UL)))
#define bM4_PORT_POSRD_POS03                      (*((volatile unsigned int*)(0x42A7070CUL)))
#define bM4_PORT_POSRD_POS04                      (*((volatile unsigned int*)(0x42A70710UL)))
#define bM4_PORT_POSRD_POS05                      (*((volatile unsigned int*)(0x42A70714UL)))
#define bM4_PORT_POSRD_POS06                      (*((volatile unsigned int*)(0x42A70718UL)))
#define bM4_PORT_POSRD_POS07                      (*((volatile unsigned int*)(0x42A7071CUL)))
#define bM4_PORT_POSRD_POS08                      (*((volatile unsigned int*)(0x42A70720UL)))
#define bM4_PORT_POSRD_POS09                      (*((volatile unsigned int*)(0x42A70724UL)))
#define bM4_PORT_POSRD_POS10                      (*((volatile unsigned int*)(0x42A70728UL)))
#define bM4_PORT_POSRD_POS11                      (*((volatile unsigned int*)(0x42A7072CUL)))
#define bM4_PORT_POSRD_POS12                      (*((volatile unsigned int*)(0x42A70730UL)))
#define bM4_PORT_POSRD_POS13                      (*((volatile unsigned int*)(0x42A70734UL)))
#define bM4_PORT_POSRD_POS14                      (*((volatile unsigned int*)(0x42A70738UL)))
#define bM4_PORT_POSRD_POS15                      (*((volatile unsigned int*)(0x42A7073CUL)))
#define bM4_PORT_PORRD_POR00                      (*((volatile unsigned int*)(0x42A70740UL)))
#define bM4_PORT_PORRD_POR01                      (*((volatile unsigned int*)(0x42A70744UL)))
#define bM4_PORT_PORRD_POR02                      (*((volatile unsigned int*)(0x42A70748UL)))
#define bM4_PORT_PORRD_POR03                      (*((volatile unsigned int*)(0x42A7074CUL)))
#define bM4_PORT_PORRD_POR04                      (*((volatile unsigned int*)(0x42A70750UL)))
#define bM4_PORT_PORRD_POR05                      (*((volatile unsigned int*)(0x42A70754UL)))
#define bM4_PORT_PORRD_POR06                      (*((volatile unsigned int*)(0x42A70758UL)))
#define bM4_PORT_PORRD_POR07                      (*((volatile unsigned int*)(0x42A7075CUL)))
#define bM4_PORT_PORRD_POR08                      (*((volatile unsigned int*)(0x42A70760UL)))
#define bM4_PORT_PORRD_POR09                      (*((volatile unsigned int*)(0x42A70764UL)))
#define bM4_PORT_PORRD_POR10                      (*((volatile unsigned int*)(0x42A70768UL)))
#define bM4_PORT_PORRD_POR11                      (*((volatile unsigned int*)(0x42A7076CUL)))
#define bM4_PORT_PORRD_POR12                      (*((volatile unsigned int*)(0x42A70770UL)))
#define bM4_PORT_PORRD_POR13                      (*((volatile unsigned int*)(0x42A70774UL)))
#define bM4_PORT_PORRD_POR14                      (*((volatile unsigned int*)(0x42A70778UL)))
#define bM4_PORT_PORRD_POR15                      (*((volatile unsigned int*)(0x42A7077CUL)))
#define bM4_PORT_POTRD_POT00                      (*((volatile unsigned int*)(0x42A70780UL)))
#define bM4_PORT_POTRD_POT01                      (*((volatile unsigned int*)(0x42A70784UL)))
#define bM4_PORT_POTRD_POT02                      (*((volatile unsigned int*)(0x42A70788UL)))
#define bM4_PORT_POTRD_POT03                      (*((volatile unsigned int*)(0x42A7078CUL)))
#define bM4_PORT_POTRD_POT04                      (*((volatile unsigned int*)(0x42A70790UL)))
#define bM4_PORT_POTRD_POT05                      (*((volatile unsigned int*)(0x42A70794UL)))
#define bM4_PORT_POTRD_POT06                      (*((volatile unsigned int*)(0x42A70798UL)))
#define bM4_PORT_POTRD_POT07                      (*((volatile unsigned int*)(0x42A7079CUL)))
#define bM4_PORT_POTRD_POT08                      (*((volatile unsigned int*)(0x42A707A0UL)))
#define bM4_PORT_POTRD_POT09                      (*((volatile unsigned int*)(0x42A707A4UL)))
#define bM4_PORT_POTRD_POT10                      (*((volatile unsigned int*)(0x42A707A8UL)))
#define bM4_PORT_POTRD_POT11                      (*((volatile unsigned int*)(0x42A707ACUL)))
#define bM4_PORT_POTRD_POT12                      (*((volatile unsigned int*)(0x42A707B0UL)))
#define bM4_PORT_POTRD_POT13                      (*((volatile unsigned int*)(0x42A707B4UL)))
#define bM4_PORT_POTRD_POT14                      (*((volatile unsigned int*)(0x42A707B8UL)))
#define bM4_PORT_POTRD_POT15                      (*((volatile unsigned int*)(0x42A707BCUL)))
#define bM4_PORT_PIDRE_PIN00                      (*((volatile unsigned int*)(0x42A70800UL)))
#define bM4_PORT_PIDRE_PIN01                      (*((volatile unsigned int*)(0x42A70804UL)))
#define bM4_PORT_PIDRE_PIN02                      (*((volatile unsigned int*)(0x42A70808UL)))
#define bM4_PORT_PIDRE_PIN03                      (*((volatile unsigned int*)(0x42A7080CUL)))
#define bM4_PORT_PIDRE_PIN04                      (*((volatile unsigned int*)(0x42A70810UL)))
#define bM4_PORT_PIDRE_PIN05                      (*((volatile unsigned int*)(0x42A70814UL)))
#define bM4_PORT_PIDRE_PIN06                      (*((volatile unsigned int*)(0x42A70818UL)))
#define bM4_PORT_PIDRE_PIN07                      (*((volatile unsigned int*)(0x42A7081CUL)))
#define bM4_PORT_PIDRE_PIN08                      (*((volatile unsigned int*)(0x42A70820UL)))
#define bM4_PORT_PIDRE_PIN09                      (*((volatile unsigned int*)(0x42A70824UL)))
#define bM4_PORT_PIDRE_PIN10                      (*((volatile unsigned int*)(0x42A70828UL)))
#define bM4_PORT_PIDRE_PIN11                      (*((volatile unsigned int*)(0x42A7082CUL)))
#define bM4_PORT_PIDRE_PIN12                      (*((volatile unsigned int*)(0x42A70830UL)))
#define bM4_PORT_PIDRE_PIN13                      (*((volatile unsigned int*)(0x42A70834UL)))
#define bM4_PORT_PIDRE_PIN14                      (*((volatile unsigned int*)(0x42A70838UL)))
#define bM4_PORT_PIDRE_PIN15                      (*((volatile unsigned int*)(0x42A7083CUL)))
#define bM4_PORT_PODRE_POUT00                     (*((volatile unsigned int*)(0x42A70880UL)))
#define bM4_PORT_PODRE_POUT01                     (*((volatile unsigned int*)(0x42A70884UL)))
#define bM4_PORT_PODRE_POUT02                     (*((volatile unsigned int*)(0x42A70888UL)))
#define bM4_PORT_PODRE_POUT03                     (*((volatile unsigned int*)(0x42A7088CUL)))
#define bM4_PORT_PODRE_POUT04                     (*((volatile unsigned int*)(0x42A70890UL)))
#define bM4_PORT_PODRE_POUT05                     (*((volatile unsigned int*)(0x42A70894UL)))
#define bM4_PORT_PODRE_POUT06                     (*((volatile unsigned int*)(0x42A70898UL)))
#define bM4_PORT_PODRE_POUT07                     (*((volatile unsigned int*)(0x42A7089CUL)))
#define bM4_PORT_PODRE_POUT08                     (*((volatile unsigned int*)(0x42A708A0UL)))
#define bM4_PORT_PODRE_POUT09                     (*((volatile unsigned int*)(0x42A708A4UL)))
#define bM4_PORT_PODRE_POUT10                     (*((volatile unsigned int*)(0x42A708A8UL)))
#define bM4_PORT_PODRE_POUT11                     (*((volatile unsigned int*)(0x42A708ACUL)))
#define bM4_PORT_PODRE_POUT12                     (*((volatile unsigned int*)(0x42A708B0UL)))
#define bM4_PORT_PODRE_POUT13                     (*((volatile unsigned int*)(0x42A708B4UL)))
#define bM4_PORT_PODRE_POUT14                     (*((volatile unsigned int*)(0x42A708B8UL)))
#define bM4_PORT_PODRE_POUT15                     (*((volatile unsigned int*)(0x42A708BCUL)))
#define bM4_PORT_POERE_POUTE00                    (*((volatile unsigned int*)(0x42A708C0UL)))
#define bM4_PORT_POERE_POUTE01                    (*((volatile unsigned int*)(0x42A708C4UL)))
#define bM4_PORT_POERE_POUTE02                    (*((volatile unsigned int*)(0x42A708C8UL)))
#define bM4_PORT_POERE_POUTE03                    (*((volatile unsigned int*)(0x42A708CCUL)))
#define bM4_PORT_POERE_POUTE04                    (*((volatile unsigned int*)(0x42A708D0UL)))
#define bM4_PORT_POERE_POUTE05                    (*((volatile unsigned int*)(0x42A708D4UL)))
#define bM4_PORT_POERE_POUTE06                    (*((volatile unsigned int*)(0x42A708D8UL)))
#define bM4_PORT_POERE_POUTE07                    (*((volatile unsigned int*)(0x42A708DCUL)))
#define bM4_PORT_POERE_POUTE08                    (*((volatile unsigned int*)(0x42A708E0UL)))
#define bM4_PORT_POERE_POUTE09                    (*((volatile unsigned int*)(0x42A708E4UL)))
#define bM4_PORT_POERE_POUTE10                    (*((volatile unsigned int*)(0x42A708E8UL)))
#define bM4_PORT_POERE_POUTE11                    (*((volatile unsigned int*)(0x42A708ECUL)))
#define bM4_PORT_POERE_POUTE12                    (*((volatile unsigned int*)(0x42A708F0UL)))
#define bM4_PORT_POERE_POUTE13                    (*((volatile unsigned int*)(0x42A708F4UL)))
#define bM4_PORT_POERE_POUTE14                    (*((volatile unsigned int*)(0x42A708F8UL)))
#define bM4_PORT_POERE_POUTE15                    (*((volatile unsigned int*)(0x42A708FCUL)))
#define bM4_PORT_POSRE_POS00                      (*((volatile unsigned int*)(0x42A70900UL)))
#define bM4_PORT_POSRE_POS01                      (*((volatile unsigned int*)(0x42A70904UL)))
#define bM4_PORT_POSRE_POS02                      (*((volatile unsigned int*)(0x42A70908UL)))
#define bM4_PORT_POSRE_POS03                      (*((volatile unsigned int*)(0x42A7090CUL)))
#define bM4_PORT_POSRE_POS04                      (*((volatile unsigned int*)(0x42A70910UL)))
#define bM4_PORT_POSRE_POS05                      (*((volatile unsigned int*)(0x42A70914UL)))
#define bM4_PORT_POSRE_POS06                      (*((volatile unsigned int*)(0x42A70918UL)))
#define bM4_PORT_POSRE_POS07                      (*((volatile unsigned int*)(0x42A7091CUL)))
#define bM4_PORT_POSRE_POS08                      (*((volatile unsigned int*)(0x42A70920UL)))
#define bM4_PORT_POSRE_POS09                      (*((volatile unsigned int*)(0x42A70924UL)))
#define bM4_PORT_POSRE_POS10                      (*((volatile unsigned int*)(0x42A70928UL)))
#define bM4_PORT_POSRE_POS11                      (*((volatile unsigned int*)(0x42A7092CUL)))
#define bM4_PORT_POSRE_POS12                      (*((volatile unsigned int*)(0x42A70930UL)))
#define bM4_PORT_POSRE_POS13                      (*((volatile unsigned int*)(0x42A70934UL)))
#define bM4_PORT_POSRE_POS14                      (*((volatile unsigned int*)(0x42A70938UL)))
#define bM4_PORT_POSRE_POS15                      (*((volatile unsigned int*)(0x42A7093CUL)))
#define bM4_PORT_PORRE_POR00                      (*((volatile unsigned int*)(0x42A70940UL)))
#define bM4_PORT_PORRE_POR01                      (*((volatile unsigned int*)(0x42A70944UL)))
#define bM4_PORT_PORRE_POR02                      (*((volatile unsigned int*)(0x42A70948UL)))
#define bM4_PORT_PORRE_POR03                      (*((volatile unsigned int*)(0x42A7094CUL)))
#define bM4_PORT_PORRE_POR04                      (*((volatile unsigned int*)(0x42A70950UL)))
#define bM4_PORT_PORRE_POR05                      (*((volatile unsigned int*)(0x42A70954UL)))
#define bM4_PORT_PORRE_POR06                      (*((volatile unsigned int*)(0x42A70958UL)))
#define bM4_PORT_PORRE_POR07                      (*((volatile unsigned int*)(0x42A7095CUL)))
#define bM4_PORT_PORRE_POR08                      (*((volatile unsigned int*)(0x42A70960UL)))
#define bM4_PORT_PORRE_POR09                      (*((volatile unsigned int*)(0x42A70964UL)))
#define bM4_PORT_PORRE_POR10                      (*((volatile unsigned int*)(0x42A70968UL)))
#define bM4_PORT_PORRE_POR11                      (*((volatile unsigned int*)(0x42A7096CUL)))
#define bM4_PORT_PORRE_POR12                      (*((volatile unsigned int*)(0x42A70970UL)))
#define bM4_PORT_PORRE_POR13                      (*((volatile unsigned int*)(0x42A70974UL)))
#define bM4_PORT_PORRE_POR14                      (*((volatile unsigned int*)(0x42A70978UL)))
#define bM4_PORT_PORRE_POR15                      (*((volatile unsigned int*)(0x42A7097CUL)))
#define bM4_PORT_POTRE_POT00                      (*((volatile unsigned int*)(0x42A70980UL)))
#define bM4_PORT_POTRE_POT01                      (*((volatile unsigned int*)(0x42A70984UL)))
#define bM4_PORT_POTRE_POT02                      (*((volatile unsigned int*)(0x42A70988UL)))
#define bM4_PORT_POTRE_POT03                      (*((volatile unsigned int*)(0x42A7098CUL)))
#define bM4_PORT_POTRE_POT04                      (*((volatile unsigned int*)(0x42A70990UL)))
#define bM4_PORT_POTRE_POT05                      (*((volatile unsigned int*)(0x42A70994UL)))
#define bM4_PORT_POTRE_POT06                      (*((volatile unsigned int*)(0x42A70998UL)))
#define bM4_PORT_POTRE_POT07                      (*((volatile unsigned int*)(0x42A7099CUL)))
#define bM4_PORT_POTRE_POT08                      (*((volatile unsigned int*)(0x42A709A0UL)))
#define bM4_PORT_POTRE_POT09                      (*((volatile unsigned int*)(0x42A709A4UL)))
#define bM4_PORT_POTRE_POT10                      (*((volatile unsigned int*)(0x42A709A8UL)))
#define bM4_PORT_POTRE_POT11                      (*((volatile unsigned int*)(0x42A709ACUL)))
#define bM4_PORT_POTRE_POT12                      (*((volatile unsigned int*)(0x42A709B0UL)))
#define bM4_PORT_POTRE_POT13                      (*((volatile unsigned int*)(0x42A709B4UL)))
#define bM4_PORT_POTRE_POT14                      (*((volatile unsigned int*)(0x42A709B8UL)))
#define bM4_PORT_POTRE_POT15                      (*((volatile unsigned int*)(0x42A709BCUL)))
#define bM4_PORT_PIDRH_PIN00                      (*((volatile unsigned int*)(0x42A70A00UL)))
#define bM4_PORT_PIDRH_PIN01                      (*((volatile unsigned int*)(0x42A70A04UL)))
#define bM4_PORT_PIDRH_PIN02                      (*((volatile unsigned int*)(0x42A70A08UL)))
#define bM4_PORT_PODRH_POUT00                     (*((volatile unsigned int*)(0x42A70A80UL)))
#define bM4_PORT_PODRH_POUT01                     (*((volatile unsigned int*)(0x42A70A84UL)))
#define bM4_PORT_PODRH_POUT02                     (*((volatile unsigned int*)(0x42A70A88UL)))
#define bM4_PORT_POERH_POUTE00                    (*((volatile unsigned int*)(0x42A70AC0UL)))
#define bM4_PORT_POERH_POUTE01                    (*((volatile unsigned int*)(0x42A70AC4UL)))
#define bM4_PORT_POERH_POUTE02                    (*((volatile unsigned int*)(0x42A70AC8UL)))
#define bM4_PORT_POSRH_POS00                      (*((volatile unsigned int*)(0x42A70B00UL)))
#define bM4_PORT_POSRH_POS01                      (*((volatile unsigned int*)(0x42A70B04UL)))
#define bM4_PORT_POSRH_POS02                      (*((volatile unsigned int*)(0x42A70B08UL)))
#define bM4_PORT_PORRH_POR00                      (*((volatile unsigned int*)(0x42A70B40UL)))
#define bM4_PORT_PORRH_POR01                      (*((volatile unsigned int*)(0x42A70B44UL)))
#define bM4_PORT_PORRH_POR02                      (*((volatile unsigned int*)(0x42A70B48UL)))
#define bM4_PORT_POTRH_POT00                      (*((volatile unsigned int*)(0x42A70B80UL)))
#define bM4_PORT_POTRH_POT01                      (*((volatile unsigned int*)(0x42A70B84UL)))
#define bM4_PORT_POTRH_POT02                      (*((volatile unsigned int*)(0x42A70B88UL)))
#define bM4_PORT_PSPCR_SPFE0                      (*((volatile unsigned int*)(0x42A77E80UL)))
#define bM4_PORT_PSPCR_SPFE1                      (*((volatile unsigned int*)(0x42A77E84UL)))
#define bM4_PORT_PSPCR_SPFE2                      (*((volatile unsigned int*)(0x42A77E88UL)))
#define bM4_PORT_PSPCR_SPFE3                      (*((volatile unsigned int*)(0x42A77E8CUL)))
#define bM4_PORT_PSPCR_SPFE4                      (*((volatile unsigned int*)(0x42A77E90UL)))
#define bM4_PORT_PCCR_BFSEL0                      (*((volatile unsigned int*)(0x42A77F00UL)))
#define bM4_PORT_PCCR_BFSEL1                      (*((volatile unsigned int*)(0x42A77F04UL)))
#define bM4_PORT_PCCR_BFSEL2                      (*((volatile unsigned int*)(0x42A77F08UL)))
#define bM4_PORT_PCCR_BFSEL3                      (*((volatile unsigned int*)(0x42A77F0CUL)))
#define bM4_PORT_PCCR_RDWT0                       (*((volatile unsigned int*)(0x42A77F38UL)))
#define bM4_PORT_PCCR_RDWT1                       (*((volatile unsigned int*)(0x42A77F3CUL)))
#define bM4_PORT_PINAER_PINAE0                    (*((volatile unsigned int*)(0x42A77F40UL)))
#define bM4_PORT_PINAER_PINAE1                    (*((volatile unsigned int*)(0x42A77F44UL)))
#define bM4_PORT_PINAER_PINAE2                    (*((volatile unsigned int*)(0x42A77F48UL)))
#define bM4_PORT_PINAER_PINAE3                    (*((volatile unsigned int*)(0x42A77F4CUL)))
#define bM4_PORT_PINAER_PINAE4                    (*((volatile unsigned int*)(0x42A77F50UL)))
#define bM4_PORT_PINAER_PINAE5                    (*((volatile unsigned int*)(0x42A77F54UL)))
#define bM4_PORT_PWPR_WE                          (*((volatile unsigned int*)(0x42A77F80UL)))
#define bM4_PORT_PWPR_WP0                         (*((volatile unsigned int*)(0x42A77FA0UL)))
#define bM4_PORT_PWPR_WP1                         (*((volatile unsigned int*)(0x42A77FA4UL)))
#define bM4_PORT_PWPR_WP2                         (*((volatile unsigned int*)(0x42A77FA8UL)))
#define bM4_PORT_PWPR_WP3                         (*((volatile unsigned int*)(0x42A77FACUL)))
#define bM4_PORT_PWPR_WP4                         (*((volatile unsigned int*)(0x42A77FB0UL)))
#define bM4_PORT_PWPR_WP5                         (*((volatile unsigned int*)(0x42A77FB4UL)))
#define bM4_PORT_PWPR_WP6                         (*((volatile unsigned int*)(0x42A77FB8UL)))
#define bM4_PORT_PWPR_WP7                         (*((volatile unsigned int*)(0x42A77FBCUL)))
#define bM4_PORT_PCRA0_POUT                       (*((volatile unsigned int*)(0x42A78000UL)))
#define bM4_PORT_PCRA0_POUTE                      (*((volatile unsigned int*)(0x42A78004UL)))
#define bM4_PORT_PCRA0_NOD                        (*((volatile unsigned int*)(0x42A78008UL)))
#define bM4_PORT_PCRA0_DRV0                       (*((volatile unsigned int*)(0x42A78010UL)))
#define bM4_PORT_PCRA0_DRV1                       (*((volatile unsigned int*)(0x42A78014UL)))
#define bM4_PORT_PCRA0_PUU                        (*((volatile unsigned int*)(0x42A78018UL)))
#define bM4_PORT_PCRA0_PIN                        (*((volatile unsigned int*)(0x42A78020UL)))
#define bM4_PORT_PCRA0_INVE                       (*((volatile unsigned int*)(0x42A78024UL)))
#define bM4_PORT_PCRA0_INTE                       (*((volatile unsigned int*)(0x42A78030UL)))
#define bM4_PORT_PCRA0_LTE                        (*((volatile unsigned int*)(0x42A78038UL)))
#define bM4_PORT_PCRA0_DDIS                       (*((volatile unsigned int*)(0x42A7803CUL)))
#define bM4_PORT_PFSRA0_FSEL0                     (*((volatile unsigned int*)(0x42A78040UL)))
#define bM4_PORT_PFSRA0_FSEL1                     (*((volatile unsigned int*)(0x42A78044UL)))
#define bM4_PORT_PFSRA0_FSEL2                     (*((volatile unsigned int*)(0x42A78048UL)))
#define bM4_PORT_PFSRA0_FSEL3                     (*((volatile unsigned int*)(0x42A7804CUL)))
#define bM4_PORT_PFSRA0_FSEL4                     (*((volatile unsigned int*)(0x42A78050UL)))
#define bM4_PORT_PFSRA0_FSEL5                     (*((volatile unsigned int*)(0x42A78054UL)))
#define bM4_PORT_PFSRA0_BFE                       (*((volatile unsigned int*)(0x42A78060UL)))
#define bM4_PORT_PCRA1_POUT                       (*((volatile unsigned int*)(0x42A78080UL)))
#define bM4_PORT_PCRA1_POUTE                      (*((volatile unsigned int*)(0x42A78084UL)))
#define bM4_PORT_PCRA1_NOD                        (*((volatile unsigned int*)(0x42A78088UL)))
#define bM4_PORT_PCRA1_DRV0                       (*((volatile unsigned int*)(0x42A78090UL)))
#define bM4_PORT_PCRA1_DRV1                       (*((volatile unsigned int*)(0x42A78094UL)))
#define bM4_PORT_PCRA1_PUU                        (*((volatile unsigned int*)(0x42A78098UL)))
#define bM4_PORT_PCRA1_PIN                        (*((volatile unsigned int*)(0x42A780A0UL)))
#define bM4_PORT_PCRA1_INVE                       (*((volatile unsigned int*)(0x42A780A4UL)))
#define bM4_PORT_PCRA1_INTE                       (*((volatile unsigned int*)(0x42A780B0UL)))
#define bM4_PORT_PCRA1_LTE                        (*((volatile unsigned int*)(0x42A780B8UL)))
#define bM4_PORT_PCRA1_DDIS                       (*((volatile unsigned int*)(0x42A780BCUL)))
#define bM4_PORT_PFSRA1_FSEL0                     (*((volatile unsigned int*)(0x42A780C0UL)))
#define bM4_PORT_PFSRA1_FSEL1                     (*((volatile unsigned int*)(0x42A780C4UL)))
#define bM4_PORT_PFSRA1_FSEL2                     (*((volatile unsigned int*)(0x42A780C8UL)))
#define bM4_PORT_PFSRA1_FSEL3                     (*((volatile unsigned int*)(0x42A780CCUL)))
#define bM4_PORT_PFSRA1_FSEL4                     (*((volatile unsigned int*)(0x42A780D0UL)))
#define bM4_PORT_PFSRA1_FSEL5                     (*((volatile unsigned int*)(0x42A780D4UL)))
#define bM4_PORT_PFSRA1_BFE                       (*((volatile unsigned int*)(0x42A780E0UL)))
#define bM4_PORT_PCRA2_POUT                       (*((volatile unsigned int*)(0x42A78100UL)))
#define bM4_PORT_PCRA2_POUTE                      (*((volatile unsigned int*)(0x42A78104UL)))
#define bM4_PORT_PCRA2_NOD                        (*((volatile unsigned int*)(0x42A78108UL)))
#define bM4_PORT_PCRA2_DRV0                       (*((volatile unsigned int*)(0x42A78110UL)))
#define bM4_PORT_PCRA2_DRV1                       (*((volatile unsigned int*)(0x42A78114UL)))
#define bM4_PORT_PCRA2_PUU                        (*((volatile unsigned int*)(0x42A78118UL)))
#define bM4_PORT_PCRA2_PIN                        (*((volatile unsigned int*)(0x42A78120UL)))
#define bM4_PORT_PCRA2_INVE                       (*((volatile unsigned int*)(0x42A78124UL)))
#define bM4_PORT_PCRA2_INTE                       (*((volatile unsigned int*)(0x42A78130UL)))
#define bM4_PORT_PCRA2_LTE                        (*((volatile unsigned int*)(0x42A78138UL)))
#define bM4_PORT_PCRA2_DDIS                       (*((volatile unsigned int*)(0x42A7813CUL)))
#define bM4_PORT_PFSRA2_FSEL0                     (*((volatile unsigned int*)(0x42A78140UL)))
#define bM4_PORT_PFSRA2_FSEL1                     (*((volatile unsigned int*)(0x42A78144UL)))
#define bM4_PORT_PFSRA2_FSEL2                     (*((volatile unsigned int*)(0x42A78148UL)))
#define bM4_PORT_PFSRA2_FSEL3                     (*((volatile unsigned int*)(0x42A7814CUL)))
#define bM4_PORT_PFSRA2_FSEL4                     (*((volatile unsigned int*)(0x42A78150UL)))
#define bM4_PORT_PFSRA2_FSEL5                     (*((volatile unsigned int*)(0x42A78154UL)))
#define bM4_PORT_PFSRA2_BFE                       (*((volatile unsigned int*)(0x42A78160UL)))
#define bM4_PORT_PCRA3_POUT                       (*((volatile unsigned int*)(0x42A78180UL)))
#define bM4_PORT_PCRA3_POUTE                      (*((volatile unsigned int*)(0x42A78184UL)))
#define bM4_PORT_PCRA3_NOD                        (*((volatile unsigned int*)(0x42A78188UL)))
#define bM4_PORT_PCRA3_DRV0                       (*((volatile unsigned int*)(0x42A78190UL)))
#define bM4_PORT_PCRA3_DRV1                       (*((volatile unsigned int*)(0x42A78194UL)))
#define bM4_PORT_PCRA3_PUU                        (*((volatile unsigned int*)(0x42A78198UL)))
#define bM4_PORT_PCRA3_PIN                        (*((volatile unsigned int*)(0x42A781A0UL)))
#define bM4_PORT_PCRA3_INVE                       (*((volatile unsigned int*)(0x42A781A4UL)))
#define bM4_PORT_PCRA3_INTE                       (*((volatile unsigned int*)(0x42A781B0UL)))
#define bM4_PORT_PCRA3_LTE                        (*((volatile unsigned int*)(0x42A781B8UL)))
#define bM4_PORT_PCRA3_DDIS                       (*((volatile unsigned int*)(0x42A781BCUL)))
#define bM4_PORT_PFSRA3_FSEL0                     (*((volatile unsigned int*)(0x42A781C0UL)))
#define bM4_PORT_PFSRA3_FSEL1                     (*((volatile unsigned int*)(0x42A781C4UL)))
#define bM4_PORT_PFSRA3_FSEL2                     (*((volatile unsigned int*)(0x42A781C8UL)))
#define bM4_PORT_PFSRA3_FSEL3                     (*((volatile unsigned int*)(0x42A781CCUL)))
#define bM4_PORT_PFSRA3_FSEL4                     (*((volatile unsigned int*)(0x42A781D0UL)))
#define bM4_PORT_PFSRA3_FSEL5                     (*((volatile unsigned int*)(0x42A781D4UL)))
#define bM4_PORT_PFSRA3_BFE                       (*((volatile unsigned int*)(0x42A781E0UL)))
#define bM4_PORT_PCRA4_POUT                       (*((volatile unsigned int*)(0x42A78200UL)))
#define bM4_PORT_PCRA4_POUTE                      (*((volatile unsigned int*)(0x42A78204UL)))
#define bM4_PORT_PCRA4_NOD                        (*((volatile unsigned int*)(0x42A78208UL)))
#define bM4_PORT_PCRA4_DRV0                       (*((volatile unsigned int*)(0x42A78210UL)))
#define bM4_PORT_PCRA4_DRV1                       (*((volatile unsigned int*)(0x42A78214UL)))
#define bM4_PORT_PCRA4_PUU                        (*((volatile unsigned int*)(0x42A78218UL)))
#define bM4_PORT_PCRA4_PIN                        (*((volatile unsigned int*)(0x42A78220UL)))
#define bM4_PORT_PCRA4_INVE                       (*((volatile unsigned int*)(0x42A78224UL)))
#define bM4_PORT_PCRA4_INTE                       (*((volatile unsigned int*)(0x42A78230UL)))
#define bM4_PORT_PCRA4_LTE                        (*((volatile unsigned int*)(0x42A78238UL)))
#define bM4_PORT_PCRA4_DDIS                       (*((volatile unsigned int*)(0x42A7823CUL)))
#define bM4_PORT_PFSRA4_FSEL0                     (*((volatile unsigned int*)(0x42A78240UL)))
#define bM4_PORT_PFSRA4_FSEL1                     (*((volatile unsigned int*)(0x42A78244UL)))
#define bM4_PORT_PFSRA4_FSEL2                     (*((volatile unsigned int*)(0x42A78248UL)))
#define bM4_PORT_PFSRA4_FSEL3                     (*((volatile unsigned int*)(0x42A7824CUL)))
#define bM4_PORT_PFSRA4_FSEL4                     (*((volatile unsigned int*)(0x42A78250UL)))
#define bM4_PORT_PFSRA4_FSEL5                     (*((volatile unsigned int*)(0x42A78254UL)))
#define bM4_PORT_PFSRA4_BFE                       (*((volatile unsigned int*)(0x42A78260UL)))
#define bM4_PORT_PCRA5_POUT                       (*((volatile unsigned int*)(0x42A78280UL)))
#define bM4_PORT_PCRA5_POUTE                      (*((volatile unsigned int*)(0x42A78284UL)))
#define bM4_PORT_PCRA5_NOD                        (*((volatile unsigned int*)(0x42A78288UL)))
#define bM4_PORT_PCRA5_DRV0                       (*((volatile unsigned int*)(0x42A78290UL)))
#define bM4_PORT_PCRA5_DRV1                       (*((volatile unsigned int*)(0x42A78294UL)))
#define bM4_PORT_PCRA5_PUU                        (*((volatile unsigned int*)(0x42A78298UL)))
#define bM4_PORT_PCRA5_PIN                        (*((volatile unsigned int*)(0x42A782A0UL)))
#define bM4_PORT_PCRA5_INVE                       (*((volatile unsigned int*)(0x42A782A4UL)))
#define bM4_PORT_PCRA5_INTE                       (*((volatile unsigned int*)(0x42A782B0UL)))
#define bM4_PORT_PCRA5_LTE                        (*((volatile unsigned int*)(0x42A782B8UL)))
#define bM4_PORT_PCRA5_DDIS                       (*((volatile unsigned int*)(0x42A782BCUL)))
#define bM4_PORT_PFSRA5_FSEL0                     (*((volatile unsigned int*)(0x42A782C0UL)))
#define bM4_PORT_PFSRA5_FSEL1                     (*((volatile unsigned int*)(0x42A782C4UL)))
#define bM4_PORT_PFSRA5_FSEL2                     (*((volatile unsigned int*)(0x42A782C8UL)))
#define bM4_PORT_PFSRA5_FSEL3                     (*((volatile unsigned int*)(0x42A782CCUL)))
#define bM4_PORT_PFSRA5_FSEL4                     (*((volatile unsigned int*)(0x42A782D0UL)))
#define bM4_PORT_PFSRA5_FSEL5                     (*((volatile unsigned int*)(0x42A782D4UL)))
#define bM4_PORT_PFSRA5_BFE                       (*((volatile unsigned int*)(0x42A782E0UL)))
#define bM4_PORT_PCRA6_POUT                       (*((volatile unsigned int*)(0x42A78300UL)))
#define bM4_PORT_PCRA6_POUTE                      (*((volatile unsigned int*)(0x42A78304UL)))
#define bM4_PORT_PCRA6_NOD                        (*((volatile unsigned int*)(0x42A78308UL)))
#define bM4_PORT_PCRA6_DRV0                       (*((volatile unsigned int*)(0x42A78310UL)))
#define bM4_PORT_PCRA6_DRV1                       (*((volatile unsigned int*)(0x42A78314UL)))
#define bM4_PORT_PCRA6_PUU                        (*((volatile unsigned int*)(0x42A78318UL)))
#define bM4_PORT_PCRA6_PIN                        (*((volatile unsigned int*)(0x42A78320UL)))
#define bM4_PORT_PCRA6_INVE                       (*((volatile unsigned int*)(0x42A78324UL)))
#define bM4_PORT_PCRA6_INTE                       (*((volatile unsigned int*)(0x42A78330UL)))
#define bM4_PORT_PCRA6_LTE                        (*((volatile unsigned int*)(0x42A78338UL)))
#define bM4_PORT_PCRA6_DDIS                       (*((volatile unsigned int*)(0x42A7833CUL)))
#define bM4_PORT_PFSRA6_FSEL0                     (*((volatile unsigned int*)(0x42A78340UL)))
#define bM4_PORT_PFSRA6_FSEL1                     (*((volatile unsigned int*)(0x42A78344UL)))
#define bM4_PORT_PFSRA6_FSEL2                     (*((volatile unsigned int*)(0x42A78348UL)))
#define bM4_PORT_PFSRA6_FSEL3                     (*((volatile unsigned int*)(0x42A7834CUL)))
#define bM4_PORT_PFSRA6_FSEL4                     (*((volatile unsigned int*)(0x42A78350UL)))
#define bM4_PORT_PFSRA6_FSEL5                     (*((volatile unsigned int*)(0x42A78354UL)))
#define bM4_PORT_PFSRA6_BFE                       (*((volatile unsigned int*)(0x42A78360UL)))
#define bM4_PORT_PCRA7_POUT                       (*((volatile unsigned int*)(0x42A78380UL)))
#define bM4_PORT_PCRA7_POUTE                      (*((volatile unsigned int*)(0x42A78384UL)))
#define bM4_PORT_PCRA7_NOD                        (*((volatile unsigned int*)(0x42A78388UL)))
#define bM4_PORT_PCRA7_DRV0                       (*((volatile unsigned int*)(0x42A78390UL)))
#define bM4_PORT_PCRA7_DRV1                       (*((volatile unsigned int*)(0x42A78394UL)))
#define bM4_PORT_PCRA7_PUU                        (*((volatile unsigned int*)(0x42A78398UL)))
#define bM4_PORT_PCRA7_PIN                        (*((volatile unsigned int*)(0x42A783A0UL)))
#define bM4_PORT_PCRA7_INVE                       (*((volatile unsigned int*)(0x42A783A4UL)))
#define bM4_PORT_PCRA7_INTE                       (*((volatile unsigned int*)(0x42A783B0UL)))
#define bM4_PORT_PCRA7_LTE                        (*((volatile unsigned int*)(0x42A783B8UL)))
#define bM4_PORT_PCRA7_DDIS                       (*((volatile unsigned int*)(0x42A783BCUL)))
#define bM4_PORT_PFSRA7_FSEL0                     (*((volatile unsigned int*)(0x42A783C0UL)))
#define bM4_PORT_PFSRA7_FSEL1                     (*((volatile unsigned int*)(0x42A783C4UL)))
#define bM4_PORT_PFSRA7_FSEL2                     (*((volatile unsigned int*)(0x42A783C8UL)))
#define bM4_PORT_PFSRA7_FSEL3                     (*((volatile unsigned int*)(0x42A783CCUL)))
#define bM4_PORT_PFSRA7_FSEL4                     (*((volatile unsigned int*)(0x42A783D0UL)))
#define bM4_PORT_PFSRA7_FSEL5                     (*((volatile unsigned int*)(0x42A783D4UL)))
#define bM4_PORT_PFSRA7_BFE                       (*((volatile unsigned int*)(0x42A783E0UL)))
#define bM4_PORT_PCRA8_POUT                       (*((volatile unsigned int*)(0x42A78400UL)))
#define bM4_PORT_PCRA8_POUTE                      (*((volatile unsigned int*)(0x42A78404UL)))
#define bM4_PORT_PCRA8_NOD                        (*((volatile unsigned int*)(0x42A78408UL)))
#define bM4_PORT_PCRA8_DRV0                       (*((volatile unsigned int*)(0x42A78410UL)))
#define bM4_PORT_PCRA8_DRV1                       (*((volatile unsigned int*)(0x42A78414UL)))
#define bM4_PORT_PCRA8_PUU                        (*((volatile unsigned int*)(0x42A78418UL)))
#define bM4_PORT_PCRA8_PIN                        (*((volatile unsigned int*)(0x42A78420UL)))
#define bM4_PORT_PCRA8_INVE                       (*((volatile unsigned int*)(0x42A78424UL)))
#define bM4_PORT_PCRA8_INTE                       (*((volatile unsigned int*)(0x42A78430UL)))
#define bM4_PORT_PCRA8_LTE                        (*((volatile unsigned int*)(0x42A78438UL)))
#define bM4_PORT_PCRA8_DDIS                       (*((volatile unsigned int*)(0x42A7843CUL)))
#define bM4_PORT_PFSRA8_FSEL0                     (*((volatile unsigned int*)(0x42A78440UL)))
#define bM4_PORT_PFSRA8_FSEL1                     (*((volatile unsigned int*)(0x42A78444UL)))
#define bM4_PORT_PFSRA8_FSEL2                     (*((volatile unsigned int*)(0x42A78448UL)))
#define bM4_PORT_PFSRA8_FSEL3                     (*((volatile unsigned int*)(0x42A7844CUL)))
#define bM4_PORT_PFSRA8_FSEL4                     (*((volatile unsigned int*)(0x42A78450UL)))
#define bM4_PORT_PFSRA8_FSEL5                     (*((volatile unsigned int*)(0x42A78454UL)))
#define bM4_PORT_PFSRA8_BFE                       (*((volatile unsigned int*)(0x42A78460UL)))
#define bM4_PORT_PCRA9_POUT                       (*((volatile unsigned int*)(0x42A78480UL)))
#define bM4_PORT_PCRA9_POUTE                      (*((volatile unsigned int*)(0x42A78484UL)))
#define bM4_PORT_PCRA9_NOD                        (*((volatile unsigned int*)(0x42A78488UL)))
#define bM4_PORT_PCRA9_DRV0                       (*((volatile unsigned int*)(0x42A78490UL)))
#define bM4_PORT_PCRA9_DRV1                       (*((volatile unsigned int*)(0x42A78494UL)))
#define bM4_PORT_PCRA9_PUU                        (*((volatile unsigned int*)(0x42A78498UL)))
#define bM4_PORT_PCRA9_PIN                        (*((volatile unsigned int*)(0x42A784A0UL)))
#define bM4_PORT_PCRA9_INVE                       (*((volatile unsigned int*)(0x42A784A4UL)))
#define bM4_PORT_PCRA9_INTE                       (*((volatile unsigned int*)(0x42A784B0UL)))
#define bM4_PORT_PCRA9_LTE                        (*((volatile unsigned int*)(0x42A784B8UL)))
#define bM4_PORT_PCRA9_DDIS                       (*((volatile unsigned int*)(0x42A784BCUL)))
#define bM4_PORT_PFSRA9_FSEL0                     (*((volatile unsigned int*)(0x42A784C0UL)))
#define bM4_PORT_PFSRA9_FSEL1                     (*((volatile unsigned int*)(0x42A784C4UL)))
#define bM4_PORT_PFSRA9_FSEL2                     (*((volatile unsigned int*)(0x42A784C8UL)))
#define bM4_PORT_PFSRA9_FSEL3                     (*((volatile unsigned int*)(0x42A784CCUL)))
#define bM4_PORT_PFSRA9_FSEL4                     (*((volatile unsigned int*)(0x42A784D0UL)))
#define bM4_PORT_PFSRA9_FSEL5                     (*((volatile unsigned int*)(0x42A784D4UL)))
#define bM4_PORT_PFSRA9_BFE                       (*((volatile unsigned int*)(0x42A784E0UL)))
#define bM4_PORT_PCRA10_POUT                      (*((volatile unsigned int*)(0x42A78500UL)))
#define bM4_PORT_PCRA10_POUTE                     (*((volatile unsigned int*)(0x42A78504UL)))
#define bM4_PORT_PCRA10_NOD                       (*((volatile unsigned int*)(0x42A78508UL)))
#define bM4_PORT_PCRA10_DRV0                      (*((volatile unsigned int*)(0x42A78510UL)))
#define bM4_PORT_PCRA10_DRV1                      (*((volatile unsigned int*)(0x42A78514UL)))
#define bM4_PORT_PCRA10_PUU                       (*((volatile unsigned int*)(0x42A78518UL)))
#define bM4_PORT_PCRA10_PIN                       (*((volatile unsigned int*)(0x42A78520UL)))
#define bM4_PORT_PCRA10_INVE                      (*((volatile unsigned int*)(0x42A78524UL)))
#define bM4_PORT_PCRA10_INTE                      (*((volatile unsigned int*)(0x42A78530UL)))
#define bM4_PORT_PCRA10_LTE                       (*((volatile unsigned int*)(0x42A78538UL)))
#define bM4_PORT_PCRA10_DDIS                      (*((volatile unsigned int*)(0x42A7853CUL)))
#define bM4_PORT_PFSRA10_FSEL0                    (*((volatile unsigned int*)(0x42A78540UL)))
#define bM4_PORT_PFSRA10_FSEL1                    (*((volatile unsigned int*)(0x42A78544UL)))
#define bM4_PORT_PFSRA10_FSEL2                    (*((volatile unsigned int*)(0x42A78548UL)))
#define bM4_PORT_PFSRA10_FSEL3                    (*((volatile unsigned int*)(0x42A7854CUL)))
#define bM4_PORT_PFSRA10_FSEL4                    (*((volatile unsigned int*)(0x42A78550UL)))
#define bM4_PORT_PFSRA10_FSEL5                    (*((volatile unsigned int*)(0x42A78554UL)))
#define bM4_PORT_PFSRA10_BFE                      (*((volatile unsigned int*)(0x42A78560UL)))
#define bM4_PORT_PCRA11_POUT                      (*((volatile unsigned int*)(0x42A78580UL)))
#define bM4_PORT_PCRA11_POUTE                     (*((volatile unsigned int*)(0x42A78584UL)))
#define bM4_PORT_PCRA11_NOD                       (*((volatile unsigned int*)(0x42A78588UL)))
#define bM4_PORT_PCRA11_DRV0                      (*((volatile unsigned int*)(0x42A78590UL)))
#define bM4_PORT_PCRA11_DRV1                      (*((volatile unsigned int*)(0x42A78594UL)))
#define bM4_PORT_PCRA11_PUU                       (*((volatile unsigned int*)(0x42A78598UL)))
#define bM4_PORT_PCRA11_PIN                       (*((volatile unsigned int*)(0x42A785A0UL)))
#define bM4_PORT_PCRA11_INVE                      (*((volatile unsigned int*)(0x42A785A4UL)))
#define bM4_PORT_PCRA11_INTE                      (*((volatile unsigned int*)(0x42A785B0UL)))
#define bM4_PORT_PCRA11_LTE                       (*((volatile unsigned int*)(0x42A785B8UL)))
#define bM4_PORT_PCRA11_DDIS                      (*((volatile unsigned int*)(0x42A785BCUL)))
#define bM4_PORT_PFSRA11_FSEL0                    (*((volatile unsigned int*)(0x42A785C0UL)))
#define bM4_PORT_PFSRA11_FSEL1                    (*((volatile unsigned int*)(0x42A785C4UL)))
#define bM4_PORT_PFSRA11_FSEL2                    (*((volatile unsigned int*)(0x42A785C8UL)))
#define bM4_PORT_PFSRA11_FSEL3                    (*((volatile unsigned int*)(0x42A785CCUL)))
#define bM4_PORT_PFSRA11_FSEL4                    (*((volatile unsigned int*)(0x42A785D0UL)))
#define bM4_PORT_PFSRA11_FSEL5                    (*((volatile unsigned int*)(0x42A785D4UL)))
#define bM4_PORT_PFSRA11_BFE                      (*((volatile unsigned int*)(0x42A785E0UL)))
#define bM4_PORT_PCRA12_POUT                      (*((volatile unsigned int*)(0x42A78600UL)))
#define bM4_PORT_PCRA12_POUTE                     (*((volatile unsigned int*)(0x42A78604UL)))
#define bM4_PORT_PCRA12_NOD                       (*((volatile unsigned int*)(0x42A78608UL)))
#define bM4_PORT_PCRA12_DRV0                      (*((volatile unsigned int*)(0x42A78610UL)))
#define bM4_PORT_PCRA12_DRV1                      (*((volatile unsigned int*)(0x42A78614UL)))
#define bM4_PORT_PCRA12_PUU                       (*((volatile unsigned int*)(0x42A78618UL)))
#define bM4_PORT_PCRA12_PIN                       (*((volatile unsigned int*)(0x42A78620UL)))
#define bM4_PORT_PCRA12_INVE                      (*((volatile unsigned int*)(0x42A78624UL)))
#define bM4_PORT_PCRA12_INTE                      (*((volatile unsigned int*)(0x42A78630UL)))
#define bM4_PORT_PCRA12_LTE                       (*((volatile unsigned int*)(0x42A78638UL)))
#define bM4_PORT_PCRA12_DDIS                      (*((volatile unsigned int*)(0x42A7863CUL)))
#define bM4_PORT_PFSRA12_FSEL0                    (*((volatile unsigned int*)(0x42A78640UL)))
#define bM4_PORT_PFSRA12_FSEL1                    (*((volatile unsigned int*)(0x42A78644UL)))
#define bM4_PORT_PFSRA12_FSEL2                    (*((volatile unsigned int*)(0x42A78648UL)))
#define bM4_PORT_PFSRA12_FSEL3                    (*((volatile unsigned int*)(0x42A7864CUL)))
#define bM4_PORT_PFSRA12_FSEL4                    (*((volatile unsigned int*)(0x42A78650UL)))
#define bM4_PORT_PFSRA12_FSEL5                    (*((volatile unsigned int*)(0x42A78654UL)))
#define bM4_PORT_PFSRA12_BFE                      (*((volatile unsigned int*)(0x42A78660UL)))
#define bM4_PORT_PCRA13_POUT                      (*((volatile unsigned int*)(0x42A78680UL)))
#define bM4_PORT_PCRA13_POUTE                     (*((volatile unsigned int*)(0x42A78684UL)))
#define bM4_PORT_PCRA13_NOD                       (*((volatile unsigned int*)(0x42A78688UL)))
#define bM4_PORT_PCRA13_DRV0                      (*((volatile unsigned int*)(0x42A78690UL)))
#define bM4_PORT_PCRA13_DRV1                      (*((volatile unsigned int*)(0x42A78694UL)))
#define bM4_PORT_PCRA13_PUU                       (*((volatile unsigned int*)(0x42A78698UL)))
#define bM4_PORT_PCRA13_PIN                       (*((volatile unsigned int*)(0x42A786A0UL)))
#define bM4_PORT_PCRA13_INVE                      (*((volatile unsigned int*)(0x42A786A4UL)))
#define bM4_PORT_PCRA13_INTE                      (*((volatile unsigned int*)(0x42A786B0UL)))
#define bM4_PORT_PCRA13_LTE                       (*((volatile unsigned int*)(0x42A786B8UL)))
#define bM4_PORT_PCRA13_DDIS                      (*((volatile unsigned int*)(0x42A786BCUL)))
#define bM4_PORT_PFSRA13_FSEL0                    (*((volatile unsigned int*)(0x42A786C0UL)))
#define bM4_PORT_PFSRA13_FSEL1                    (*((volatile unsigned int*)(0x42A786C4UL)))
#define bM4_PORT_PFSRA13_FSEL2                    (*((volatile unsigned int*)(0x42A786C8UL)))
#define bM4_PORT_PFSRA13_FSEL3                    (*((volatile unsigned int*)(0x42A786CCUL)))
#define bM4_PORT_PFSRA13_FSEL4                    (*((volatile unsigned int*)(0x42A786D0UL)))
#define bM4_PORT_PFSRA13_FSEL5                    (*((volatile unsigned int*)(0x42A786D4UL)))
#define bM4_PORT_PFSRA13_BFE                      (*((volatile unsigned int*)(0x42A786E0UL)))
#define bM4_PORT_PCRA14_POUT                      (*((volatile unsigned int*)(0x42A78700UL)))
#define bM4_PORT_PCRA14_POUTE                     (*((volatile unsigned int*)(0x42A78704UL)))
#define bM4_PORT_PCRA14_NOD                       (*((volatile unsigned int*)(0x42A78708UL)))
#define bM4_PORT_PCRA14_DRV0                      (*((volatile unsigned int*)(0x42A78710UL)))
#define bM4_PORT_PCRA14_DRV1                      (*((volatile unsigned int*)(0x42A78714UL)))
#define bM4_PORT_PCRA14_PUU                       (*((volatile unsigned int*)(0x42A78718UL)))
#define bM4_PORT_PCRA14_PIN                       (*((volatile unsigned int*)(0x42A78720UL)))
#define bM4_PORT_PCRA14_INVE                      (*((volatile unsigned int*)(0x42A78724UL)))
#define bM4_PORT_PCRA14_INTE                      (*((volatile unsigned int*)(0x42A78730UL)))
#define bM4_PORT_PCRA14_LTE                       (*((volatile unsigned int*)(0x42A78738UL)))
#define bM4_PORT_PCRA14_DDIS                      (*((volatile unsigned int*)(0x42A7873CUL)))
#define bM4_PORT_PFSRA14_FSEL0                    (*((volatile unsigned int*)(0x42A78740UL)))
#define bM4_PORT_PFSRA14_FSEL1                    (*((volatile unsigned int*)(0x42A78744UL)))
#define bM4_PORT_PFSRA14_FSEL2                    (*((volatile unsigned int*)(0x42A78748UL)))
#define bM4_PORT_PFSRA14_FSEL3                    (*((volatile unsigned int*)(0x42A7874CUL)))
#define bM4_PORT_PFSRA14_FSEL4                    (*((volatile unsigned int*)(0x42A78750UL)))
#define bM4_PORT_PFSRA14_FSEL5                    (*((volatile unsigned int*)(0x42A78754UL)))
#define bM4_PORT_PFSRA14_BFE                      (*((volatile unsigned int*)(0x42A78760UL)))
#define bM4_PORT_PCRA15_POUT                      (*((volatile unsigned int*)(0x42A78780UL)))
#define bM4_PORT_PCRA15_POUTE                     (*((volatile unsigned int*)(0x42A78784UL)))
#define bM4_PORT_PCRA15_NOD                       (*((volatile unsigned int*)(0x42A78788UL)))
#define bM4_PORT_PCRA15_DRV0                      (*((volatile unsigned int*)(0x42A78790UL)))
#define bM4_PORT_PCRA15_DRV1                      (*((volatile unsigned int*)(0x42A78794UL)))
#define bM4_PORT_PCRA15_PUU                       (*((volatile unsigned int*)(0x42A78798UL)))
#define bM4_PORT_PCRA15_PIN                       (*((volatile unsigned int*)(0x42A787A0UL)))
#define bM4_PORT_PCRA15_INVE                      (*((volatile unsigned int*)(0x42A787A4UL)))
#define bM4_PORT_PCRA15_INTE                      (*((volatile unsigned int*)(0x42A787B0UL)))
#define bM4_PORT_PCRA15_LTE                       (*((volatile unsigned int*)(0x42A787B8UL)))
#define bM4_PORT_PCRA15_DDIS                      (*((volatile unsigned int*)(0x42A787BCUL)))
#define bM4_PORT_PFSRA15_FSEL0                    (*((volatile unsigned int*)(0x42A787C0UL)))
#define bM4_PORT_PFSRA15_FSEL1                    (*((volatile unsigned int*)(0x42A787C4UL)))
#define bM4_PORT_PFSRA15_FSEL2                    (*((volatile unsigned int*)(0x42A787C8UL)))
#define bM4_PORT_PFSRA15_FSEL3                    (*((volatile unsigned int*)(0x42A787CCUL)))
#define bM4_PORT_PFSRA15_FSEL4                    (*((volatile unsigned int*)(0x42A787D0UL)))
#define bM4_PORT_PFSRA15_FSEL5                    (*((volatile unsigned int*)(0x42A787D4UL)))
#define bM4_PORT_PFSRA15_BFE                      (*((volatile unsigned int*)(0x42A787E0UL)))
#define bM4_PORT_PCRB0_POUT                       (*((volatile unsigned int*)(0x42A78800UL)))
#define bM4_PORT_PCRB0_POUTE                      (*((volatile unsigned int*)(0x42A78804UL)))
#define bM4_PORT_PCRB0_NOD                        (*((volatile unsigned int*)(0x42A78808UL)))
#define bM4_PORT_PCRB0_DRV0                       (*((volatile unsigned int*)(0x42A78810UL)))
#define bM4_PORT_PCRB0_DRV1                       (*((volatile unsigned int*)(0x42A78814UL)))
#define bM4_PORT_PCRB0_PUU                        (*((volatile unsigned int*)(0x42A78818UL)))
#define bM4_PORT_PCRB0_PIN                        (*((volatile unsigned int*)(0x42A78820UL)))
#define bM4_PORT_PCRB0_INVE                       (*((volatile unsigned int*)(0x42A78824UL)))
#define bM4_PORT_PCRB0_INTE                       (*((volatile unsigned int*)(0x42A78830UL)))
#define bM4_PORT_PCRB0_LTE                        (*((volatile unsigned int*)(0x42A78838UL)))
#define bM4_PORT_PCRB0_DDIS                       (*((volatile unsigned int*)(0x42A7883CUL)))
#define bM4_PORT_PFSRB0_FSEL0                     (*((volatile unsigned int*)(0x42A78840UL)))
#define bM4_PORT_PFSRB0_FSEL1                     (*((volatile unsigned int*)(0x42A78844UL)))
#define bM4_PORT_PFSRB0_FSEL2                     (*((volatile unsigned int*)(0x42A78848UL)))
#define bM4_PORT_PFSRB0_FSEL3                     (*((volatile unsigned int*)(0x42A7884CUL)))
#define bM4_PORT_PFSRB0_FSEL4                     (*((volatile unsigned int*)(0x42A78850UL)))
#define bM4_PORT_PFSRB0_FSEL5                     (*((volatile unsigned int*)(0x42A78854UL)))
#define bM4_PORT_PFSRB0_BFE                       (*((volatile unsigned int*)(0x42A78860UL)))
#define bM4_PORT_PCRB1_POUT                       (*((volatile unsigned int*)(0x42A78880UL)))
#define bM4_PORT_PCRB1_POUTE                      (*((volatile unsigned int*)(0x42A78884UL)))
#define bM4_PORT_PCRB1_NOD                        (*((volatile unsigned int*)(0x42A78888UL)))
#define bM4_PORT_PCRB1_DRV0                       (*((volatile unsigned int*)(0x42A78890UL)))
#define bM4_PORT_PCRB1_DRV1                       (*((volatile unsigned int*)(0x42A78894UL)))
#define bM4_PORT_PCRB1_PUU                        (*((volatile unsigned int*)(0x42A78898UL)))
#define bM4_PORT_PCRB1_PIN                        (*((volatile unsigned int*)(0x42A788A0UL)))
#define bM4_PORT_PCRB1_INVE                       (*((volatile unsigned int*)(0x42A788A4UL)))
#define bM4_PORT_PCRB1_INTE                       (*((volatile unsigned int*)(0x42A788B0UL)))
#define bM4_PORT_PCRB1_LTE                        (*((volatile unsigned int*)(0x42A788B8UL)))
#define bM4_PORT_PCRB1_DDIS                       (*((volatile unsigned int*)(0x42A788BCUL)))
#define bM4_PORT_PFSRB1_FSEL0                     (*((volatile unsigned int*)(0x42A788C0UL)))
#define bM4_PORT_PFSRB1_FSEL1                     (*((volatile unsigned int*)(0x42A788C4UL)))
#define bM4_PORT_PFSRB1_FSEL2                     (*((volatile unsigned int*)(0x42A788C8UL)))
#define bM4_PORT_PFSRB1_FSEL3                     (*((volatile unsigned int*)(0x42A788CCUL)))
#define bM4_PORT_PFSRB1_FSEL4                     (*((volatile unsigned int*)(0x42A788D0UL)))
#define bM4_PORT_PFSRB1_FSEL5                     (*((volatile unsigned int*)(0x42A788D4UL)))
#define bM4_PORT_PFSRB1_BFE                       (*((volatile unsigned int*)(0x42A788E0UL)))
#define bM4_PORT_PCRB2_POUT                       (*((volatile unsigned int*)(0x42A78900UL)))
#define bM4_PORT_PCRB2_POUTE                      (*((volatile unsigned int*)(0x42A78904UL)))
#define bM4_PORT_PCRB2_NOD                        (*((volatile unsigned int*)(0x42A78908UL)))
#define bM4_PORT_PCRB2_DRV0                       (*((volatile unsigned int*)(0x42A78910UL)))
#define bM4_PORT_PCRB2_DRV1                       (*((volatile unsigned int*)(0x42A78914UL)))
#define bM4_PORT_PCRB2_PUU                        (*((volatile unsigned int*)(0x42A78918UL)))
#define bM4_PORT_PCRB2_PIN                        (*((volatile unsigned int*)(0x42A78920UL)))
#define bM4_PORT_PCRB2_INVE                       (*((volatile unsigned int*)(0x42A78924UL)))
#define bM4_PORT_PCRB2_INTE                       (*((volatile unsigned int*)(0x42A78930UL)))
#define bM4_PORT_PCRB2_LTE                        (*((volatile unsigned int*)(0x42A78938UL)))
#define bM4_PORT_PCRB2_DDIS                       (*((volatile unsigned int*)(0x42A7893CUL)))
#define bM4_PORT_PFSRB2_FSEL0                     (*((volatile unsigned int*)(0x42A78940UL)))
#define bM4_PORT_PFSRB2_FSEL1                     (*((volatile unsigned int*)(0x42A78944UL)))
#define bM4_PORT_PFSRB2_FSEL2                     (*((volatile unsigned int*)(0x42A78948UL)))
#define bM4_PORT_PFSRB2_FSEL3                     (*((volatile unsigned int*)(0x42A7894CUL)))
#define bM4_PORT_PFSRB2_FSEL4                     (*((volatile unsigned int*)(0x42A78950UL)))
#define bM4_PORT_PFSRB2_FSEL5                     (*((volatile unsigned int*)(0x42A78954UL)))
#define bM4_PORT_PFSRB2_BFE                       (*((volatile unsigned int*)(0x42A78960UL)))
#define bM4_PORT_PCRB3_POUT                       (*((volatile unsigned int*)(0x42A78980UL)))
#define bM4_PORT_PCRB3_POUTE                      (*((volatile unsigned int*)(0x42A78984UL)))
#define bM4_PORT_PCRB3_NOD                        (*((volatile unsigned int*)(0x42A78988UL)))
#define bM4_PORT_PCRB3_DRV0                       (*((volatile unsigned int*)(0x42A78990UL)))
#define bM4_PORT_PCRB3_DRV1                       (*((volatile unsigned int*)(0x42A78994UL)))
#define bM4_PORT_PCRB3_PUU                        (*((volatile unsigned int*)(0x42A78998UL)))
#define bM4_PORT_PCRB3_PIN                        (*((volatile unsigned int*)(0x42A789A0UL)))
#define bM4_PORT_PCRB3_INVE                       (*((volatile unsigned int*)(0x42A789A4UL)))
#define bM4_PORT_PCRB3_INTE                       (*((volatile unsigned int*)(0x42A789B0UL)))
#define bM4_PORT_PCRB3_LTE                        (*((volatile unsigned int*)(0x42A789B8UL)))
#define bM4_PORT_PCRB3_DDIS                       (*((volatile unsigned int*)(0x42A789BCUL)))
#define bM4_PORT_PFSRB3_FSEL0                     (*((volatile unsigned int*)(0x42A789C0UL)))
#define bM4_PORT_PFSRB3_FSEL1                     (*((volatile unsigned int*)(0x42A789C4UL)))
#define bM4_PORT_PFSRB3_FSEL2                     (*((volatile unsigned int*)(0x42A789C8UL)))
#define bM4_PORT_PFSRB3_FSEL3                     (*((volatile unsigned int*)(0x42A789CCUL)))
#define bM4_PORT_PFSRB3_FSEL4                     (*((volatile unsigned int*)(0x42A789D0UL)))
#define bM4_PORT_PFSRB3_FSEL5                     (*((volatile unsigned int*)(0x42A789D4UL)))
#define bM4_PORT_PFSRB3_BFE                       (*((volatile unsigned int*)(0x42A789E0UL)))
#define bM4_PORT_PCRB4_POUT                       (*((volatile unsigned int*)(0x42A78A00UL)))
#define bM4_PORT_PCRB4_POUTE                      (*((volatile unsigned int*)(0x42A78A04UL)))
#define bM4_PORT_PCRB4_NOD                        (*((volatile unsigned int*)(0x42A78A08UL)))
#define bM4_PORT_PCRB4_DRV0                       (*((volatile unsigned int*)(0x42A78A10UL)))
#define bM4_PORT_PCRB4_DRV1                       (*((volatile unsigned int*)(0x42A78A14UL)))
#define bM4_PORT_PCRB4_PUU                        (*((volatile unsigned int*)(0x42A78A18UL)))
#define bM4_PORT_PCRB4_PIN                        (*((volatile unsigned int*)(0x42A78A20UL)))
#define bM4_PORT_PCRB4_INVE                       (*((volatile unsigned int*)(0x42A78A24UL)))
#define bM4_PORT_PCRB4_INTE                       (*((volatile unsigned int*)(0x42A78A30UL)))
#define bM4_PORT_PCRB4_LTE                        (*((volatile unsigned int*)(0x42A78A38UL)))
#define bM4_PORT_PCRB4_DDIS                       (*((volatile unsigned int*)(0x42A78A3CUL)))
#define bM4_PORT_PFSRB4_FSEL0                     (*((volatile unsigned int*)(0x42A78A40UL)))
#define bM4_PORT_PFSRB4_FSEL1                     (*((volatile unsigned int*)(0x42A78A44UL)))
#define bM4_PORT_PFSRB4_FSEL2                     (*((volatile unsigned int*)(0x42A78A48UL)))
#define bM4_PORT_PFSRB4_FSEL3                     (*((volatile unsigned int*)(0x42A78A4CUL)))
#define bM4_PORT_PFSRB4_FSEL4                     (*((volatile unsigned int*)(0x42A78A50UL)))
#define bM4_PORT_PFSRB4_FSEL5                     (*((volatile unsigned int*)(0x42A78A54UL)))
#define bM4_PORT_PFSRB4_BFE                       (*((volatile unsigned int*)(0x42A78A60UL)))
#define bM4_PORT_PCRB5_POUT                       (*((volatile unsigned int*)(0x42A78A80UL)))
#define bM4_PORT_PCRB5_POUTE                      (*((volatile unsigned int*)(0x42A78A84UL)))
#define bM4_PORT_PCRB5_NOD                        (*((volatile unsigned int*)(0x42A78A88UL)))
#define bM4_PORT_PCRB5_DRV0                       (*((volatile unsigned int*)(0x42A78A90UL)))
#define bM4_PORT_PCRB5_DRV1                       (*((volatile unsigned int*)(0x42A78A94UL)))
#define bM4_PORT_PCRB5_PUU                        (*((volatile unsigned int*)(0x42A78A98UL)))
#define bM4_PORT_PCRB5_PIN                        (*((volatile unsigned int*)(0x42A78AA0UL)))
#define bM4_PORT_PCRB5_INVE                       (*((volatile unsigned int*)(0x42A78AA4UL)))
#define bM4_PORT_PCRB5_INTE                       (*((volatile unsigned int*)(0x42A78AB0UL)))
#define bM4_PORT_PCRB5_LTE                        (*((volatile unsigned int*)(0x42A78AB8UL)))
#define bM4_PORT_PCRB5_DDIS                       (*((volatile unsigned int*)(0x42A78ABCUL)))
#define bM4_PORT_PFSRB5_FSEL0                     (*((volatile unsigned int*)(0x42A78AC0UL)))
#define bM4_PORT_PFSRB5_FSEL1                     (*((volatile unsigned int*)(0x42A78AC4UL)))
#define bM4_PORT_PFSRB5_FSEL2                     (*((volatile unsigned int*)(0x42A78AC8UL)))
#define bM4_PORT_PFSRB5_FSEL3                     (*((volatile unsigned int*)(0x42A78ACCUL)))
#define bM4_PORT_PFSRB5_FSEL4                     (*((volatile unsigned int*)(0x42A78AD0UL)))
#define bM4_PORT_PFSRB5_FSEL5                     (*((volatile unsigned int*)(0x42A78AD4UL)))
#define bM4_PORT_PFSRB5_BFE                       (*((volatile unsigned int*)(0x42A78AE0UL)))
#define bM4_PORT_PCRB6_POUT                       (*((volatile unsigned int*)(0x42A78B00UL)))
#define bM4_PORT_PCRB6_POUTE                      (*((volatile unsigned int*)(0x42A78B04UL)))
#define bM4_PORT_PCRB6_NOD                        (*((volatile unsigned int*)(0x42A78B08UL)))
#define bM4_PORT_PCRB6_DRV0                       (*((volatile unsigned int*)(0x42A78B10UL)))
#define bM4_PORT_PCRB6_DRV1                       (*((volatile unsigned int*)(0x42A78B14UL)))
#define bM4_PORT_PCRB6_PUU                        (*((volatile unsigned int*)(0x42A78B18UL)))
#define bM4_PORT_PCRB6_PIN                        (*((volatile unsigned int*)(0x42A78B20UL)))
#define bM4_PORT_PCRB6_INVE                       (*((volatile unsigned int*)(0x42A78B24UL)))
#define bM4_PORT_PCRB6_INTE                       (*((volatile unsigned int*)(0x42A78B30UL)))
#define bM4_PORT_PCRB6_LTE                        (*((volatile unsigned int*)(0x42A78B38UL)))
#define bM4_PORT_PCRB6_DDIS                       (*((volatile unsigned int*)(0x42A78B3CUL)))
#define bM4_PORT_PFSRB6_FSEL0                     (*((volatile unsigned int*)(0x42A78B40UL)))
#define bM4_PORT_PFSRB6_FSEL1                     (*((volatile unsigned int*)(0x42A78B44UL)))
#define bM4_PORT_PFSRB6_FSEL2                     (*((volatile unsigned int*)(0x42A78B48UL)))
#define bM4_PORT_PFSRB6_FSEL3                     (*((volatile unsigned int*)(0x42A78B4CUL)))
#define bM4_PORT_PFSRB6_FSEL4                     (*((volatile unsigned int*)(0x42A78B50UL)))
#define bM4_PORT_PFSRB6_FSEL5                     (*((volatile unsigned int*)(0x42A78B54UL)))
#define bM4_PORT_PFSRB6_BFE                       (*((volatile unsigned int*)(0x42A78B60UL)))
#define bM4_PORT_PCRB7_POUT                       (*((volatile unsigned int*)(0x42A78B80UL)))
#define bM4_PORT_PCRB7_POUTE                      (*((volatile unsigned int*)(0x42A78B84UL)))
#define bM4_PORT_PCRB7_NOD                        (*((volatile unsigned int*)(0x42A78B88UL)))
#define bM4_PORT_PCRB7_DRV0                       (*((volatile unsigned int*)(0x42A78B90UL)))
#define bM4_PORT_PCRB7_DRV1                       (*((volatile unsigned int*)(0x42A78B94UL)))
#define bM4_PORT_PCRB7_PUU                        (*((volatile unsigned int*)(0x42A78B98UL)))
#define bM4_PORT_PCRB7_PIN                        (*((volatile unsigned int*)(0x42A78BA0UL)))
#define bM4_PORT_PCRB7_INVE                       (*((volatile unsigned int*)(0x42A78BA4UL)))
#define bM4_PORT_PCRB7_INTE                       (*((volatile unsigned int*)(0x42A78BB0UL)))
#define bM4_PORT_PCRB7_LTE                        (*((volatile unsigned int*)(0x42A78BB8UL)))
#define bM4_PORT_PCRB7_DDIS                       (*((volatile unsigned int*)(0x42A78BBCUL)))
#define bM4_PORT_PFSRB7_FSEL0                     (*((volatile unsigned int*)(0x42A78BC0UL)))
#define bM4_PORT_PFSRB7_FSEL1                     (*((volatile unsigned int*)(0x42A78BC4UL)))
#define bM4_PORT_PFSRB7_FSEL2                     (*((volatile unsigned int*)(0x42A78BC8UL)))
#define bM4_PORT_PFSRB7_FSEL3                     (*((volatile unsigned int*)(0x42A78BCCUL)))
#define bM4_PORT_PFSRB7_FSEL4                     (*((volatile unsigned int*)(0x42A78BD0UL)))
#define bM4_PORT_PFSRB7_FSEL5                     (*((volatile unsigned int*)(0x42A78BD4UL)))
#define bM4_PORT_PFSRB7_BFE                       (*((volatile unsigned int*)(0x42A78BE0UL)))
#define bM4_PORT_PCRB8_POUT                       (*((volatile unsigned int*)(0x42A78C00UL)))
#define bM4_PORT_PCRB8_POUTE                      (*((volatile unsigned int*)(0x42A78C04UL)))
#define bM4_PORT_PCRB8_NOD                        (*((volatile unsigned int*)(0x42A78C08UL)))
#define bM4_PORT_PCRB8_DRV0                       (*((volatile unsigned int*)(0x42A78C10UL)))
#define bM4_PORT_PCRB8_DRV1                       (*((volatile unsigned int*)(0x42A78C14UL)))
#define bM4_PORT_PCRB8_PUU                        (*((volatile unsigned int*)(0x42A78C18UL)))
#define bM4_PORT_PCRB8_PIN                        (*((volatile unsigned int*)(0x42A78C20UL)))
#define bM4_PORT_PCRB8_INVE                       (*((volatile unsigned int*)(0x42A78C24UL)))
#define bM4_PORT_PCRB8_INTE                       (*((volatile unsigned int*)(0x42A78C30UL)))
#define bM4_PORT_PCRB8_LTE                        (*((volatile unsigned int*)(0x42A78C38UL)))
#define bM4_PORT_PCRB8_DDIS                       (*((volatile unsigned int*)(0x42A78C3CUL)))
#define bM4_PORT_PFSRB8_FSEL0                     (*((volatile unsigned int*)(0x42A78C40UL)))
#define bM4_PORT_PFSRB8_FSEL1                     (*((volatile unsigned int*)(0x42A78C44UL)))
#define bM4_PORT_PFSRB8_FSEL2                     (*((volatile unsigned int*)(0x42A78C48UL)))
#define bM4_PORT_PFSRB8_FSEL3                     (*((volatile unsigned int*)(0x42A78C4CUL)))
#define bM4_PORT_PFSRB8_FSEL4                     (*((volatile unsigned int*)(0x42A78C50UL)))
#define bM4_PORT_PFSRB8_FSEL5                     (*((volatile unsigned int*)(0x42A78C54UL)))
#define bM4_PORT_PFSRB8_BFE                       (*((volatile unsigned int*)(0x42A78C60UL)))
#define bM4_PORT_PCRB9_POUT                       (*((volatile unsigned int*)(0x42A78C80UL)))
#define bM4_PORT_PCRB9_POUTE                      (*((volatile unsigned int*)(0x42A78C84UL)))
#define bM4_PORT_PCRB9_NOD                        (*((volatile unsigned int*)(0x42A78C88UL)))
#define bM4_PORT_PCRB9_DRV0                       (*((volatile unsigned int*)(0x42A78C90UL)))
#define bM4_PORT_PCRB9_DRV1                       (*((volatile unsigned int*)(0x42A78C94UL)))
#define bM4_PORT_PCRB9_PUU                        (*((volatile unsigned int*)(0x42A78C98UL)))
#define bM4_PORT_PCRB9_PIN                        (*((volatile unsigned int*)(0x42A78CA0UL)))
#define bM4_PORT_PCRB9_INVE                       (*((volatile unsigned int*)(0x42A78CA4UL)))
#define bM4_PORT_PCRB9_INTE                       (*((volatile unsigned int*)(0x42A78CB0UL)))
#define bM4_PORT_PCRB9_LTE                        (*((volatile unsigned int*)(0x42A78CB8UL)))
#define bM4_PORT_PCRB9_DDIS                       (*((volatile unsigned int*)(0x42A78CBCUL)))
#define bM4_PORT_PFSRB9_FSEL0                     (*((volatile unsigned int*)(0x42A78CC0UL)))
#define bM4_PORT_PFSRB9_FSEL1                     (*((volatile unsigned int*)(0x42A78CC4UL)))
#define bM4_PORT_PFSRB9_FSEL2                     (*((volatile unsigned int*)(0x42A78CC8UL)))
#define bM4_PORT_PFSRB9_FSEL3                     (*((volatile unsigned int*)(0x42A78CCCUL)))
#define bM4_PORT_PFSRB9_FSEL4                     (*((volatile unsigned int*)(0x42A78CD0UL)))
#define bM4_PORT_PFSRB9_FSEL5                     (*((volatile unsigned int*)(0x42A78CD4UL)))
#define bM4_PORT_PFSRB9_BFE                       (*((volatile unsigned int*)(0x42A78CE0UL)))
#define bM4_PORT_PCRB10_POUT                      (*((volatile unsigned int*)(0x42A78D00UL)))
#define bM4_PORT_PCRB10_POUTE                     (*((volatile unsigned int*)(0x42A78D04UL)))
#define bM4_PORT_PCRB10_NOD                       (*((volatile unsigned int*)(0x42A78D08UL)))
#define bM4_PORT_PCRB10_DRV0                      (*((volatile unsigned int*)(0x42A78D10UL)))
#define bM4_PORT_PCRB10_DRV1                      (*((volatile unsigned int*)(0x42A78D14UL)))
#define bM4_PORT_PCRB10_PUU                       (*((volatile unsigned int*)(0x42A78D18UL)))
#define bM4_PORT_PCRB10_PIN                       (*((volatile unsigned int*)(0x42A78D20UL)))
#define bM4_PORT_PCRB10_INVE                      (*((volatile unsigned int*)(0x42A78D24UL)))
#define bM4_PORT_PCRB10_INTE                      (*((volatile unsigned int*)(0x42A78D30UL)))
#define bM4_PORT_PCRB10_LTE                       (*((volatile unsigned int*)(0x42A78D38UL)))
#define bM4_PORT_PCRB10_DDIS                      (*((volatile unsigned int*)(0x42A78D3CUL)))
#define bM4_PORT_PFSRB10_FSEL0                    (*((volatile unsigned int*)(0x42A78D40UL)))
#define bM4_PORT_PFSRB10_FSEL1                    (*((volatile unsigned int*)(0x42A78D44UL)))
#define bM4_PORT_PFSRB10_FSEL2                    (*((volatile unsigned int*)(0x42A78D48UL)))
#define bM4_PORT_PFSRB10_FSEL3                    (*((volatile unsigned int*)(0x42A78D4CUL)))
#define bM4_PORT_PFSRB10_FSEL4                    (*((volatile unsigned int*)(0x42A78D50UL)))
#define bM4_PORT_PFSRB10_FSEL5                    (*((volatile unsigned int*)(0x42A78D54UL)))
#define bM4_PORT_PFSRB10_BFE                      (*((volatile unsigned int*)(0x42A78D60UL)))
#define bM4_PORT_PCRB11_POUT                      (*((volatile unsigned int*)(0x42A78D80UL)))
#define bM4_PORT_PCRB11_POUTE                     (*((volatile unsigned int*)(0x42A78D84UL)))
#define bM4_PORT_PCRB11_NOD                       (*((volatile unsigned int*)(0x42A78D88UL)))
#define bM4_PORT_PCRB11_DRV0                      (*((volatile unsigned int*)(0x42A78D90UL)))
#define bM4_PORT_PCRB11_DRV1                      (*((volatile unsigned int*)(0x42A78D94UL)))
#define bM4_PORT_PCRB11_PUU                       (*((volatile unsigned int*)(0x42A78D98UL)))
#define bM4_PORT_PCRB11_PIN                       (*((volatile unsigned int*)(0x42A78DA0UL)))
#define bM4_PORT_PCRB11_INVE                      (*((volatile unsigned int*)(0x42A78DA4UL)))
#define bM4_PORT_PCRB11_INTE                      (*((volatile unsigned int*)(0x42A78DB0UL)))
#define bM4_PORT_PCRB11_LTE                       (*((volatile unsigned int*)(0x42A78DB8UL)))
#define bM4_PORT_PCRB11_DDIS                      (*((volatile unsigned int*)(0x42A78DBCUL)))
#define bM4_PORT_PFSRB11_FSEL0                    (*((volatile unsigned int*)(0x42A78DC0UL)))
#define bM4_PORT_PFSRB11_FSEL1                    (*((volatile unsigned int*)(0x42A78DC4UL)))
#define bM4_PORT_PFSRB11_FSEL2                    (*((volatile unsigned int*)(0x42A78DC8UL)))
#define bM4_PORT_PFSRB11_FSEL3                    (*((volatile unsigned int*)(0x42A78DCCUL)))
#define bM4_PORT_PFSRB11_FSEL4                    (*((volatile unsigned int*)(0x42A78DD0UL)))
#define bM4_PORT_PFSRB11_FSEL5                    (*((volatile unsigned int*)(0x42A78DD4UL)))
#define bM4_PORT_PFSRB11_BFE                      (*((volatile unsigned int*)(0x42A78DE0UL)))
#define bM4_PORT_PCRB12_POUT                      (*((volatile unsigned int*)(0x42A78E00UL)))
#define bM4_PORT_PCRB12_POUTE                     (*((volatile unsigned int*)(0x42A78E04UL)))
#define bM4_PORT_PCRB12_NOD                       (*((volatile unsigned int*)(0x42A78E08UL)))
#define bM4_PORT_PCRB12_DRV0                      (*((volatile unsigned int*)(0x42A78E10UL)))
#define bM4_PORT_PCRB12_DRV1                      (*((volatile unsigned int*)(0x42A78E14UL)))
#define bM4_PORT_PCRB12_PUU                       (*((volatile unsigned int*)(0x42A78E18UL)))
#define bM4_PORT_PCRB12_PIN                       (*((volatile unsigned int*)(0x42A78E20UL)))
#define bM4_PORT_PCRB12_INVE                      (*((volatile unsigned int*)(0x42A78E24UL)))
#define bM4_PORT_PCRB12_INTE                      (*((volatile unsigned int*)(0x42A78E30UL)))
#define bM4_PORT_PCRB12_LTE                       (*((volatile unsigned int*)(0x42A78E38UL)))
#define bM4_PORT_PCRB12_DDIS                      (*((volatile unsigned int*)(0x42A78E3CUL)))
#define bM4_PORT_PFSRB12_FSEL0                    (*((volatile unsigned int*)(0x42A78E40UL)))
#define bM4_PORT_PFSRB12_FSEL1                    (*((volatile unsigned int*)(0x42A78E44UL)))
#define bM4_PORT_PFSRB12_FSEL2                    (*((volatile unsigned int*)(0x42A78E48UL)))
#define bM4_PORT_PFSRB12_FSEL3                    (*((volatile unsigned int*)(0x42A78E4CUL)))
#define bM4_PORT_PFSRB12_FSEL4                    (*((volatile unsigned int*)(0x42A78E50UL)))
#define bM4_PORT_PFSRB12_FSEL5                    (*((volatile unsigned int*)(0x42A78E54UL)))
#define bM4_PORT_PFSRB12_BFE                      (*((volatile unsigned int*)(0x42A78E60UL)))
#define bM4_PORT_PCRB13_POUT                      (*((volatile unsigned int*)(0x42A78E80UL)))
#define bM4_PORT_PCRB13_POUTE                     (*((volatile unsigned int*)(0x42A78E84UL)))
#define bM4_PORT_PCRB13_NOD                       (*((volatile unsigned int*)(0x42A78E88UL)))
#define bM4_PORT_PCRB13_DRV0                      (*((volatile unsigned int*)(0x42A78E90UL)))
#define bM4_PORT_PCRB13_DRV1                      (*((volatile unsigned int*)(0x42A78E94UL)))
#define bM4_PORT_PCRB13_PUU                       (*((volatile unsigned int*)(0x42A78E98UL)))
#define bM4_PORT_PCRB13_PIN                       (*((volatile unsigned int*)(0x42A78EA0UL)))
#define bM4_PORT_PCRB13_INVE                      (*((volatile unsigned int*)(0x42A78EA4UL)))
#define bM4_PORT_PCRB13_INTE                      (*((volatile unsigned int*)(0x42A78EB0UL)))
#define bM4_PORT_PCRB13_LTE                       (*((volatile unsigned int*)(0x42A78EB8UL)))
#define bM4_PORT_PCRB13_DDIS                      (*((volatile unsigned int*)(0x42A78EBCUL)))
#define bM4_PORT_PFSRB13_FSEL0                    (*((volatile unsigned int*)(0x42A78EC0UL)))
#define bM4_PORT_PFSRB13_FSEL1                    (*((volatile unsigned int*)(0x42A78EC4UL)))
#define bM4_PORT_PFSRB13_FSEL2                    (*((volatile unsigned int*)(0x42A78EC8UL)))
#define bM4_PORT_PFSRB13_FSEL3                    (*((volatile unsigned int*)(0x42A78ECCUL)))
#define bM4_PORT_PFSRB13_FSEL4                    (*((volatile unsigned int*)(0x42A78ED0UL)))
#define bM4_PORT_PFSRB13_FSEL5                    (*((volatile unsigned int*)(0x42A78ED4UL)))
#define bM4_PORT_PFSRB13_BFE                      (*((volatile unsigned int*)(0x42A78EE0UL)))
#define bM4_PORT_PCRB14_POUT                      (*((volatile unsigned int*)(0x42A78F00UL)))
#define bM4_PORT_PCRB14_POUTE                     (*((volatile unsigned int*)(0x42A78F04UL)))
#define bM4_PORT_PCRB14_NOD                       (*((volatile unsigned int*)(0x42A78F08UL)))
#define bM4_PORT_PCRB14_DRV0                      (*((volatile unsigned int*)(0x42A78F10UL)))
#define bM4_PORT_PCRB14_DRV1                      (*((volatile unsigned int*)(0x42A78F14UL)))
#define bM4_PORT_PCRB14_PUU                       (*((volatile unsigned int*)(0x42A78F18UL)))
#define bM4_PORT_PCRB14_PIN                       (*((volatile unsigned int*)(0x42A78F20UL)))
#define bM4_PORT_PCRB14_INVE                      (*((volatile unsigned int*)(0x42A78F24UL)))
#define bM4_PORT_PCRB14_INTE                      (*((volatile unsigned int*)(0x42A78F30UL)))
#define bM4_PORT_PCRB14_LTE                       (*((volatile unsigned int*)(0x42A78F38UL)))
#define bM4_PORT_PCRB14_DDIS                      (*((volatile unsigned int*)(0x42A78F3CUL)))
#define bM4_PORT_PFSRB14_FSEL0                    (*((volatile unsigned int*)(0x42A78F40UL)))
#define bM4_PORT_PFSRB14_FSEL1                    (*((volatile unsigned int*)(0x42A78F44UL)))
#define bM4_PORT_PFSRB14_FSEL2                    (*((volatile unsigned int*)(0x42A78F48UL)))
#define bM4_PORT_PFSRB14_FSEL3                    (*((volatile unsigned int*)(0x42A78F4CUL)))
#define bM4_PORT_PFSRB14_FSEL4                    (*((volatile unsigned int*)(0x42A78F50UL)))
#define bM4_PORT_PFSRB14_FSEL5                    (*((volatile unsigned int*)(0x42A78F54UL)))
#define bM4_PORT_PFSRB14_BFE                      (*((volatile unsigned int*)(0x42A78F60UL)))
#define bM4_PORT_PCRB15_POUT                      (*((volatile unsigned int*)(0x42A78F80UL)))
#define bM4_PORT_PCRB15_POUTE                     (*((volatile unsigned int*)(0x42A78F84UL)))
#define bM4_PORT_PCRB15_NOD                       (*((volatile unsigned int*)(0x42A78F88UL)))
#define bM4_PORT_PCRB15_DRV0                      (*((volatile unsigned int*)(0x42A78F90UL)))
#define bM4_PORT_PCRB15_DRV1                      (*((volatile unsigned int*)(0x42A78F94UL)))
#define bM4_PORT_PCRB15_PUU                       (*((volatile unsigned int*)(0x42A78F98UL)))
#define bM4_PORT_PCRB15_PIN                       (*((volatile unsigned int*)(0x42A78FA0UL)))
#define bM4_PORT_PCRB15_INVE                      (*((volatile unsigned int*)(0x42A78FA4UL)))
#define bM4_PORT_PCRB15_INTE                      (*((volatile unsigned int*)(0x42A78FB0UL)))
#define bM4_PORT_PCRB15_LTE                       (*((volatile unsigned int*)(0x42A78FB8UL)))
#define bM4_PORT_PCRB15_DDIS                      (*((volatile unsigned int*)(0x42A78FBCUL)))
#define bM4_PORT_PFSRB15_FSEL0                    (*((volatile unsigned int*)(0x42A78FC0UL)))
#define bM4_PORT_PFSRB15_FSEL1                    (*((volatile unsigned int*)(0x42A78FC4UL)))
#define bM4_PORT_PFSRB15_FSEL2                    (*((volatile unsigned int*)(0x42A78FC8UL)))
#define bM4_PORT_PFSRB15_FSEL3                    (*((volatile unsigned int*)(0x42A78FCCUL)))
#define bM4_PORT_PFSRB15_FSEL4                    (*((volatile unsigned int*)(0x42A78FD0UL)))
#define bM4_PORT_PFSRB15_FSEL5                    (*((volatile unsigned int*)(0x42A78FD4UL)))
#define bM4_PORT_PFSRB15_BFE                      (*((volatile unsigned int*)(0x42A78FE0UL)))
#define bM4_PORT_PCRC0_POUT                       (*((volatile unsigned int*)(0x42A79000UL)))
#define bM4_PORT_PCRC0_POUTE                      (*((volatile unsigned int*)(0x42A79004UL)))
#define bM4_PORT_PCRC0_NOD                        (*((volatile unsigned int*)(0x42A79008UL)))
#define bM4_PORT_PCRC0_DRV0                       (*((volatile unsigned int*)(0x42A79010UL)))
#define bM4_PORT_PCRC0_DRV1                       (*((volatile unsigned int*)(0x42A79014UL)))
#define bM4_PORT_PCRC0_PUU                        (*((volatile unsigned int*)(0x42A79018UL)))
#define bM4_PORT_PCRC0_PIN                        (*((volatile unsigned int*)(0x42A79020UL)))
#define bM4_PORT_PCRC0_INVE                       (*((volatile unsigned int*)(0x42A79024UL)))
#define bM4_PORT_PCRC0_INTE                       (*((volatile unsigned int*)(0x42A79030UL)))
#define bM4_PORT_PCRC0_LTE                        (*((volatile unsigned int*)(0x42A79038UL)))
#define bM4_PORT_PCRC0_DDIS                       (*((volatile unsigned int*)(0x42A7903CUL)))
#define bM4_PORT_PFSRC0_FSEL0                     (*((volatile unsigned int*)(0x42A79040UL)))
#define bM4_PORT_PFSRC0_FSEL1                     (*((volatile unsigned int*)(0x42A79044UL)))
#define bM4_PORT_PFSRC0_FSEL2                     (*((volatile unsigned int*)(0x42A79048UL)))
#define bM4_PORT_PFSRC0_FSEL3                     (*((volatile unsigned int*)(0x42A7904CUL)))
#define bM4_PORT_PFSRC0_FSEL4                     (*((volatile unsigned int*)(0x42A79050UL)))
#define bM4_PORT_PFSRC0_FSEL5                     (*((volatile unsigned int*)(0x42A79054UL)))
#define bM4_PORT_PFSRC0_BFE                       (*((volatile unsigned int*)(0x42A79060UL)))
#define bM4_PORT_PCRC1_POUT                       (*((volatile unsigned int*)(0x42A79080UL)))
#define bM4_PORT_PCRC1_POUTE                      (*((volatile unsigned int*)(0x42A79084UL)))
#define bM4_PORT_PCRC1_NOD                        (*((volatile unsigned int*)(0x42A79088UL)))
#define bM4_PORT_PCRC1_DRV0                       (*((volatile unsigned int*)(0x42A79090UL)))
#define bM4_PORT_PCRC1_DRV1                       (*((volatile unsigned int*)(0x42A79094UL)))
#define bM4_PORT_PCRC1_PUU                        (*((volatile unsigned int*)(0x42A79098UL)))
#define bM4_PORT_PCRC1_PIN                        (*((volatile unsigned int*)(0x42A790A0UL)))
#define bM4_PORT_PCRC1_INVE                       (*((volatile unsigned int*)(0x42A790A4UL)))
#define bM4_PORT_PCRC1_INTE                       (*((volatile unsigned int*)(0x42A790B0UL)))
#define bM4_PORT_PCRC1_LTE                        (*((volatile unsigned int*)(0x42A790B8UL)))
#define bM4_PORT_PCRC1_DDIS                       (*((volatile unsigned int*)(0x42A790BCUL)))
#define bM4_PORT_PFSRC1_FSEL0                     (*((volatile unsigned int*)(0x42A790C0UL)))
#define bM4_PORT_PFSRC1_FSEL1                     (*((volatile unsigned int*)(0x42A790C4UL)))
#define bM4_PORT_PFSRC1_FSEL2                     (*((volatile unsigned int*)(0x42A790C8UL)))
#define bM4_PORT_PFSRC1_FSEL3                     (*((volatile unsigned int*)(0x42A790CCUL)))
#define bM4_PORT_PFSRC1_FSEL4                     (*((volatile unsigned int*)(0x42A790D0UL)))
#define bM4_PORT_PFSRC1_FSEL5                     (*((volatile unsigned int*)(0x42A790D4UL)))
#define bM4_PORT_PFSRC1_BFE                       (*((volatile unsigned int*)(0x42A790E0UL)))
#define bM4_PORT_PCRC2_POUT                       (*((volatile unsigned int*)(0x42A79100UL)))
#define bM4_PORT_PCRC2_POUTE                      (*((volatile unsigned int*)(0x42A79104UL)))
#define bM4_PORT_PCRC2_NOD                        (*((volatile unsigned int*)(0x42A79108UL)))
#define bM4_PORT_PCRC2_DRV0                       (*((volatile unsigned int*)(0x42A79110UL)))
#define bM4_PORT_PCRC2_DRV1                       (*((volatile unsigned int*)(0x42A79114UL)))
#define bM4_PORT_PCRC2_PUU                        (*((volatile unsigned int*)(0x42A79118UL)))
#define bM4_PORT_PCRC2_PIN                        (*((volatile unsigned int*)(0x42A79120UL)))
#define bM4_PORT_PCRC2_INVE                       (*((volatile unsigned int*)(0x42A79124UL)))
#define bM4_PORT_PCRC2_INTE                       (*((volatile unsigned int*)(0x42A79130UL)))
#define bM4_PORT_PCRC2_LTE                        (*((volatile unsigned int*)(0x42A79138UL)))
#define bM4_PORT_PCRC2_DDIS                       (*((volatile unsigned int*)(0x42A7913CUL)))
#define bM4_PORT_PFSRC2_FSEL0                     (*((volatile unsigned int*)(0x42A79140UL)))
#define bM4_PORT_PFSRC2_FSEL1                     (*((volatile unsigned int*)(0x42A79144UL)))
#define bM4_PORT_PFSRC2_FSEL2                     (*((volatile unsigned int*)(0x42A79148UL)))
#define bM4_PORT_PFSRC2_FSEL3                     (*((volatile unsigned int*)(0x42A7914CUL)))
#define bM4_PORT_PFSRC2_FSEL4                     (*((volatile unsigned int*)(0x42A79150UL)))
#define bM4_PORT_PFSRC2_FSEL5                     (*((volatile unsigned int*)(0x42A79154UL)))
#define bM4_PORT_PFSRC2_BFE                       (*((volatile unsigned int*)(0x42A79160UL)))
#define bM4_PORT_PCRC3_POUT                       (*((volatile unsigned int*)(0x42A79180UL)))
#define bM4_PORT_PCRC3_POUTE                      (*((volatile unsigned int*)(0x42A79184UL)))
#define bM4_PORT_PCRC3_NOD                        (*((volatile unsigned int*)(0x42A79188UL)))
#define bM4_PORT_PCRC3_DRV0                       (*((volatile unsigned int*)(0x42A79190UL)))
#define bM4_PORT_PCRC3_DRV1                       (*((volatile unsigned int*)(0x42A79194UL)))
#define bM4_PORT_PCRC3_PUU                        (*((volatile unsigned int*)(0x42A79198UL)))
#define bM4_PORT_PCRC3_PIN                        (*((volatile unsigned int*)(0x42A791A0UL)))
#define bM4_PORT_PCRC3_INVE                       (*((volatile unsigned int*)(0x42A791A4UL)))
#define bM4_PORT_PCRC3_INTE                       (*((volatile unsigned int*)(0x42A791B0UL)))
#define bM4_PORT_PCRC3_LTE                        (*((volatile unsigned int*)(0x42A791B8UL)))
#define bM4_PORT_PCRC3_DDIS                       (*((volatile unsigned int*)(0x42A791BCUL)))
#define bM4_PORT_PFSRC3_FSEL0                     (*((volatile unsigned int*)(0x42A791C0UL)))
#define bM4_PORT_PFSRC3_FSEL1                     (*((volatile unsigned int*)(0x42A791C4UL)))
#define bM4_PORT_PFSRC3_FSEL2                     (*((volatile unsigned int*)(0x42A791C8UL)))
#define bM4_PORT_PFSRC3_FSEL3                     (*((volatile unsigned int*)(0x42A791CCUL)))
#define bM4_PORT_PFSRC3_FSEL4                     (*((volatile unsigned int*)(0x42A791D0UL)))
#define bM4_PORT_PFSRC3_FSEL5                     (*((volatile unsigned int*)(0x42A791D4UL)))
#define bM4_PORT_PFSRC3_BFE                       (*((volatile unsigned int*)(0x42A791E0UL)))
#define bM4_PORT_PCRC4_POUT                       (*((volatile unsigned int*)(0x42A79200UL)))
#define bM4_PORT_PCRC4_POUTE                      (*((volatile unsigned int*)(0x42A79204UL)))
#define bM4_PORT_PCRC4_NOD                        (*((volatile unsigned int*)(0x42A79208UL)))
#define bM4_PORT_PCRC4_DRV0                       (*((volatile unsigned int*)(0x42A79210UL)))
#define bM4_PORT_PCRC4_DRV1                       (*((volatile unsigned int*)(0x42A79214UL)))
#define bM4_PORT_PCRC4_PUU                        (*((volatile unsigned int*)(0x42A79218UL)))
#define bM4_PORT_PCRC4_PIN                        (*((volatile unsigned int*)(0x42A79220UL)))
#define bM4_PORT_PCRC4_INVE                       (*((volatile unsigned int*)(0x42A79224UL)))
#define bM4_PORT_PCRC4_INTE                       (*((volatile unsigned int*)(0x42A79230UL)))
#define bM4_PORT_PCRC4_LTE                        (*((volatile unsigned int*)(0x42A79238UL)))
#define bM4_PORT_PCRC4_DDIS                       (*((volatile unsigned int*)(0x42A7923CUL)))
#define bM4_PORT_PFSRC4_FSEL0                     (*((volatile unsigned int*)(0x42A79240UL)))
#define bM4_PORT_PFSRC4_FSEL1                     (*((volatile unsigned int*)(0x42A79244UL)))
#define bM4_PORT_PFSRC4_FSEL2                     (*((volatile unsigned int*)(0x42A79248UL)))
#define bM4_PORT_PFSRC4_FSEL3                     (*((volatile unsigned int*)(0x42A7924CUL)))
#define bM4_PORT_PFSRC4_FSEL4                     (*((volatile unsigned int*)(0x42A79250UL)))
#define bM4_PORT_PFSRC4_FSEL5                     (*((volatile unsigned int*)(0x42A79254UL)))
#define bM4_PORT_PFSRC4_BFE                       (*((volatile unsigned int*)(0x42A79260UL)))
#define bM4_PORT_PCRC5_POUT                       (*((volatile unsigned int*)(0x42A79280UL)))
#define bM4_PORT_PCRC5_POUTE                      (*((volatile unsigned int*)(0x42A79284UL)))
#define bM4_PORT_PCRC5_NOD                        (*((volatile unsigned int*)(0x42A79288UL)))
#define bM4_PORT_PCRC5_DRV0                       (*((volatile unsigned int*)(0x42A79290UL)))
#define bM4_PORT_PCRC5_DRV1                       (*((volatile unsigned int*)(0x42A79294UL)))
#define bM4_PORT_PCRC5_PUU                        (*((volatile unsigned int*)(0x42A79298UL)))
#define bM4_PORT_PCRC5_PIN                        (*((volatile unsigned int*)(0x42A792A0UL)))
#define bM4_PORT_PCRC5_INVE                       (*((volatile unsigned int*)(0x42A792A4UL)))
#define bM4_PORT_PCRC5_INTE                       (*((volatile unsigned int*)(0x42A792B0UL)))
#define bM4_PORT_PCRC5_LTE                        (*((volatile unsigned int*)(0x42A792B8UL)))
#define bM4_PORT_PCRC5_DDIS                       (*((volatile unsigned int*)(0x42A792BCUL)))
#define bM4_PORT_PFSRC5_FSEL0                     (*((volatile unsigned int*)(0x42A792C0UL)))
#define bM4_PORT_PFSRC5_FSEL1                     (*((volatile unsigned int*)(0x42A792C4UL)))
#define bM4_PORT_PFSRC5_FSEL2                     (*((volatile unsigned int*)(0x42A792C8UL)))
#define bM4_PORT_PFSRC5_FSEL3                     (*((volatile unsigned int*)(0x42A792CCUL)))
#define bM4_PORT_PFSRC5_FSEL4                     (*((volatile unsigned int*)(0x42A792D0UL)))
#define bM4_PORT_PFSRC5_FSEL5                     (*((volatile unsigned int*)(0x42A792D4UL)))
#define bM4_PORT_PFSRC5_BFE                       (*((volatile unsigned int*)(0x42A792E0UL)))
#define bM4_PORT_PCRC6_POUT                       (*((volatile unsigned int*)(0x42A79300UL)))
#define bM4_PORT_PCRC6_POUTE                      (*((volatile unsigned int*)(0x42A79304UL)))
#define bM4_PORT_PCRC6_NOD                        (*((volatile unsigned int*)(0x42A79308UL)))
#define bM4_PORT_PCRC6_DRV0                       (*((volatile unsigned int*)(0x42A79310UL)))
#define bM4_PORT_PCRC6_DRV1                       (*((volatile unsigned int*)(0x42A79314UL)))
#define bM4_PORT_PCRC6_PUU                        (*((volatile unsigned int*)(0x42A79318UL)))
#define bM4_PORT_PCRC6_PIN                        (*((volatile unsigned int*)(0x42A79320UL)))
#define bM4_PORT_PCRC6_INVE                       (*((volatile unsigned int*)(0x42A79324UL)))
#define bM4_PORT_PCRC6_INTE                       (*((volatile unsigned int*)(0x42A79330UL)))
#define bM4_PORT_PCRC6_LTE                        (*((volatile unsigned int*)(0x42A79338UL)))
#define bM4_PORT_PCRC6_DDIS                       (*((volatile unsigned int*)(0x42A7933CUL)))
#define bM4_PORT_PFSRC6_FSEL0                     (*((volatile unsigned int*)(0x42A79340UL)))
#define bM4_PORT_PFSRC6_FSEL1                     (*((volatile unsigned int*)(0x42A79344UL)))
#define bM4_PORT_PFSRC6_FSEL2                     (*((volatile unsigned int*)(0x42A79348UL)))
#define bM4_PORT_PFSRC6_FSEL3                     (*((volatile unsigned int*)(0x42A7934CUL)))
#define bM4_PORT_PFSRC6_FSEL4                     (*((volatile unsigned int*)(0x42A79350UL)))
#define bM4_PORT_PFSRC6_FSEL5                     (*((volatile unsigned int*)(0x42A79354UL)))
#define bM4_PORT_PFSRC6_BFE                       (*((volatile unsigned int*)(0x42A79360UL)))
#define bM4_PORT_PCRC7_POUT                       (*((volatile unsigned int*)(0x42A79380UL)))
#define bM4_PORT_PCRC7_POUTE                      (*((volatile unsigned int*)(0x42A79384UL)))
#define bM4_PORT_PCRC7_NOD                        (*((volatile unsigned int*)(0x42A79388UL)))
#define bM4_PORT_PCRC7_DRV0                       (*((volatile unsigned int*)(0x42A79390UL)))
#define bM4_PORT_PCRC7_DRV1                       (*((volatile unsigned int*)(0x42A79394UL)))
#define bM4_PORT_PCRC7_PUU                        (*((volatile unsigned int*)(0x42A79398UL)))
#define bM4_PORT_PCRC7_PIN                        (*((volatile unsigned int*)(0x42A793A0UL)))
#define bM4_PORT_PCRC7_INVE                       (*((volatile unsigned int*)(0x42A793A4UL)))
#define bM4_PORT_PCRC7_INTE                       (*((volatile unsigned int*)(0x42A793B0UL)))
#define bM4_PORT_PCRC7_LTE                        (*((volatile unsigned int*)(0x42A793B8UL)))
#define bM4_PORT_PCRC7_DDIS                       (*((volatile unsigned int*)(0x42A793BCUL)))
#define bM4_PORT_PFSRC7_FSEL0                     (*((volatile unsigned int*)(0x42A793C0UL)))
#define bM4_PORT_PFSRC7_FSEL1                     (*((volatile unsigned int*)(0x42A793C4UL)))
#define bM4_PORT_PFSRC7_FSEL2                     (*((volatile unsigned int*)(0x42A793C8UL)))
#define bM4_PORT_PFSRC7_FSEL3                     (*((volatile unsigned int*)(0x42A793CCUL)))
#define bM4_PORT_PFSRC7_FSEL4                     (*((volatile unsigned int*)(0x42A793D0UL)))
#define bM4_PORT_PFSRC7_FSEL5                     (*((volatile unsigned int*)(0x42A793D4UL)))
#define bM4_PORT_PFSRC7_BFE                       (*((volatile unsigned int*)(0x42A793E0UL)))
#define bM4_PORT_PCRC8_POUT                       (*((volatile unsigned int*)(0x42A79400UL)))
#define bM4_PORT_PCRC8_POUTE                      (*((volatile unsigned int*)(0x42A79404UL)))
#define bM4_PORT_PCRC8_NOD                        (*((volatile unsigned int*)(0x42A79408UL)))
#define bM4_PORT_PCRC8_DRV0                       (*((volatile unsigned int*)(0x42A79410UL)))
#define bM4_PORT_PCRC8_DRV1                       (*((volatile unsigned int*)(0x42A79414UL)))
#define bM4_PORT_PCRC8_PUU                        (*((volatile unsigned int*)(0x42A79418UL)))
#define bM4_PORT_PCRC8_PIN                        (*((volatile unsigned int*)(0x42A79420UL)))
#define bM4_PORT_PCRC8_INVE                       (*((volatile unsigned int*)(0x42A79424UL)))
#define bM4_PORT_PCRC8_INTE                       (*((volatile unsigned int*)(0x42A79430UL)))
#define bM4_PORT_PCRC8_LTE                        (*((volatile unsigned int*)(0x42A79438UL)))
#define bM4_PORT_PCRC8_DDIS                       (*((volatile unsigned int*)(0x42A7943CUL)))
#define bM4_PORT_PFSRC8_FSEL0                     (*((volatile unsigned int*)(0x42A79440UL)))
#define bM4_PORT_PFSRC8_FSEL1                     (*((volatile unsigned int*)(0x42A79444UL)))
#define bM4_PORT_PFSRC8_FSEL2                     (*((volatile unsigned int*)(0x42A79448UL)))
#define bM4_PORT_PFSRC8_FSEL3                     (*((volatile unsigned int*)(0x42A7944CUL)))
#define bM4_PORT_PFSRC8_FSEL4                     (*((volatile unsigned int*)(0x42A79450UL)))
#define bM4_PORT_PFSRC8_FSEL5                     (*((volatile unsigned int*)(0x42A79454UL)))
#define bM4_PORT_PFSRC8_BFE                       (*((volatile unsigned int*)(0x42A79460UL)))
#define bM4_PORT_PCRC9_POUT                       (*((volatile unsigned int*)(0x42A79480UL)))
#define bM4_PORT_PCRC9_POUTE                      (*((volatile unsigned int*)(0x42A79484UL)))
#define bM4_PORT_PCRC9_NOD                        (*((volatile unsigned int*)(0x42A79488UL)))
#define bM4_PORT_PCRC9_DRV0                       (*((volatile unsigned int*)(0x42A79490UL)))
#define bM4_PORT_PCRC9_DRV1                       (*((volatile unsigned int*)(0x42A79494UL)))
#define bM4_PORT_PCRC9_PUU                        (*((volatile unsigned int*)(0x42A79498UL)))
#define bM4_PORT_PCRC9_PIN                        (*((volatile unsigned int*)(0x42A794A0UL)))
#define bM4_PORT_PCRC9_INVE                       (*((volatile unsigned int*)(0x42A794A4UL)))
#define bM4_PORT_PCRC9_INTE                       (*((volatile unsigned int*)(0x42A794B0UL)))
#define bM4_PORT_PCRC9_LTE                        (*((volatile unsigned int*)(0x42A794B8UL)))
#define bM4_PORT_PCRC9_DDIS                       (*((volatile unsigned int*)(0x42A794BCUL)))
#define bM4_PORT_PFSRC9_FSEL0                     (*((volatile unsigned int*)(0x42A794C0UL)))
#define bM4_PORT_PFSRC9_FSEL1                     (*((volatile unsigned int*)(0x42A794C4UL)))
#define bM4_PORT_PFSRC9_FSEL2                     (*((volatile unsigned int*)(0x42A794C8UL)))
#define bM4_PORT_PFSRC9_FSEL3                     (*((volatile unsigned int*)(0x42A794CCUL)))
#define bM4_PORT_PFSRC9_FSEL4                     (*((volatile unsigned int*)(0x42A794D0UL)))
#define bM4_PORT_PFSRC9_FSEL5                     (*((volatile unsigned int*)(0x42A794D4UL)))
#define bM4_PORT_PFSRC9_BFE                       (*((volatile unsigned int*)(0x42A794E0UL)))
#define bM4_PORT_PCRC10_POUT                      (*((volatile unsigned int*)(0x42A79500UL)))
#define bM4_PORT_PCRC10_POUTE                     (*((volatile unsigned int*)(0x42A79504UL)))
#define bM4_PORT_PCRC10_NOD                       (*((volatile unsigned int*)(0x42A79508UL)))
#define bM4_PORT_PCRC10_DRV0                      (*((volatile unsigned int*)(0x42A79510UL)))
#define bM4_PORT_PCRC10_DRV1                      (*((volatile unsigned int*)(0x42A79514UL)))
#define bM4_PORT_PCRC10_PUU                       (*((volatile unsigned int*)(0x42A79518UL)))
#define bM4_PORT_PCRC10_PIN                       (*((volatile unsigned int*)(0x42A79520UL)))
#define bM4_PORT_PCRC10_INVE                      (*((volatile unsigned int*)(0x42A79524UL)))
#define bM4_PORT_PCRC10_INTE                      (*((volatile unsigned int*)(0x42A79530UL)))
#define bM4_PORT_PCRC10_LTE                       (*((volatile unsigned int*)(0x42A79538UL)))
#define bM4_PORT_PCRC10_DDIS                      (*((volatile unsigned int*)(0x42A7953CUL)))
#define bM4_PORT_PFSRC10_FSEL0                    (*((volatile unsigned int*)(0x42A79540UL)))
#define bM4_PORT_PFSRC10_FSEL1                    (*((volatile unsigned int*)(0x42A79544UL)))
#define bM4_PORT_PFSRC10_FSEL2                    (*((volatile unsigned int*)(0x42A79548UL)))
#define bM4_PORT_PFSRC10_FSEL3                    (*((volatile unsigned int*)(0x42A7954CUL)))
#define bM4_PORT_PFSRC10_FSEL4                    (*((volatile unsigned int*)(0x42A79550UL)))
#define bM4_PORT_PFSRC10_FSEL5                    (*((volatile unsigned int*)(0x42A79554UL)))
#define bM4_PORT_PFSRC10_BFE                      (*((volatile unsigned int*)(0x42A79560UL)))
#define bM4_PORT_PCRC11_POUT                      (*((volatile unsigned int*)(0x42A79580UL)))
#define bM4_PORT_PCRC11_POUTE                     (*((volatile unsigned int*)(0x42A79584UL)))
#define bM4_PORT_PCRC11_NOD                       (*((volatile unsigned int*)(0x42A79588UL)))
#define bM4_PORT_PCRC11_DRV0                      (*((volatile unsigned int*)(0x42A79590UL)))
#define bM4_PORT_PCRC11_DRV1                      (*((volatile unsigned int*)(0x42A79594UL)))
#define bM4_PORT_PCRC11_PUU                       (*((volatile unsigned int*)(0x42A79598UL)))
#define bM4_PORT_PCRC11_PIN                       (*((volatile unsigned int*)(0x42A795A0UL)))
#define bM4_PORT_PCRC11_INVE                      (*((volatile unsigned int*)(0x42A795A4UL)))
#define bM4_PORT_PCRC11_INTE                      (*((volatile unsigned int*)(0x42A795B0UL)))
#define bM4_PORT_PCRC11_LTE                       (*((volatile unsigned int*)(0x42A795B8UL)))
#define bM4_PORT_PCRC11_DDIS                      (*((volatile unsigned int*)(0x42A795BCUL)))
#define bM4_PORT_PFSRC11_FSEL0                    (*((volatile unsigned int*)(0x42A795C0UL)))
#define bM4_PORT_PFSRC11_FSEL1                    (*((volatile unsigned int*)(0x42A795C4UL)))
#define bM4_PORT_PFSRC11_FSEL2                    (*((volatile unsigned int*)(0x42A795C8UL)))
#define bM4_PORT_PFSRC11_FSEL3                    (*((volatile unsigned int*)(0x42A795CCUL)))
#define bM4_PORT_PFSRC11_FSEL4                    (*((volatile unsigned int*)(0x42A795D0UL)))
#define bM4_PORT_PFSRC11_FSEL5                    (*((volatile unsigned int*)(0x42A795D4UL)))
#define bM4_PORT_PFSRC11_BFE                      (*((volatile unsigned int*)(0x42A795E0UL)))
#define bM4_PORT_PCRC12_POUT                      (*((volatile unsigned int*)(0x42A79600UL)))
#define bM4_PORT_PCRC12_POUTE                     (*((volatile unsigned int*)(0x42A79604UL)))
#define bM4_PORT_PCRC12_NOD                       (*((volatile unsigned int*)(0x42A79608UL)))
#define bM4_PORT_PCRC12_DRV0                      (*((volatile unsigned int*)(0x42A79610UL)))
#define bM4_PORT_PCRC12_DRV1                      (*((volatile unsigned int*)(0x42A79614UL)))
#define bM4_PORT_PCRC12_PUU                       (*((volatile unsigned int*)(0x42A79618UL)))
#define bM4_PORT_PCRC12_PIN                       (*((volatile unsigned int*)(0x42A79620UL)))
#define bM4_PORT_PCRC12_INVE                      (*((volatile unsigned int*)(0x42A79624UL)))
#define bM4_PORT_PCRC12_INTE                      (*((volatile unsigned int*)(0x42A79630UL)))
#define bM4_PORT_PCRC12_LTE                       (*((volatile unsigned int*)(0x42A79638UL)))
#define bM4_PORT_PCRC12_DDIS                      (*((volatile unsigned int*)(0x42A7963CUL)))
#define bM4_PORT_PFSRC12_FSEL0                    (*((volatile unsigned int*)(0x42A79640UL)))
#define bM4_PORT_PFSRC12_FSEL1                    (*((volatile unsigned int*)(0x42A79644UL)))
#define bM4_PORT_PFSRC12_FSEL2                    (*((volatile unsigned int*)(0x42A79648UL)))
#define bM4_PORT_PFSRC12_FSEL3                    (*((volatile unsigned int*)(0x42A7964CUL)))
#define bM4_PORT_PFSRC12_FSEL4                    (*((volatile unsigned int*)(0x42A79650UL)))
#define bM4_PORT_PFSRC12_FSEL5                    (*((volatile unsigned int*)(0x42A79654UL)))
#define bM4_PORT_PFSRC12_BFE                      (*((volatile unsigned int*)(0x42A79660UL)))
#define bM4_PORT_PCRC13_POUT                      (*((volatile unsigned int*)(0x42A79680UL)))
#define bM4_PORT_PCRC13_POUTE                     (*((volatile unsigned int*)(0x42A79684UL)))
#define bM4_PORT_PCRC13_NOD                       (*((volatile unsigned int*)(0x42A79688UL)))
#define bM4_PORT_PCRC13_DRV0                      (*((volatile unsigned int*)(0x42A79690UL)))
#define bM4_PORT_PCRC13_DRV1                      (*((volatile unsigned int*)(0x42A79694UL)))
#define bM4_PORT_PCRC13_PUU                       (*((volatile unsigned int*)(0x42A79698UL)))
#define bM4_PORT_PCRC13_PIN                       (*((volatile unsigned int*)(0x42A796A0UL)))
#define bM4_PORT_PCRC13_INVE                      (*((volatile unsigned int*)(0x42A796A4UL)))
#define bM4_PORT_PCRC13_INTE                      (*((volatile unsigned int*)(0x42A796B0UL)))
#define bM4_PORT_PCRC13_LTE                       (*((volatile unsigned int*)(0x42A796B8UL)))
#define bM4_PORT_PCRC13_DDIS                      (*((volatile unsigned int*)(0x42A796BCUL)))
#define bM4_PORT_PFSRC13_FSEL0                    (*((volatile unsigned int*)(0x42A796C0UL)))
#define bM4_PORT_PFSRC13_FSEL1                    (*((volatile unsigned int*)(0x42A796C4UL)))
#define bM4_PORT_PFSRC13_FSEL2                    (*((volatile unsigned int*)(0x42A796C8UL)))
#define bM4_PORT_PFSRC13_FSEL3                    (*((volatile unsigned int*)(0x42A796CCUL)))
#define bM4_PORT_PFSRC13_FSEL4                    (*((volatile unsigned int*)(0x42A796D0UL)))
#define bM4_PORT_PFSRC13_FSEL5                    (*((volatile unsigned int*)(0x42A796D4UL)))
#define bM4_PORT_PFSRC13_BFE                      (*((volatile unsigned int*)(0x42A796E0UL)))
#define bM4_PORT_PCRC14_POUT                      (*((volatile unsigned int*)(0x42A79700UL)))
#define bM4_PORT_PCRC14_POUTE                     (*((volatile unsigned int*)(0x42A79704UL)))
#define bM4_PORT_PCRC14_NOD                       (*((volatile unsigned int*)(0x42A79708UL)))
#define bM4_PORT_PCRC14_DRV0                      (*((volatile unsigned int*)(0x42A79710UL)))
#define bM4_PORT_PCRC14_DRV1                      (*((volatile unsigned int*)(0x42A79714UL)))
#define bM4_PORT_PCRC14_PUU                       (*((volatile unsigned int*)(0x42A79718UL)))
#define bM4_PORT_PCRC14_PIN                       (*((volatile unsigned int*)(0x42A79720UL)))
#define bM4_PORT_PCRC14_INVE                      (*((volatile unsigned int*)(0x42A79724UL)))
#define bM4_PORT_PCRC14_INTE                      (*((volatile unsigned int*)(0x42A79730UL)))
#define bM4_PORT_PCRC14_LTE                       (*((volatile unsigned int*)(0x42A79738UL)))
#define bM4_PORT_PCRC14_DDIS                      (*((volatile unsigned int*)(0x42A7973CUL)))
#define bM4_PORT_PFSRC14_FSEL0                    (*((volatile unsigned int*)(0x42A79740UL)))
#define bM4_PORT_PFSRC14_FSEL1                    (*((volatile unsigned int*)(0x42A79744UL)))
#define bM4_PORT_PFSRC14_FSEL2                    (*((volatile unsigned int*)(0x42A79748UL)))
#define bM4_PORT_PFSRC14_FSEL3                    (*((volatile unsigned int*)(0x42A7974CUL)))
#define bM4_PORT_PFSRC14_FSEL4                    (*((volatile unsigned int*)(0x42A79750UL)))
#define bM4_PORT_PFSRC14_FSEL5                    (*((volatile unsigned int*)(0x42A79754UL)))
#define bM4_PORT_PFSRC14_BFE                      (*((volatile unsigned int*)(0x42A79760UL)))
#define bM4_PORT_PCRC15_POUT                      (*((volatile unsigned int*)(0x42A79780UL)))
#define bM4_PORT_PCRC15_POUTE                     (*((volatile unsigned int*)(0x42A79784UL)))
#define bM4_PORT_PCRC15_NOD                       (*((volatile unsigned int*)(0x42A79788UL)))
#define bM4_PORT_PCRC15_DRV0                      (*((volatile unsigned int*)(0x42A79790UL)))
#define bM4_PORT_PCRC15_DRV1                      (*((volatile unsigned int*)(0x42A79794UL)))
#define bM4_PORT_PCRC15_PUU                       (*((volatile unsigned int*)(0x42A79798UL)))
#define bM4_PORT_PCRC15_PIN                       (*((volatile unsigned int*)(0x42A797A0UL)))
#define bM4_PORT_PCRC15_INVE                      (*((volatile unsigned int*)(0x42A797A4UL)))
#define bM4_PORT_PCRC15_INTE                      (*((volatile unsigned int*)(0x42A797B0UL)))
#define bM4_PORT_PCRC15_LTE                       (*((volatile unsigned int*)(0x42A797B8UL)))
#define bM4_PORT_PCRC15_DDIS                      (*((volatile unsigned int*)(0x42A797BCUL)))
#define bM4_PORT_PFSRC15_FSEL0                    (*((volatile unsigned int*)(0x42A797C0UL)))
#define bM4_PORT_PFSRC15_FSEL1                    (*((volatile unsigned int*)(0x42A797C4UL)))
#define bM4_PORT_PFSRC15_FSEL2                    (*((volatile unsigned int*)(0x42A797C8UL)))
#define bM4_PORT_PFSRC15_FSEL3                    (*((volatile unsigned int*)(0x42A797CCUL)))
#define bM4_PORT_PFSRC15_FSEL4                    (*((volatile unsigned int*)(0x42A797D0UL)))
#define bM4_PORT_PFSRC15_FSEL5                    (*((volatile unsigned int*)(0x42A797D4UL)))
#define bM4_PORT_PFSRC15_BFE                      (*((volatile unsigned int*)(0x42A797E0UL)))
#define bM4_PORT_PCRD0_POUT                       (*((volatile unsigned int*)(0x42A79800UL)))
#define bM4_PORT_PCRD0_POUTE                      (*((volatile unsigned int*)(0x42A79804UL)))
#define bM4_PORT_PCRD0_NOD                        (*((volatile unsigned int*)(0x42A79808UL)))
#define bM4_PORT_PCRD0_DRV0                       (*((volatile unsigned int*)(0x42A79810UL)))
#define bM4_PORT_PCRD0_DRV1                       (*((volatile unsigned int*)(0x42A79814UL)))
#define bM4_PORT_PCRD0_PUU                        (*((volatile unsigned int*)(0x42A79818UL)))
#define bM4_PORT_PCRD0_PIN                        (*((volatile unsigned int*)(0x42A79820UL)))
#define bM4_PORT_PCRD0_INVE                       (*((volatile unsigned int*)(0x42A79824UL)))
#define bM4_PORT_PCRD0_INTE                       (*((volatile unsigned int*)(0x42A79830UL)))
#define bM4_PORT_PCRD0_LTE                        (*((volatile unsigned int*)(0x42A79838UL)))
#define bM4_PORT_PCRD0_DDIS                       (*((volatile unsigned int*)(0x42A7983CUL)))
#define bM4_PORT_PFSRD0_FSEL0                     (*((volatile unsigned int*)(0x42A79840UL)))
#define bM4_PORT_PFSRD0_FSEL1                     (*((volatile unsigned int*)(0x42A79844UL)))
#define bM4_PORT_PFSRD0_FSEL2                     (*((volatile unsigned int*)(0x42A79848UL)))
#define bM4_PORT_PFSRD0_FSEL3                     (*((volatile unsigned int*)(0x42A7984CUL)))
#define bM4_PORT_PFSRD0_FSEL4                     (*((volatile unsigned int*)(0x42A79850UL)))
#define bM4_PORT_PFSRD0_FSEL5                     (*((volatile unsigned int*)(0x42A79854UL)))
#define bM4_PORT_PFSRD0_BFE                       (*((volatile unsigned int*)(0x42A79860UL)))
#define bM4_PORT_PCRD1_POUT                       (*((volatile unsigned int*)(0x42A79880UL)))
#define bM4_PORT_PCRD1_POUTE                      (*((volatile unsigned int*)(0x42A79884UL)))
#define bM4_PORT_PCRD1_NOD                        (*((volatile unsigned int*)(0x42A79888UL)))
#define bM4_PORT_PCRD1_DRV0                       (*((volatile unsigned int*)(0x42A79890UL)))
#define bM4_PORT_PCRD1_DRV1                       (*((volatile unsigned int*)(0x42A79894UL)))
#define bM4_PORT_PCRD1_PUU                        (*((volatile unsigned int*)(0x42A79898UL)))
#define bM4_PORT_PCRD1_PIN                        (*((volatile unsigned int*)(0x42A798A0UL)))
#define bM4_PORT_PCRD1_INVE                       (*((volatile unsigned int*)(0x42A798A4UL)))
#define bM4_PORT_PCRD1_INTE                       (*((volatile unsigned int*)(0x42A798B0UL)))
#define bM4_PORT_PCRD1_LTE                        (*((volatile unsigned int*)(0x42A798B8UL)))
#define bM4_PORT_PCRD1_DDIS                       (*((volatile unsigned int*)(0x42A798BCUL)))
#define bM4_PORT_PFSRD1_FSEL0                     (*((volatile unsigned int*)(0x42A798C0UL)))
#define bM4_PORT_PFSRD1_FSEL1                     (*((volatile unsigned int*)(0x42A798C4UL)))
#define bM4_PORT_PFSRD1_FSEL2                     (*((volatile unsigned int*)(0x42A798C8UL)))
#define bM4_PORT_PFSRD1_FSEL3                     (*((volatile unsigned int*)(0x42A798CCUL)))
#define bM4_PORT_PFSRD1_FSEL4                     (*((volatile unsigned int*)(0x42A798D0UL)))
#define bM4_PORT_PFSRD1_FSEL5                     (*((volatile unsigned int*)(0x42A798D4UL)))
#define bM4_PORT_PFSRD1_BFE                       (*((volatile unsigned int*)(0x42A798E0UL)))
#define bM4_PORT_PCRD2_POUT                       (*((volatile unsigned int*)(0x42A79900UL)))
#define bM4_PORT_PCRD2_POUTE                      (*((volatile unsigned int*)(0x42A79904UL)))
#define bM4_PORT_PCRD2_NOD                        (*((volatile unsigned int*)(0x42A79908UL)))
#define bM4_PORT_PCRD2_DRV0                       (*((volatile unsigned int*)(0x42A79910UL)))
#define bM4_PORT_PCRD2_DRV1                       (*((volatile unsigned int*)(0x42A79914UL)))
#define bM4_PORT_PCRD2_PUU                        (*((volatile unsigned int*)(0x42A79918UL)))
#define bM4_PORT_PCRD2_PIN                        (*((volatile unsigned int*)(0x42A79920UL)))
#define bM4_PORT_PCRD2_INVE                       (*((volatile unsigned int*)(0x42A79924UL)))
#define bM4_PORT_PCRD2_INTE                       (*((volatile unsigned int*)(0x42A79930UL)))
#define bM4_PORT_PCRD2_LTE                        (*((volatile unsigned int*)(0x42A79938UL)))
#define bM4_PORT_PCRD2_DDIS                       (*((volatile unsigned int*)(0x42A7993CUL)))
#define bM4_PORT_PFSRD2_FSEL0                     (*((volatile unsigned int*)(0x42A79940UL)))
#define bM4_PORT_PFSRD2_FSEL1                     (*((volatile unsigned int*)(0x42A79944UL)))
#define bM4_PORT_PFSRD2_FSEL2                     (*((volatile unsigned int*)(0x42A79948UL)))
#define bM4_PORT_PFSRD2_FSEL3                     (*((volatile unsigned int*)(0x42A7994CUL)))
#define bM4_PORT_PFSRD2_FSEL4                     (*((volatile unsigned int*)(0x42A79950UL)))
#define bM4_PORT_PFSRD2_FSEL5                     (*((volatile unsigned int*)(0x42A79954UL)))
#define bM4_PORT_PFSRD2_BFE                       (*((volatile unsigned int*)(0x42A79960UL)))
#define bM4_PORT_PCRD3_POUT                       (*((volatile unsigned int*)(0x42A79980UL)))
#define bM4_PORT_PCRD3_POUTE                      (*((volatile unsigned int*)(0x42A79984UL)))
#define bM4_PORT_PCRD3_NOD                        (*((volatile unsigned int*)(0x42A79988UL)))
#define bM4_PORT_PCRD3_DRV0                       (*((volatile unsigned int*)(0x42A79990UL)))
#define bM4_PORT_PCRD3_DRV1                       (*((volatile unsigned int*)(0x42A79994UL)))
#define bM4_PORT_PCRD3_PUU                        (*((volatile unsigned int*)(0x42A79998UL)))
#define bM4_PORT_PCRD3_PIN                        (*((volatile unsigned int*)(0x42A799A0UL)))
#define bM4_PORT_PCRD3_INVE                       (*((volatile unsigned int*)(0x42A799A4UL)))
#define bM4_PORT_PCRD3_INTE                       (*((volatile unsigned int*)(0x42A799B0UL)))
#define bM4_PORT_PCRD3_LTE                        (*((volatile unsigned int*)(0x42A799B8UL)))
#define bM4_PORT_PCRD3_DDIS                       (*((volatile unsigned int*)(0x42A799BCUL)))
#define bM4_PORT_PFSRD3_FSEL0                     (*((volatile unsigned int*)(0x42A799C0UL)))
#define bM4_PORT_PFSRD3_FSEL1                     (*((volatile unsigned int*)(0x42A799C4UL)))
#define bM4_PORT_PFSRD3_FSEL2                     (*((volatile unsigned int*)(0x42A799C8UL)))
#define bM4_PORT_PFSRD3_FSEL3                     (*((volatile unsigned int*)(0x42A799CCUL)))
#define bM4_PORT_PFSRD3_FSEL4                     (*((volatile unsigned int*)(0x42A799D0UL)))
#define bM4_PORT_PFSRD3_FSEL5                     (*((volatile unsigned int*)(0x42A799D4UL)))
#define bM4_PORT_PFSRD3_BFE                       (*((volatile unsigned int*)(0x42A799E0UL)))
#define bM4_PORT_PCRD4_POUT                       (*((volatile unsigned int*)(0x42A79A00UL)))
#define bM4_PORT_PCRD4_POUTE                      (*((volatile unsigned int*)(0x42A79A04UL)))
#define bM4_PORT_PCRD4_NOD                        (*((volatile unsigned int*)(0x42A79A08UL)))
#define bM4_PORT_PCRD4_DRV0                       (*((volatile unsigned int*)(0x42A79A10UL)))
#define bM4_PORT_PCRD4_DRV1                       (*((volatile unsigned int*)(0x42A79A14UL)))
#define bM4_PORT_PCRD4_PUU                        (*((volatile unsigned int*)(0x42A79A18UL)))
#define bM4_PORT_PCRD4_PIN                        (*((volatile unsigned int*)(0x42A79A20UL)))
#define bM4_PORT_PCRD4_INVE                       (*((volatile unsigned int*)(0x42A79A24UL)))
#define bM4_PORT_PCRD4_INTE                       (*((volatile unsigned int*)(0x42A79A30UL)))
#define bM4_PORT_PCRD4_LTE                        (*((volatile unsigned int*)(0x42A79A38UL)))
#define bM4_PORT_PCRD4_DDIS                       (*((volatile unsigned int*)(0x42A79A3CUL)))
#define bM4_PORT_PFSRD4_FSEL0                     (*((volatile unsigned int*)(0x42A79A40UL)))
#define bM4_PORT_PFSRD4_FSEL1                     (*((volatile unsigned int*)(0x42A79A44UL)))
#define bM4_PORT_PFSRD4_FSEL2                     (*((volatile unsigned int*)(0x42A79A48UL)))
#define bM4_PORT_PFSRD4_FSEL3                     (*((volatile unsigned int*)(0x42A79A4CUL)))
#define bM4_PORT_PFSRD4_FSEL4                     (*((volatile unsigned int*)(0x42A79A50UL)))
#define bM4_PORT_PFSRD4_FSEL5                     (*((volatile unsigned int*)(0x42A79A54UL)))
#define bM4_PORT_PFSRD4_BFE                       (*((volatile unsigned int*)(0x42A79A60UL)))
#define bM4_PORT_PCRD5_POUT                       (*((volatile unsigned int*)(0x42A79A80UL)))
#define bM4_PORT_PCRD5_POUTE                      (*((volatile unsigned int*)(0x42A79A84UL)))
#define bM4_PORT_PCRD5_NOD                        (*((volatile unsigned int*)(0x42A79A88UL)))
#define bM4_PORT_PCRD5_DRV0                       (*((volatile unsigned int*)(0x42A79A90UL)))
#define bM4_PORT_PCRD5_DRV1                       (*((volatile unsigned int*)(0x42A79A94UL)))
#define bM4_PORT_PCRD5_PUU                        (*((volatile unsigned int*)(0x42A79A98UL)))
#define bM4_PORT_PCRD5_PIN                        (*((volatile unsigned int*)(0x42A79AA0UL)))
#define bM4_PORT_PCRD5_INVE                       (*((volatile unsigned int*)(0x42A79AA4UL)))
#define bM4_PORT_PCRD5_INTE                       (*((volatile unsigned int*)(0x42A79AB0UL)))
#define bM4_PORT_PCRD5_LTE                        (*((volatile unsigned int*)(0x42A79AB8UL)))
#define bM4_PORT_PCRD5_DDIS                       (*((volatile unsigned int*)(0x42A79ABCUL)))
#define bM4_PORT_PFSRD5_FSEL0                     (*((volatile unsigned int*)(0x42A79AC0UL)))
#define bM4_PORT_PFSRD5_FSEL1                     (*((volatile unsigned int*)(0x42A79AC4UL)))
#define bM4_PORT_PFSRD5_FSEL2                     (*((volatile unsigned int*)(0x42A79AC8UL)))
#define bM4_PORT_PFSRD5_FSEL3                     (*((volatile unsigned int*)(0x42A79ACCUL)))
#define bM4_PORT_PFSRD5_FSEL4                     (*((volatile unsigned int*)(0x42A79AD0UL)))
#define bM4_PORT_PFSRD5_FSEL5                     (*((volatile unsigned int*)(0x42A79AD4UL)))
#define bM4_PORT_PFSRD5_BFE                       (*((volatile unsigned int*)(0x42A79AE0UL)))
#define bM4_PORT_PCRD6_POUT                       (*((volatile unsigned int*)(0x42A79B00UL)))
#define bM4_PORT_PCRD6_POUTE                      (*((volatile unsigned int*)(0x42A79B04UL)))
#define bM4_PORT_PCRD6_NOD                        (*((volatile unsigned int*)(0x42A79B08UL)))
#define bM4_PORT_PCRD6_DRV0                       (*((volatile unsigned int*)(0x42A79B10UL)))
#define bM4_PORT_PCRD6_DRV1                       (*((volatile unsigned int*)(0x42A79B14UL)))
#define bM4_PORT_PCRD6_PUU                        (*((volatile unsigned int*)(0x42A79B18UL)))
#define bM4_PORT_PCRD6_PIN                        (*((volatile unsigned int*)(0x42A79B20UL)))
#define bM4_PORT_PCRD6_INVE                       (*((volatile unsigned int*)(0x42A79B24UL)))
#define bM4_PORT_PCRD6_INTE                       (*((volatile unsigned int*)(0x42A79B30UL)))
#define bM4_PORT_PCRD6_LTE                        (*((volatile unsigned int*)(0x42A79B38UL)))
#define bM4_PORT_PCRD6_DDIS                       (*((volatile unsigned int*)(0x42A79B3CUL)))
#define bM4_PORT_PFSRD6_FSEL0                     (*((volatile unsigned int*)(0x42A79B40UL)))
#define bM4_PORT_PFSRD6_FSEL1                     (*((volatile unsigned int*)(0x42A79B44UL)))
#define bM4_PORT_PFSRD6_FSEL2                     (*((volatile unsigned int*)(0x42A79B48UL)))
#define bM4_PORT_PFSRD6_FSEL3                     (*((volatile unsigned int*)(0x42A79B4CUL)))
#define bM4_PORT_PFSRD6_FSEL4                     (*((volatile unsigned int*)(0x42A79B50UL)))
#define bM4_PORT_PFSRD6_FSEL5                     (*((volatile unsigned int*)(0x42A79B54UL)))
#define bM4_PORT_PFSRD6_BFE                       (*((volatile unsigned int*)(0x42A79B60UL)))
#define bM4_PORT_PCRD7_POUT                       (*((volatile unsigned int*)(0x42A79B80UL)))
#define bM4_PORT_PCRD7_POUTE                      (*((volatile unsigned int*)(0x42A79B84UL)))
#define bM4_PORT_PCRD7_NOD                        (*((volatile unsigned int*)(0x42A79B88UL)))
#define bM4_PORT_PCRD7_DRV0                       (*((volatile unsigned int*)(0x42A79B90UL)))
#define bM4_PORT_PCRD7_DRV1                       (*((volatile unsigned int*)(0x42A79B94UL)))
#define bM4_PORT_PCRD7_PUU                        (*((volatile unsigned int*)(0x42A79B98UL)))
#define bM4_PORT_PCRD7_PIN                        (*((volatile unsigned int*)(0x42A79BA0UL)))
#define bM4_PORT_PCRD7_INVE                       (*((volatile unsigned int*)(0x42A79BA4UL)))
#define bM4_PORT_PCRD7_INTE                       (*((volatile unsigned int*)(0x42A79BB0UL)))
#define bM4_PORT_PCRD7_LTE                        (*((volatile unsigned int*)(0x42A79BB8UL)))
#define bM4_PORT_PCRD7_DDIS                       (*((volatile unsigned int*)(0x42A79BBCUL)))
#define bM4_PORT_PFSRD7_FSEL0                     (*((volatile unsigned int*)(0x42A79BC0UL)))
#define bM4_PORT_PFSRD7_FSEL1                     (*((volatile unsigned int*)(0x42A79BC4UL)))
#define bM4_PORT_PFSRD7_FSEL2                     (*((volatile unsigned int*)(0x42A79BC8UL)))
#define bM4_PORT_PFSRD7_FSEL3                     (*((volatile unsigned int*)(0x42A79BCCUL)))
#define bM4_PORT_PFSRD7_FSEL4                     (*((volatile unsigned int*)(0x42A79BD0UL)))
#define bM4_PORT_PFSRD7_FSEL5                     (*((volatile unsigned int*)(0x42A79BD4UL)))
#define bM4_PORT_PFSRD7_BFE                       (*((volatile unsigned int*)(0x42A79BE0UL)))
#define bM4_PORT_PCRD8_POUT                       (*((volatile unsigned int*)(0x42A79C00UL)))
#define bM4_PORT_PCRD8_POUTE                      (*((volatile unsigned int*)(0x42A79C04UL)))
#define bM4_PORT_PCRD8_NOD                        (*((volatile unsigned int*)(0x42A79C08UL)))
#define bM4_PORT_PCRD8_DRV0                       (*((volatile unsigned int*)(0x42A79C10UL)))
#define bM4_PORT_PCRD8_DRV1                       (*((volatile unsigned int*)(0x42A79C14UL)))
#define bM4_PORT_PCRD8_PUU                        (*((volatile unsigned int*)(0x42A79C18UL)))
#define bM4_PORT_PCRD8_PIN                        (*((volatile unsigned int*)(0x42A79C20UL)))
#define bM4_PORT_PCRD8_INVE                       (*((volatile unsigned int*)(0x42A79C24UL)))
#define bM4_PORT_PCRD8_INTE                       (*((volatile unsigned int*)(0x42A79C30UL)))
#define bM4_PORT_PCRD8_LTE                        (*((volatile unsigned int*)(0x42A79C38UL)))
#define bM4_PORT_PCRD8_DDIS                       (*((volatile unsigned int*)(0x42A79C3CUL)))
#define bM4_PORT_PFSRD8_FSEL0                     (*((volatile unsigned int*)(0x42A79C40UL)))
#define bM4_PORT_PFSRD8_FSEL1                     (*((volatile unsigned int*)(0x42A79C44UL)))
#define bM4_PORT_PFSRD8_FSEL2                     (*((volatile unsigned int*)(0x42A79C48UL)))
#define bM4_PORT_PFSRD8_FSEL3                     (*((volatile unsigned int*)(0x42A79C4CUL)))
#define bM4_PORT_PFSRD8_FSEL4                     (*((volatile unsigned int*)(0x42A79C50UL)))
#define bM4_PORT_PFSRD8_FSEL5                     (*((volatile unsigned int*)(0x42A79C54UL)))
#define bM4_PORT_PFSRD8_BFE                       (*((volatile unsigned int*)(0x42A79C60UL)))
#define bM4_PORT_PCRD9_POUT                       (*((volatile unsigned int*)(0x42A79C80UL)))
#define bM4_PORT_PCRD9_POUTE                      (*((volatile unsigned int*)(0x42A79C84UL)))
#define bM4_PORT_PCRD9_NOD                        (*((volatile unsigned int*)(0x42A79C88UL)))
#define bM4_PORT_PCRD9_DRV0                       (*((volatile unsigned int*)(0x42A79C90UL)))
#define bM4_PORT_PCRD9_DRV1                       (*((volatile unsigned int*)(0x42A79C94UL)))
#define bM4_PORT_PCRD9_PUU                        (*((volatile unsigned int*)(0x42A79C98UL)))
#define bM4_PORT_PCRD9_PIN                        (*((volatile unsigned int*)(0x42A79CA0UL)))
#define bM4_PORT_PCRD9_INVE                       (*((volatile unsigned int*)(0x42A79CA4UL)))
#define bM4_PORT_PCRD9_INTE                       (*((volatile unsigned int*)(0x42A79CB0UL)))
#define bM4_PORT_PCRD9_LTE                        (*((volatile unsigned int*)(0x42A79CB8UL)))
#define bM4_PORT_PCRD9_DDIS                       (*((volatile unsigned int*)(0x42A79CBCUL)))
#define bM4_PORT_PFSRD9_FSEL0                     (*((volatile unsigned int*)(0x42A79CC0UL)))
#define bM4_PORT_PFSRD9_FSEL1                     (*((volatile unsigned int*)(0x42A79CC4UL)))
#define bM4_PORT_PFSRD9_FSEL2                     (*((volatile unsigned int*)(0x42A79CC8UL)))
#define bM4_PORT_PFSRD9_FSEL3                     (*((volatile unsigned int*)(0x42A79CCCUL)))
#define bM4_PORT_PFSRD9_FSEL4                     (*((volatile unsigned int*)(0x42A79CD0UL)))
#define bM4_PORT_PFSRD9_FSEL5                     (*((volatile unsigned int*)(0x42A79CD4UL)))
#define bM4_PORT_PFSRD9_BFE                       (*((volatile unsigned int*)(0x42A79CE0UL)))
#define bM4_PORT_PCRD10_POUT                      (*((volatile unsigned int*)(0x42A79D00UL)))
#define bM4_PORT_PCRD10_POUTE                     (*((volatile unsigned int*)(0x42A79D04UL)))
#define bM4_PORT_PCRD10_NOD                       (*((volatile unsigned int*)(0x42A79D08UL)))
#define bM4_PORT_PCRD10_DRV0                      (*((volatile unsigned int*)(0x42A79D10UL)))
#define bM4_PORT_PCRD10_DRV1                      (*((volatile unsigned int*)(0x42A79D14UL)))
#define bM4_PORT_PCRD10_PUU                       (*((volatile unsigned int*)(0x42A79D18UL)))
#define bM4_PORT_PCRD10_PIN                       (*((volatile unsigned int*)(0x42A79D20UL)))
#define bM4_PORT_PCRD10_INVE                      (*((volatile unsigned int*)(0x42A79D24UL)))
#define bM4_PORT_PCRD10_INTE                      (*((volatile unsigned int*)(0x42A79D30UL)))
#define bM4_PORT_PCRD10_LTE                       (*((volatile unsigned int*)(0x42A79D38UL)))
#define bM4_PORT_PCRD10_DDIS                      (*((volatile unsigned int*)(0x42A79D3CUL)))
#define bM4_PORT_PFSRD10_FSEL0                    (*((volatile unsigned int*)(0x42A79D40UL)))
#define bM4_PORT_PFSRD10_FSEL1                    (*((volatile unsigned int*)(0x42A79D44UL)))
#define bM4_PORT_PFSRD10_FSEL2                    (*((volatile unsigned int*)(0x42A79D48UL)))
#define bM4_PORT_PFSRD10_FSEL3                    (*((volatile unsigned int*)(0x42A79D4CUL)))
#define bM4_PORT_PFSRD10_FSEL4                    (*((volatile unsigned int*)(0x42A79D50UL)))
#define bM4_PORT_PFSRD10_FSEL5                    (*((volatile unsigned int*)(0x42A79D54UL)))
#define bM4_PORT_PFSRD10_BFE                      (*((volatile unsigned int*)(0x42A79D60UL)))
#define bM4_PORT_PCRD11_POUT                      (*((volatile unsigned int*)(0x42A79D80UL)))
#define bM4_PORT_PCRD11_POUTE                     (*((volatile unsigned int*)(0x42A79D84UL)))
#define bM4_PORT_PCRD11_NOD                       (*((volatile unsigned int*)(0x42A79D88UL)))
#define bM4_PORT_PCRD11_DRV0                      (*((volatile unsigned int*)(0x42A79D90UL)))
#define bM4_PORT_PCRD11_DRV1                      (*((volatile unsigned int*)(0x42A79D94UL)))
#define bM4_PORT_PCRD11_PUU                       (*((volatile unsigned int*)(0x42A79D98UL)))
#define bM4_PORT_PCRD11_PIN                       (*((volatile unsigned int*)(0x42A79DA0UL)))
#define bM4_PORT_PCRD11_INVE                      (*((volatile unsigned int*)(0x42A79DA4UL)))
#define bM4_PORT_PCRD11_INTE                      (*((volatile unsigned int*)(0x42A79DB0UL)))
#define bM4_PORT_PCRD11_LTE                       (*((volatile unsigned int*)(0x42A79DB8UL)))
#define bM4_PORT_PCRD11_DDIS                      (*((volatile unsigned int*)(0x42A79DBCUL)))
#define bM4_PORT_PFSRD11_FSEL0                    (*((volatile unsigned int*)(0x42A79DC0UL)))
#define bM4_PORT_PFSRD11_FSEL1                    (*((volatile unsigned int*)(0x42A79DC4UL)))
#define bM4_PORT_PFSRD11_FSEL2                    (*((volatile unsigned int*)(0x42A79DC8UL)))
#define bM4_PORT_PFSRD11_FSEL3                    (*((volatile unsigned int*)(0x42A79DCCUL)))
#define bM4_PORT_PFSRD11_FSEL4                    (*((volatile unsigned int*)(0x42A79DD0UL)))
#define bM4_PORT_PFSRD11_FSEL5                    (*((volatile unsigned int*)(0x42A79DD4UL)))
#define bM4_PORT_PFSRD11_BFE                      (*((volatile unsigned int*)(0x42A79DE0UL)))
#define bM4_PORT_PCRD12_POUT                      (*((volatile unsigned int*)(0x42A79E00UL)))
#define bM4_PORT_PCRD12_POUTE                     (*((volatile unsigned int*)(0x42A79E04UL)))
#define bM4_PORT_PCRD12_NOD                       (*((volatile unsigned int*)(0x42A79E08UL)))
#define bM4_PORT_PCRD12_DRV0                      (*((volatile unsigned int*)(0x42A79E10UL)))
#define bM4_PORT_PCRD12_DRV1                      (*((volatile unsigned int*)(0x42A79E14UL)))
#define bM4_PORT_PCRD12_PUU                       (*((volatile unsigned int*)(0x42A79E18UL)))
#define bM4_PORT_PCRD12_PIN                       (*((volatile unsigned int*)(0x42A79E20UL)))
#define bM4_PORT_PCRD12_INVE                      (*((volatile unsigned int*)(0x42A79E24UL)))
#define bM4_PORT_PCRD12_INTE                      (*((volatile unsigned int*)(0x42A79E30UL)))
#define bM4_PORT_PCRD12_LTE                       (*((volatile unsigned int*)(0x42A79E38UL)))
#define bM4_PORT_PCRD12_DDIS                      (*((volatile unsigned int*)(0x42A79E3CUL)))
#define bM4_PORT_PFSRD12_FSEL0                    (*((volatile unsigned int*)(0x42A79E40UL)))
#define bM4_PORT_PFSRD12_FSEL1                    (*((volatile unsigned int*)(0x42A79E44UL)))
#define bM4_PORT_PFSRD12_FSEL2                    (*((volatile unsigned int*)(0x42A79E48UL)))
#define bM4_PORT_PFSRD12_FSEL3                    (*((volatile unsigned int*)(0x42A79E4CUL)))
#define bM4_PORT_PFSRD12_FSEL4                    (*((volatile unsigned int*)(0x42A79E50UL)))
#define bM4_PORT_PFSRD12_FSEL5                    (*((volatile unsigned int*)(0x42A79E54UL)))
#define bM4_PORT_PFSRD12_BFE                      (*((volatile unsigned int*)(0x42A79E60UL)))
#define bM4_PORT_PCRD13_POUT                      (*((volatile unsigned int*)(0x42A79E80UL)))
#define bM4_PORT_PCRD13_POUTE                     (*((volatile unsigned int*)(0x42A79E84UL)))
#define bM4_PORT_PCRD13_NOD                       (*((volatile unsigned int*)(0x42A79E88UL)))
#define bM4_PORT_PCRD13_DRV0                      (*((volatile unsigned int*)(0x42A79E90UL)))
#define bM4_PORT_PCRD13_DRV1                      (*((volatile unsigned int*)(0x42A79E94UL)))
#define bM4_PORT_PCRD13_PUU                       (*((volatile unsigned int*)(0x42A79E98UL)))
#define bM4_PORT_PCRD13_PIN                       (*((volatile unsigned int*)(0x42A79EA0UL)))
#define bM4_PORT_PCRD13_INVE                      (*((volatile unsigned int*)(0x42A79EA4UL)))
#define bM4_PORT_PCRD13_INTE                      (*((volatile unsigned int*)(0x42A79EB0UL)))
#define bM4_PORT_PCRD13_LTE                       (*((volatile unsigned int*)(0x42A79EB8UL)))
#define bM4_PORT_PCRD13_DDIS                      (*((volatile unsigned int*)(0x42A79EBCUL)))
#define bM4_PORT_PFSRD13_FSEL0                    (*((volatile unsigned int*)(0x42A79EC0UL)))
#define bM4_PORT_PFSRD13_FSEL1                    (*((volatile unsigned int*)(0x42A79EC4UL)))
#define bM4_PORT_PFSRD13_FSEL2                    (*((volatile unsigned int*)(0x42A79EC8UL)))
#define bM4_PORT_PFSRD13_FSEL3                    (*((volatile unsigned int*)(0x42A79ECCUL)))
#define bM4_PORT_PFSRD13_FSEL4                    (*((volatile unsigned int*)(0x42A79ED0UL)))
#define bM4_PORT_PFSRD13_FSEL5                    (*((volatile unsigned int*)(0x42A79ED4UL)))
#define bM4_PORT_PFSRD13_BFE                      (*((volatile unsigned int*)(0x42A79EE0UL)))
#define bM4_PORT_PCRD14_POUT                      (*((volatile unsigned int*)(0x42A79F00UL)))
#define bM4_PORT_PCRD14_POUTE                     (*((volatile unsigned int*)(0x42A79F04UL)))
#define bM4_PORT_PCRD14_NOD                       (*((volatile unsigned int*)(0x42A79F08UL)))
#define bM4_PORT_PCRD14_DRV0                      (*((volatile unsigned int*)(0x42A79F10UL)))
#define bM4_PORT_PCRD14_DRV1                      (*((volatile unsigned int*)(0x42A79F14UL)))
#define bM4_PORT_PCRD14_PUU                       (*((volatile unsigned int*)(0x42A79F18UL)))
#define bM4_PORT_PCRD14_PIN                       (*((volatile unsigned int*)(0x42A79F20UL)))
#define bM4_PORT_PCRD14_INVE                      (*((volatile unsigned int*)(0x42A79F24UL)))
#define bM4_PORT_PCRD14_INTE                      (*((volatile unsigned int*)(0x42A79F30UL)))
#define bM4_PORT_PCRD14_LTE                       (*((volatile unsigned int*)(0x42A79F38UL)))
#define bM4_PORT_PCRD14_DDIS                      (*((volatile unsigned int*)(0x42A79F3CUL)))
#define bM4_PORT_PFSRD14_FSEL0                    (*((volatile unsigned int*)(0x42A79F40UL)))
#define bM4_PORT_PFSRD14_FSEL1                    (*((volatile unsigned int*)(0x42A79F44UL)))
#define bM4_PORT_PFSRD14_FSEL2                    (*((volatile unsigned int*)(0x42A79F48UL)))
#define bM4_PORT_PFSRD14_FSEL3                    (*((volatile unsigned int*)(0x42A79F4CUL)))
#define bM4_PORT_PFSRD14_FSEL4                    (*((volatile unsigned int*)(0x42A79F50UL)))
#define bM4_PORT_PFSRD14_FSEL5                    (*((volatile unsigned int*)(0x42A79F54UL)))
#define bM4_PORT_PFSRD14_BFE                      (*((volatile unsigned int*)(0x42A79F60UL)))
#define bM4_PORT_PCRD15_POUT                      (*((volatile unsigned int*)(0x42A79F80UL)))
#define bM4_PORT_PCRD15_POUTE                     (*((volatile unsigned int*)(0x42A79F84UL)))
#define bM4_PORT_PCRD15_NOD                       (*((volatile unsigned int*)(0x42A79F88UL)))
#define bM4_PORT_PCRD15_DRV0                      (*((volatile unsigned int*)(0x42A79F90UL)))
#define bM4_PORT_PCRD15_DRV1                      (*((volatile unsigned int*)(0x42A79F94UL)))
#define bM4_PORT_PCRD15_PUU                       (*((volatile unsigned int*)(0x42A79F98UL)))
#define bM4_PORT_PCRD15_PIN                       (*((volatile unsigned int*)(0x42A79FA0UL)))
#define bM4_PORT_PCRD15_INVE                      (*((volatile unsigned int*)(0x42A79FA4UL)))
#define bM4_PORT_PCRD15_INTE                      (*((volatile unsigned int*)(0x42A79FB0UL)))
#define bM4_PORT_PCRD15_LTE                       (*((volatile unsigned int*)(0x42A79FB8UL)))
#define bM4_PORT_PCRD15_DDIS                      (*((volatile unsigned int*)(0x42A79FBCUL)))
#define bM4_PORT_PFSRD15_FSEL0                    (*((volatile unsigned int*)(0x42A79FC0UL)))
#define bM4_PORT_PFSRD15_FSEL1                    (*((volatile unsigned int*)(0x42A79FC4UL)))
#define bM4_PORT_PFSRD15_FSEL2                    (*((volatile unsigned int*)(0x42A79FC8UL)))
#define bM4_PORT_PFSRD15_FSEL3                    (*((volatile unsigned int*)(0x42A79FCCUL)))
#define bM4_PORT_PFSRD15_FSEL4                    (*((volatile unsigned int*)(0x42A79FD0UL)))
#define bM4_PORT_PFSRD15_FSEL5                    (*((volatile unsigned int*)(0x42A79FD4UL)))
#define bM4_PORT_PFSRD15_BFE                      (*((volatile unsigned int*)(0x42A79FE0UL)))
#define bM4_PORT_PCRE0_POUT                       (*((volatile unsigned int*)(0x42A7A000UL)))
#define bM4_PORT_PCRE0_POUTE                      (*((volatile unsigned int*)(0x42A7A004UL)))
#define bM4_PORT_PCRE0_NOD                        (*((volatile unsigned int*)(0x42A7A008UL)))
#define bM4_PORT_PCRE0_DRV0                       (*((volatile unsigned int*)(0x42A7A010UL)))
#define bM4_PORT_PCRE0_DRV1                       (*((volatile unsigned int*)(0x42A7A014UL)))
#define bM4_PORT_PCRE0_PUU                        (*((volatile unsigned int*)(0x42A7A018UL)))
#define bM4_PORT_PCRE0_PIN                        (*((volatile unsigned int*)(0x42A7A020UL)))
#define bM4_PORT_PCRE0_INVE                       (*((volatile unsigned int*)(0x42A7A024UL)))
#define bM4_PORT_PCRE0_INTE                       (*((volatile unsigned int*)(0x42A7A030UL)))
#define bM4_PORT_PCRE0_LTE                        (*((volatile unsigned int*)(0x42A7A038UL)))
#define bM4_PORT_PCRE0_DDIS                       (*((volatile unsigned int*)(0x42A7A03CUL)))
#define bM4_PORT_PFSRE0_FSEL0                     (*((volatile unsigned int*)(0x42A7A040UL)))
#define bM4_PORT_PFSRE0_FSEL1                     (*((volatile unsigned int*)(0x42A7A044UL)))
#define bM4_PORT_PFSRE0_FSEL2                     (*((volatile unsigned int*)(0x42A7A048UL)))
#define bM4_PORT_PFSRE0_FSEL3                     (*((volatile unsigned int*)(0x42A7A04CUL)))
#define bM4_PORT_PFSRE0_FSEL4                     (*((volatile unsigned int*)(0x42A7A050UL)))
#define bM4_PORT_PFSRE0_FSEL5                     (*((volatile unsigned int*)(0x42A7A054UL)))
#define bM4_PORT_PFSRE0_BFE                       (*((volatile unsigned int*)(0x42A7A060UL)))
#define bM4_PORT_PCRE1_POUT                       (*((volatile unsigned int*)(0x42A7A080UL)))
#define bM4_PORT_PCRE1_POUTE                      (*((volatile unsigned int*)(0x42A7A084UL)))
#define bM4_PORT_PCRE1_NOD                        (*((volatile unsigned int*)(0x42A7A088UL)))
#define bM4_PORT_PCRE1_DRV0                       (*((volatile unsigned int*)(0x42A7A090UL)))
#define bM4_PORT_PCRE1_DRV1                       (*((volatile unsigned int*)(0x42A7A094UL)))
#define bM4_PORT_PCRE1_PUU                        (*((volatile unsigned int*)(0x42A7A098UL)))
#define bM4_PORT_PCRE1_PIN                        (*((volatile unsigned int*)(0x42A7A0A0UL)))
#define bM4_PORT_PCRE1_INVE                       (*((volatile unsigned int*)(0x42A7A0A4UL)))
#define bM4_PORT_PCRE1_INTE                       (*((volatile unsigned int*)(0x42A7A0B0UL)))
#define bM4_PORT_PCRE1_LTE                        (*((volatile unsigned int*)(0x42A7A0B8UL)))
#define bM4_PORT_PCRE1_DDIS                       (*((volatile unsigned int*)(0x42A7A0BCUL)))
#define bM4_PORT_PFSRE1_FSEL0                     (*((volatile unsigned int*)(0x42A7A0C0UL)))
#define bM4_PORT_PFSRE1_FSEL1                     (*((volatile unsigned int*)(0x42A7A0C4UL)))
#define bM4_PORT_PFSRE1_FSEL2                     (*((volatile unsigned int*)(0x42A7A0C8UL)))
#define bM4_PORT_PFSRE1_FSEL3                     (*((volatile unsigned int*)(0x42A7A0CCUL)))
#define bM4_PORT_PFSRE1_FSEL4                     (*((volatile unsigned int*)(0x42A7A0D0UL)))
#define bM4_PORT_PFSRE1_FSEL5                     (*((volatile unsigned int*)(0x42A7A0D4UL)))
#define bM4_PORT_PFSRE1_BFE                       (*((volatile unsigned int*)(0x42A7A0E0UL)))
#define bM4_PORT_PCRE2_POUT                       (*((volatile unsigned int*)(0x42A7A100UL)))
#define bM4_PORT_PCRE2_POUTE                      (*((volatile unsigned int*)(0x42A7A104UL)))
#define bM4_PORT_PCRE2_NOD                        (*((volatile unsigned int*)(0x42A7A108UL)))
#define bM4_PORT_PCRE2_DRV0                       (*((volatile unsigned int*)(0x42A7A110UL)))
#define bM4_PORT_PCRE2_DRV1                       (*((volatile unsigned int*)(0x42A7A114UL)))
#define bM4_PORT_PCRE2_PUU                        (*((volatile unsigned int*)(0x42A7A118UL)))
#define bM4_PORT_PCRE2_PIN                        (*((volatile unsigned int*)(0x42A7A120UL)))
#define bM4_PORT_PCRE2_INVE                       (*((volatile unsigned int*)(0x42A7A124UL)))
#define bM4_PORT_PCRE2_INTE                       (*((volatile unsigned int*)(0x42A7A130UL)))
#define bM4_PORT_PCRE2_LTE                        (*((volatile unsigned int*)(0x42A7A138UL)))
#define bM4_PORT_PCRE2_DDIS                       (*((volatile unsigned int*)(0x42A7A13CUL)))
#define bM4_PORT_PFSRE2_FSEL0                     (*((volatile unsigned int*)(0x42A7A140UL)))
#define bM4_PORT_PFSRE2_FSEL1                     (*((volatile unsigned int*)(0x42A7A144UL)))
#define bM4_PORT_PFSRE2_FSEL2                     (*((volatile unsigned int*)(0x42A7A148UL)))
#define bM4_PORT_PFSRE2_FSEL3                     (*((volatile unsigned int*)(0x42A7A14CUL)))
#define bM4_PORT_PFSRE2_FSEL4                     (*((volatile unsigned int*)(0x42A7A150UL)))
#define bM4_PORT_PFSRE2_FSEL5                     (*((volatile unsigned int*)(0x42A7A154UL)))
#define bM4_PORT_PFSRE2_BFE                       (*((volatile unsigned int*)(0x42A7A160UL)))
#define bM4_PORT_PCRE3_POUT                       (*((volatile unsigned int*)(0x42A7A180UL)))
#define bM4_PORT_PCRE3_POUTE                      (*((volatile unsigned int*)(0x42A7A184UL)))
#define bM4_PORT_PCRE3_NOD                        (*((volatile unsigned int*)(0x42A7A188UL)))
#define bM4_PORT_PCRE3_DRV0                       (*((volatile unsigned int*)(0x42A7A190UL)))
#define bM4_PORT_PCRE3_DRV1                       (*((volatile unsigned int*)(0x42A7A194UL)))
#define bM4_PORT_PCRE3_PUU                        (*((volatile unsigned int*)(0x42A7A198UL)))
#define bM4_PORT_PCRE3_PIN                        (*((volatile unsigned int*)(0x42A7A1A0UL)))
#define bM4_PORT_PCRE3_INVE                       (*((volatile unsigned int*)(0x42A7A1A4UL)))
#define bM4_PORT_PCRE3_INTE                       (*((volatile unsigned int*)(0x42A7A1B0UL)))
#define bM4_PORT_PCRE3_LTE                        (*((volatile unsigned int*)(0x42A7A1B8UL)))
#define bM4_PORT_PCRE3_DDIS                       (*((volatile unsigned int*)(0x42A7A1BCUL)))
#define bM4_PORT_PFSRE3_FSEL0                     (*((volatile unsigned int*)(0x42A7A1C0UL)))
#define bM4_PORT_PFSRE3_FSEL1                     (*((volatile unsigned int*)(0x42A7A1C4UL)))
#define bM4_PORT_PFSRE3_FSEL2                     (*((volatile unsigned int*)(0x42A7A1C8UL)))
#define bM4_PORT_PFSRE3_FSEL3                     (*((volatile unsigned int*)(0x42A7A1CCUL)))
#define bM4_PORT_PFSRE3_FSEL4                     (*((volatile unsigned int*)(0x42A7A1D0UL)))
#define bM4_PORT_PFSRE3_FSEL5                     (*((volatile unsigned int*)(0x42A7A1D4UL)))
#define bM4_PORT_PFSRE3_BFE                       (*((volatile unsigned int*)(0x42A7A1E0UL)))
#define bM4_PORT_PCRE4_POUT                       (*((volatile unsigned int*)(0x42A7A200UL)))
#define bM4_PORT_PCRE4_POUTE                      (*((volatile unsigned int*)(0x42A7A204UL)))
#define bM4_PORT_PCRE4_NOD                        (*((volatile unsigned int*)(0x42A7A208UL)))
#define bM4_PORT_PCRE4_DRV0                       (*((volatile unsigned int*)(0x42A7A210UL)))
#define bM4_PORT_PCRE4_DRV1                       (*((volatile unsigned int*)(0x42A7A214UL)))
#define bM4_PORT_PCRE4_PUU                        (*((volatile unsigned int*)(0x42A7A218UL)))
#define bM4_PORT_PCRE4_PIN                        (*((volatile unsigned int*)(0x42A7A220UL)))
#define bM4_PORT_PCRE4_INVE                       (*((volatile unsigned int*)(0x42A7A224UL)))
#define bM4_PORT_PCRE4_INTE                       (*((volatile unsigned int*)(0x42A7A230UL)))
#define bM4_PORT_PCRE4_LTE                        (*((volatile unsigned int*)(0x42A7A238UL)))
#define bM4_PORT_PCRE4_DDIS                       (*((volatile unsigned int*)(0x42A7A23CUL)))
#define bM4_PORT_PFSRE4_FSEL0                     (*((volatile unsigned int*)(0x42A7A240UL)))
#define bM4_PORT_PFSRE4_FSEL1                     (*((volatile unsigned int*)(0x42A7A244UL)))
#define bM4_PORT_PFSRE4_FSEL2                     (*((volatile unsigned int*)(0x42A7A248UL)))
#define bM4_PORT_PFSRE4_FSEL3                     (*((volatile unsigned int*)(0x42A7A24CUL)))
#define bM4_PORT_PFSRE4_FSEL4                     (*((volatile unsigned int*)(0x42A7A250UL)))
#define bM4_PORT_PFSRE4_FSEL5                     (*((volatile unsigned int*)(0x42A7A254UL)))
#define bM4_PORT_PFSRE4_BFE                       (*((volatile unsigned int*)(0x42A7A260UL)))
#define bM4_PORT_PCRE5_POUT                       (*((volatile unsigned int*)(0x42A7A280UL)))
#define bM4_PORT_PCRE5_POUTE                      (*((volatile unsigned int*)(0x42A7A284UL)))
#define bM4_PORT_PCRE5_NOD                        (*((volatile unsigned int*)(0x42A7A288UL)))
#define bM4_PORT_PCRE5_DRV0                       (*((volatile unsigned int*)(0x42A7A290UL)))
#define bM4_PORT_PCRE5_DRV1                       (*((volatile unsigned int*)(0x42A7A294UL)))
#define bM4_PORT_PCRE5_PUU                        (*((volatile unsigned int*)(0x42A7A298UL)))
#define bM4_PORT_PCRE5_PIN                        (*((volatile unsigned int*)(0x42A7A2A0UL)))
#define bM4_PORT_PCRE5_INVE                       (*((volatile unsigned int*)(0x42A7A2A4UL)))
#define bM4_PORT_PCRE5_INTE                       (*((volatile unsigned int*)(0x42A7A2B0UL)))
#define bM4_PORT_PCRE5_LTE                        (*((volatile unsigned int*)(0x42A7A2B8UL)))
#define bM4_PORT_PCRE5_DDIS                       (*((volatile unsigned int*)(0x42A7A2BCUL)))
#define bM4_PORT_PFSRE5_FSEL0                     (*((volatile unsigned int*)(0x42A7A2C0UL)))
#define bM4_PORT_PFSRE5_FSEL1                     (*((volatile unsigned int*)(0x42A7A2C4UL)))
#define bM4_PORT_PFSRE5_FSEL2                     (*((volatile unsigned int*)(0x42A7A2C8UL)))
#define bM4_PORT_PFSRE5_FSEL3                     (*((volatile unsigned int*)(0x42A7A2CCUL)))
#define bM4_PORT_PFSRE5_FSEL4                     (*((volatile unsigned int*)(0x42A7A2D0UL)))
#define bM4_PORT_PFSRE5_FSEL5                     (*((volatile unsigned int*)(0x42A7A2D4UL)))
#define bM4_PORT_PFSRE5_BFE                       (*((volatile unsigned int*)(0x42A7A2E0UL)))
#define bM4_PORT_PCRE6_POUT                       (*((volatile unsigned int*)(0x42A7A300UL)))
#define bM4_PORT_PCRE6_POUTE                      (*((volatile unsigned int*)(0x42A7A304UL)))
#define bM4_PORT_PCRE6_NOD                        (*((volatile unsigned int*)(0x42A7A308UL)))
#define bM4_PORT_PCRE6_DRV0                       (*((volatile unsigned int*)(0x42A7A310UL)))
#define bM4_PORT_PCRE6_DRV1                       (*((volatile unsigned int*)(0x42A7A314UL)))
#define bM4_PORT_PCRE6_PUU                        (*((volatile unsigned int*)(0x42A7A318UL)))
#define bM4_PORT_PCRE6_PIN                        (*((volatile unsigned int*)(0x42A7A320UL)))
#define bM4_PORT_PCRE6_INVE                       (*((volatile unsigned int*)(0x42A7A324UL)))
#define bM4_PORT_PCRE6_INTE                       (*((volatile unsigned int*)(0x42A7A330UL)))
#define bM4_PORT_PCRE6_LTE                        (*((volatile unsigned int*)(0x42A7A338UL)))
#define bM4_PORT_PCRE6_DDIS                       (*((volatile unsigned int*)(0x42A7A33CUL)))
#define bM4_PORT_PFSRE6_FSEL0                     (*((volatile unsigned int*)(0x42A7A340UL)))
#define bM4_PORT_PFSRE6_FSEL1                     (*((volatile unsigned int*)(0x42A7A344UL)))
#define bM4_PORT_PFSRE6_FSEL2                     (*((volatile unsigned int*)(0x42A7A348UL)))
#define bM4_PORT_PFSRE6_FSEL3                     (*((volatile unsigned int*)(0x42A7A34CUL)))
#define bM4_PORT_PFSRE6_FSEL4                     (*((volatile unsigned int*)(0x42A7A350UL)))
#define bM4_PORT_PFSRE6_FSEL5                     (*((volatile unsigned int*)(0x42A7A354UL)))
#define bM4_PORT_PFSRE6_BFE                       (*((volatile unsigned int*)(0x42A7A360UL)))
#define bM4_PORT_PCRE7_POUT                       (*((volatile unsigned int*)(0x42A7A380UL)))
#define bM4_PORT_PCRE7_POUTE                      (*((volatile unsigned int*)(0x42A7A384UL)))
#define bM4_PORT_PCRE7_NOD                        (*((volatile unsigned int*)(0x42A7A388UL)))
#define bM4_PORT_PCRE7_DRV0                       (*((volatile unsigned int*)(0x42A7A390UL)))
#define bM4_PORT_PCRE7_DRV1                       (*((volatile unsigned int*)(0x42A7A394UL)))
#define bM4_PORT_PCRE7_PUU                        (*((volatile unsigned int*)(0x42A7A398UL)))
#define bM4_PORT_PCRE7_PIN                        (*((volatile unsigned int*)(0x42A7A3A0UL)))
#define bM4_PORT_PCRE7_INVE                       (*((volatile unsigned int*)(0x42A7A3A4UL)))
#define bM4_PORT_PCRE7_INTE                       (*((volatile unsigned int*)(0x42A7A3B0UL)))
#define bM4_PORT_PCRE7_LTE                        (*((volatile unsigned int*)(0x42A7A3B8UL)))
#define bM4_PORT_PCRE7_DDIS                       (*((volatile unsigned int*)(0x42A7A3BCUL)))
#define bM4_PORT_PFSRE7_FSEL0                     (*((volatile unsigned int*)(0x42A7A3C0UL)))
#define bM4_PORT_PFSRE7_FSEL1                     (*((volatile unsigned int*)(0x42A7A3C4UL)))
#define bM4_PORT_PFSRE7_FSEL2                     (*((volatile unsigned int*)(0x42A7A3C8UL)))
#define bM4_PORT_PFSRE7_FSEL3                     (*((volatile unsigned int*)(0x42A7A3CCUL)))
#define bM4_PORT_PFSRE7_FSEL4                     (*((volatile unsigned int*)(0x42A7A3D0UL)))
#define bM4_PORT_PFSRE7_FSEL5                     (*((volatile unsigned int*)(0x42A7A3D4UL)))
#define bM4_PORT_PFSRE7_BFE                       (*((volatile unsigned int*)(0x42A7A3E0UL)))
#define bM4_PORT_PCRE8_POUT                       (*((volatile unsigned int*)(0x42A7A400UL)))
#define bM4_PORT_PCRE8_POUTE                      (*((volatile unsigned int*)(0x42A7A404UL)))
#define bM4_PORT_PCRE8_NOD                        (*((volatile unsigned int*)(0x42A7A408UL)))
#define bM4_PORT_PCRE8_DRV0                       (*((volatile unsigned int*)(0x42A7A410UL)))
#define bM4_PORT_PCRE8_DRV1                       (*((volatile unsigned int*)(0x42A7A414UL)))
#define bM4_PORT_PCRE8_PUU                        (*((volatile unsigned int*)(0x42A7A418UL)))
#define bM4_PORT_PCRE8_PIN                        (*((volatile unsigned int*)(0x42A7A420UL)))
#define bM4_PORT_PCRE8_INVE                       (*((volatile unsigned int*)(0x42A7A424UL)))
#define bM4_PORT_PCRE8_INTE                       (*((volatile unsigned int*)(0x42A7A430UL)))
#define bM4_PORT_PCRE8_LTE                        (*((volatile unsigned int*)(0x42A7A438UL)))
#define bM4_PORT_PCRE8_DDIS                       (*((volatile unsigned int*)(0x42A7A43CUL)))
#define bM4_PORT_PFSRE8_FSEL0                     (*((volatile unsigned int*)(0x42A7A440UL)))
#define bM4_PORT_PFSRE8_FSEL1                     (*((volatile unsigned int*)(0x42A7A444UL)))
#define bM4_PORT_PFSRE8_FSEL2                     (*((volatile unsigned int*)(0x42A7A448UL)))
#define bM4_PORT_PFSRE8_FSEL3                     (*((volatile unsigned int*)(0x42A7A44CUL)))
#define bM4_PORT_PFSRE8_FSEL4                     (*((volatile unsigned int*)(0x42A7A450UL)))
#define bM4_PORT_PFSRE8_FSEL5                     (*((volatile unsigned int*)(0x42A7A454UL)))
#define bM4_PORT_PFSRE8_BFE                       (*((volatile unsigned int*)(0x42A7A460UL)))
#define bM4_PORT_PCRE9_POUT                       (*((volatile unsigned int*)(0x42A7A480UL)))
#define bM4_PORT_PCRE9_POUTE                      (*((volatile unsigned int*)(0x42A7A484UL)))
#define bM4_PORT_PCRE9_NOD                        (*((volatile unsigned int*)(0x42A7A488UL)))
#define bM4_PORT_PCRE9_DRV0                       (*((volatile unsigned int*)(0x42A7A490UL)))
#define bM4_PORT_PCRE9_DRV1                       (*((volatile unsigned int*)(0x42A7A494UL)))
#define bM4_PORT_PCRE9_PUU                        (*((volatile unsigned int*)(0x42A7A498UL)))
#define bM4_PORT_PCRE9_PIN                        (*((volatile unsigned int*)(0x42A7A4A0UL)))
#define bM4_PORT_PCRE9_INVE                       (*((volatile unsigned int*)(0x42A7A4A4UL)))
#define bM4_PORT_PCRE9_INTE                       (*((volatile unsigned int*)(0x42A7A4B0UL)))
#define bM4_PORT_PCRE9_LTE                        (*((volatile unsigned int*)(0x42A7A4B8UL)))
#define bM4_PORT_PCRE9_DDIS                       (*((volatile unsigned int*)(0x42A7A4BCUL)))
#define bM4_PORT_PFSRE9_FSEL0                     (*((volatile unsigned int*)(0x42A7A4C0UL)))
#define bM4_PORT_PFSRE9_FSEL1                     (*((volatile unsigned int*)(0x42A7A4C4UL)))
#define bM4_PORT_PFSRE9_FSEL2                     (*((volatile unsigned int*)(0x42A7A4C8UL)))
#define bM4_PORT_PFSRE9_FSEL3                     (*((volatile unsigned int*)(0x42A7A4CCUL)))
#define bM4_PORT_PFSRE9_FSEL4                     (*((volatile unsigned int*)(0x42A7A4D0UL)))
#define bM4_PORT_PFSRE9_FSEL5                     (*((volatile unsigned int*)(0x42A7A4D4UL)))
#define bM4_PORT_PFSRE9_BFE                       (*((volatile unsigned int*)(0x42A7A4E0UL)))
#define bM4_PORT_PCRE10_POUT                      (*((volatile unsigned int*)(0x42A7A500UL)))
#define bM4_PORT_PCRE10_POUTE                     (*((volatile unsigned int*)(0x42A7A504UL)))
#define bM4_PORT_PCRE10_NOD                       (*((volatile unsigned int*)(0x42A7A508UL)))
#define bM4_PORT_PCRE10_DRV0                      (*((volatile unsigned int*)(0x42A7A510UL)))
#define bM4_PORT_PCRE10_DRV1                      (*((volatile unsigned int*)(0x42A7A514UL)))
#define bM4_PORT_PCRE10_PUU                       (*((volatile unsigned int*)(0x42A7A518UL)))
#define bM4_PORT_PCRE10_PIN                       (*((volatile unsigned int*)(0x42A7A520UL)))
#define bM4_PORT_PCRE10_INVE                      (*((volatile unsigned int*)(0x42A7A524UL)))
#define bM4_PORT_PCRE10_INTE                      (*((volatile unsigned int*)(0x42A7A530UL)))
#define bM4_PORT_PCRE10_LTE                       (*((volatile unsigned int*)(0x42A7A538UL)))
#define bM4_PORT_PCRE10_DDIS                      (*((volatile unsigned int*)(0x42A7A53CUL)))
#define bM4_PORT_PFSRE10_FSEL0                    (*((volatile unsigned int*)(0x42A7A540UL)))
#define bM4_PORT_PFSRE10_FSEL1                    (*((volatile unsigned int*)(0x42A7A544UL)))
#define bM4_PORT_PFSRE10_FSEL2                    (*((volatile unsigned int*)(0x42A7A548UL)))
#define bM4_PORT_PFSRE10_FSEL3                    (*((volatile unsigned int*)(0x42A7A54CUL)))
#define bM4_PORT_PFSRE10_FSEL4                    (*((volatile unsigned int*)(0x42A7A550UL)))
#define bM4_PORT_PFSRE10_FSEL5                    (*((volatile unsigned int*)(0x42A7A554UL)))
#define bM4_PORT_PFSRE10_BFE                      (*((volatile unsigned int*)(0x42A7A560UL)))
#define bM4_PORT_PCRE11_POUT                      (*((volatile unsigned int*)(0x42A7A580UL)))
#define bM4_PORT_PCRE11_POUTE                     (*((volatile unsigned int*)(0x42A7A584UL)))
#define bM4_PORT_PCRE11_NOD                       (*((volatile unsigned int*)(0x42A7A588UL)))
#define bM4_PORT_PCRE11_DRV0                      (*((volatile unsigned int*)(0x42A7A590UL)))
#define bM4_PORT_PCRE11_DRV1                      (*((volatile unsigned int*)(0x42A7A594UL)))
#define bM4_PORT_PCRE11_PUU                       (*((volatile unsigned int*)(0x42A7A598UL)))
#define bM4_PORT_PCRE11_PIN                       (*((volatile unsigned int*)(0x42A7A5A0UL)))
#define bM4_PORT_PCRE11_INVE                      (*((volatile unsigned int*)(0x42A7A5A4UL)))
#define bM4_PORT_PCRE11_INTE                      (*((volatile unsigned int*)(0x42A7A5B0UL)))
#define bM4_PORT_PCRE11_LTE                       (*((volatile unsigned int*)(0x42A7A5B8UL)))
#define bM4_PORT_PCRE11_DDIS                      (*((volatile unsigned int*)(0x42A7A5BCUL)))
#define bM4_PORT_PFSRE11_FSEL0                    (*((volatile unsigned int*)(0x42A7A5C0UL)))
#define bM4_PORT_PFSRE11_FSEL1                    (*((volatile unsigned int*)(0x42A7A5C4UL)))
#define bM4_PORT_PFSRE11_FSEL2                    (*((volatile unsigned int*)(0x42A7A5C8UL)))
#define bM4_PORT_PFSRE11_FSEL3                    (*((volatile unsigned int*)(0x42A7A5CCUL)))
#define bM4_PORT_PFSRE11_FSEL4                    (*((volatile unsigned int*)(0x42A7A5D0UL)))
#define bM4_PORT_PFSRE11_FSEL5                    (*((volatile unsigned int*)(0x42A7A5D4UL)))
#define bM4_PORT_PFSRE11_BFE                      (*((volatile unsigned int*)(0x42A7A5E0UL)))
#define bM4_PORT_PCRE12_POUT                      (*((volatile unsigned int*)(0x42A7A600UL)))
#define bM4_PORT_PCRE12_POUTE                     (*((volatile unsigned int*)(0x42A7A604UL)))
#define bM4_PORT_PCRE12_NOD                       (*((volatile unsigned int*)(0x42A7A608UL)))
#define bM4_PORT_PCRE12_DRV0                      (*((volatile unsigned int*)(0x42A7A610UL)))
#define bM4_PORT_PCRE12_DRV1                      (*((volatile unsigned int*)(0x42A7A614UL)))
#define bM4_PORT_PCRE12_PUU                       (*((volatile unsigned int*)(0x42A7A618UL)))
#define bM4_PORT_PCRE12_PIN                       (*((volatile unsigned int*)(0x42A7A620UL)))
#define bM4_PORT_PCRE12_INVE                      (*((volatile unsigned int*)(0x42A7A624UL)))
#define bM4_PORT_PCRE12_INTE                      (*((volatile unsigned int*)(0x42A7A630UL)))
#define bM4_PORT_PCRE12_LTE                       (*((volatile unsigned int*)(0x42A7A638UL)))
#define bM4_PORT_PCRE12_DDIS                      (*((volatile unsigned int*)(0x42A7A63CUL)))
#define bM4_PORT_PFSRE12_FSEL0                    (*((volatile unsigned int*)(0x42A7A640UL)))
#define bM4_PORT_PFSRE12_FSEL1                    (*((volatile unsigned int*)(0x42A7A644UL)))
#define bM4_PORT_PFSRE12_FSEL2                    (*((volatile unsigned int*)(0x42A7A648UL)))
#define bM4_PORT_PFSRE12_FSEL3                    (*((volatile unsigned int*)(0x42A7A64CUL)))
#define bM4_PORT_PFSRE12_FSEL4                    (*((volatile unsigned int*)(0x42A7A650UL)))
#define bM4_PORT_PFSRE12_FSEL5                    (*((volatile unsigned int*)(0x42A7A654UL)))
#define bM4_PORT_PFSRE12_BFE                      (*((volatile unsigned int*)(0x42A7A660UL)))
#define bM4_PORT_PCRE13_POUT                      (*((volatile unsigned int*)(0x42A7A680UL)))
#define bM4_PORT_PCRE13_POUTE                     (*((volatile unsigned int*)(0x42A7A684UL)))
#define bM4_PORT_PCRE13_NOD                       (*((volatile unsigned int*)(0x42A7A688UL)))
#define bM4_PORT_PCRE13_DRV0                      (*((volatile unsigned int*)(0x42A7A690UL)))
#define bM4_PORT_PCRE13_DRV1                      (*((volatile unsigned int*)(0x42A7A694UL)))
#define bM4_PORT_PCRE13_PUU                       (*((volatile unsigned int*)(0x42A7A698UL)))
#define bM4_PORT_PCRE13_PIN                       (*((volatile unsigned int*)(0x42A7A6A0UL)))
#define bM4_PORT_PCRE13_INVE                      (*((volatile unsigned int*)(0x42A7A6A4UL)))
#define bM4_PORT_PCRE13_INTE                      (*((volatile unsigned int*)(0x42A7A6B0UL)))
#define bM4_PORT_PCRE13_LTE                       (*((volatile unsigned int*)(0x42A7A6B8UL)))
#define bM4_PORT_PCRE13_DDIS                      (*((volatile unsigned int*)(0x42A7A6BCUL)))
#define bM4_PORT_PFSRE13_FSEL0                    (*((volatile unsigned int*)(0x42A7A6C0UL)))
#define bM4_PORT_PFSRE13_FSEL1                    (*((volatile unsigned int*)(0x42A7A6C4UL)))
#define bM4_PORT_PFSRE13_FSEL2                    (*((volatile unsigned int*)(0x42A7A6C8UL)))
#define bM4_PORT_PFSRE13_FSEL3                    (*((volatile unsigned int*)(0x42A7A6CCUL)))
#define bM4_PORT_PFSRE13_FSEL4                    (*((volatile unsigned int*)(0x42A7A6D0UL)))
#define bM4_PORT_PFSRE13_FSEL5                    (*((volatile unsigned int*)(0x42A7A6D4UL)))
#define bM4_PORT_PFSRE13_BFE                      (*((volatile unsigned int*)(0x42A7A6E0UL)))
#define bM4_PORT_PCRE14_POUT                      (*((volatile unsigned int*)(0x42A7A700UL)))
#define bM4_PORT_PCRE14_POUTE                     (*((volatile unsigned int*)(0x42A7A704UL)))
#define bM4_PORT_PCRE14_NOD                       (*((volatile unsigned int*)(0x42A7A708UL)))
#define bM4_PORT_PCRE14_DRV0                      (*((volatile unsigned int*)(0x42A7A710UL)))
#define bM4_PORT_PCRE14_DRV1                      (*((volatile unsigned int*)(0x42A7A714UL)))
#define bM4_PORT_PCRE14_PUU                       (*((volatile unsigned int*)(0x42A7A718UL)))
#define bM4_PORT_PCRE14_PIN                       (*((volatile unsigned int*)(0x42A7A720UL)))
#define bM4_PORT_PCRE14_INVE                      (*((volatile unsigned int*)(0x42A7A724UL)))
#define bM4_PORT_PCRE14_INTE                      (*((volatile unsigned int*)(0x42A7A730UL)))
#define bM4_PORT_PCRE14_LTE                       (*((volatile unsigned int*)(0x42A7A738UL)))
#define bM4_PORT_PCRE14_DDIS                      (*((volatile unsigned int*)(0x42A7A73CUL)))
#define bM4_PORT_PFSRE14_FSEL0                    (*((volatile unsigned int*)(0x42A7A740UL)))
#define bM4_PORT_PFSRE14_FSEL1                    (*((volatile unsigned int*)(0x42A7A744UL)))
#define bM4_PORT_PFSRE14_FSEL2                    (*((volatile unsigned int*)(0x42A7A748UL)))
#define bM4_PORT_PFSRE14_FSEL3                    (*((volatile unsigned int*)(0x42A7A74CUL)))
#define bM4_PORT_PFSRE14_FSEL4                    (*((volatile unsigned int*)(0x42A7A750UL)))
#define bM4_PORT_PFSRE14_FSEL5                    (*((volatile unsigned int*)(0x42A7A754UL)))
#define bM4_PORT_PFSRE14_BFE                      (*((volatile unsigned int*)(0x42A7A760UL)))
#define bM4_PORT_PCRE15_POUT                      (*((volatile unsigned int*)(0x42A7A780UL)))
#define bM4_PORT_PCRE15_POUTE                     (*((volatile unsigned int*)(0x42A7A784UL)))
#define bM4_PORT_PCRE15_NOD                       (*((volatile unsigned int*)(0x42A7A788UL)))
#define bM4_PORT_PCRE15_DRV0                      (*((volatile unsigned int*)(0x42A7A790UL)))
#define bM4_PORT_PCRE15_DRV1                      (*((volatile unsigned int*)(0x42A7A794UL)))
#define bM4_PORT_PCRE15_PUU                       (*((volatile unsigned int*)(0x42A7A798UL)))
#define bM4_PORT_PCRE15_PIN                       (*((volatile unsigned int*)(0x42A7A7A0UL)))
#define bM4_PORT_PCRE15_INVE                      (*((volatile unsigned int*)(0x42A7A7A4UL)))
#define bM4_PORT_PCRE15_INTE                      (*((volatile unsigned int*)(0x42A7A7B0UL)))
#define bM4_PORT_PCRE15_LTE                       (*((volatile unsigned int*)(0x42A7A7B8UL)))
#define bM4_PORT_PCRE15_DDIS                      (*((volatile unsigned int*)(0x42A7A7BCUL)))
#define bM4_PORT_PFSRE15_FSEL0                    (*((volatile unsigned int*)(0x42A7A7C0UL)))
#define bM4_PORT_PFSRE15_FSEL1                    (*((volatile unsigned int*)(0x42A7A7C4UL)))
#define bM4_PORT_PFSRE15_FSEL2                    (*((volatile unsigned int*)(0x42A7A7C8UL)))
#define bM4_PORT_PFSRE15_FSEL3                    (*((volatile unsigned int*)(0x42A7A7CCUL)))
#define bM4_PORT_PFSRE15_FSEL4                    (*((volatile unsigned int*)(0x42A7A7D0UL)))
#define bM4_PORT_PFSRE15_FSEL5                    (*((volatile unsigned int*)(0x42A7A7D4UL)))
#define bM4_PORT_PFSRE15_BFE                      (*((volatile unsigned int*)(0x42A7A7E0UL)))
#define bM4_PORT_PCRH0_POUT                       (*((volatile unsigned int*)(0x42A7A800UL)))
#define bM4_PORT_PCRH0_POUTE                      (*((volatile unsigned int*)(0x42A7A804UL)))
#define bM4_PORT_PCRH0_NOD                        (*((volatile unsigned int*)(0x42A7A808UL)))
#define bM4_PORT_PCRH0_DRV0                       (*((volatile unsigned int*)(0x42A7A810UL)))
#define bM4_PORT_PCRH0_DRV1                       (*((volatile unsigned int*)(0x42A7A814UL)))
#define bM4_PORT_PCRH0_PUU                        (*((volatile unsigned int*)(0x42A7A818UL)))
#define bM4_PORT_PCRH0_PIN                        (*((volatile unsigned int*)(0x42A7A820UL)))
#define bM4_PORT_PCRH0_INVE                       (*((volatile unsigned int*)(0x42A7A824UL)))
#define bM4_PORT_PCRH0_INTE                       (*((volatile unsigned int*)(0x42A7A830UL)))
#define bM4_PORT_PCRH0_LTE                        (*((volatile unsigned int*)(0x42A7A838UL)))
#define bM4_PORT_PCRH0_DDIS                       (*((volatile unsigned int*)(0x42A7A83CUL)))
#define bM4_PORT_PFSRH0_FSEL0                     (*((volatile unsigned int*)(0x42A7A840UL)))
#define bM4_PORT_PFSRH0_FSEL1                     (*((volatile unsigned int*)(0x42A7A844UL)))
#define bM4_PORT_PFSRH0_FSEL2                     (*((volatile unsigned int*)(0x42A7A848UL)))
#define bM4_PORT_PFSRH0_FSEL3                     (*((volatile unsigned int*)(0x42A7A84CUL)))
#define bM4_PORT_PFSRH0_FSEL4                     (*((volatile unsigned int*)(0x42A7A850UL)))
#define bM4_PORT_PFSRH0_FSEL5                     (*((volatile unsigned int*)(0x42A7A854UL)))
#define bM4_PORT_PFSRH0_BFE                       (*((volatile unsigned int*)(0x42A7A860UL)))
#define bM4_PORT_PCRH1_POUT                       (*((volatile unsigned int*)(0x42A7A880UL)))
#define bM4_PORT_PCRH1_POUTE                      (*((volatile unsigned int*)(0x42A7A884UL)))
#define bM4_PORT_PCRH1_NOD                        (*((volatile unsigned int*)(0x42A7A888UL)))
#define bM4_PORT_PCRH1_DRV0                       (*((volatile unsigned int*)(0x42A7A890UL)))
#define bM4_PORT_PCRH1_DRV1                       (*((volatile unsigned int*)(0x42A7A894UL)))
#define bM4_PORT_PCRH1_PUU                        (*((volatile unsigned int*)(0x42A7A898UL)))
#define bM4_PORT_PCRH1_PIN                        (*((volatile unsigned int*)(0x42A7A8A0UL)))
#define bM4_PORT_PCRH1_INVE                       (*((volatile unsigned int*)(0x42A7A8A4UL)))
#define bM4_PORT_PCRH1_INTE                       (*((volatile unsigned int*)(0x42A7A8B0UL)))
#define bM4_PORT_PCRH1_LTE                        (*((volatile unsigned int*)(0x42A7A8B8UL)))
#define bM4_PORT_PCRH1_DDIS                       (*((volatile unsigned int*)(0x42A7A8BCUL)))
#define bM4_PORT_PFSRH1_FSEL0                     (*((volatile unsigned int*)(0x42A7A8C0UL)))
#define bM4_PORT_PFSRH1_FSEL1                     (*((volatile unsigned int*)(0x42A7A8C4UL)))
#define bM4_PORT_PFSRH1_FSEL2                     (*((volatile unsigned int*)(0x42A7A8C8UL)))
#define bM4_PORT_PFSRH1_FSEL3                     (*((volatile unsigned int*)(0x42A7A8CCUL)))
#define bM4_PORT_PFSRH1_FSEL4                     (*((volatile unsigned int*)(0x42A7A8D0UL)))
#define bM4_PORT_PFSRH1_FSEL5                     (*((volatile unsigned int*)(0x42A7A8D4UL)))
#define bM4_PORT_PFSRH1_BFE                       (*((volatile unsigned int*)(0x42A7A8E0UL)))
#define bM4_PORT_PCRH2_POUT                       (*((volatile unsigned int*)(0x42A7A900UL)))
#define bM4_PORT_PCRH2_POUTE                      (*((volatile unsigned int*)(0x42A7A904UL)))
#define bM4_PORT_PCRH2_NOD                        (*((volatile unsigned int*)(0x42A7A908UL)))
#define bM4_PORT_PCRH2_DRV0                       (*((volatile unsigned int*)(0x42A7A910UL)))
#define bM4_PORT_PCRH2_DRV1                       (*((volatile unsigned int*)(0x42A7A914UL)))
#define bM4_PORT_PCRH2_PUU                        (*((volatile unsigned int*)(0x42A7A918UL)))
#define bM4_PORT_PCRH2_PIN                        (*((volatile unsigned int*)(0x42A7A920UL)))
#define bM4_PORT_PCRH2_INVE                       (*((volatile unsigned int*)(0x42A7A924UL)))
#define bM4_PORT_PCRH2_INTE                       (*((volatile unsigned int*)(0x42A7A930UL)))
#define bM4_PORT_PCRH2_LTE                        (*((volatile unsigned int*)(0x42A7A938UL)))
#define bM4_PORT_PCRH2_DDIS                       (*((volatile unsigned int*)(0x42A7A93CUL)))
#define bM4_PORT_PFSRH2_FSEL0                     (*((volatile unsigned int*)(0x42A7A940UL)))
#define bM4_PORT_PFSRH2_FSEL1                     (*((volatile unsigned int*)(0x42A7A944UL)))
#define bM4_PORT_PFSRH2_FSEL2                     (*((volatile unsigned int*)(0x42A7A948UL)))
#define bM4_PORT_PFSRH2_FSEL3                     (*((volatile unsigned int*)(0x42A7A94CUL)))
#define bM4_PORT_PFSRH2_FSEL4                     (*((volatile unsigned int*)(0x42A7A950UL)))
#define bM4_PORT_PFSRH2_FSEL5                     (*((volatile unsigned int*)(0x42A7A954UL)))
#define bM4_PORT_PFSRH2_BFE                       (*((volatile unsigned int*)(0x42A7A960UL)))
#define bM4_RTC_CR0_RESET                         (*((volatile unsigned int*)(0x42980000UL)))
#define bM4_RTC_CR1_PRDS0                         (*((volatile unsigned int*)(0x42980080UL)))
#define bM4_RTC_CR1_PRDS1                         (*((volatile unsigned int*)(0x42980084UL)))
#define bM4_RTC_CR1_PRDS2                         (*((volatile unsigned int*)(0x42980088UL)))
#define bM4_RTC_CR1_AMPM                          (*((volatile unsigned int*)(0x4298008CUL)))
#define bM4_RTC_CR1_ALMFCLR                       (*((volatile unsigned int*)(0x42980090UL)))
#define bM4_RTC_CR1_ONEHZOE                       (*((volatile unsigned int*)(0x42980094UL)))
#define bM4_RTC_CR1_ONEHZSEL                      (*((volatile unsigned int*)(0x42980098UL)))
#define bM4_RTC_CR1_START                         (*((volatile unsigned int*)(0x4298009CUL)))
#define bM4_RTC_CR2_RWREQ                         (*((volatile unsigned int*)(0x42980100UL)))
#define bM4_RTC_CR2_RWEN                          (*((volatile unsigned int*)(0x42980104UL)))
#define bM4_RTC_CR2_ALMF                          (*((volatile unsigned int*)(0x4298010CUL)))
#define bM4_RTC_CR2_PRDIE                         (*((volatile unsigned int*)(0x42980114UL)))
#define bM4_RTC_CR2_ALMIE                         (*((volatile unsigned int*)(0x42980118UL)))
#define bM4_RTC_CR2_ALME                          (*((volatile unsigned int*)(0x4298011CUL)))
#define bM4_RTC_CR3_LRCEN                         (*((volatile unsigned int*)(0x42980190UL)))
#define bM4_RTC_CR3_RCKSEL                        (*((volatile unsigned int*)(0x4298019CUL)))
#define bM4_RTC_SEC_SECU0                         (*((volatile unsigned int*)(0x42980200UL)))
#define bM4_RTC_SEC_SECU1                         (*((volatile unsigned int*)(0x42980204UL)))
#define bM4_RTC_SEC_SECU2                         (*((volatile unsigned int*)(0x42980208UL)))
#define bM4_RTC_SEC_SECU3                         (*((volatile unsigned int*)(0x4298020CUL)))
#define bM4_RTC_SEC_SECD0                         (*((volatile unsigned int*)(0x42980210UL)))
#define bM4_RTC_SEC_SECD1                         (*((volatile unsigned int*)(0x42980214UL)))
#define bM4_RTC_SEC_SECD2                         (*((volatile unsigned int*)(0x42980218UL)))
#define bM4_RTC_MIN_MINU0                         (*((volatile unsigned int*)(0x42980280UL)))
#define bM4_RTC_MIN_MINU1                         (*((volatile unsigned int*)(0x42980284UL)))
#define bM4_RTC_MIN_MINU2                         (*((volatile unsigned int*)(0x42980288UL)))
#define bM4_RTC_MIN_MINU3                         (*((volatile unsigned int*)(0x4298028CUL)))
#define bM4_RTC_MIN_MIND0                         (*((volatile unsigned int*)(0x42980290UL)))
#define bM4_RTC_MIN_MIND1                         (*((volatile unsigned int*)(0x42980294UL)))
#define bM4_RTC_MIN_MIND2                         (*((volatile unsigned int*)(0x42980298UL)))
#define bM4_RTC_HOUR_HOURU0                       (*((volatile unsigned int*)(0x42980300UL)))
#define bM4_RTC_HOUR_HOURU1                       (*((volatile unsigned int*)(0x42980304UL)))
#define bM4_RTC_HOUR_HOURU2                       (*((volatile unsigned int*)(0x42980308UL)))
#define bM4_RTC_HOUR_HOURU3                       (*((volatile unsigned int*)(0x4298030CUL)))
#define bM4_RTC_HOUR_HOURD0                       (*((volatile unsigned int*)(0x42980310UL)))
#define bM4_RTC_HOUR_HOURD1                       (*((volatile unsigned int*)(0x42980314UL)))
#define bM4_RTC_WEEK_WEEK0                        (*((volatile unsigned int*)(0x42980380UL)))
#define bM4_RTC_WEEK_WEEK1                        (*((volatile unsigned int*)(0x42980384UL)))
#define bM4_RTC_WEEK_WEEK2                        (*((volatile unsigned int*)(0x42980388UL)))
#define bM4_RTC_DAY_DAYU0                         (*((volatile unsigned int*)(0x42980400UL)))
#define bM4_RTC_DAY_DAYU1                         (*((volatile unsigned int*)(0x42980404UL)))
#define bM4_RTC_DAY_DAYU2                         (*((volatile unsigned int*)(0x42980408UL)))
#define bM4_RTC_DAY_DAYU3                         (*((volatile unsigned int*)(0x4298040CUL)))
#define bM4_RTC_DAY_DAYD0                         (*((volatile unsigned int*)(0x42980410UL)))
#define bM4_RTC_DAY_DAYD1                         (*((volatile unsigned int*)(0x42980414UL)))
#define bM4_RTC_MON_MON0                          (*((volatile unsigned int*)(0x42980480UL)))
#define bM4_RTC_MON_MON1                          (*((volatile unsigned int*)(0x42980484UL)))
#define bM4_RTC_MON_MON2                          (*((volatile unsigned int*)(0x42980488UL)))
#define bM4_RTC_MON_MON3                          (*((volatile unsigned int*)(0x4298048CUL)))
#define bM4_RTC_MON_MON4                          (*((volatile unsigned int*)(0x42980490UL)))
#define bM4_RTC_YEAR_YEARU0                       (*((volatile unsigned int*)(0x42980500UL)))
#define bM4_RTC_YEAR_YEARU1                       (*((volatile unsigned int*)(0x42980504UL)))
#define bM4_RTC_YEAR_YEARU2                       (*((volatile unsigned int*)(0x42980508UL)))
#define bM4_RTC_YEAR_YEARU3                       (*((volatile unsigned int*)(0x4298050CUL)))
#define bM4_RTC_YEAR_YEARD0                       (*((volatile unsigned int*)(0x42980510UL)))
#define bM4_RTC_YEAR_YEARD1                       (*((volatile unsigned int*)(0x42980514UL)))
#define bM4_RTC_YEAR_YEARD2                       (*((volatile unsigned int*)(0x42980518UL)))
#define bM4_RTC_YEAR_YEARD3                       (*((volatile unsigned int*)(0x4298051CUL)))
#define bM4_RTC_ALMMIN_ALMMINU0                   (*((volatile unsigned int*)(0x42980580UL)))
#define bM4_RTC_ALMMIN_ALMMINU1                   (*((volatile unsigned int*)(0x42980584UL)))
#define bM4_RTC_ALMMIN_ALMMINU2                   (*((volatile unsigned int*)(0x42980588UL)))
#define bM4_RTC_ALMMIN_ALMMINU3                   (*((volatile unsigned int*)(0x4298058CUL)))
#define bM4_RTC_ALMMIN_ALMMIND0                   (*((volatile unsigned int*)(0x42980590UL)))
#define bM4_RTC_ALMMIN_ALMMIND1                   (*((volatile unsigned int*)(0x42980594UL)))
#define bM4_RTC_ALMMIN_ALMMIND2                   (*((volatile unsigned int*)(0x42980598UL)))
#define bM4_RTC_ALMHOUR_ALMHOURU0                 (*((volatile unsigned int*)(0x42980600UL)))
#define bM4_RTC_ALMHOUR_ALMHOURU1                 (*((volatile unsigned int*)(0x42980604UL)))
#define bM4_RTC_ALMHOUR_ALMHOURU2                 (*((volatile unsigned int*)(0x42980608UL)))
#define bM4_RTC_ALMHOUR_ALMHOURU3                 (*((volatile unsigned int*)(0x4298060CUL)))
#define bM4_RTC_ALMHOUR_ALMHOURD0                 (*((volatile unsigned int*)(0x42980610UL)))
#define bM4_RTC_ALMHOUR_ALMHOURD1                 (*((volatile unsigned int*)(0x42980614UL)))
#define bM4_RTC_ALMWEEK_ALMWEEK0                  (*((volatile unsigned int*)(0x42980680UL)))
#define bM4_RTC_ALMWEEK_ALMWEEK1                  (*((volatile unsigned int*)(0x42980684UL)))
#define bM4_RTC_ALMWEEK_ALMWEEK2                  (*((volatile unsigned int*)(0x42980688UL)))
#define bM4_RTC_ALMWEEK_ALMWEEK3                  (*((volatile unsigned int*)(0x4298068CUL)))
#define bM4_RTC_ALMWEEK_ALMWEEK4                  (*((volatile unsigned int*)(0x42980690UL)))
#define bM4_RTC_ALMWEEK_ALMWEEK5                  (*((volatile unsigned int*)(0x42980694UL)))
#define bM4_RTC_ALMWEEK_ALMWEEK6                  (*((volatile unsigned int*)(0x42980698UL)))
#define bM4_RTC_ERRCRH_COMP8                      (*((volatile unsigned int*)(0x42980700UL)))
#define bM4_RTC_ERRCRH_COMPEN                     (*((volatile unsigned int*)(0x4298071CUL)))
#define bM4_RTC_ERRCRL_COMP0                      (*((volatile unsigned int*)(0x42980780UL)))
#define bM4_RTC_ERRCRL_COMP1                      (*((volatile unsigned int*)(0x42980784UL)))
#define bM4_RTC_ERRCRL_COMP2                      (*((volatile unsigned int*)(0x42980788UL)))
#define bM4_RTC_ERRCRL_COMP3                      (*((volatile unsigned int*)(0x4298078CUL)))
#define bM4_RTC_ERRCRL_COMP4                      (*((volatile unsigned int*)(0x42980790UL)))
#define bM4_RTC_ERRCRL_COMP5                      (*((volatile unsigned int*)(0x42980794UL)))
#define bM4_RTC_ERRCRL_COMP6                      (*((volatile unsigned int*)(0x42980798UL)))
#define bM4_RTC_ERRCRL_COMP7                      (*((volatile unsigned int*)(0x4298079CUL)))
#define bM4_SDIOC1_BLKSIZE_TBS0                   (*((volatile unsigned int*)(0x42DF8080UL)))
#define bM4_SDIOC1_BLKSIZE_TBS1                   (*((volatile unsigned int*)(0x42DF8084UL)))
#define bM4_SDIOC1_BLKSIZE_TBS2                   (*((volatile unsigned int*)(0x42DF8088UL)))
#define bM4_SDIOC1_BLKSIZE_TBS3                   (*((volatile unsigned int*)(0x42DF808CUL)))
#define bM4_SDIOC1_BLKSIZE_TBS4                   (*((volatile unsigned int*)(0x42DF8090UL)))
#define bM4_SDIOC1_BLKSIZE_TBS5                   (*((volatile unsigned int*)(0x42DF8094UL)))
#define bM4_SDIOC1_BLKSIZE_TBS6                   (*((volatile unsigned int*)(0x42DF8098UL)))
#define bM4_SDIOC1_BLKSIZE_TBS7                   (*((volatile unsigned int*)(0x42DF809CUL)))
#define bM4_SDIOC1_BLKSIZE_TBS8                   (*((volatile unsigned int*)(0x42DF80A0UL)))
#define bM4_SDIOC1_BLKSIZE_TBS9                   (*((volatile unsigned int*)(0x42DF80A4UL)))
#define bM4_SDIOC1_BLKSIZE_TBS10                  (*((volatile unsigned int*)(0x42DF80A8UL)))
#define bM4_SDIOC1_BLKSIZE_TBS11                  (*((volatile unsigned int*)(0x42DF80ACUL)))
#define bM4_SDIOC1_TRANSMODE_BCE                  (*((volatile unsigned int*)(0x42DF8184UL)))
#define bM4_SDIOC1_TRANSMODE_ATCEN0               (*((volatile unsigned int*)(0x42DF8188UL)))
#define bM4_SDIOC1_TRANSMODE_ATCEN1               (*((volatile unsigned int*)(0x42DF818CUL)))
#define bM4_SDIOC1_TRANSMODE_DDIR                 (*((volatile unsigned int*)(0x42DF8190UL)))
#define bM4_SDIOC1_TRANSMODE_MULB                 (*((volatile unsigned int*)(0x42DF8194UL)))
#define bM4_SDIOC1_CMD_RESTYP0                    (*((volatile unsigned int*)(0x42DF81C0UL)))
#define bM4_SDIOC1_CMD_RESTYP1                    (*((volatile unsigned int*)(0x42DF81C4UL)))
#define bM4_SDIOC1_CMD_CCE                        (*((volatile unsigned int*)(0x42DF81CCUL)))
#define bM4_SDIOC1_CMD_ICE                        (*((volatile unsigned int*)(0x42DF81D0UL)))
#define bM4_SDIOC1_CMD_DAT                        (*((volatile unsigned int*)(0x42DF81D4UL)))
#define bM4_SDIOC1_CMD_TYP0                       (*((volatile unsigned int*)(0x42DF81D8UL)))
#define bM4_SDIOC1_CMD_TYP1                       (*((volatile unsigned int*)(0x42DF81DCUL)))
#define bM4_SDIOC1_CMD_IDX0                       (*((volatile unsigned int*)(0x42DF81E0UL)))
#define bM4_SDIOC1_CMD_IDX1                       (*((volatile unsigned int*)(0x42DF81E4UL)))
#define bM4_SDIOC1_CMD_IDX2                       (*((volatile unsigned int*)(0x42DF81E8UL)))
#define bM4_SDIOC1_CMD_IDX3                       (*((volatile unsigned int*)(0x42DF81ECUL)))
#define bM4_SDIOC1_CMD_IDX4                       (*((volatile unsigned int*)(0x42DF81F0UL)))
#define bM4_SDIOC1_CMD_IDX5                       (*((volatile unsigned int*)(0x42DF81F4UL)))
#define bM4_SDIOC1_PSTAT_CIC                      (*((volatile unsigned int*)(0x42DF8480UL)))
#define bM4_SDIOC1_PSTAT_CID                      (*((volatile unsigned int*)(0x42DF8484UL)))
#define bM4_SDIOC1_PSTAT_DA                       (*((volatile unsigned int*)(0x42DF8488UL)))
#define bM4_SDIOC1_PSTAT_WTA                      (*((volatile unsigned int*)(0x42DF84A0UL)))
#define bM4_SDIOC1_PSTAT_RTA                      (*((volatile unsigned int*)(0x42DF84A4UL)))
#define bM4_SDIOC1_PSTAT_BWE                      (*((volatile unsigned int*)(0x42DF84A8UL)))
#define bM4_SDIOC1_PSTAT_BRE                      (*((volatile unsigned int*)(0x42DF84ACUL)))
#define bM4_SDIOC1_PSTAT_CIN                      (*((volatile unsigned int*)(0x42DF84C0UL)))
#define bM4_SDIOC1_PSTAT_CSS                      (*((volatile unsigned int*)(0x42DF84C4UL)))
#define bM4_SDIOC1_PSTAT_CDL                      (*((volatile unsigned int*)(0x42DF84C8UL)))
#define bM4_SDIOC1_PSTAT_WPL                      (*((volatile unsigned int*)(0x42DF84CCUL)))
#define bM4_SDIOC1_PSTAT_DATL0                    (*((volatile unsigned int*)(0x42DF84D0UL)))
#define bM4_SDIOC1_PSTAT_DATL1                    (*((volatile unsigned int*)(0x42DF84D4UL)))
#define bM4_SDIOC1_PSTAT_DATL2                    (*((volatile unsigned int*)(0x42DF84D8UL)))
#define bM4_SDIOC1_PSTAT_DATL3                    (*((volatile unsigned int*)(0x42DF84DCUL)))
#define bM4_SDIOC1_PSTAT_CMDL                     (*((volatile unsigned int*)(0x42DF84E0UL)))
#define bM4_SDIOC1_HOSTCON_DW                     (*((volatile unsigned int*)(0x42DF8504UL)))
#define bM4_SDIOC1_HOSTCON_HSEN                   (*((volatile unsigned int*)(0x42DF8508UL)))
#define bM4_SDIOC1_HOSTCON_EXDW                   (*((volatile unsigned int*)(0x42DF8514UL)))
#define bM4_SDIOC1_HOSTCON_CDTL                   (*((volatile unsigned int*)(0x42DF8518UL)))
#define bM4_SDIOC1_HOSTCON_CDSS                   (*((volatile unsigned int*)(0x42DF851CUL)))
#define bM4_SDIOC1_PWRCON_PWON                    (*((volatile unsigned int*)(0x42DF8520UL)))
#define bM4_SDIOC1_BLKGPCON_SABGR                 (*((volatile unsigned int*)(0x42DF8540UL)))
#define bM4_SDIOC1_BLKGPCON_CR                    (*((volatile unsigned int*)(0x42DF8544UL)))
#define bM4_SDIOC1_BLKGPCON_RWC                   (*((volatile unsigned int*)(0x42DF8548UL)))
#define bM4_SDIOC1_BLKGPCON_IABG                  (*((volatile unsigned int*)(0x42DF854CUL)))
#define bM4_SDIOC1_CLKCON_ICE                     (*((volatile unsigned int*)(0x42DF8580UL)))
#define bM4_SDIOC1_CLKCON_CE                      (*((volatile unsigned int*)(0x42DF8588UL)))
#define bM4_SDIOC1_CLKCON_FS0                     (*((volatile unsigned int*)(0x42DF85A0UL)))
#define bM4_SDIOC1_CLKCON_FS1                     (*((volatile unsigned int*)(0x42DF85A4UL)))
#define bM4_SDIOC1_CLKCON_FS2                     (*((volatile unsigned int*)(0x42DF85A8UL)))
#define bM4_SDIOC1_CLKCON_FS3                     (*((volatile unsigned int*)(0x42DF85ACUL)))
#define bM4_SDIOC1_CLKCON_FS4                     (*((volatile unsigned int*)(0x42DF85B0UL)))
#define bM4_SDIOC1_CLKCON_FS5                     (*((volatile unsigned int*)(0x42DF85B4UL)))
#define bM4_SDIOC1_CLKCON_FS6                     (*((volatile unsigned int*)(0x42DF85B8UL)))
#define bM4_SDIOC1_CLKCON_FS7                     (*((volatile unsigned int*)(0x42DF85BCUL)))
#define bM4_SDIOC1_TOUTCON_DTO0                   (*((volatile unsigned int*)(0x42DF85C0UL)))
#define bM4_SDIOC1_TOUTCON_DTO1                   (*((volatile unsigned int*)(0x42DF85C4UL)))
#define bM4_SDIOC1_TOUTCON_DTO2                   (*((volatile unsigned int*)(0x42DF85C8UL)))
#define bM4_SDIOC1_TOUTCON_DTO3                   (*((volatile unsigned int*)(0x42DF85CCUL)))
#define bM4_SDIOC1_SFTRST_RSTA                    (*((volatile unsigned int*)(0x42DF85E0UL)))
#define bM4_SDIOC1_SFTRST_RSTC                    (*((volatile unsigned int*)(0x42DF85E4UL)))
#define bM4_SDIOC1_SFTRST_RSTD                    (*((volatile unsigned int*)(0x42DF85E8UL)))
#define bM4_SDIOC1_NORINTST_CC                    (*((volatile unsigned int*)(0x42DF8600UL)))
#define bM4_SDIOC1_NORINTST_TC                    (*((volatile unsigned int*)(0x42DF8604UL)))
#define bM4_SDIOC1_NORINTST_BGE                   (*((volatile unsigned int*)(0x42DF8608UL)))
#define bM4_SDIOC1_NORINTST_BWR                   (*((volatile unsigned int*)(0x42DF8610UL)))
#define bM4_SDIOC1_NORINTST_BRR                   (*((volatile unsigned int*)(0x42DF8614UL)))
#define bM4_SDIOC1_NORINTST_CIST                  (*((volatile unsigned int*)(0x42DF8618UL)))
#define bM4_SDIOC1_NORINTST_CRM                   (*((volatile unsigned int*)(0x42DF861CUL)))
#define bM4_SDIOC1_NORINTST_CINT                  (*((volatile unsigned int*)(0x42DF8620UL)))
#define bM4_SDIOC1_NORINTST_EI                    (*((volatile unsigned int*)(0x42DF863CUL)))
#define bM4_SDIOC1_ERRINTST_CTOE                  (*((volatile unsigned int*)(0x42DF8640UL)))
#define bM4_SDIOC1_ERRINTST_CCE                   (*((volatile unsigned int*)(0x42DF8644UL)))
#define bM4_SDIOC1_ERRINTST_CEBE                  (*((volatile unsigned int*)(0x42DF8648UL)))
#define bM4_SDIOC1_ERRINTST_CIE                   (*((volatile unsigned int*)(0x42DF864CUL)))
#define bM4_SDIOC1_ERRINTST_DTOE                  (*((volatile unsigned int*)(0x42DF8650UL)))
#define bM4_SDIOC1_ERRINTST_DCE                   (*((volatile unsigned int*)(0x42DF8654UL)))
#define bM4_SDIOC1_ERRINTST_DEBE                  (*((volatile unsigned int*)(0x42DF8658UL)))
#define bM4_SDIOC1_ERRINTST_ACE                   (*((volatile unsigned int*)(0x42DF8660UL)))
#define bM4_SDIOC1_NORINTSTEN_CCEN                (*((volatile unsigned int*)(0x42DF8680UL)))
#define bM4_SDIOC1_NORINTSTEN_TCEN                (*((volatile unsigned int*)(0x42DF8684UL)))
#define bM4_SDIOC1_NORINTSTEN_BGEEN               (*((volatile unsigned int*)(0x42DF8688UL)))
#define bM4_SDIOC1_NORINTSTEN_BWREN               (*((volatile unsigned int*)(0x42DF8690UL)))
#define bM4_SDIOC1_NORINTSTEN_BRREN               (*((volatile unsigned int*)(0x42DF8694UL)))
#define bM4_SDIOC1_NORINTSTEN_CISTEN              (*((volatile unsigned int*)(0x42DF8698UL)))
#define bM4_SDIOC1_NORINTSTEN_CRMEN               (*((volatile unsigned int*)(0x42DF869CUL)))
#define bM4_SDIOC1_NORINTSTEN_CINTEN              (*((volatile unsigned int*)(0x42DF86A0UL)))
#define bM4_SDIOC1_ERRINTSTEN_CTOEEN              (*((volatile unsigned int*)(0x42DF86C0UL)))
#define bM4_SDIOC1_ERRINTSTEN_CCEEN               (*((volatile unsigned int*)(0x42DF86C4UL)))
#define bM4_SDIOC1_ERRINTSTEN_CEBEEN              (*((volatile unsigned int*)(0x42DF86C8UL)))
#define bM4_SDIOC1_ERRINTSTEN_CIEEN               (*((volatile unsigned int*)(0x42DF86CCUL)))
#define bM4_SDIOC1_ERRINTSTEN_DTOEEN              (*((volatile unsigned int*)(0x42DF86D0UL)))
#define bM4_SDIOC1_ERRINTSTEN_DCEEN               (*((volatile unsigned int*)(0x42DF86D4UL)))
#define bM4_SDIOC1_ERRINTSTEN_DEBEEN              (*((volatile unsigned int*)(0x42DF86D8UL)))
#define bM4_SDIOC1_ERRINTSTEN_ACEEN               (*((volatile unsigned int*)(0x42DF86E0UL)))
#define bM4_SDIOC1_NORINTSGEN_CCSEN               (*((volatile unsigned int*)(0x42DF8700UL)))
#define bM4_SDIOC1_NORINTSGEN_TCSEN               (*((volatile unsigned int*)(0x42DF8704UL)))
#define bM4_SDIOC1_NORINTSGEN_BGESEN              (*((volatile unsigned int*)(0x42DF8708UL)))
#define bM4_SDIOC1_NORINTSGEN_BWRSEN              (*((volatile unsigned int*)(0x42DF8710UL)))
#define bM4_SDIOC1_NORINTSGEN_BRRSEN              (*((volatile unsigned int*)(0x42DF8714UL)))
#define bM4_SDIOC1_NORINTSGEN_CISTSEN             (*((volatile unsigned int*)(0x42DF8718UL)))
#define bM4_SDIOC1_NORINTSGEN_CRMSEN              (*((volatile unsigned int*)(0x42DF871CUL)))
#define bM4_SDIOC1_NORINTSGEN_CINTSEN             (*((volatile unsigned int*)(0x42DF8720UL)))
#define bM4_SDIOC1_ERRINTSGEN_CTOESEN             (*((volatile unsigned int*)(0x42DF8740UL)))
#define bM4_SDIOC1_ERRINTSGEN_CCESEN              (*((volatile unsigned int*)(0x42DF8744UL)))
#define bM4_SDIOC1_ERRINTSGEN_CEBESEN             (*((volatile unsigned int*)(0x42DF8748UL)))
#define bM4_SDIOC1_ERRINTSGEN_CIESEN              (*((volatile unsigned int*)(0x42DF874CUL)))
#define bM4_SDIOC1_ERRINTSGEN_DTOESEN             (*((volatile unsigned int*)(0x42DF8750UL)))
#define bM4_SDIOC1_ERRINTSGEN_DCESEN              (*((volatile unsigned int*)(0x42DF8754UL)))
#define bM4_SDIOC1_ERRINTSGEN_DEBESEN             (*((volatile unsigned int*)(0x42DF8758UL)))
#define bM4_SDIOC1_ERRINTSGEN_ACESEN              (*((volatile unsigned int*)(0x42DF8760UL)))
#define bM4_SDIOC1_ATCERRST_NE                    (*((volatile unsigned int*)(0x42DF8780UL)))
#define bM4_SDIOC1_ATCERRST_TOE                   (*((volatile unsigned int*)(0x42DF8784UL)))
#define bM4_SDIOC1_ATCERRST_CE                    (*((volatile unsigned int*)(0x42DF8788UL)))
#define bM4_SDIOC1_ATCERRST_EBE                   (*((volatile unsigned int*)(0x42DF878CUL)))
#define bM4_SDIOC1_ATCERRST_IE                    (*((volatile unsigned int*)(0x42DF8790UL)))
#define bM4_SDIOC1_ATCERRST_CMDE                  (*((volatile unsigned int*)(0x42DF879CUL)))
#define bM4_SDIOC1_FEA_FNE                        (*((volatile unsigned int*)(0x42DF8A00UL)))
#define bM4_SDIOC1_FEA_FTOE                       (*((volatile unsigned int*)(0x42DF8A04UL)))
#define bM4_SDIOC1_FEA_FCE                        (*((volatile unsigned int*)(0x42DF8A08UL)))
#define bM4_SDIOC1_FEA_FEBE                       (*((volatile unsigned int*)(0x42DF8A0CUL)))
#define bM4_SDIOC1_FEA_FIE                        (*((volatile unsigned int*)(0x42DF8A10UL)))
#define bM4_SDIOC1_FEA_FCMDE                      (*((volatile unsigned int*)(0x42DF8A1CUL)))
#define bM4_SDIOC1_FEE_FCTOE                      (*((volatile unsigned int*)(0x42DF8A40UL)))
#define bM4_SDIOC1_FEE_FCCE                       (*((volatile unsigned int*)(0x42DF8A44UL)))
#define bM4_SDIOC1_FEE_FCEBE                      (*((volatile unsigned int*)(0x42DF8A48UL)))
#define bM4_SDIOC1_FEE_FCIE                       (*((volatile unsigned int*)(0x42DF8A4CUL)))
#define bM4_SDIOC1_FEE_FDTOE                      (*((volatile unsigned int*)(0x42DF8A50UL)))
#define bM4_SDIOC1_FEE_FDCE                       (*((volatile unsigned int*)(0x42DF8A54UL)))
#define bM4_SDIOC1_FEE_FDEBE                      (*((volatile unsigned int*)(0x42DF8A58UL)))
#define bM4_SDIOC1_FEE_FACE                       (*((volatile unsigned int*)(0x42DF8A60UL)))
#define bM4_SDIOC2_BLKSIZE_TBS0                   (*((volatile unsigned int*)(0x42E00080UL)))
#define bM4_SDIOC2_BLKSIZE_TBS1                   (*((volatile unsigned int*)(0x42E00084UL)))
#define bM4_SDIOC2_BLKSIZE_TBS2                   (*((volatile unsigned int*)(0x42E00088UL)))
#define bM4_SDIOC2_BLKSIZE_TBS3                   (*((volatile unsigned int*)(0x42E0008CUL)))
#define bM4_SDIOC2_BLKSIZE_TBS4                   (*((volatile unsigned int*)(0x42E00090UL)))
#define bM4_SDIOC2_BLKSIZE_TBS5                   (*((volatile unsigned int*)(0x42E00094UL)))
#define bM4_SDIOC2_BLKSIZE_TBS6                   (*((volatile unsigned int*)(0x42E00098UL)))
#define bM4_SDIOC2_BLKSIZE_TBS7                   (*((volatile unsigned int*)(0x42E0009CUL)))
#define bM4_SDIOC2_BLKSIZE_TBS8                   (*((volatile unsigned int*)(0x42E000A0UL)))
#define bM4_SDIOC2_BLKSIZE_TBS9                   (*((volatile unsigned int*)(0x42E000A4UL)))
#define bM4_SDIOC2_BLKSIZE_TBS10                  (*((volatile unsigned int*)(0x42E000A8UL)))
#define bM4_SDIOC2_BLKSIZE_TBS11                  (*((volatile unsigned int*)(0x42E000ACUL)))
#define bM4_SDIOC2_TRANSMODE_BCE                  (*((volatile unsigned int*)(0x42E00184UL)))
#define bM4_SDIOC2_TRANSMODE_ATCEN0               (*((volatile unsigned int*)(0x42E00188UL)))
#define bM4_SDIOC2_TRANSMODE_ATCEN1               (*((volatile unsigned int*)(0x42E0018CUL)))
#define bM4_SDIOC2_TRANSMODE_DDIR                 (*((volatile unsigned int*)(0x42E00190UL)))
#define bM4_SDIOC2_TRANSMODE_MULB                 (*((volatile unsigned int*)(0x42E00194UL)))
#define bM4_SDIOC2_CMD_RESTYP0                    (*((volatile unsigned int*)(0x42E001C0UL)))
#define bM4_SDIOC2_CMD_RESTYP1                    (*((volatile unsigned int*)(0x42E001C4UL)))
#define bM4_SDIOC2_CMD_CCE                        (*((volatile unsigned int*)(0x42E001CCUL)))
#define bM4_SDIOC2_CMD_ICE                        (*((volatile unsigned int*)(0x42E001D0UL)))
#define bM4_SDIOC2_CMD_DAT                        (*((volatile unsigned int*)(0x42E001D4UL)))
#define bM4_SDIOC2_CMD_TYP0                       (*((volatile unsigned int*)(0x42E001D8UL)))
#define bM4_SDIOC2_CMD_TYP1                       (*((volatile unsigned int*)(0x42E001DCUL)))
#define bM4_SDIOC2_CMD_IDX0                       (*((volatile unsigned int*)(0x42E001E0UL)))
#define bM4_SDIOC2_CMD_IDX1                       (*((volatile unsigned int*)(0x42E001E4UL)))
#define bM4_SDIOC2_CMD_IDX2                       (*((volatile unsigned int*)(0x42E001E8UL)))
#define bM4_SDIOC2_CMD_IDX3                       (*((volatile unsigned int*)(0x42E001ECUL)))
#define bM4_SDIOC2_CMD_IDX4                       (*((volatile unsigned int*)(0x42E001F0UL)))
#define bM4_SDIOC2_CMD_IDX5                       (*((volatile unsigned int*)(0x42E001F4UL)))
#define bM4_SDIOC2_PSTAT_CIC                      (*((volatile unsigned int*)(0x42E00480UL)))
#define bM4_SDIOC2_PSTAT_CID                      (*((volatile unsigned int*)(0x42E00484UL)))
#define bM4_SDIOC2_PSTAT_DA                       (*((volatile unsigned int*)(0x42E00488UL)))
#define bM4_SDIOC2_PSTAT_WTA                      (*((volatile unsigned int*)(0x42E004A0UL)))
#define bM4_SDIOC2_PSTAT_RTA                      (*((volatile unsigned int*)(0x42E004A4UL)))
#define bM4_SDIOC2_PSTAT_BWE                      (*((volatile unsigned int*)(0x42E004A8UL)))
#define bM4_SDIOC2_PSTAT_BRE                      (*((volatile unsigned int*)(0x42E004ACUL)))
#define bM4_SDIOC2_PSTAT_CIN                      (*((volatile unsigned int*)(0x42E004C0UL)))
#define bM4_SDIOC2_PSTAT_CSS                      (*((volatile unsigned int*)(0x42E004C4UL)))
#define bM4_SDIOC2_PSTAT_CDL                      (*((volatile unsigned int*)(0x42E004C8UL)))
#define bM4_SDIOC2_PSTAT_WPL                      (*((volatile unsigned int*)(0x42E004CCUL)))
#define bM4_SDIOC2_PSTAT_DATL0                    (*((volatile unsigned int*)(0x42E004D0UL)))
#define bM4_SDIOC2_PSTAT_DATL1                    (*((volatile unsigned int*)(0x42E004D4UL)))
#define bM4_SDIOC2_PSTAT_DATL2                    (*((volatile unsigned int*)(0x42E004D8UL)))
#define bM4_SDIOC2_PSTAT_DATL3                    (*((volatile unsigned int*)(0x42E004DCUL)))
#define bM4_SDIOC2_PSTAT_CMDL                     (*((volatile unsigned int*)(0x42E004E0UL)))
#define bM4_SDIOC2_HOSTCON_DW                     (*((volatile unsigned int*)(0x42E00504UL)))
#define bM4_SDIOC2_HOSTCON_HSEN                   (*((volatile unsigned int*)(0x42E00508UL)))
#define bM4_SDIOC2_HOSTCON_EXDW                   (*((volatile unsigned int*)(0x42E00514UL)))
#define bM4_SDIOC2_HOSTCON_CDTL                   (*((volatile unsigned int*)(0x42E00518UL)))
#define bM4_SDIOC2_HOSTCON_CDSS                   (*((volatile unsigned int*)(0x42E0051CUL)))
#define bM4_SDIOC2_PWRCON_PWON                    (*((volatile unsigned int*)(0x42E00520UL)))
#define bM4_SDIOC2_BLKGPCON_SABGR                 (*((volatile unsigned int*)(0x42E00540UL)))
#define bM4_SDIOC2_BLKGPCON_CR                    (*((volatile unsigned int*)(0x42E00544UL)))
#define bM4_SDIOC2_BLKGPCON_RWC                   (*((volatile unsigned int*)(0x42E00548UL)))
#define bM4_SDIOC2_BLKGPCON_IABG                  (*((volatile unsigned int*)(0x42E0054CUL)))
#define bM4_SDIOC2_CLKCON_ICE                     (*((volatile unsigned int*)(0x42E00580UL)))
#define bM4_SDIOC2_CLKCON_CE                      (*((volatile unsigned int*)(0x42E00588UL)))
#define bM4_SDIOC2_CLKCON_FS0                     (*((volatile unsigned int*)(0x42E005A0UL)))
#define bM4_SDIOC2_CLKCON_FS1                     (*((volatile unsigned int*)(0x42E005A4UL)))
#define bM4_SDIOC2_CLKCON_FS2                     (*((volatile unsigned int*)(0x42E005A8UL)))
#define bM4_SDIOC2_CLKCON_FS3                     (*((volatile unsigned int*)(0x42E005ACUL)))
#define bM4_SDIOC2_CLKCON_FS4                     (*((volatile unsigned int*)(0x42E005B0UL)))
#define bM4_SDIOC2_CLKCON_FS5                     (*((volatile unsigned int*)(0x42E005B4UL)))
#define bM4_SDIOC2_CLKCON_FS6                     (*((volatile unsigned int*)(0x42E005B8UL)))
#define bM4_SDIOC2_CLKCON_FS7                     (*((volatile unsigned int*)(0x42E005BCUL)))
#define bM4_SDIOC2_TOUTCON_DTO0                   (*((volatile unsigned int*)(0x42E005C0UL)))
#define bM4_SDIOC2_TOUTCON_DTO1                   (*((volatile unsigned int*)(0x42E005C4UL)))
#define bM4_SDIOC2_TOUTCON_DTO2                   (*((volatile unsigned int*)(0x42E005C8UL)))
#define bM4_SDIOC2_TOUTCON_DTO3                   (*((volatile unsigned int*)(0x42E005CCUL)))
#define bM4_SDIOC2_SFTRST_RSTA                    (*((volatile unsigned int*)(0x42E005E0UL)))
#define bM4_SDIOC2_SFTRST_RSTC                    (*((volatile unsigned int*)(0x42E005E4UL)))
#define bM4_SDIOC2_SFTRST_RSTD                    (*((volatile unsigned int*)(0x42E005E8UL)))
#define bM4_SDIOC2_NORINTST_CC                    (*((volatile unsigned int*)(0x42E00600UL)))
#define bM4_SDIOC2_NORINTST_TC                    (*((volatile unsigned int*)(0x42E00604UL)))
#define bM4_SDIOC2_NORINTST_BGE                   (*((volatile unsigned int*)(0x42E00608UL)))
#define bM4_SDIOC2_NORINTST_BWR                   (*((volatile unsigned int*)(0x42E00610UL)))
#define bM4_SDIOC2_NORINTST_BRR                   (*((volatile unsigned int*)(0x42E00614UL)))
#define bM4_SDIOC2_NORINTST_CIST                  (*((volatile unsigned int*)(0x42E00618UL)))
#define bM4_SDIOC2_NORINTST_CRM                   (*((volatile unsigned int*)(0x42E0061CUL)))
#define bM4_SDIOC2_NORINTST_CINT                  (*((volatile unsigned int*)(0x42E00620UL)))
#define bM4_SDIOC2_NORINTST_EI                    (*((volatile unsigned int*)(0x42E0063CUL)))
#define bM4_SDIOC2_ERRINTST_CTOE                  (*((volatile unsigned int*)(0x42E00640UL)))
#define bM4_SDIOC2_ERRINTST_CCE                   (*((volatile unsigned int*)(0x42E00644UL)))
#define bM4_SDIOC2_ERRINTST_CEBE                  (*((volatile unsigned int*)(0x42E00648UL)))
#define bM4_SDIOC2_ERRINTST_CIE                   (*((volatile unsigned int*)(0x42E0064CUL)))
#define bM4_SDIOC2_ERRINTST_DTOE                  (*((volatile unsigned int*)(0x42E00650UL)))
#define bM4_SDIOC2_ERRINTST_DCE                   (*((volatile unsigned int*)(0x42E00654UL)))
#define bM4_SDIOC2_ERRINTST_DEBE                  (*((volatile unsigned int*)(0x42E00658UL)))
#define bM4_SDIOC2_ERRINTST_ACE                   (*((volatile unsigned int*)(0x42E00660UL)))
#define bM4_SDIOC2_NORINTSTEN_CCEN                (*((volatile unsigned int*)(0x42E00680UL)))
#define bM4_SDIOC2_NORINTSTEN_TCEN                (*((volatile unsigned int*)(0x42E00684UL)))
#define bM4_SDIOC2_NORINTSTEN_BGEEN               (*((volatile unsigned int*)(0x42E00688UL)))
#define bM4_SDIOC2_NORINTSTEN_BWREN               (*((volatile unsigned int*)(0x42E00690UL)))
#define bM4_SDIOC2_NORINTSTEN_BRREN               (*((volatile unsigned int*)(0x42E00694UL)))
#define bM4_SDIOC2_NORINTSTEN_CISTEN              (*((volatile unsigned int*)(0x42E00698UL)))
#define bM4_SDIOC2_NORINTSTEN_CRMEN               (*((volatile unsigned int*)(0x42E0069CUL)))
#define bM4_SDIOC2_NORINTSTEN_CINTEN              (*((volatile unsigned int*)(0x42E006A0UL)))
#define bM4_SDIOC2_ERRINTSTEN_CTOEEN              (*((volatile unsigned int*)(0x42E006C0UL)))
#define bM4_SDIOC2_ERRINTSTEN_CCEEN               (*((volatile unsigned int*)(0x42E006C4UL)))
#define bM4_SDIOC2_ERRINTSTEN_CEBEEN              (*((volatile unsigned int*)(0x42E006C8UL)))
#define bM4_SDIOC2_ERRINTSTEN_CIEEN               (*((volatile unsigned int*)(0x42E006CCUL)))
#define bM4_SDIOC2_ERRINTSTEN_DTOEEN              (*((volatile unsigned int*)(0x42E006D0UL)))
#define bM4_SDIOC2_ERRINTSTEN_DCEEN               (*((volatile unsigned int*)(0x42E006D4UL)))
#define bM4_SDIOC2_ERRINTSTEN_DEBEEN              (*((volatile unsigned int*)(0x42E006D8UL)))
#define bM4_SDIOC2_ERRINTSTEN_ACEEN               (*((volatile unsigned int*)(0x42E006E0UL)))
#define bM4_SDIOC2_NORINTSGEN_CCSEN               (*((volatile unsigned int*)(0x42E00700UL)))
#define bM4_SDIOC2_NORINTSGEN_TCSEN               (*((volatile unsigned int*)(0x42E00704UL)))
#define bM4_SDIOC2_NORINTSGEN_BGESEN              (*((volatile unsigned int*)(0x42E00708UL)))
#define bM4_SDIOC2_NORINTSGEN_BWRSEN              (*((volatile unsigned int*)(0x42E00710UL)))
#define bM4_SDIOC2_NORINTSGEN_BRRSEN              (*((volatile unsigned int*)(0x42E00714UL)))
#define bM4_SDIOC2_NORINTSGEN_CISTSEN             (*((volatile unsigned int*)(0x42E00718UL)))
#define bM4_SDIOC2_NORINTSGEN_CRMSEN              (*((volatile unsigned int*)(0x42E0071CUL)))
#define bM4_SDIOC2_NORINTSGEN_CINTSEN             (*((volatile unsigned int*)(0x42E00720UL)))
#define bM4_SDIOC2_ERRINTSGEN_CTOESEN             (*((volatile unsigned int*)(0x42E00740UL)))
#define bM4_SDIOC2_ERRINTSGEN_CCESEN              (*((volatile unsigned int*)(0x42E00744UL)))
#define bM4_SDIOC2_ERRINTSGEN_CEBESEN             (*((volatile unsigned int*)(0x42E00748UL)))
#define bM4_SDIOC2_ERRINTSGEN_CIESEN              (*((volatile unsigned int*)(0x42E0074CUL)))
#define bM4_SDIOC2_ERRINTSGEN_DTOESEN             (*((volatile unsigned int*)(0x42E00750UL)))
#define bM4_SDIOC2_ERRINTSGEN_DCESEN              (*((volatile unsigned int*)(0x42E00754UL)))
#define bM4_SDIOC2_ERRINTSGEN_DEBESEN             (*((volatile unsigned int*)(0x42E00758UL)))
#define bM4_SDIOC2_ERRINTSGEN_ACESEN              (*((volatile unsigned int*)(0x42E00760UL)))
#define bM4_SDIOC2_ATCERRST_NE                    (*((volatile unsigned int*)(0x42E00780UL)))
#define bM4_SDIOC2_ATCERRST_TOE                   (*((volatile unsigned int*)(0x42E00784UL)))
#define bM4_SDIOC2_ATCERRST_CE                    (*((volatile unsigned int*)(0x42E00788UL)))
#define bM4_SDIOC2_ATCERRST_EBE                   (*((volatile unsigned int*)(0x42E0078CUL)))
#define bM4_SDIOC2_ATCERRST_IE                    (*((volatile unsigned int*)(0x42E00790UL)))
#define bM4_SDIOC2_ATCERRST_CMDE                  (*((volatile unsigned int*)(0x42E0079CUL)))
#define bM4_SDIOC2_FEA_FNE                        (*((volatile unsigned int*)(0x42E00A00UL)))
#define bM4_SDIOC2_FEA_FTOE                       (*((volatile unsigned int*)(0x42E00A04UL)))
#define bM4_SDIOC2_FEA_FCE                        (*((volatile unsigned int*)(0x42E00A08UL)))
#define bM4_SDIOC2_FEA_FEBE                       (*((volatile unsigned int*)(0x42E00A0CUL)))
#define bM4_SDIOC2_FEA_FIE                        (*((volatile unsigned int*)(0x42E00A10UL)))
#define bM4_SDIOC2_FEA_FCMDE                      (*((volatile unsigned int*)(0x42E00A1CUL)))
#define bM4_SDIOC2_FEE_FCTOE                      (*((volatile unsigned int*)(0x42E00A40UL)))
#define bM4_SDIOC2_FEE_FCCE                       (*((volatile unsigned int*)(0x42E00A44UL)))
#define bM4_SDIOC2_FEE_FCEBE                      (*((volatile unsigned int*)(0x42E00A48UL)))
#define bM4_SDIOC2_FEE_FCIE                       (*((volatile unsigned int*)(0x42E00A4CUL)))
#define bM4_SDIOC2_FEE_FDTOE                      (*((volatile unsigned int*)(0x42E00A50UL)))
#define bM4_SDIOC2_FEE_FDCE                       (*((volatile unsigned int*)(0x42E00A54UL)))
#define bM4_SDIOC2_FEE_FDEBE                      (*((volatile unsigned int*)(0x42E00A58UL)))
#define bM4_SDIOC2_FEE_FACE                       (*((volatile unsigned int*)(0x42E00A60UL)))
#define bM4_SPI1_CR1_SPIMDS                       (*((volatile unsigned int*)(0x42380080UL)))
#define bM4_SPI1_CR1_TXMDS                        (*((volatile unsigned int*)(0x42380084UL)))
#define bM4_SPI1_CR1_MSTR                         (*((volatile unsigned int*)(0x4238008CUL)))
#define bM4_SPI1_CR1_SPLPBK                       (*((volatile unsigned int*)(0x42380090UL)))
#define bM4_SPI1_CR1_SPLPBK2                      (*((volatile unsigned int*)(0x42380094UL)))
#define bM4_SPI1_CR1_SPE                          (*((volatile unsigned int*)(0x42380098UL)))
#define bM4_SPI1_CR1_CSUSPE                       (*((volatile unsigned int*)(0x4238009CUL)))
#define bM4_SPI1_CR1_EIE                          (*((volatile unsigned int*)(0x423800A0UL)))
#define bM4_SPI1_CR1_TXIE                         (*((volatile unsigned int*)(0x423800A4UL)))
#define bM4_SPI1_CR1_RXIE                         (*((volatile unsigned int*)(0x423800A8UL)))
#define bM4_SPI1_CR1_IDIE                         (*((volatile unsigned int*)(0x423800ACUL)))
#define bM4_SPI1_CR1_MODFE                        (*((volatile unsigned int*)(0x423800B0UL)))
#define bM4_SPI1_CR1_PATE                         (*((volatile unsigned int*)(0x423800B4UL)))
#define bM4_SPI1_CR1_PAOE                         (*((volatile unsigned int*)(0x423800B8UL)))
#define bM4_SPI1_CR1_PAE                          (*((volatile unsigned int*)(0x423800BCUL)))
#define bM4_SPI1_CFG1_FTHLV0                      (*((volatile unsigned int*)(0x42380180UL)))
#define bM4_SPI1_CFG1_FTHLV1                      (*((volatile unsigned int*)(0x42380184UL)))
#define bM4_SPI1_CFG1_SPRDTD                      (*((volatile unsigned int*)(0x42380198UL)))
#define bM4_SPI1_CFG1_SS0PV                       (*((volatile unsigned int*)(0x423801A0UL)))
#define bM4_SPI1_CFG1_SS1PV                       (*((volatile unsigned int*)(0x423801A4UL)))
#define bM4_SPI1_CFG1_SS2PV                       (*((volatile unsigned int*)(0x423801A8UL)))
#define bM4_SPI1_CFG1_SS3PV                       (*((volatile unsigned int*)(0x423801ACUL)))
#define bM4_SPI1_CFG1_MSSI0                       (*((volatile unsigned int*)(0x423801D0UL)))
#define bM4_SPI1_CFG1_MSSI1                       (*((volatile unsigned int*)(0x423801D4UL)))
#define bM4_SPI1_CFG1_MSSI2                       (*((volatile unsigned int*)(0x423801D8UL)))
#define bM4_SPI1_CFG1_MSSDL0                      (*((volatile unsigned int*)(0x423801E0UL)))
#define bM4_SPI1_CFG1_MSSDL1                      (*((volatile unsigned int*)(0x423801E4UL)))
#define bM4_SPI1_CFG1_MSSDL2                      (*((volatile unsigned int*)(0x423801E8UL)))
#define bM4_SPI1_CFG1_MIDI0                       (*((volatile unsigned int*)(0x423801F0UL)))
#define bM4_SPI1_CFG1_MIDI1                       (*((volatile unsigned int*)(0x423801F4UL)))
#define bM4_SPI1_CFG1_MIDI2                       (*((volatile unsigned int*)(0x423801F8UL)))
#define bM4_SPI1_SR_OVRERF                        (*((volatile unsigned int*)(0x42380280UL)))
#define bM4_SPI1_SR_IDLNF                         (*((volatile unsigned int*)(0x42380284UL)))
#define bM4_SPI1_SR_MODFERF                       (*((volatile unsigned int*)(0x42380288UL)))
#define bM4_SPI1_SR_PERF                          (*((volatile unsigned int*)(0x4238028CUL)))
#define bM4_SPI1_SR_UDRERF                        (*((volatile unsigned int*)(0x42380290UL)))
#define bM4_SPI1_SR_TDEF                          (*((volatile unsigned int*)(0x42380294UL)))
#define bM4_SPI1_SR_RDFF                          (*((volatile unsigned int*)(0x4238029CUL)))
#define bM4_SPI1_CFG2_CPHA                        (*((volatile unsigned int*)(0x42380300UL)))
#define bM4_SPI1_CFG2_CPOL                        (*((volatile unsigned int*)(0x42380304UL)))
#define bM4_SPI1_CFG2_MBR0                        (*((volatile unsigned int*)(0x42380308UL)))
#define bM4_SPI1_CFG2_MBR1                        (*((volatile unsigned int*)(0x4238030CUL)))
#define bM4_SPI1_CFG2_MBR2                        (*((volatile unsigned int*)(0x42380310UL)))
#define bM4_SPI1_CFG2_SSA0                        (*((volatile unsigned int*)(0x42380314UL)))
#define bM4_SPI1_CFG2_SSA1                        (*((volatile unsigned int*)(0x42380318UL)))
#define bM4_SPI1_CFG2_SSA2                        (*((volatile unsigned int*)(0x4238031CUL)))
#define bM4_SPI1_CFG2_DSIZE0                      (*((volatile unsigned int*)(0x42380320UL)))
#define bM4_SPI1_CFG2_DSIZE1                      (*((volatile unsigned int*)(0x42380324UL)))
#define bM4_SPI1_CFG2_DSIZE2                      (*((volatile unsigned int*)(0x42380328UL)))
#define bM4_SPI1_CFG2_DSIZE3                      (*((volatile unsigned int*)(0x4238032CUL)))
#define bM4_SPI1_CFG2_LSBF                        (*((volatile unsigned int*)(0x42380330UL)))
#define bM4_SPI1_CFG2_MIDIE                       (*((volatile unsigned int*)(0x42380334UL)))
#define bM4_SPI1_CFG2_MSSDLE                      (*((volatile unsigned int*)(0x42380338UL)))
#define bM4_SPI1_CFG2_MSSIE                       (*((volatile unsigned int*)(0x4238033CUL)))
#define bM4_SPI2_CR1_SPIMDS                       (*((volatile unsigned int*)(0x42388080UL)))
#define bM4_SPI2_CR1_TXMDS                        (*((volatile unsigned int*)(0x42388084UL)))
#define bM4_SPI2_CR1_MSTR                         (*((volatile unsigned int*)(0x4238808CUL)))
#define bM4_SPI2_CR1_SPLPBK                       (*((volatile unsigned int*)(0x42388090UL)))
#define bM4_SPI2_CR1_SPLPBK2                      (*((volatile unsigned int*)(0x42388094UL)))
#define bM4_SPI2_CR1_SPE                          (*((volatile unsigned int*)(0x42388098UL)))
#define bM4_SPI2_CR1_CSUSPE                       (*((volatile unsigned int*)(0x4238809CUL)))
#define bM4_SPI2_CR1_EIE                          (*((volatile unsigned int*)(0x423880A0UL)))
#define bM4_SPI2_CR1_TXIE                         (*((volatile unsigned int*)(0x423880A4UL)))
#define bM4_SPI2_CR1_RXIE                         (*((volatile unsigned int*)(0x423880A8UL)))
#define bM4_SPI2_CR1_IDIE                         (*((volatile unsigned int*)(0x423880ACUL)))
#define bM4_SPI2_CR1_MODFE                        (*((volatile unsigned int*)(0x423880B0UL)))
#define bM4_SPI2_CR1_PATE                         (*((volatile unsigned int*)(0x423880B4UL)))
#define bM4_SPI2_CR1_PAOE                         (*((volatile unsigned int*)(0x423880B8UL)))
#define bM4_SPI2_CR1_PAE                          (*((volatile unsigned int*)(0x423880BCUL)))
#define bM4_SPI2_CFG1_FTHLV0                      (*((volatile unsigned int*)(0x42388180UL)))
#define bM4_SPI2_CFG1_FTHLV1                      (*((volatile unsigned int*)(0x42388184UL)))
#define bM4_SPI2_CFG1_SPRDTD                      (*((volatile unsigned int*)(0x42388198UL)))
#define bM4_SPI2_CFG1_SS0PV                       (*((volatile unsigned int*)(0x423881A0UL)))
#define bM4_SPI2_CFG1_SS1PV                       (*((volatile unsigned int*)(0x423881A4UL)))
#define bM4_SPI2_CFG1_SS2PV                       (*((volatile unsigned int*)(0x423881A8UL)))
#define bM4_SPI2_CFG1_SS3PV                       (*((volatile unsigned int*)(0x423881ACUL)))
#define bM4_SPI2_CFG1_MSSI0                       (*((volatile unsigned int*)(0x423881D0UL)))
#define bM4_SPI2_CFG1_MSSI1                       (*((volatile unsigned int*)(0x423881D4UL)))
#define bM4_SPI2_CFG1_MSSI2                       (*((volatile unsigned int*)(0x423881D8UL)))
#define bM4_SPI2_CFG1_MSSDL0                      (*((volatile unsigned int*)(0x423881E0UL)))
#define bM4_SPI2_CFG1_MSSDL1                      (*((volatile unsigned int*)(0x423881E4UL)))
#define bM4_SPI2_CFG1_MSSDL2                      (*((volatile unsigned int*)(0x423881E8UL)))
#define bM4_SPI2_CFG1_MIDI0                       (*((volatile unsigned int*)(0x423881F0UL)))
#define bM4_SPI2_CFG1_MIDI1                       (*((volatile unsigned int*)(0x423881F4UL)))
#define bM4_SPI2_CFG1_MIDI2                       (*((volatile unsigned int*)(0x423881F8UL)))
#define bM4_SPI2_SR_OVRERF                        (*((volatile unsigned int*)(0x42388280UL)))
#define bM4_SPI2_SR_IDLNF                         (*((volatile unsigned int*)(0x42388284UL)))
#define bM4_SPI2_SR_MODFERF                       (*((volatile unsigned int*)(0x42388288UL)))
#define bM4_SPI2_SR_PERF                          (*((volatile unsigned int*)(0x4238828CUL)))
#define bM4_SPI2_SR_UDRERF                        (*((volatile unsigned int*)(0x42388290UL)))
#define bM4_SPI2_SR_TDEF                          (*((volatile unsigned int*)(0x42388294UL)))
#define bM4_SPI2_SR_RDFF                          (*((volatile unsigned int*)(0x4238829CUL)))
#define bM4_SPI2_CFG2_CPHA                        (*((volatile unsigned int*)(0x42388300UL)))
#define bM4_SPI2_CFG2_CPOL                        (*((volatile unsigned int*)(0x42388304UL)))
#define bM4_SPI2_CFG2_MBR0                        (*((volatile unsigned int*)(0x42388308UL)))
#define bM4_SPI2_CFG2_MBR1                        (*((volatile unsigned int*)(0x4238830CUL)))
#define bM4_SPI2_CFG2_MBR2                        (*((volatile unsigned int*)(0x42388310UL)))
#define bM4_SPI2_CFG2_SSA0                        (*((volatile unsigned int*)(0x42388314UL)))
#define bM4_SPI2_CFG2_SSA1                        (*((volatile unsigned int*)(0x42388318UL)))
#define bM4_SPI2_CFG2_SSA2                        (*((volatile unsigned int*)(0x4238831CUL)))
#define bM4_SPI2_CFG2_DSIZE0                      (*((volatile unsigned int*)(0x42388320UL)))
#define bM4_SPI2_CFG2_DSIZE1                      (*((volatile unsigned int*)(0x42388324UL)))
#define bM4_SPI2_CFG2_DSIZE2                      (*((volatile unsigned int*)(0x42388328UL)))
#define bM4_SPI2_CFG2_DSIZE3                      (*((volatile unsigned int*)(0x4238832CUL)))
#define bM4_SPI2_CFG2_LSBF                        (*((volatile unsigned int*)(0x42388330UL)))
#define bM4_SPI2_CFG2_MIDIE                       (*((volatile unsigned int*)(0x42388334UL)))
#define bM4_SPI2_CFG2_MSSDLE                      (*((volatile unsigned int*)(0x42388338UL)))
#define bM4_SPI2_CFG2_MSSIE                       (*((volatile unsigned int*)(0x4238833CUL)))
#define bM4_SPI3_CR1_SPIMDS                       (*((volatile unsigned int*)(0x42400080UL)))
#define bM4_SPI3_CR1_TXMDS                        (*((volatile unsigned int*)(0x42400084UL)))
#define bM4_SPI3_CR1_MSTR                         (*((volatile unsigned int*)(0x4240008CUL)))
#define bM4_SPI3_CR1_SPLPBK                       (*((volatile unsigned int*)(0x42400090UL)))
#define bM4_SPI3_CR1_SPLPBK2                      (*((volatile unsigned int*)(0x42400094UL)))
#define bM4_SPI3_CR1_SPE                          (*((volatile unsigned int*)(0x42400098UL)))
#define bM4_SPI3_CR1_CSUSPE                       (*((volatile unsigned int*)(0x4240009CUL)))
#define bM4_SPI3_CR1_EIE                          (*((volatile unsigned int*)(0x424000A0UL)))
#define bM4_SPI3_CR1_TXIE                         (*((volatile unsigned int*)(0x424000A4UL)))
#define bM4_SPI3_CR1_RXIE                         (*((volatile unsigned int*)(0x424000A8UL)))
#define bM4_SPI3_CR1_IDIE                         (*((volatile unsigned int*)(0x424000ACUL)))
#define bM4_SPI3_CR1_MODFE                        (*((volatile unsigned int*)(0x424000B0UL)))
#define bM4_SPI3_CR1_PATE                         (*((volatile unsigned int*)(0x424000B4UL)))
#define bM4_SPI3_CR1_PAOE                         (*((volatile unsigned int*)(0x424000B8UL)))
#define bM4_SPI3_CR1_PAE                          (*((volatile unsigned int*)(0x424000BCUL)))
#define bM4_SPI3_CFG1_FTHLV0                      (*((volatile unsigned int*)(0x42400180UL)))
#define bM4_SPI3_CFG1_FTHLV1                      (*((volatile unsigned int*)(0x42400184UL)))
#define bM4_SPI3_CFG1_SPRDTD                      (*((volatile unsigned int*)(0x42400198UL)))
#define bM4_SPI3_CFG1_SS0PV                       (*((volatile unsigned int*)(0x424001A0UL)))
#define bM4_SPI3_CFG1_SS1PV                       (*((volatile unsigned int*)(0x424001A4UL)))
#define bM4_SPI3_CFG1_SS2PV                       (*((volatile unsigned int*)(0x424001A8UL)))
#define bM4_SPI3_CFG1_SS3PV                       (*((volatile unsigned int*)(0x424001ACUL)))
#define bM4_SPI3_CFG1_MSSI0                       (*((volatile unsigned int*)(0x424001D0UL)))
#define bM4_SPI3_CFG1_MSSI1                       (*((volatile unsigned int*)(0x424001D4UL)))
#define bM4_SPI3_CFG1_MSSI2                       (*((volatile unsigned int*)(0x424001D8UL)))
#define bM4_SPI3_CFG1_MSSDL0                      (*((volatile unsigned int*)(0x424001E0UL)))
#define bM4_SPI3_CFG1_MSSDL1                      (*((volatile unsigned int*)(0x424001E4UL)))
#define bM4_SPI3_CFG1_MSSDL2                      (*((volatile unsigned int*)(0x424001E8UL)))
#define bM4_SPI3_CFG1_MIDI0                       (*((volatile unsigned int*)(0x424001F0UL)))
#define bM4_SPI3_CFG1_MIDI1                       (*((volatile unsigned int*)(0x424001F4UL)))
#define bM4_SPI3_CFG1_MIDI2                       (*((volatile unsigned int*)(0x424001F8UL)))
#define bM4_SPI3_SR_OVRERF                        (*((volatile unsigned int*)(0x42400280UL)))
#define bM4_SPI3_SR_IDLNF                         (*((volatile unsigned int*)(0x42400284UL)))
#define bM4_SPI3_SR_MODFERF                       (*((volatile unsigned int*)(0x42400288UL)))
#define bM4_SPI3_SR_PERF                          (*((volatile unsigned int*)(0x4240028CUL)))
#define bM4_SPI3_SR_UDRERF                        (*((volatile unsigned int*)(0x42400290UL)))
#define bM4_SPI3_SR_TDEF                          (*((volatile unsigned int*)(0x42400294UL)))
#define bM4_SPI3_SR_RDFF                          (*((volatile unsigned int*)(0x4240029CUL)))
#define bM4_SPI3_CFG2_CPHA                        (*((volatile unsigned int*)(0x42400300UL)))
#define bM4_SPI3_CFG2_CPOL                        (*((volatile unsigned int*)(0x42400304UL)))
#define bM4_SPI3_CFG2_MBR0                        (*((volatile unsigned int*)(0x42400308UL)))
#define bM4_SPI3_CFG2_MBR1                        (*((volatile unsigned int*)(0x4240030CUL)))
#define bM4_SPI3_CFG2_MBR2                        (*((volatile unsigned int*)(0x42400310UL)))
#define bM4_SPI3_CFG2_SSA0                        (*((volatile unsigned int*)(0x42400314UL)))
#define bM4_SPI3_CFG2_SSA1                        (*((volatile unsigned int*)(0x42400318UL)))
#define bM4_SPI3_CFG2_SSA2                        (*((volatile unsigned int*)(0x4240031CUL)))
#define bM4_SPI3_CFG2_DSIZE0                      (*((volatile unsigned int*)(0x42400320UL)))
#define bM4_SPI3_CFG2_DSIZE1                      (*((volatile unsigned int*)(0x42400324UL)))
#define bM4_SPI3_CFG2_DSIZE2                      (*((volatile unsigned int*)(0x42400328UL)))
#define bM4_SPI3_CFG2_DSIZE3                      (*((volatile unsigned int*)(0x4240032CUL)))
#define bM4_SPI3_CFG2_LSBF                        (*((volatile unsigned int*)(0x42400330UL)))
#define bM4_SPI3_CFG2_MIDIE                       (*((volatile unsigned int*)(0x42400334UL)))
#define bM4_SPI3_CFG2_MSSDLE                      (*((volatile unsigned int*)(0x42400338UL)))
#define bM4_SPI3_CFG2_MSSIE                       (*((volatile unsigned int*)(0x4240033CUL)))
#define bM4_SPI4_CR1_SPIMDS                       (*((volatile unsigned int*)(0x42408080UL)))
#define bM4_SPI4_CR1_TXMDS                        (*((volatile unsigned int*)(0x42408084UL)))
#define bM4_SPI4_CR1_MSTR                         (*((volatile unsigned int*)(0x4240808CUL)))
#define bM4_SPI4_CR1_SPLPBK                       (*((volatile unsigned int*)(0x42408090UL)))
#define bM4_SPI4_CR1_SPLPBK2                      (*((volatile unsigned int*)(0x42408094UL)))
#define bM4_SPI4_CR1_SPE                          (*((volatile unsigned int*)(0x42408098UL)))
#define bM4_SPI4_CR1_CSUSPE                       (*((volatile unsigned int*)(0x4240809CUL)))
#define bM4_SPI4_CR1_EIE                          (*((volatile unsigned int*)(0x424080A0UL)))
#define bM4_SPI4_CR1_TXIE                         (*((volatile unsigned int*)(0x424080A4UL)))
#define bM4_SPI4_CR1_RXIE                         (*((volatile unsigned int*)(0x424080A8UL)))
#define bM4_SPI4_CR1_IDIE                         (*((volatile unsigned int*)(0x424080ACUL)))
#define bM4_SPI4_CR1_MODFE                        (*((volatile unsigned int*)(0x424080B0UL)))
#define bM4_SPI4_CR1_PATE                         (*((volatile unsigned int*)(0x424080B4UL)))
#define bM4_SPI4_CR1_PAOE                         (*((volatile unsigned int*)(0x424080B8UL)))
#define bM4_SPI4_CR1_PAE                          (*((volatile unsigned int*)(0x424080BCUL)))
#define bM4_SPI4_CFG1_FTHLV0                      (*((volatile unsigned int*)(0x42408180UL)))
#define bM4_SPI4_CFG1_FTHLV1                      (*((volatile unsigned int*)(0x42408184UL)))
#define bM4_SPI4_CFG1_SPRDTD                      (*((volatile unsigned int*)(0x42408198UL)))
#define bM4_SPI4_CFG1_SS0PV                       (*((volatile unsigned int*)(0x424081A0UL)))
#define bM4_SPI4_CFG1_SS1PV                       (*((volatile unsigned int*)(0x424081A4UL)))
#define bM4_SPI4_CFG1_SS2PV                       (*((volatile unsigned int*)(0x424081A8UL)))
#define bM4_SPI4_CFG1_SS3PV                       (*((volatile unsigned int*)(0x424081ACUL)))
#define bM4_SPI4_CFG1_MSSI0                       (*((volatile unsigned int*)(0x424081D0UL)))
#define bM4_SPI4_CFG1_MSSI1                       (*((volatile unsigned int*)(0x424081D4UL)))
#define bM4_SPI4_CFG1_MSSI2                       (*((volatile unsigned int*)(0x424081D8UL)))
#define bM4_SPI4_CFG1_MSSDL0                      (*((volatile unsigned int*)(0x424081E0UL)))
#define bM4_SPI4_CFG1_MSSDL1                      (*((volatile unsigned int*)(0x424081E4UL)))
#define bM4_SPI4_CFG1_MSSDL2                      (*((volatile unsigned int*)(0x424081E8UL)))
#define bM4_SPI4_CFG1_MIDI0                       (*((volatile unsigned int*)(0x424081F0UL)))
#define bM4_SPI4_CFG1_MIDI1                       (*((volatile unsigned int*)(0x424081F4UL)))
#define bM4_SPI4_CFG1_MIDI2                       (*((volatile unsigned int*)(0x424081F8UL)))
#define bM4_SPI4_SR_OVRERF                        (*((volatile unsigned int*)(0x42408280UL)))
#define bM4_SPI4_SR_IDLNF                         (*((volatile unsigned int*)(0x42408284UL)))
#define bM4_SPI4_SR_MODFERF                       (*((volatile unsigned int*)(0x42408288UL)))
#define bM4_SPI4_SR_PERF                          (*((volatile unsigned int*)(0x4240828CUL)))
#define bM4_SPI4_SR_UDRERF                        (*((volatile unsigned int*)(0x42408290UL)))
#define bM4_SPI4_SR_TDEF                          (*((volatile unsigned int*)(0x42408294UL)))
#define bM4_SPI4_SR_RDFF                          (*((volatile unsigned int*)(0x4240829CUL)))
#define bM4_SPI4_CFG2_CPHA                        (*((volatile unsigned int*)(0x42408300UL)))
#define bM4_SPI4_CFG2_CPOL                        (*((volatile unsigned int*)(0x42408304UL)))
#define bM4_SPI4_CFG2_MBR0                        (*((volatile unsigned int*)(0x42408308UL)))
#define bM4_SPI4_CFG2_MBR1                        (*((volatile unsigned int*)(0x4240830CUL)))
#define bM4_SPI4_CFG2_MBR2                        (*((volatile unsigned int*)(0x42408310UL)))
#define bM4_SPI4_CFG2_SSA0                        (*((volatile unsigned int*)(0x42408314UL)))
#define bM4_SPI4_CFG2_SSA1                        (*((volatile unsigned int*)(0x42408318UL)))
#define bM4_SPI4_CFG2_SSA2                        (*((volatile unsigned int*)(0x4240831CUL)))
#define bM4_SPI4_CFG2_DSIZE0                      (*((volatile unsigned int*)(0x42408320UL)))
#define bM4_SPI4_CFG2_DSIZE1                      (*((volatile unsigned int*)(0x42408324UL)))
#define bM4_SPI4_CFG2_DSIZE2                      (*((volatile unsigned int*)(0x42408328UL)))
#define bM4_SPI4_CFG2_DSIZE3                      (*((volatile unsigned int*)(0x4240832CUL)))
#define bM4_SPI4_CFG2_LSBF                        (*((volatile unsigned int*)(0x42408330UL)))
#define bM4_SPI4_CFG2_MIDIE                       (*((volatile unsigned int*)(0x42408334UL)))
#define bM4_SPI4_CFG2_MSSDLE                      (*((volatile unsigned int*)(0x42408338UL)))
#define bM4_SPI4_CFG2_MSSIE                       (*((volatile unsigned int*)(0x4240833CUL)))
#define bM4_SRAMC_WTCR_SRAM12_RWT0                (*((volatile unsigned int*)(0x42A10000UL)))
#define bM4_SRAMC_WTCR_SRAM12_RWT1                (*((volatile unsigned int*)(0x42A10004UL)))
#define bM4_SRAMC_WTCR_SRAM12_RWT2                (*((volatile unsigned int*)(0x42A10008UL)))
#define bM4_SRAMC_WTCR_SRAM12_WWT0                (*((volatile unsigned int*)(0x42A10010UL)))
#define bM4_SRAMC_WTCR_SRAM12_WWT1                (*((volatile unsigned int*)(0x42A10014UL)))
#define bM4_SRAMC_WTCR_SRAM12_WWT2                (*((volatile unsigned int*)(0x42A10018UL)))
#define bM4_SRAMC_WTCR_SRAM3_RWT0                 (*((volatile unsigned int*)(0x42A10020UL)))
#define bM4_SRAMC_WTCR_SRAM3_RWT1                 (*((volatile unsigned int*)(0x42A10024UL)))
#define bM4_SRAMC_WTCR_SRAM3_RWT2                 (*((volatile unsigned int*)(0x42A10028UL)))
#define bM4_SRAMC_WTCR_SRAM3_WWT0                 (*((volatile unsigned int*)(0x42A10030UL)))
#define bM4_SRAMC_WTCR_SRAM3_WWT1                 (*((volatile unsigned int*)(0x42A10034UL)))
#define bM4_SRAMC_WTCR_SRAM3_WWT2                 (*((volatile unsigned int*)(0x42A10038UL)))
#define bM4_SRAMC_WTCR_SRAMH_RWT0                 (*((volatile unsigned int*)(0x42A10040UL)))
#define bM4_SRAMC_WTCR_SRAMH_RWT1                 (*((volatile unsigned int*)(0x42A10044UL)))
#define bM4_SRAMC_WTCR_SRAMH_RWT2                 (*((volatile unsigned int*)(0x42A10048UL)))
#define bM4_SRAMC_WTCR_SRAMH_WWT0                 (*((volatile unsigned int*)(0x42A10050UL)))
#define bM4_SRAMC_WTCR_SRAMH_WWT1                 (*((volatile unsigned int*)(0x42A10054UL)))
#define bM4_SRAMC_WTCR_SRAMH_WWT2                 (*((volatile unsigned int*)(0x42A10058UL)))
#define bM4_SRAMC_WTCR_SRAMR_RWT0                 (*((volatile unsigned int*)(0x42A10060UL)))
#define bM4_SRAMC_WTCR_SRAMR_RWT1                 (*((volatile unsigned int*)(0x42A10064UL)))
#define bM4_SRAMC_WTCR_SRAMR_RWT2                 (*((volatile unsigned int*)(0x42A10068UL)))
#define bM4_SRAMC_WTCR_SRAMR_WWT0                 (*((volatile unsigned int*)(0x42A10070UL)))
#define bM4_SRAMC_WTCR_SRAMR_WWT1                 (*((volatile unsigned int*)(0x42A10074UL)))
#define bM4_SRAMC_WTCR_SRAMR_WWT2                 (*((volatile unsigned int*)(0x42A10078UL)))
#define bM4_SRAMC_WTPR_WTPRC                      (*((volatile unsigned int*)(0x42A10080UL)))
#define bM4_SRAMC_WTPR_WTPRKW0                    (*((volatile unsigned int*)(0x42A10084UL)))
#define bM4_SRAMC_WTPR_WTPRKW1                    (*((volatile unsigned int*)(0x42A10088UL)))
#define bM4_SRAMC_WTPR_WTPRKW2                    (*((volatile unsigned int*)(0x42A1008CUL)))
#define bM4_SRAMC_WTPR_WTPRKW3                    (*((volatile unsigned int*)(0x42A10090UL)))
#define bM4_SRAMC_WTPR_WTPRKW4                    (*((volatile unsigned int*)(0x42A10094UL)))
#define bM4_SRAMC_WTPR_WTPRKW5                    (*((volatile unsigned int*)(0x42A10098UL)))
#define bM4_SRAMC_WTPR_WTPRKW6                    (*((volatile unsigned int*)(0x42A1009CUL)))
#define bM4_SRAMC_CKCR_PYOAD                      (*((volatile unsigned int*)(0x42A10100UL)))
#define bM4_SRAMC_CKCR_ECCOAD                     (*((volatile unsigned int*)(0x42A10140UL)))
#define bM4_SRAMC_CKCR_ECCMOD0                    (*((volatile unsigned int*)(0x42A10160UL)))
#define bM4_SRAMC_CKCR_ECCMOD1                    (*((volatile unsigned int*)(0x42A10164UL)))
#define bM4_SRAMC_CKPR_CKPRC                      (*((volatile unsigned int*)(0x42A10180UL)))
#define bM4_SRAMC_CKPR_CKPRKW0                    (*((volatile unsigned int*)(0x42A10184UL)))
#define bM4_SRAMC_CKPR_CKPRKW1                    (*((volatile unsigned int*)(0x42A10188UL)))
#define bM4_SRAMC_CKPR_CKPRKW2                    (*((volatile unsigned int*)(0x42A1018CUL)))
#define bM4_SRAMC_CKPR_CKPRKW3                    (*((volatile unsigned int*)(0x42A10190UL)))
#define bM4_SRAMC_CKPR_CKPRKW4                    (*((volatile unsigned int*)(0x42A10194UL)))
#define bM4_SRAMC_CKPR_CKPRKW5                    (*((volatile unsigned int*)(0x42A10198UL)))
#define bM4_SRAMC_CKPR_CKPRKW6                    (*((volatile unsigned int*)(0x42A1019CUL)))
#define bM4_SRAMC_CKSR_SRAM3_1ERR                 (*((volatile unsigned int*)(0x42A10200UL)))
#define bM4_SRAMC_CKSR_SRAM3_2ERR                 (*((volatile unsigned int*)(0x42A10204UL)))
#define bM4_SRAMC_CKSR_SRAM12_PYERR               (*((volatile unsigned int*)(0x42A10208UL)))
#define bM4_SRAMC_CKSR_SRAMH_PYERR                (*((volatile unsigned int*)(0x42A1020CUL)))
#define bM4_SRAMC_CKSR_SRAMR_PYERR                (*((volatile unsigned int*)(0x42A10210UL)))
#define bM4_SWDT_SR_CNT0                          (*((volatile unsigned int*)(0x42928080UL)))
#define bM4_SWDT_SR_CNT1                          (*((volatile unsigned int*)(0x42928084UL)))
#define bM4_SWDT_SR_CNT2                          (*((volatile unsigned int*)(0x42928088UL)))
#define bM4_SWDT_SR_CNT3                          (*((volatile unsigned int*)(0x4292808CUL)))
#define bM4_SWDT_SR_CNT4                          (*((volatile unsigned int*)(0x42928090UL)))
#define bM4_SWDT_SR_CNT5                          (*((volatile unsigned int*)(0x42928094UL)))
#define bM4_SWDT_SR_CNT6                          (*((volatile unsigned int*)(0x42928098UL)))
#define bM4_SWDT_SR_CNT7                          (*((volatile unsigned int*)(0x4292809CUL)))
#define bM4_SWDT_SR_CNT8                          (*((volatile unsigned int*)(0x429280A0UL)))
#define bM4_SWDT_SR_CNT9                          (*((volatile unsigned int*)(0x429280A4UL)))
#define bM4_SWDT_SR_CNT10                         (*((volatile unsigned int*)(0x429280A8UL)))
#define bM4_SWDT_SR_CNT11                         (*((volatile unsigned int*)(0x429280ACUL)))
#define bM4_SWDT_SR_CNT12                         (*((volatile unsigned int*)(0x429280B0UL)))
#define bM4_SWDT_SR_CNT13                         (*((volatile unsigned int*)(0x429280B4UL)))
#define bM4_SWDT_SR_CNT14                         (*((volatile unsigned int*)(0x429280B8UL)))
#define bM4_SWDT_SR_CNT15                         (*((volatile unsigned int*)(0x429280BCUL)))
#define bM4_SWDT_SR_UDF                           (*((volatile unsigned int*)(0x429280C0UL)))
#define bM4_SWDT_SR_REF                           (*((volatile unsigned int*)(0x429280C4UL)))
#define bM4_SWDT_RR_RF0                           (*((volatile unsigned int*)(0x42928100UL)))
#define bM4_SWDT_RR_RF1                           (*((volatile unsigned int*)(0x42928104UL)))
#define bM4_SWDT_RR_RF2                           (*((volatile unsigned int*)(0x42928108UL)))
#define bM4_SWDT_RR_RF3                           (*((volatile unsigned int*)(0x4292810CUL)))
#define bM4_SWDT_RR_RF4                           (*((volatile unsigned int*)(0x42928110UL)))
#define bM4_SWDT_RR_RF5                           (*((volatile unsigned int*)(0x42928114UL)))
#define bM4_SWDT_RR_RF6                           (*((volatile unsigned int*)(0x42928118UL)))
#define bM4_SWDT_RR_RF7                           (*((volatile unsigned int*)(0x4292811CUL)))
#define bM4_SWDT_RR_RF8                           (*((volatile unsigned int*)(0x42928120UL)))
#define bM4_SWDT_RR_RF9                           (*((volatile unsigned int*)(0x42928124UL)))
#define bM4_SWDT_RR_RF10                          (*((volatile unsigned int*)(0x42928128UL)))
#define bM4_SWDT_RR_RF11                          (*((volatile unsigned int*)(0x4292812CUL)))
#define bM4_SWDT_RR_RF12                          (*((volatile unsigned int*)(0x42928130UL)))
#define bM4_SWDT_RR_RF13                          (*((volatile unsigned int*)(0x42928134UL)))
#define bM4_SWDT_RR_RF14                          (*((volatile unsigned int*)(0x42928138UL)))
#define bM4_SWDT_RR_RF15                          (*((volatile unsigned int*)(0x4292813CUL)))
#define bM4_SYSREG_PWR_STPMCR_FLNWT               (*((volatile unsigned int*)(0x42A80180UL)))
#define bM4_SYSREG_PWR_STPMCR_CKSMRC              (*((volatile unsigned int*)(0x42A80184UL)))
#define bM4_SYSREG_PWR_STPMCR_STOP                (*((volatile unsigned int*)(0x42A801BCUL)))
#define bM4_SYSREG_CMU_PERICKSEL_PERICKSEL0       (*((volatile unsigned int*)(0x42A80200UL)))
#define bM4_SYSREG_CMU_PERICKSEL_PERICKSEL1       (*((volatile unsigned int*)(0x42A80204UL)))
#define bM4_SYSREG_CMU_PERICKSEL_PERICKSEL2       (*((volatile unsigned int*)(0x42A80208UL)))
#define bM4_SYSREG_CMU_PERICKSEL_PERICKSEL3       (*((volatile unsigned int*)(0x42A8020CUL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S1CKSEL0        (*((volatile unsigned int*)(0x42A80240UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S1CKSEL1        (*((volatile unsigned int*)(0x42A80244UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S1CKSEL2        (*((volatile unsigned int*)(0x42A80248UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S1CKSEL3        (*((volatile unsigned int*)(0x42A8024CUL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S2CKSEL0        (*((volatile unsigned int*)(0x42A80250UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S2CKSEL1        (*((volatile unsigned int*)(0x42A80254UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S2CKSEL2        (*((volatile unsigned int*)(0x42A80258UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S2CKSEL3        (*((volatile unsigned int*)(0x42A8025CUL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S3CKSEL0        (*((volatile unsigned int*)(0x42A80260UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S3CKSEL1        (*((volatile unsigned int*)(0x42A80264UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S3CKSEL2        (*((volatile unsigned int*)(0x42A80268UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S3CKSEL3        (*((volatile unsigned int*)(0x42A8026CUL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S4CKSEL0        (*((volatile unsigned int*)(0x42A80270UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S4CKSEL1        (*((volatile unsigned int*)(0x42A80274UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S4CKSEL2        (*((volatile unsigned int*)(0x42A80278UL)))
#define bM4_SYSREG_CMU_I2SCKSEL_I2S4CKSEL3        (*((volatile unsigned int*)(0x42A8027CUL)))
#define bM4_SYSREG_PWR_RAMPC0_RAMPDC0             (*((volatile unsigned int*)(0x42A80280UL)))
#define bM4_SYSREG_PWR_RAMPC0_RAMPDC1             (*((volatile unsigned int*)(0x42A80284UL)))
#define bM4_SYSREG_PWR_RAMPC0_RAMPDC2             (*((volatile unsigned int*)(0x42A80288UL)))
#define bM4_SYSREG_PWR_RAMPC0_RAMPDC3             (*((volatile unsigned int*)(0x42A8028CUL)))
#define bM4_SYSREG_PWR_RAMPC0_RAMPDC4             (*((volatile unsigned int*)(0x42A80290UL)))
#define bM4_SYSREG_PWR_RAMPC0_RAMPDC5             (*((volatile unsigned int*)(0x42A80294UL)))
#define bM4_SYSREG_PWR_RAMPC0_RAMPDC6             (*((volatile unsigned int*)(0x42A80298UL)))
#define bM4_SYSREG_PWR_RAMPC0_RAMPDC7             (*((volatile unsigned int*)(0x42A8029CUL)))
#define bM4_SYSREG_PWR_RAMPC0_RAMPDC8             (*((volatile unsigned int*)(0x42A802A0UL)))
#define bM4_SYSREG_MPU_IPPR_AESRDP                (*((volatile unsigned int*)(0x42A80380UL)))
#define bM4_SYSREG_MPU_IPPR_AESWRP                (*((volatile unsigned int*)(0x42A80384UL)))
#define bM4_SYSREG_MPU_IPPR_HASHRDP               (*((volatile unsigned int*)(0x42A80388UL)))
#define bM4_SYSREG_MPU_IPPR_HASHWRP               (*((volatile unsigned int*)(0x42A8038CUL)))
#define bM4_SYSREG_MPU_IPPR_TRNGRDP               (*((volatile unsigned int*)(0x42A80390UL)))
#define bM4_SYSREG_MPU_IPPR_TRNGWRP               (*((volatile unsigned int*)(0x42A80394UL)))
#define bM4_SYSREG_MPU_IPPR_CRCRDP                (*((volatile unsigned int*)(0x42A80398UL)))
#define bM4_SYSREG_MPU_IPPR_CRCWRP                (*((volatile unsigned int*)(0x42A8039CUL)))
#define bM4_SYSREG_MPU_IPPR_FMCRDP                (*((volatile unsigned int*)(0x42A803A0UL)))
#define bM4_SYSREG_MPU_IPPR_FMCWRP                (*((volatile unsigned int*)(0x42A803A4UL)))
#define bM4_SYSREG_MPU_IPPR_WDTRDP                (*((volatile unsigned int*)(0x42A803B0UL)))
#define bM4_SYSREG_MPU_IPPR_WDTWRP                (*((volatile unsigned int*)(0x42A803B4UL)))
#define bM4_SYSREG_MPU_IPPR_SWDTRDP               (*((volatile unsigned int*)(0x42A803B8UL)))
#define bM4_SYSREG_MPU_IPPR_SWDTWRP               (*((volatile unsigned int*)(0x42A803BCUL)))
#define bM4_SYSREG_MPU_IPPR_BKSRAMRDP             (*((volatile unsigned int*)(0x42A803C0UL)))
#define bM4_SYSREG_MPU_IPPR_BKSRAMWRP             (*((volatile unsigned int*)(0x42A803C4UL)))
#define bM4_SYSREG_MPU_IPPR_RTCRDP                (*((volatile unsigned int*)(0x42A803C8UL)))
#define bM4_SYSREG_MPU_IPPR_RTCWRP                (*((volatile unsigned int*)(0x42A803CCUL)))
#define bM4_SYSREG_MPU_IPPR_DMPURDP               (*((volatile unsigned int*)(0x42A803D0UL)))
#define bM4_SYSREG_MPU_IPPR_DMPUWRP               (*((volatile unsigned int*)(0x42A803D4UL)))
#define bM4_SYSREG_MPU_IPPR_SRAMCRDP              (*((volatile unsigned int*)(0x42A803D8UL)))
#define bM4_SYSREG_MPU_IPPR_SRAMCWRP              (*((volatile unsigned int*)(0x42A803DCUL)))
#define bM4_SYSREG_MPU_IPPR_INTCRDP               (*((volatile unsigned int*)(0x42A803E0UL)))
#define bM4_SYSREG_MPU_IPPR_INTCWRP               (*((volatile unsigned int*)(0x42A803E4UL)))
#define bM4_SYSREG_MPU_IPPR_SYSCRDP               (*((volatile unsigned int*)(0x42A803E8UL)))
#define bM4_SYSREG_MPU_IPPR_SYSCWRP               (*((volatile unsigned int*)(0x42A803ECUL)))
#define bM4_SYSREG_MPU_IPPR_MSTPRDP               (*((volatile unsigned int*)(0x42A803F0UL)))
#define bM4_SYSREG_MPU_IPPR_MSTPWRP               (*((volatile unsigned int*)(0x42A803F4UL)))
#define bM4_SYSREG_MPU_IPPR_BUSERRE               (*((volatile unsigned int*)(0x42A803FCUL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK0S0              (*((volatile unsigned int*)(0x42A80400UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK0S1              (*((volatile unsigned int*)(0x42A80404UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK0S2              (*((volatile unsigned int*)(0x42A80408UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK1S0              (*((volatile unsigned int*)(0x42A80410UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK1S1              (*((volatile unsigned int*)(0x42A80414UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK1S2              (*((volatile unsigned int*)(0x42A80418UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK2S0              (*((volatile unsigned int*)(0x42A80420UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK2S1              (*((volatile unsigned int*)(0x42A80424UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK2S2              (*((volatile unsigned int*)(0x42A80428UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK3S0              (*((volatile unsigned int*)(0x42A80430UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK3S1              (*((volatile unsigned int*)(0x42A80434UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK3S2              (*((volatile unsigned int*)(0x42A80438UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK4S0              (*((volatile unsigned int*)(0x42A80440UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK4S1              (*((volatile unsigned int*)(0x42A80444UL)))
#define bM4_SYSREG_CMU_SCFGR_PCLK4S2              (*((volatile unsigned int*)(0x42A80448UL)))
#define bM4_SYSREG_CMU_SCFGR_EXCKS0               (*((volatile unsigned int*)(0x42A80450UL)))
#define bM4_SYSREG_CMU_SCFGR_EXCKS1               (*((volatile unsigned int*)(0x42A80454UL)))
#define bM4_SYSREG_CMU_SCFGR_EXCKS2               (*((volatile unsigned int*)(0x42A80458UL)))
#define bM4_SYSREG_CMU_SCFGR_HCLKS0               (*((volatile unsigned int*)(0x42A80460UL)))
#define bM4_SYSREG_CMU_SCFGR_HCLKS1               (*((volatile unsigned int*)(0x42A80464UL)))
#define bM4_SYSREG_CMU_SCFGR_HCLKS2               (*((volatile unsigned int*)(0x42A80468UL)))
#define bM4_SYSREG_CMU_UFSCKCFGR_USBCKS0          (*((volatile unsigned int*)(0x42A80490UL)))
#define bM4_SYSREG_CMU_UFSCKCFGR_USBCKS1          (*((volatile unsigned int*)(0x42A80494UL)))
#define bM4_SYSREG_CMU_UFSCKCFGR_USBCKS2          (*((volatile unsigned int*)(0x42A80498UL)))
#define bM4_SYSREG_CMU_UFSCKCFGR_USBCKS3          (*((volatile unsigned int*)(0x42A8049CUL)))
#define bM4_SYSREG_CMU_CKSWR_CKSW0                (*((volatile unsigned int*)(0x42A804C0UL)))
#define bM4_SYSREG_CMU_CKSWR_CKSW1                (*((volatile unsigned int*)(0x42A804C4UL)))
#define bM4_SYSREG_CMU_CKSWR_CKSW2                (*((volatile unsigned int*)(0x42A804C8UL)))
#define bM4_SYSREG_CMU_PLLCR_MPLLOFF              (*((volatile unsigned int*)(0x42A80540UL)))
#define bM4_SYSREG_CMU_UPLLCR_UPLLOFF             (*((volatile unsigned int*)(0x42A805C0UL)))
#define bM4_SYSREG_CMU_XTALCR_XTALSTP             (*((volatile unsigned int*)(0x42A80640UL)))
#define bM4_SYSREG_CMU_HRCCR_HRCSTP               (*((volatile unsigned int*)(0x42A806C0UL)))
#define bM4_SYSREG_CMU_MRCCR_MRCSTP               (*((volatile unsigned int*)(0x42A80700UL)))
#define bM4_SYSREG_CMU_OSCSTBSR_HRCSTBF           (*((volatile unsigned int*)(0x42A80780UL)))
#define bM4_SYSREG_CMU_OSCSTBSR_XTALSTBF          (*((volatile unsigned int*)(0x42A8078CUL)))
#define bM4_SYSREG_CMU_OSCSTBSR_MPLLSTBF          (*((volatile unsigned int*)(0x42A80794UL)))
#define bM4_SYSREG_CMU_OSCSTBSR_UPLLSTBF          (*((volatile unsigned int*)(0x42A80798UL)))
#define bM4_SYSREG_CMU_MCO1CFGR_MCO1SEL0          (*((volatile unsigned int*)(0x42A807A0UL)))
#define bM4_SYSREG_CMU_MCO1CFGR_MCO1SEL1          (*((volatile unsigned int*)(0x42A807A4UL)))
#define bM4_SYSREG_CMU_MCO1CFGR_MCO1SEL2          (*((volatile unsigned int*)(0x42A807A8UL)))
#define bM4_SYSREG_CMU_MCO1CFGR_MCO1SEL3          (*((volatile unsigned int*)(0x42A807ACUL)))
#define bM4_SYSREG_CMU_MCO1CFGR_MCO1DIV0          (*((volatile unsigned int*)(0x42A807B0UL)))
#define bM4_SYSREG_CMU_MCO1CFGR_MCO1DIV1          (*((volatile unsigned int*)(0x42A807B4UL)))
#define bM4_SYSREG_CMU_MCO1CFGR_MCO1DIV2          (*((volatile unsigned int*)(0x42A807B8UL)))
#define bM4_SYSREG_CMU_MCO1CFGR_MCO1EN            (*((volatile unsigned int*)(0x42A807BCUL)))
#define bM4_SYSREG_CMU_MCO2CFGR_MCO2SEL0          (*((volatile unsigned int*)(0x42A807C0UL)))
#define bM4_SYSREG_CMU_MCO2CFGR_MCO2SEL1          (*((volatile unsigned int*)(0x42A807C4UL)))
#define bM4_SYSREG_CMU_MCO2CFGR_MCO2SEL2          (*((volatile unsigned int*)(0x42A807C8UL)))
#define bM4_SYSREG_CMU_MCO2CFGR_MCO2SEL3          (*((volatile unsigned int*)(0x42A807CCUL)))
#define bM4_SYSREG_CMU_MCO2CFGR_MCO2DIV0          (*((volatile unsigned int*)(0x42A807D0UL)))
#define bM4_SYSREG_CMU_MCO2CFGR_MCO2DIV1          (*((volatile unsigned int*)(0x42A807D4UL)))
#define bM4_SYSREG_CMU_MCO2CFGR_MCO2DIV2          (*((volatile unsigned int*)(0x42A807D8UL)))
#define bM4_SYSREG_CMU_MCO2CFGR_MCO2EN            (*((volatile unsigned int*)(0x42A807DCUL)))
#define bM4_SYSREG_CMU_TPIUCKCFGR_TPIUCKS0        (*((volatile unsigned int*)(0x42A807E0UL)))
#define bM4_SYSREG_CMU_TPIUCKCFGR_TPIUCKS1        (*((volatile unsigned int*)(0x42A807E4UL)))
#define bM4_SYSREG_CMU_TPIUCKCFGR_TPIUCKOE        (*((volatile unsigned int*)(0x42A807FCUL)))
#define bM4_SYSREG_CMU_XTALSTDCR_XTALSTDIE        (*((volatile unsigned int*)(0x42A80800UL)))
#define bM4_SYSREG_CMU_XTALSTDCR_XTALSTDRE        (*((volatile unsigned int*)(0x42A80804UL)))
#define bM4_SYSREG_CMU_XTALSTDCR_XTALSTDRIS       (*((volatile unsigned int*)(0x42A80808UL)))
#define bM4_SYSREG_CMU_XTALSTDCR_XTALSTDE         (*((volatile unsigned int*)(0x42A8081CUL)))
#define bM4_SYSREG_CMU_XTALSTDSR_XTALSTDF         (*((volatile unsigned int*)(0x42A80820UL)))
#define bM4_SYSREG_CMU_XTALSTBCR_XTALSTB0         (*((volatile unsigned int*)(0x42A81440UL)))
#define bM4_SYSREG_CMU_XTALSTBCR_XTALSTB1         (*((volatile unsigned int*)(0x42A81444UL)))
#define bM4_SYSREG_CMU_XTALSTBCR_XTALSTB2         (*((volatile unsigned int*)(0x42A81448UL)))
#define bM4_SYSREG_CMU_XTALSTBCR_XTALSTB3         (*((volatile unsigned int*)(0x42A8144CUL)))
#define bM4_SYSREG_RMU_RSTF0_PORF                 (*((volatile unsigned int*)(0x42A81800UL)))
#define bM4_SYSREG_RMU_RSTF0_PINRF                (*((volatile unsigned int*)(0x42A81804UL)))
#define bM4_SYSREG_RMU_RSTF0_BORF                 (*((volatile unsigned int*)(0x42A81808UL)))
#define bM4_SYSREG_RMU_RSTF0_PVD1RF               (*((volatile unsigned int*)(0x42A8180CUL)))
#define bM4_SYSREG_RMU_RSTF0_PVD2RF               (*((volatile unsigned int*)(0x42A81810UL)))
#define bM4_SYSREG_RMU_RSTF0_WDRF                 (*((volatile unsigned int*)(0x42A81814UL)))
#define bM4_SYSREG_RMU_RSTF0_SWDRF                (*((volatile unsigned int*)(0x42A81818UL)))
#define bM4_SYSREG_RMU_RSTF0_PDRF                 (*((volatile unsigned int*)(0x42A8181CUL)))
#define bM4_SYSREG_RMU_RSTF0_SWRF                 (*((volatile unsigned int*)(0x42A81820UL)))
#define bM4_SYSREG_RMU_RSTF0_MPUERF               (*((volatile unsigned int*)(0x42A81824UL)))
#define bM4_SYSREG_RMU_RSTF0_RAPERF               (*((volatile unsigned int*)(0x42A81828UL)))
#define bM4_SYSREG_RMU_RSTF0_RAECRF               (*((volatile unsigned int*)(0x42A8182CUL)))
#define bM4_SYSREG_RMU_RSTF0_CKFERF               (*((volatile unsigned int*)(0x42A81830UL)))
#define bM4_SYSREG_RMU_RSTF0_XTALERF              (*((volatile unsigned int*)(0x42A81834UL)))
#define bM4_SYSREG_RMU_RSTF0_MULTIRF              (*((volatile unsigned int*)(0x42A81838UL)))
#define bM4_SYSREG_RMU_RSTF0_CLRF                 (*((volatile unsigned int*)(0x42A8183CUL)))
#define bM4_SYSREG_PWR_PVDICR_PVD1NMIS            (*((volatile unsigned int*)(0x42A81C00UL)))
#define bM4_SYSREG_PWR_PVDICR_PVD2NMIS            (*((volatile unsigned int*)(0x42A81C10UL)))
#define bM4_SYSREG_PWR_PVDDSR_PVD1MON             (*((volatile unsigned int*)(0x42A81C20UL)))
#define bM4_SYSREG_PWR_PVDDSR_PVD1DETFLG          (*((volatile unsigned int*)(0x42A81C24UL)))
#define bM4_SYSREG_PWR_PVDDSR_PVD2MON             (*((volatile unsigned int*)(0x42A81C30UL)))
#define bM4_SYSREG_PWR_PVDDSR_PVD2DETFLG          (*((volatile unsigned int*)(0x42A81C34UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLM0             (*((volatile unsigned int*)(0x42A82000UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLM1             (*((volatile unsigned int*)(0x42A82004UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLM2             (*((volatile unsigned int*)(0x42A82008UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLM3             (*((volatile unsigned int*)(0x42A8200CUL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLM4             (*((volatile unsigned int*)(0x42A82010UL)))
#define bM4_SYSREG_CMU_PLLCFGR_PLLSRC             (*((volatile unsigned int*)(0x42A8201CUL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLN0             (*((volatile unsigned int*)(0x42A82020UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLN1             (*((volatile unsigned int*)(0x42A82024UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLN2             (*((volatile unsigned int*)(0x42A82028UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLN3             (*((volatile unsigned int*)(0x42A8202CUL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLN4             (*((volatile unsigned int*)(0x42A82030UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLN5             (*((volatile unsigned int*)(0x42A82034UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLN6             (*((volatile unsigned int*)(0x42A82038UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLN7             (*((volatile unsigned int*)(0x42A8203CUL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLN8             (*((volatile unsigned int*)(0x42A82040UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLR0             (*((volatile unsigned int*)(0x42A82050UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLR1             (*((volatile unsigned int*)(0x42A82054UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLR2             (*((volatile unsigned int*)(0x42A82058UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLR3             (*((volatile unsigned int*)(0x42A8205CUL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLQ0             (*((volatile unsigned int*)(0x42A82060UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLQ1             (*((volatile unsigned int*)(0x42A82064UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLQ2             (*((volatile unsigned int*)(0x42A82068UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLQ3             (*((volatile unsigned int*)(0x42A8206CUL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLP0             (*((volatile unsigned int*)(0x42A82070UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLP1             (*((volatile unsigned int*)(0x42A82074UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLP2             (*((volatile unsigned int*)(0x42A82078UL)))
#define bM4_SYSREG_CMU_PLLCFGR_MPLLP3             (*((volatile unsigned int*)(0x42A8207CUL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLM0            (*((volatile unsigned int*)(0x42A82080UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLM1            (*((volatile unsigned int*)(0x42A82084UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLM2            (*((volatile unsigned int*)(0x42A82088UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLM3            (*((volatile unsigned int*)(0x42A8208CUL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLM4            (*((volatile unsigned int*)(0x42A82090UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLN0            (*((volatile unsigned int*)(0x42A820A0UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLN1            (*((volatile unsigned int*)(0x42A820A4UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLN2            (*((volatile unsigned int*)(0x42A820A8UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLN3            (*((volatile unsigned int*)(0x42A820ACUL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLN4            (*((volatile unsigned int*)(0x42A820B0UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLN5            (*((volatile unsigned int*)(0x42A820B4UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLN6            (*((volatile unsigned int*)(0x42A820B8UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLN7            (*((volatile unsigned int*)(0x42A820BCUL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLN8            (*((volatile unsigned int*)(0x42A820C0UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLR0            (*((volatile unsigned int*)(0x42A820D0UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLR1            (*((volatile unsigned int*)(0x42A820D4UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLR2            (*((volatile unsigned int*)(0x42A820D8UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLR3            (*((volatile unsigned int*)(0x42A820DCUL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLQ0            (*((volatile unsigned int*)(0x42A820E0UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLQ1            (*((volatile unsigned int*)(0x42A820E4UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLQ2            (*((volatile unsigned int*)(0x42A820E8UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLQ3            (*((volatile unsigned int*)(0x42A820ECUL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLP0            (*((volatile unsigned int*)(0x42A820F0UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLP1            (*((volatile unsigned int*)(0x42A820F4UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLP2            (*((volatile unsigned int*)(0x42A820F8UL)))
#define bM4_SYSREG_CMU_UPLLCFGR_UPLLP3            (*((volatile unsigned int*)(0x42A820FCUL)))
#define bM4_SYSREG_PWR_FPRC_FPRCB0                (*((volatile unsigned int*)(0x42A87FC0UL)))
#define bM4_SYSREG_PWR_FPRC_FPRCB1                (*((volatile unsigned int*)(0x42A87FC4UL)))
#define bM4_SYSREG_PWR_FPRC_FPRCB2                (*((volatile unsigned int*)(0x42A87FC8UL)))
#define bM4_SYSREG_PWR_FPRC_FPRCB3                (*((volatile unsigned int*)(0x42A87FCCUL)))
#define bM4_SYSREG_PWR_FPRC_FPRCWE0               (*((volatile unsigned int*)(0x42A87FE0UL)))
#define bM4_SYSREG_PWR_FPRC_FPRCWE1               (*((volatile unsigned int*)(0x42A87FE4UL)))
#define bM4_SYSREG_PWR_FPRC_FPRCWE2               (*((volatile unsigned int*)(0x42A87FE8UL)))
#define bM4_SYSREG_PWR_FPRC_FPRCWE3               (*((volatile unsigned int*)(0x42A87FECUL)))
#define bM4_SYSREG_PWR_FPRC_FPRCWE4               (*((volatile unsigned int*)(0x42A87FF0UL)))
#define bM4_SYSREG_PWR_FPRC_FPRCWE5               (*((volatile unsigned int*)(0x42A87FF4UL)))
#define bM4_SYSREG_PWR_FPRC_FPRCWE6               (*((volatile unsigned int*)(0x42A87FF8UL)))
#define bM4_SYSREG_PWR_FPRC_FPRCWE7               (*((volatile unsigned int*)(0x42A87FFCUL)))
#define bM4_SYSREG_PWR_PWRC0_PDMDS0               (*((volatile unsigned int*)(0x42A88000UL)))
#define bM4_SYSREG_PWR_PWRC0_PDMDS1               (*((volatile unsigned int*)(0x42A88004UL)))
#define bM4_SYSREG_PWR_PWRC0_VVDRSD               (*((volatile unsigned int*)(0x42A88008UL)))
#define bM4_SYSREG_PWR_PWRC0_RETRAMSD             (*((volatile unsigned int*)(0x42A8800CUL)))
#define bM4_SYSREG_PWR_PWRC0_IORTN0               (*((volatile unsigned int*)(0x42A88010UL)))
#define bM4_SYSREG_PWR_PWRC0_IORTN1               (*((volatile unsigned int*)(0x42A88014UL)))
#define bM4_SYSREG_PWR_PWRC0_PWDN                 (*((volatile unsigned int*)(0x42A8801CUL)))
#define bM4_SYSREG_PWR_PWRC1_VPLLSD               (*((volatile unsigned int*)(0x42A88020UL)))
#define bM4_SYSREG_PWR_PWRC1_VHRCSD               (*((volatile unsigned int*)(0x42A88024UL)))
#define bM4_SYSREG_PWR_PWRC1_STPDAS0              (*((volatile unsigned int*)(0x42A88038UL)))
#define bM4_SYSREG_PWR_PWRC1_STPDAS1              (*((volatile unsigned int*)(0x42A8803CUL)))
#define bM4_SYSREG_PWR_PWRC2_DDAS0                (*((volatile unsigned int*)(0x42A88040UL)))
#define bM4_SYSREG_PWR_PWRC2_DDAS1                (*((volatile unsigned int*)(0x42A88044UL)))
#define bM4_SYSREG_PWR_PWRC2_DDAS2                (*((volatile unsigned int*)(0x42A88048UL)))
#define bM4_SYSREG_PWR_PWRC2_DDAS3                (*((volatile unsigned int*)(0x42A8804CUL)))
#define bM4_SYSREG_PWR_PWRC2_DVS0                 (*((volatile unsigned int*)(0x42A88050UL)))
#define bM4_SYSREG_PWR_PWRC2_DVS1                 (*((volatile unsigned int*)(0x42A88054UL)))
#define bM4_SYSREG_PWR_PWRC3_PDTS                 (*((volatile unsigned int*)(0x42A88068UL)))
#define bM4_SYSREG_PWR_PDWKE0_WKE00               (*((volatile unsigned int*)(0x42A88080UL)))
#define bM4_SYSREG_PWR_PDWKE0_WKE01               (*((volatile unsigned int*)(0x42A88084UL)))
#define bM4_SYSREG_PWR_PDWKE0_WKE02               (*((volatile unsigned int*)(0x42A88088UL)))
#define bM4_SYSREG_PWR_PDWKE0_WKE03               (*((volatile unsigned int*)(0x42A8808CUL)))
#define bM4_SYSREG_PWR_PDWKE0_WKE10               (*((volatile unsigned int*)(0x42A88090UL)))
#define bM4_SYSREG_PWR_PDWKE0_WKE11               (*((volatile unsigned int*)(0x42A88094UL)))
#define bM4_SYSREG_PWR_PDWKE0_WKE12               (*((volatile unsigned int*)(0x42A88098UL)))
#define bM4_SYSREG_PWR_PDWKE0_WKE13               (*((volatile unsigned int*)(0x42A8809CUL)))
#define bM4_SYSREG_PWR_PDWKE1_WKE20               (*((volatile unsigned int*)(0x42A880A0UL)))
#define bM4_SYSREG_PWR_PDWKE1_WKE21               (*((volatile unsigned int*)(0x42A880A4UL)))
#define bM4_SYSREG_PWR_PDWKE1_WKE22               (*((volatile unsigned int*)(0x42A880A8UL)))
#define bM4_SYSREG_PWR_PDWKE1_WKE23               (*((volatile unsigned int*)(0x42A880ACUL)))
#define bM4_SYSREG_PWR_PDWKE1_WKE30               (*((volatile unsigned int*)(0x42A880B0UL)))
#define bM4_SYSREG_PWR_PDWKE1_WKE31               (*((volatile unsigned int*)(0x42A880B4UL)))
#define bM4_SYSREG_PWR_PDWKE1_WKE32               (*((volatile unsigned int*)(0x42A880B8UL)))
#define bM4_SYSREG_PWR_PDWKE1_WKE33               (*((volatile unsigned int*)(0x42A880BCUL)))
#define bM4_SYSREG_PWR_PDWKE2_VD1WKE              (*((volatile unsigned int*)(0x42A880C0UL)))
#define bM4_SYSREG_PWR_PDWKE2_VD2WKE              (*((volatile unsigned int*)(0x42A880C4UL)))
#define bM4_SYSREG_PWR_PDWKE2_NMIWKE              (*((volatile unsigned int*)(0x42A880C8UL)))
#define bM4_SYSREG_PWR_PDWKE2_RTCPRDWKE           (*((volatile unsigned int*)(0x42A880D0UL)))
#define bM4_SYSREG_PWR_PDWKE2_RTCALMWKE           (*((volatile unsigned int*)(0x42A880D4UL)))
#define bM4_SYSREG_PWR_PDWKE2_WKTMWKE             (*((volatile unsigned int*)(0x42A880DCUL)))
#define bM4_SYSREG_PWR_PDWKES_WK0EGS              (*((volatile unsigned int*)(0x42A880E0UL)))
#define bM4_SYSREG_PWR_PDWKES_WK1EGS              (*((volatile unsigned int*)(0x42A880E4UL)))
#define bM4_SYSREG_PWR_PDWKES_WK2EGS              (*((volatile unsigned int*)(0x42A880E8UL)))
#define bM4_SYSREG_PWR_PDWKES_WK3EGS              (*((volatile unsigned int*)(0x42A880ECUL)))
#define bM4_SYSREG_PWR_PDWKES_VD1EGS              (*((volatile unsigned int*)(0x42A880F0UL)))
#define bM4_SYSREG_PWR_PDWKES_VD2EGS              (*((volatile unsigned int*)(0x42A880F4UL)))
#define bM4_SYSREG_PWR_PDWKES_NMIEGS              (*((volatile unsigned int*)(0x42A880F8UL)))
#define bM4_SYSREG_PWR_PDWKF0_PTWK0F              (*((volatile unsigned int*)(0x42A88100UL)))
#define bM4_SYSREG_PWR_PDWKF0_PTWK1F              (*((volatile unsigned int*)(0x42A88104UL)))
#define bM4_SYSREG_PWR_PDWKF0_PTWK2F              (*((volatile unsigned int*)(0x42A88108UL)))
#define bM4_SYSREG_PWR_PDWKF0_PTWK3F              (*((volatile unsigned int*)(0x42A8810CUL)))
#define bM4_SYSREG_PWR_PDWKF0_VD1WKF              (*((volatile unsigned int*)(0x42A88110UL)))
#define bM4_SYSREG_PWR_PDWKF0_VD2WKF              (*((volatile unsigned int*)(0x42A88114UL)))
#define bM4_SYSREG_PWR_PDWKF0_NMIWKF              (*((volatile unsigned int*)(0x42A88118UL)))
#define bM4_SYSREG_PWR_PDWKF1_RTCPRDWKF           (*((volatile unsigned int*)(0x42A88130UL)))
#define bM4_SYSREG_PWR_PDWKF1_RTCALMWKF           (*((volatile unsigned int*)(0x42A88134UL)))
#define bM4_SYSREG_PWR_PDWKF1_WKTMWKF             (*((volatile unsigned int*)(0x42A8813CUL)))
#define bM4_SYSREG_PWR_PWCMR_ADBUFE               (*((volatile unsigned int*)(0x42A8815CUL)))
#define bM4_SYSREG_CMU_XTALCFGR_XTALDRV0          (*((volatile unsigned int*)(0x42A88210UL)))
#define bM4_SYSREG_CMU_XTALCFGR_XTALDRV1          (*((volatile unsigned int*)(0x42A88214UL)))
#define bM4_SYSREG_CMU_XTALCFGR_XTALMS            (*((volatile unsigned int*)(0x42A88218UL)))
#define bM4_SYSREG_CMU_XTALCFGR_SUPDRV            (*((volatile unsigned int*)(0x42A8821CUL)))
#define bM4_SYSREG_PWR_PVDCR0_EXVCCINEN           (*((volatile unsigned int*)(0x42A88240UL)))
#define bM4_SYSREG_PWR_PVDCR0_PVD1EN              (*((volatile unsigned int*)(0x42A88254UL)))
#define bM4_SYSREG_PWR_PVDCR0_PVD2EN              (*((volatile unsigned int*)(0x42A88258UL)))
#define bM4_SYSREG_PWR_PVDCR1_PVD1IRE             (*((volatile unsigned int*)(0x42A88260UL)))
#define bM4_SYSREG_PWR_PVDCR1_PVD1IRS             (*((volatile unsigned int*)(0x42A88264UL)))
#define bM4_SYSREG_PWR_PVDCR1_PVD1CMPOE           (*((volatile unsigned int*)(0x42A88268UL)))
#define bM4_SYSREG_PWR_PVDCR1_PVD2IRE             (*((volatile unsigned int*)(0x42A88270UL)))
#define bM4_SYSREG_PWR_PVDCR1_PVD2IRS             (*((volatile unsigned int*)(0x42A88274UL)))
#define bM4_SYSREG_PWR_PVDCR1_PVD2CMPOE           (*((volatile unsigned int*)(0x42A88278UL)))
#define bM4_SYSREG_PWR_PVDFCR_PVD1NFDIS           (*((volatile unsigned int*)(0x42A88280UL)))
#define bM4_SYSREG_PWR_PVDFCR_PVD1NFCKS0          (*((volatile unsigned int*)(0x42A88284UL)))
#define bM4_SYSREG_PWR_PVDFCR_PVD1NFCKS1          (*((volatile unsigned int*)(0x42A88288UL)))
#define bM4_SYSREG_PWR_PVDFCR_PVD2NFDIS           (*((volatile unsigned int*)(0x42A88290UL)))
#define bM4_SYSREG_PWR_PVDFCR_PVD2NFCKS0          (*((volatile unsigned int*)(0x42A88294UL)))
#define bM4_SYSREG_PWR_PVDFCR_PVD2NFCKS1          (*((volatile unsigned int*)(0x42A88298UL)))
#define bM4_SYSREG_PWR_PVDLCR_PVD1LVL0            (*((volatile unsigned int*)(0x42A882A0UL)))
#define bM4_SYSREG_PWR_PVDLCR_PVD1LVL1            (*((volatile unsigned int*)(0x42A882A4UL)))
#define bM4_SYSREG_PWR_PVDLCR_PVD1LVL2            (*((volatile unsigned int*)(0x42A882A8UL)))
#define bM4_SYSREG_PWR_PVDLCR_PVD2LVL0            (*((volatile unsigned int*)(0x42A882B0UL)))
#define bM4_SYSREG_PWR_PVDLCR_PVD2LVL1            (*((volatile unsigned int*)(0x42A882B4UL)))
#define bM4_SYSREG_PWR_PVDLCR_PVD2LVL2            (*((volatile unsigned int*)(0x42A882B8UL)))
#define bM4_SYSREG_CMU_XTAL32CR_XTAL32STP         (*((volatile unsigned int*)(0x42A88400UL)))
#define bM4_SYSREG_CMU_XTAL32CFGR_XTAL32DRV0      (*((volatile unsigned int*)(0x42A88420UL)))
#define bM4_SYSREG_CMU_XTAL32CFGR_XTAL32DRV1      (*((volatile unsigned int*)(0x42A88424UL)))
#define bM4_SYSREG_CMU_XTAL32CFGR_XTAL32DRV2      (*((volatile unsigned int*)(0x42A88428UL)))
#define bM4_SYSREG_CMU_XTAL32NFR_XTAL32NF0        (*((volatile unsigned int*)(0x42A884A0UL)))
#define bM4_SYSREG_CMU_XTAL32NFR_XTAL32NF1        (*((volatile unsigned int*)(0x42A884A4UL)))
#define bM4_SYSREG_CMU_LRCCR_LRCSTP               (*((volatile unsigned int*)(0x42A884E0UL)))
#define bM4_SYSREG_PWR_XTAL32CS_CSDIS             (*((volatile unsigned int*)(0x42A8857CUL)))
#define bM4_TMR01_CNTAR_CNTA0                     (*((volatile unsigned int*)(0x42480000UL)))
#define bM4_TMR01_CNTAR_CNTA1                     (*((volatile unsigned int*)(0x42480004UL)))
#define bM4_TMR01_CNTAR_CNTA2                     (*((volatile unsigned int*)(0x42480008UL)))
#define bM4_TMR01_CNTAR_CNTA3                     (*((volatile unsigned int*)(0x4248000CUL)))
#define bM4_TMR01_CNTAR_CNTA4                     (*((volatile unsigned int*)(0x42480010UL)))
#define bM4_TMR01_CNTAR_CNTA5                     (*((volatile unsigned int*)(0x42480014UL)))
#define bM4_TMR01_CNTAR_CNTA6                     (*((volatile unsigned int*)(0x42480018UL)))
#define bM4_TMR01_CNTAR_CNTA7                     (*((volatile unsigned int*)(0x4248001CUL)))
#define bM4_TMR01_CNTAR_CNTA8                     (*((volatile unsigned int*)(0x42480020UL)))
#define bM4_TMR01_CNTAR_CNTA9                     (*((volatile unsigned int*)(0x42480024UL)))
#define bM4_TMR01_CNTAR_CNTA10                    (*((volatile unsigned int*)(0x42480028UL)))
#define bM4_TMR01_CNTAR_CNTA11                    (*((volatile unsigned int*)(0x4248002CUL)))
#define bM4_TMR01_CNTAR_CNTA12                    (*((volatile unsigned int*)(0x42480030UL)))
#define bM4_TMR01_CNTAR_CNTA13                    (*((volatile unsigned int*)(0x42480034UL)))
#define bM4_TMR01_CNTAR_CNTA14                    (*((volatile unsigned int*)(0x42480038UL)))
#define bM4_TMR01_CNTAR_CNTA15                    (*((volatile unsigned int*)(0x4248003CUL)))
#define bM4_TMR01_CNTBR_CNTB0                     (*((volatile unsigned int*)(0x42480080UL)))
#define bM4_TMR01_CNTBR_CNTB1                     (*((volatile unsigned int*)(0x42480084UL)))
#define bM4_TMR01_CNTBR_CNTB2                     (*((volatile unsigned int*)(0x42480088UL)))
#define bM4_TMR01_CNTBR_CNTB3                     (*((volatile unsigned int*)(0x4248008CUL)))
#define bM4_TMR01_CNTBR_CNTB4                     (*((volatile unsigned int*)(0x42480090UL)))
#define bM4_TMR01_CNTBR_CNTB5                     (*((volatile unsigned int*)(0x42480094UL)))
#define bM4_TMR01_CNTBR_CNTB6                     (*((volatile unsigned int*)(0x42480098UL)))
#define bM4_TMR01_CNTBR_CNTB7                     (*((volatile unsigned int*)(0x4248009CUL)))
#define bM4_TMR01_CNTBR_CNTB8                     (*((volatile unsigned int*)(0x424800A0UL)))
#define bM4_TMR01_CNTBR_CNTB9                     (*((volatile unsigned int*)(0x424800A4UL)))
#define bM4_TMR01_CNTBR_CNTB10                    (*((volatile unsigned int*)(0x424800A8UL)))
#define bM4_TMR01_CNTBR_CNTB11                    (*((volatile unsigned int*)(0x424800ACUL)))
#define bM4_TMR01_CNTBR_CNTB12                    (*((volatile unsigned int*)(0x424800B0UL)))
#define bM4_TMR01_CNTBR_CNTB13                    (*((volatile unsigned int*)(0x424800B4UL)))
#define bM4_TMR01_CNTBR_CNTB14                    (*((volatile unsigned int*)(0x424800B8UL)))
#define bM4_TMR01_CNTBR_CNTB15                    (*((volatile unsigned int*)(0x424800BCUL)))
#define bM4_TMR01_CMPAR_CMPA0                     (*((volatile unsigned int*)(0x42480100UL)))
#define bM4_TMR01_CMPAR_CMPA1                     (*((volatile unsigned int*)(0x42480104UL)))
#define bM4_TMR01_CMPAR_CMPA2                     (*((volatile unsigned int*)(0x42480108UL)))
#define bM4_TMR01_CMPAR_CMPA3                     (*((volatile unsigned int*)(0x4248010CUL)))
#define bM4_TMR01_CMPAR_CMPA4                     (*((volatile unsigned int*)(0x42480110UL)))
#define bM4_TMR01_CMPAR_CMPA5                     (*((volatile unsigned int*)(0x42480114UL)))
#define bM4_TMR01_CMPAR_CMPA6                     (*((volatile unsigned int*)(0x42480118UL)))
#define bM4_TMR01_CMPAR_CMPA7                     (*((volatile unsigned int*)(0x4248011CUL)))
#define bM4_TMR01_CMPAR_CMPA8                     (*((volatile unsigned int*)(0x42480120UL)))
#define bM4_TMR01_CMPAR_CMPA9                     (*((volatile unsigned int*)(0x42480124UL)))
#define bM4_TMR01_CMPAR_CMPA10                    (*((volatile unsigned int*)(0x42480128UL)))
#define bM4_TMR01_CMPAR_CMPA11                    (*((volatile unsigned int*)(0x4248012CUL)))
#define bM4_TMR01_CMPAR_CMPA12                    (*((volatile unsigned int*)(0x42480130UL)))
#define bM4_TMR01_CMPAR_CMPA13                    (*((volatile unsigned int*)(0x42480134UL)))
#define bM4_TMR01_CMPAR_CMPA14                    (*((volatile unsigned int*)(0x42480138UL)))
#define bM4_TMR01_CMPAR_CMPA15                    (*((volatile unsigned int*)(0x4248013CUL)))
#define bM4_TMR01_CMPBR_CMPB0                     (*((volatile unsigned int*)(0x42480180UL)))
#define bM4_TMR01_CMPBR_CMPB1                     (*((volatile unsigned int*)(0x42480184UL)))
#define bM4_TMR01_CMPBR_CMPB2                     (*((volatile unsigned int*)(0x42480188UL)))
#define bM4_TMR01_CMPBR_CMPB3                     (*((volatile unsigned int*)(0x4248018CUL)))
#define bM4_TMR01_CMPBR_CMPB4                     (*((volatile unsigned int*)(0x42480190UL)))
#define bM4_TMR01_CMPBR_CMPB5                     (*((volatile unsigned int*)(0x42480194UL)))
#define bM4_TMR01_CMPBR_CMPB6                     (*((volatile unsigned int*)(0x42480198UL)))
#define bM4_TMR01_CMPBR_CMPB7                     (*((volatile unsigned int*)(0x4248019CUL)))
#define bM4_TMR01_CMPBR_CMPB8                     (*((volatile unsigned int*)(0x424801A0UL)))
#define bM4_TMR01_CMPBR_CMPB9                     (*((volatile unsigned int*)(0x424801A4UL)))
#define bM4_TMR01_CMPBR_CMPB10                    (*((volatile unsigned int*)(0x424801A8UL)))
#define bM4_TMR01_CMPBR_CMPB11                    (*((volatile unsigned int*)(0x424801ACUL)))
#define bM4_TMR01_CMPBR_CMPB12                    (*((volatile unsigned int*)(0x424801B0UL)))
#define bM4_TMR01_CMPBR_CMPB13                    (*((volatile unsigned int*)(0x424801B4UL)))
#define bM4_TMR01_CMPBR_CMPB14                    (*((volatile unsigned int*)(0x424801B8UL)))
#define bM4_TMR01_CMPBR_CMPB15                    (*((volatile unsigned int*)(0x424801BCUL)))
#define bM4_TMR01_BCONR_CSTA                      (*((volatile unsigned int*)(0x42480200UL)))
#define bM4_TMR01_BCONR_CAPMDA                    (*((volatile unsigned int*)(0x42480204UL)))
#define bM4_TMR01_BCONR_INTENA                    (*((volatile unsigned int*)(0x42480208UL)))
#define bM4_TMR01_BCONR_CKDIVA0                   (*((volatile unsigned int*)(0x42480210UL)))
#define bM4_TMR01_BCONR_CKDIVA1                   (*((volatile unsigned int*)(0x42480214UL)))
#define bM4_TMR01_BCONR_CKDIVA2                   (*((volatile unsigned int*)(0x42480218UL)))
#define bM4_TMR01_BCONR_CKDIVA3                   (*((volatile unsigned int*)(0x4248021CUL)))
#define bM4_TMR01_BCONR_SYNSA                     (*((volatile unsigned int*)(0x42480220UL)))
#define bM4_TMR01_BCONR_SYNCLKA                   (*((volatile unsigned int*)(0x42480224UL)))
#define bM4_TMR01_BCONR_ASYNCLKA                  (*((volatile unsigned int*)(0x42480228UL)))
#define bM4_TMR01_BCONR_HSTAA                     (*((volatile unsigned int*)(0x42480230UL)))
#define bM4_TMR01_BCONR_HSTPA                     (*((volatile unsigned int*)(0x42480234UL)))
#define bM4_TMR01_BCONR_HCLEA                     (*((volatile unsigned int*)(0x42480238UL)))
#define bM4_TMR01_BCONR_HICPA                     (*((volatile unsigned int*)(0x4248023CUL)))
#define bM4_TMR01_BCONR_CSTB                      (*((volatile unsigned int*)(0x42480240UL)))
#define bM4_TMR01_BCONR_CAPMDB                    (*((volatile unsigned int*)(0x42480244UL)))
#define bM4_TMR01_BCONR_INTENB                    (*((volatile unsigned int*)(0x42480248UL)))
#define bM4_TMR01_BCONR_CKDIVB0                   (*((volatile unsigned int*)(0x42480250UL)))
#define bM4_TMR01_BCONR_CKDIVB1                   (*((volatile unsigned int*)(0x42480254UL)))
#define bM4_TMR01_BCONR_CKDIVB2                   (*((volatile unsigned int*)(0x42480258UL)))
#define bM4_TMR01_BCONR_CKDIVB3                   (*((volatile unsigned int*)(0x4248025CUL)))
#define bM4_TMR01_BCONR_SYNSB                     (*((volatile unsigned int*)(0x42480260UL)))
#define bM4_TMR01_BCONR_SYNCLKB                   (*((volatile unsigned int*)(0x42480264UL)))
#define bM4_TMR01_BCONR_ASYNCLKB                  (*((volatile unsigned int*)(0x42480268UL)))
#define bM4_TMR01_BCONR_HSTAB                     (*((volatile unsigned int*)(0x42480270UL)))
#define bM4_TMR01_BCONR_HSTPB                     (*((volatile unsigned int*)(0x42480274UL)))
#define bM4_TMR01_BCONR_HCLEB                     (*((volatile unsigned int*)(0x42480278UL)))
#define bM4_TMR01_BCONR_HICPB                     (*((volatile unsigned int*)(0x4248027CUL)))
#define bM4_TMR01_STFLR_CMAF                      (*((volatile unsigned int*)(0x42480280UL)))
#define bM4_TMR01_STFLR_CMBF                      (*((volatile unsigned int*)(0x424802C0UL)))
#define bM4_TMR02_CNTAR_CNTA0                     (*((volatile unsigned int*)(0x42488000UL)))
#define bM4_TMR02_CNTAR_CNTA1                     (*((volatile unsigned int*)(0x42488004UL)))
#define bM4_TMR02_CNTAR_CNTA2                     (*((volatile unsigned int*)(0x42488008UL)))
#define bM4_TMR02_CNTAR_CNTA3                     (*((volatile unsigned int*)(0x4248800CUL)))
#define bM4_TMR02_CNTAR_CNTA4                     (*((volatile unsigned int*)(0x42488010UL)))
#define bM4_TMR02_CNTAR_CNTA5                     (*((volatile unsigned int*)(0x42488014UL)))
#define bM4_TMR02_CNTAR_CNTA6                     (*((volatile unsigned int*)(0x42488018UL)))
#define bM4_TMR02_CNTAR_CNTA7                     (*((volatile unsigned int*)(0x4248801CUL)))
#define bM4_TMR02_CNTAR_CNTA8                     (*((volatile unsigned int*)(0x42488020UL)))
#define bM4_TMR02_CNTAR_CNTA9                     (*((volatile unsigned int*)(0x42488024UL)))
#define bM4_TMR02_CNTAR_CNTA10                    (*((volatile unsigned int*)(0x42488028UL)))
#define bM4_TMR02_CNTAR_CNTA11                    (*((volatile unsigned int*)(0x4248802CUL)))
#define bM4_TMR02_CNTAR_CNTA12                    (*((volatile unsigned int*)(0x42488030UL)))
#define bM4_TMR02_CNTAR_CNTA13                    (*((volatile unsigned int*)(0x42488034UL)))
#define bM4_TMR02_CNTAR_CNTA14                    (*((volatile unsigned int*)(0x42488038UL)))
#define bM4_TMR02_CNTAR_CNTA15                    (*((volatile unsigned int*)(0x4248803CUL)))
#define bM4_TMR02_CNTBR_CNTB0                     (*((volatile unsigned int*)(0x42488080UL)))
#define bM4_TMR02_CNTBR_CNTB1                     (*((volatile unsigned int*)(0x42488084UL)))
#define bM4_TMR02_CNTBR_CNTB2                     (*((volatile unsigned int*)(0x42488088UL)))
#define bM4_TMR02_CNTBR_CNTB3                     (*((volatile unsigned int*)(0x4248808CUL)))
#define bM4_TMR02_CNTBR_CNTB4                     (*((volatile unsigned int*)(0x42488090UL)))
#define bM4_TMR02_CNTBR_CNTB5                     (*((volatile unsigned int*)(0x42488094UL)))
#define bM4_TMR02_CNTBR_CNTB6                     (*((volatile unsigned int*)(0x42488098UL)))
#define bM4_TMR02_CNTBR_CNTB7                     (*((volatile unsigned int*)(0x4248809CUL)))
#define bM4_TMR02_CNTBR_CNTB8                     (*((volatile unsigned int*)(0x424880A0UL)))
#define bM4_TMR02_CNTBR_CNTB9                     (*((volatile unsigned int*)(0x424880A4UL)))
#define bM4_TMR02_CNTBR_CNTB10                    (*((volatile unsigned int*)(0x424880A8UL)))
#define bM4_TMR02_CNTBR_CNTB11                    (*((volatile unsigned int*)(0x424880ACUL)))
#define bM4_TMR02_CNTBR_CNTB12                    (*((volatile unsigned int*)(0x424880B0UL)))
#define bM4_TMR02_CNTBR_CNTB13                    (*((volatile unsigned int*)(0x424880B4UL)))
#define bM4_TMR02_CNTBR_CNTB14                    (*((volatile unsigned int*)(0x424880B8UL)))
#define bM4_TMR02_CNTBR_CNTB15                    (*((volatile unsigned int*)(0x424880BCUL)))
#define bM4_TMR02_CMPAR_CMPA0                     (*((volatile unsigned int*)(0x42488100UL)))
#define bM4_TMR02_CMPAR_CMPA1                     (*((volatile unsigned int*)(0x42488104UL)))
#define bM4_TMR02_CMPAR_CMPA2                     (*((volatile unsigned int*)(0x42488108UL)))
#define bM4_TMR02_CMPAR_CMPA3                     (*((volatile unsigned int*)(0x4248810CUL)))
#define bM4_TMR02_CMPAR_CMPA4                     (*((volatile unsigned int*)(0x42488110UL)))
#define bM4_TMR02_CMPAR_CMPA5                     (*((volatile unsigned int*)(0x42488114UL)))
#define bM4_TMR02_CMPAR_CMPA6                     (*((volatile unsigned int*)(0x42488118UL)))
#define bM4_TMR02_CMPAR_CMPA7                     (*((volatile unsigned int*)(0x4248811CUL)))
#define bM4_TMR02_CMPAR_CMPA8                     (*((volatile unsigned int*)(0x42488120UL)))
#define bM4_TMR02_CMPAR_CMPA9                     (*((volatile unsigned int*)(0x42488124UL)))
#define bM4_TMR02_CMPAR_CMPA10                    (*((volatile unsigned int*)(0x42488128UL)))
#define bM4_TMR02_CMPAR_CMPA11                    (*((volatile unsigned int*)(0x4248812CUL)))
#define bM4_TMR02_CMPAR_CMPA12                    (*((volatile unsigned int*)(0x42488130UL)))
#define bM4_TMR02_CMPAR_CMPA13                    (*((volatile unsigned int*)(0x42488134UL)))
#define bM4_TMR02_CMPAR_CMPA14                    (*((volatile unsigned int*)(0x42488138UL)))
#define bM4_TMR02_CMPAR_CMPA15                    (*((volatile unsigned int*)(0x4248813CUL)))
#define bM4_TMR02_CMPBR_CMPB0                     (*((volatile unsigned int*)(0x42488180UL)))
#define bM4_TMR02_CMPBR_CMPB1                     (*((volatile unsigned int*)(0x42488184UL)))
#define bM4_TMR02_CMPBR_CMPB2                     (*((volatile unsigned int*)(0x42488188UL)))
#define bM4_TMR02_CMPBR_CMPB3                     (*((volatile unsigned int*)(0x4248818CUL)))
#define bM4_TMR02_CMPBR_CMPB4                     (*((volatile unsigned int*)(0x42488190UL)))
#define bM4_TMR02_CMPBR_CMPB5                     (*((volatile unsigned int*)(0x42488194UL)))
#define bM4_TMR02_CMPBR_CMPB6                     (*((volatile unsigned int*)(0x42488198UL)))
#define bM4_TMR02_CMPBR_CMPB7                     (*((volatile unsigned int*)(0x4248819CUL)))
#define bM4_TMR02_CMPBR_CMPB8                     (*((volatile unsigned int*)(0x424881A0UL)))
#define bM4_TMR02_CMPBR_CMPB9                     (*((volatile unsigned int*)(0x424881A4UL)))
#define bM4_TMR02_CMPBR_CMPB10                    (*((volatile unsigned int*)(0x424881A8UL)))
#define bM4_TMR02_CMPBR_CMPB11                    (*((volatile unsigned int*)(0x424881ACUL)))
#define bM4_TMR02_CMPBR_CMPB12                    (*((volatile unsigned int*)(0x424881B0UL)))
#define bM4_TMR02_CMPBR_CMPB13                    (*((volatile unsigned int*)(0x424881B4UL)))
#define bM4_TMR02_CMPBR_CMPB14                    (*((volatile unsigned int*)(0x424881B8UL)))
#define bM4_TMR02_CMPBR_CMPB15                    (*((volatile unsigned int*)(0x424881BCUL)))
#define bM4_TMR02_BCONR_CSTA                      (*((volatile unsigned int*)(0x42488200UL)))
#define bM4_TMR02_BCONR_CAPMDA                    (*((volatile unsigned int*)(0x42488204UL)))
#define bM4_TMR02_BCONR_INTENA                    (*((volatile unsigned int*)(0x42488208UL)))
#define bM4_TMR02_BCONR_CKDIVA0                   (*((volatile unsigned int*)(0x42488210UL)))
#define bM4_TMR02_BCONR_CKDIVA1                   (*((volatile unsigned int*)(0x42488214UL)))
#define bM4_TMR02_BCONR_CKDIVA2                   (*((volatile unsigned int*)(0x42488218UL)))
#define bM4_TMR02_BCONR_CKDIVA3                   (*((volatile unsigned int*)(0x4248821CUL)))
#define bM4_TMR02_BCONR_SYNSA                     (*((volatile unsigned int*)(0x42488220UL)))
#define bM4_TMR02_BCONR_SYNCLKA                   (*((volatile unsigned int*)(0x42488224UL)))
#define bM4_TMR02_BCONR_ASYNCLKA                  (*((volatile unsigned int*)(0x42488228UL)))
#define bM4_TMR02_BCONR_HSTAA                     (*((volatile unsigned int*)(0x42488230UL)))
#define bM4_TMR02_BCONR_HSTPA                     (*((volatile unsigned int*)(0x42488234UL)))
#define bM4_TMR02_BCONR_HCLEA                     (*((volatile unsigned int*)(0x42488238UL)))
#define bM4_TMR02_BCONR_HICPA                     (*((volatile unsigned int*)(0x4248823CUL)))
#define bM4_TMR02_BCONR_CSTB                      (*((volatile unsigned int*)(0x42488240UL)))
#define bM4_TMR02_BCONR_CAPMDB                    (*((volatile unsigned int*)(0x42488244UL)))
#define bM4_TMR02_BCONR_INTENB                    (*((volatile unsigned int*)(0x42488248UL)))
#define bM4_TMR02_BCONR_CKDIVB0                   (*((volatile unsigned int*)(0x42488250UL)))
#define bM4_TMR02_BCONR_CKDIVB1                   (*((volatile unsigned int*)(0x42488254UL)))
#define bM4_TMR02_BCONR_CKDIVB2                   (*((volatile unsigned int*)(0x42488258UL)))
#define bM4_TMR02_BCONR_CKDIVB3                   (*((volatile unsigned int*)(0x4248825CUL)))
#define bM4_TMR02_BCONR_SYNSB                     (*((volatile unsigned int*)(0x42488260UL)))
#define bM4_TMR02_BCONR_SYNCLKB                   (*((volatile unsigned int*)(0x42488264UL)))
#define bM4_TMR02_BCONR_ASYNCLKB                  (*((volatile unsigned int*)(0x42488268UL)))
#define bM4_TMR02_BCONR_HSTAB                     (*((volatile unsigned int*)(0x42488270UL)))
#define bM4_TMR02_BCONR_HSTPB                     (*((volatile unsigned int*)(0x42488274UL)))
#define bM4_TMR02_BCONR_HCLEB                     (*((volatile unsigned int*)(0x42488278UL)))
#define bM4_TMR02_BCONR_HICPB                     (*((volatile unsigned int*)(0x4248827CUL)))
#define bM4_TMR02_STFLR_CMAF                      (*((volatile unsigned int*)(0x42488280UL)))
#define bM4_TMR02_STFLR_CMBF                      (*((volatile unsigned int*)(0x424882C0UL)))
#define bM4_TMR41_OCSRU_OCEH                      (*((volatile unsigned int*)(0x422E0300UL)))
#define bM4_TMR41_OCSRU_OCEL                      (*((volatile unsigned int*)(0x422E0304UL)))
#define bM4_TMR41_OCSRU_OCPH                      (*((volatile unsigned int*)(0x422E0308UL)))
#define bM4_TMR41_OCSRU_OCPL                      (*((volatile unsigned int*)(0x422E030CUL)))
#define bM4_TMR41_OCSRU_OCIEH                     (*((volatile unsigned int*)(0x422E0310UL)))
#define bM4_TMR41_OCSRU_OCIEL                     (*((volatile unsigned int*)(0x422E0314UL)))
#define bM4_TMR41_OCSRU_OCFH                      (*((volatile unsigned int*)(0x422E0318UL)))
#define bM4_TMR41_OCSRU_OCFL                      (*((volatile unsigned int*)(0x422E031CUL)))
#define bM4_TMR41_OCERU_CHBUFEN0                  (*((volatile unsigned int*)(0x422E0340UL)))
#define bM4_TMR41_OCERU_CHBUFEN1                  (*((volatile unsigned int*)(0x422E0344UL)))
#define bM4_TMR41_OCERU_CLBUFEN0                  (*((volatile unsigned int*)(0x422E0348UL)))
#define bM4_TMR41_OCERU_CLBUFEN1                  (*((volatile unsigned int*)(0x422E034CUL)))
#define bM4_TMR41_OCERU_MHBUFEN0                  (*((volatile unsigned int*)(0x422E0350UL)))
#define bM4_TMR41_OCERU_MHBUFEN1                  (*((volatile unsigned int*)(0x422E0354UL)))
#define bM4_TMR41_OCERU_MLBUFEN0                  (*((volatile unsigned int*)(0x422E0358UL)))
#define bM4_TMR41_OCERU_MLBUFEN1                  (*((volatile unsigned int*)(0x422E035CUL)))
#define bM4_TMR41_OCERU_LMCH                      (*((volatile unsigned int*)(0x422E0360UL)))
#define bM4_TMR41_OCERU_LMCL                      (*((volatile unsigned int*)(0x422E0364UL)))
#define bM4_TMR41_OCERU_LMMH                      (*((volatile unsigned int*)(0x422E0368UL)))
#define bM4_TMR41_OCERU_LMML                      (*((volatile unsigned int*)(0x422E036CUL)))
#define bM4_TMR41_OCERU_MCECH                     (*((volatile unsigned int*)(0x422E0370UL)))
#define bM4_TMR41_OCERU_MCECL                     (*((volatile unsigned int*)(0x422E0374UL)))
#define bM4_TMR41_OCSRV_OCEH                      (*((volatile unsigned int*)(0x422E0380UL)))
#define bM4_TMR41_OCSRV_OCEL                      (*((volatile unsigned int*)(0x422E0384UL)))
#define bM4_TMR41_OCSRV_OCPH                      (*((volatile unsigned int*)(0x422E0388UL)))
#define bM4_TMR41_OCSRV_OCPL                      (*((volatile unsigned int*)(0x422E038CUL)))
#define bM4_TMR41_OCSRV_OCIEH                     (*((volatile unsigned int*)(0x422E0390UL)))
#define bM4_TMR41_OCSRV_OCIEL                     (*((volatile unsigned int*)(0x422E0394UL)))
#define bM4_TMR41_OCSRV_OCFH                      (*((volatile unsigned int*)(0x422E0398UL)))
#define bM4_TMR41_OCSRV_OCFL                      (*((volatile unsigned int*)(0x422E039CUL)))
#define bM4_TMR41_OCERV_CHBUFEN0                  (*((volatile unsigned int*)(0x422E03C0UL)))
#define bM4_TMR41_OCERV_CHBUFEN1                  (*((volatile unsigned int*)(0x422E03C4UL)))
#define bM4_TMR41_OCERV_CLBUFEN0                  (*((volatile unsigned int*)(0x422E03C8UL)))
#define bM4_TMR41_OCERV_CLBUFEN1                  (*((volatile unsigned int*)(0x422E03CCUL)))
#define bM4_TMR41_OCERV_MHBUFEN0                  (*((volatile unsigned int*)(0x422E03D0UL)))
#define bM4_TMR41_OCERV_MHBUFEN1                  (*((volatile unsigned int*)(0x422E03D4UL)))
#define bM4_TMR41_OCERV_MLBUFEN0                  (*((volatile unsigned int*)(0x422E03D8UL)))
#define bM4_TMR41_OCERV_MLBUFEN1                  (*((volatile unsigned int*)(0x422E03DCUL)))
#define bM4_TMR41_OCERV_LMCH                      (*((volatile unsigned int*)(0x422E03E0UL)))
#define bM4_TMR41_OCERV_LMCL                      (*((volatile unsigned int*)(0x422E03E4UL)))
#define bM4_TMR41_OCERV_LMMH                      (*((volatile unsigned int*)(0x422E03E8UL)))
#define bM4_TMR41_OCERV_LMML                      (*((volatile unsigned int*)(0x422E03ECUL)))
#define bM4_TMR41_OCERV_MCECH                     (*((volatile unsigned int*)(0x422E03F0UL)))
#define bM4_TMR41_OCERV_MCECL                     (*((volatile unsigned int*)(0x422E03F4UL)))
#define bM4_TMR41_OCSRW_OCEH                      (*((volatile unsigned int*)(0x422E0400UL)))
#define bM4_TMR41_OCSRW_OCEL                      (*((volatile unsigned int*)(0x422E0404UL)))
#define bM4_TMR41_OCSRW_OCPH                      (*((volatile unsigned int*)(0x422E0408UL)))
#define bM4_TMR41_OCSRW_OCPL                      (*((volatile unsigned int*)(0x422E040CUL)))
#define bM4_TMR41_OCSRW_OCIEH                     (*((volatile unsigned int*)(0x422E0410UL)))
#define bM4_TMR41_OCSRW_OCIEL                     (*((volatile unsigned int*)(0x422E0414UL)))
#define bM4_TMR41_OCSRW_OCFH                      (*((volatile unsigned int*)(0x422E0418UL)))
#define bM4_TMR41_OCSRW_OCFL                      (*((volatile unsigned int*)(0x422E041CUL)))
#define bM4_TMR41_OCERW_CHBUFEN0                  (*((volatile unsigned int*)(0x422E0440UL)))
#define bM4_TMR41_OCERW_CHBUFEN1                  (*((volatile unsigned int*)(0x422E0444UL)))
#define bM4_TMR41_OCERW_CLBUFEN0                  (*((volatile unsigned int*)(0x422E0448UL)))
#define bM4_TMR41_OCERW_CLBUFEN1                  (*((volatile unsigned int*)(0x422E044CUL)))
#define bM4_TMR41_OCERW_MHBUFEN0                  (*((volatile unsigned int*)(0x422E0450UL)))
#define bM4_TMR41_OCERW_MHBUFEN1                  (*((volatile unsigned int*)(0x422E0454UL)))
#define bM4_TMR41_OCERW_MLBUFEN0                  (*((volatile unsigned int*)(0x422E0458UL)))
#define bM4_TMR41_OCERW_MLBUFEN1                  (*((volatile unsigned int*)(0x422E045CUL)))
#define bM4_TMR41_OCERW_LMCH                      (*((volatile unsigned int*)(0x422E0460UL)))
#define bM4_TMR41_OCERW_LMCL                      (*((volatile unsigned int*)(0x422E0464UL)))
#define bM4_TMR41_OCERW_LMMH                      (*((volatile unsigned int*)(0x422E0468UL)))
#define bM4_TMR41_OCERW_LMML                      (*((volatile unsigned int*)(0x422E046CUL)))
#define bM4_TMR41_OCERW_MCECH                     (*((volatile unsigned int*)(0x422E0470UL)))
#define bM4_TMR41_OCERW_MCECL                     (*((volatile unsigned int*)(0x422E0474UL)))
#define bM4_TMR41_OCMRHUH_OCFDCH                  (*((volatile unsigned int*)(0x422E0480UL)))
#define bM4_TMR41_OCMRHUH_OCFPKH                  (*((volatile unsigned int*)(0x422E0484UL)))
#define bM4_TMR41_OCMRHUH_OCFUCH                  (*((volatile unsigned int*)(0x422E0488UL)))
#define bM4_TMR41_OCMRHUH_OCFZRH                  (*((volatile unsigned int*)(0x422E048CUL)))
#define bM4_TMR41_OCMRHUH_OPDCH0                  (*((volatile unsigned int*)(0x422E0490UL)))
#define bM4_TMR41_OCMRHUH_OPDCH1                  (*((volatile unsigned int*)(0x422E0494UL)))
#define bM4_TMR41_OCMRHUH_OPPKH0                  (*((volatile unsigned int*)(0x422E0498UL)))
#define bM4_TMR41_OCMRHUH_OPPKH1                  (*((volatile unsigned int*)(0x422E049CUL)))
#define bM4_TMR41_OCMRHUH_OPUCH0                  (*((volatile unsigned int*)(0x422E04A0UL)))
#define bM4_TMR41_OCMRHUH_OPUCH1                  (*((volatile unsigned int*)(0x422E04A4UL)))
#define bM4_TMR41_OCMRHUH_OPZRH0                  (*((volatile unsigned int*)(0x422E04A8UL)))
#define bM4_TMR41_OCMRHUH_OPZRH1                  (*((volatile unsigned int*)(0x422E04ACUL)))
#define bM4_TMR41_OCMRHUH_OPNPKH0                 (*((volatile unsigned int*)(0x422E04B0UL)))
#define bM4_TMR41_OCMRHUH_OPNPKH1                 (*((volatile unsigned int*)(0x422E04B4UL)))
#define bM4_TMR41_OCMRHUH_OPNZRH0                 (*((volatile unsigned int*)(0x422E04B8UL)))
#define bM4_TMR41_OCMRHUH_OPNZRH1                 (*((volatile unsigned int*)(0x422E04BCUL)))
#define bM4_TMR41_OCMRLUL_OCFDCL                  (*((volatile unsigned int*)(0x422E0500UL)))
#define bM4_TMR41_OCMRLUL_OCFPKL                  (*((volatile unsigned int*)(0x422E0504UL)))
#define bM4_TMR41_OCMRLUL_OCFUCL                  (*((volatile unsigned int*)(0x422E0508UL)))
#define bM4_TMR41_OCMRLUL_OCFZRL                  (*((volatile unsigned int*)(0x422E050CUL)))
#define bM4_TMR41_OCMRLUL_OPDCL0                  (*((volatile unsigned int*)(0x422E0510UL)))
#define bM4_TMR41_OCMRLUL_OPDCL1                  (*((volatile unsigned int*)(0x422E0514UL)))
#define bM4_TMR41_OCMRLUL_OPPKL0                  (*((volatile unsigned int*)(0x422E0518UL)))
#define bM4_TMR41_OCMRLUL_OPPKL1                  (*((volatile unsigned int*)(0x422E051CUL)))
#define bM4_TMR41_OCMRLUL_OPUCL0                  (*((volatile unsigned int*)(0x422E0520UL)))
#define bM4_TMR41_OCMRLUL_OPUCL1                  (*((volatile unsigned int*)(0x422E0524UL)))
#define bM4_TMR41_OCMRLUL_OPZRL0                  (*((volatile unsigned int*)(0x422E0528UL)))
#define bM4_TMR41_OCMRLUL_OPZRL1                  (*((volatile unsigned int*)(0x422E052CUL)))
#define bM4_TMR41_OCMRLUL_OPNPKL0                 (*((volatile unsigned int*)(0x422E0530UL)))
#define bM4_TMR41_OCMRLUL_OPNPKL1                 (*((volatile unsigned int*)(0x422E0534UL)))
#define bM4_TMR41_OCMRLUL_OPNZRL0                 (*((volatile unsigned int*)(0x422E0538UL)))
#define bM4_TMR41_OCMRLUL_OPNZRL1                 (*((volatile unsigned int*)(0x422E053CUL)))
#define bM4_TMR41_OCMRLUL_EOPNDCL0                (*((volatile unsigned int*)(0x422E0540UL)))
#define bM4_TMR41_OCMRLUL_EOPNDCL1                (*((volatile unsigned int*)(0x422E0544UL)))
#define bM4_TMR41_OCMRLUL_EOPNUCL0                (*((volatile unsigned int*)(0x422E0548UL)))
#define bM4_TMR41_OCMRLUL_EOPNUCL1                (*((volatile unsigned int*)(0x422E054CUL)))
#define bM4_TMR41_OCMRLUL_EOPDCL0                 (*((volatile unsigned int*)(0x422E0550UL)))
#define bM4_TMR41_OCMRLUL_EOPDCL1                 (*((volatile unsigned int*)(0x422E0554UL)))
#define bM4_TMR41_OCMRLUL_EOPPKL0                 (*((volatile unsigned int*)(0x422E0558UL)))
#define bM4_TMR41_OCMRLUL_EOPPKL1                 (*((volatile unsigned int*)(0x422E055CUL)))
#define bM4_TMR41_OCMRLUL_EOPUCL0                 (*((volatile unsigned int*)(0x422E0560UL)))
#define bM4_TMR41_OCMRLUL_EOPUCL1                 (*((volatile unsigned int*)(0x422E0564UL)))
#define bM4_TMR41_OCMRLUL_EOPZRL0                 (*((volatile unsigned int*)(0x422E0568UL)))
#define bM4_TMR41_OCMRLUL_EOPZRL1                 (*((volatile unsigned int*)(0x422E056CUL)))
#define bM4_TMR41_OCMRLUL_EOPNPKL0                (*((volatile unsigned int*)(0x422E0570UL)))
#define bM4_TMR41_OCMRLUL_EOPNPKL1                (*((volatile unsigned int*)(0x422E0574UL)))
#define bM4_TMR41_OCMRLUL_EOPNZRL0                (*((volatile unsigned int*)(0x422E0578UL)))
#define bM4_TMR41_OCMRLUL_EOPNZRL1                (*((volatile unsigned int*)(0x422E057CUL)))
#define bM4_TMR41_OCMRHVH_OCFDCH                  (*((volatile unsigned int*)(0x422E0580UL)))
#define bM4_TMR41_OCMRHVH_OCFPKH                  (*((volatile unsigned int*)(0x422E0584UL)))
#define bM4_TMR41_OCMRHVH_OCFUCH                  (*((volatile unsigned int*)(0x422E0588UL)))
#define bM4_TMR41_OCMRHVH_OCFZRH                  (*((volatile unsigned int*)(0x422E058CUL)))
#define bM4_TMR41_OCMRHVH_OPDCH0                  (*((volatile unsigned int*)(0x422E0590UL)))
#define bM4_TMR41_OCMRHVH_OPDCH1                  (*((volatile unsigned int*)(0x422E0594UL)))
#define bM4_TMR41_OCMRHVH_OPPKH0                  (*((volatile unsigned int*)(0x422E0598UL)))
#define bM4_TMR41_OCMRHVH_OPPKH1                  (*((volatile unsigned int*)(0x422E059CUL)))
#define bM4_TMR41_OCMRHVH_OPUCH0                  (*((volatile unsigned int*)(0x422E05A0UL)))
#define bM4_TMR41_OCMRHVH_OPUCH1                  (*((volatile unsigned int*)(0x422E05A4UL)))
#define bM4_TMR41_OCMRHVH_OPZRH0                  (*((volatile unsigned int*)(0x422E05A8UL)))
#define bM4_TMR41_OCMRHVH_OPZRH1                  (*((volatile unsigned int*)(0x422E05ACUL)))
#define bM4_TMR41_OCMRHVH_OPNPKH0                 (*((volatile unsigned int*)(0x422E05B0UL)))
#define bM4_TMR41_OCMRHVH_OPNPKH1                 (*((volatile unsigned int*)(0x422E05B4UL)))
#define bM4_TMR41_OCMRHVH_OPNZRH0                 (*((volatile unsigned int*)(0x422E05B8UL)))
#define bM4_TMR41_OCMRHVH_OPNZRH1                 (*((volatile unsigned int*)(0x422E05BCUL)))
#define bM4_TMR41_OCMRLVL_OCFDCL                  (*((volatile unsigned int*)(0x422E0600UL)))
#define bM4_TMR41_OCMRLVL_OCFPKL                  (*((volatile unsigned int*)(0x422E0604UL)))
#define bM4_TMR41_OCMRLVL_OCFUCL                  (*((volatile unsigned int*)(0x422E0608UL)))
#define bM4_TMR41_OCMRLVL_OCFZRL                  (*((volatile unsigned int*)(0x422E060CUL)))
#define bM4_TMR41_OCMRLVL_OPDCL0                  (*((volatile unsigned int*)(0x422E0610UL)))
#define bM4_TMR41_OCMRLVL_OPDCL1                  (*((volatile unsigned int*)(0x422E0614UL)))
#define bM4_TMR41_OCMRLVL_OPPKL0                  (*((volatile unsigned int*)(0x422E0618UL)))
#define bM4_TMR41_OCMRLVL_OPPKL1                  (*((volatile unsigned int*)(0x422E061CUL)))
#define bM4_TMR41_OCMRLVL_OPUCL0                  (*((volatile unsigned int*)(0x422E0620UL)))
#define bM4_TMR41_OCMRLVL_OPUCL1                  (*((volatile unsigned int*)(0x422E0624UL)))
#define bM4_TMR41_OCMRLVL_OPZRL0                  (*((volatile unsigned int*)(0x422E0628UL)))
#define bM4_TMR41_OCMRLVL_OPZRL1                  (*((volatile unsigned int*)(0x422E062CUL)))
#define bM4_TMR41_OCMRLVL_OPNPKL0                 (*((volatile unsigned int*)(0x422E0630UL)))
#define bM4_TMR41_OCMRLVL_OPNPKL1                 (*((volatile unsigned int*)(0x422E0634UL)))
#define bM4_TMR41_OCMRLVL_OPNZRL0                 (*((volatile unsigned int*)(0x422E0638UL)))
#define bM4_TMR41_OCMRLVL_OPNZRL1                 (*((volatile unsigned int*)(0x422E063CUL)))
#define bM4_TMR41_OCMRLVL_EOPNDCL0                (*((volatile unsigned int*)(0x422E0640UL)))
#define bM4_TMR41_OCMRLVL_EOPNDCL1                (*((volatile unsigned int*)(0x422E0644UL)))
#define bM4_TMR41_OCMRLVL_EOPNUCL0                (*((volatile unsigned int*)(0x422E0648UL)))
#define bM4_TMR41_OCMRLVL_EOPNUCL1                (*((volatile unsigned int*)(0x422E064CUL)))
#define bM4_TMR41_OCMRLVL_EOPDCL0                 (*((volatile unsigned int*)(0x422E0650UL)))
#define bM4_TMR41_OCMRLVL_EOPDCL1                 (*((volatile unsigned int*)(0x422E0654UL)))
#define bM4_TMR41_OCMRLVL_EOPPKL0                 (*((volatile unsigned int*)(0x422E0658UL)))
#define bM4_TMR41_OCMRLVL_EOPPKL1                 (*((volatile unsigned int*)(0x422E065CUL)))
#define bM4_TMR41_OCMRLVL_EOPUCL0                 (*((volatile unsigned int*)(0x422E0660UL)))
#define bM4_TMR41_OCMRLVL_EOPUCL1                 (*((volatile unsigned int*)(0x422E0664UL)))
#define bM4_TMR41_OCMRLVL_EOPZRL0                 (*((volatile unsigned int*)(0x422E0668UL)))
#define bM4_TMR41_OCMRLVL_EOPZRL1                 (*((volatile unsigned int*)(0x422E066CUL)))
#define bM4_TMR41_OCMRLVL_EOPNPKL0                (*((volatile unsigned int*)(0x422E0670UL)))
#define bM4_TMR41_OCMRLVL_EOPNPKL1                (*((volatile unsigned int*)(0x422E0674UL)))
#define bM4_TMR41_OCMRLVL_EOPNZRL0                (*((volatile unsigned int*)(0x422E0678UL)))
#define bM4_TMR41_OCMRLVL_EOPNZRL1                (*((volatile unsigned int*)(0x422E067CUL)))
#define bM4_TMR41_OCMRHWH_OCFDCH                  (*((volatile unsigned int*)(0x422E0680UL)))
#define bM4_TMR41_OCMRHWH_OCFPKH                  (*((volatile unsigned int*)(0x422E0684UL)))
#define bM4_TMR41_OCMRHWH_OCFUCH                  (*((volatile unsigned int*)(0x422E0688UL)))
#define bM4_TMR41_OCMRHWH_OCFZRH                  (*((volatile unsigned int*)(0x422E068CUL)))
#define bM4_TMR41_OCMRHWH_OPDCH0                  (*((volatile unsigned int*)(0x422E0690UL)))
#define bM4_TMR41_OCMRHWH_OPDCH1                  (*((volatile unsigned int*)(0x422E0694UL)))
#define bM4_TMR41_OCMRHWH_OPPKH0                  (*((volatile unsigned int*)(0x422E0698UL)))
#define bM4_TMR41_OCMRHWH_OPPKH1                  (*((volatile unsigned int*)(0x422E069CUL)))
#define bM4_TMR41_OCMRHWH_OPUCH0                  (*((volatile unsigned int*)(0x422E06A0UL)))
#define bM4_TMR41_OCMRHWH_OPUCH1                  (*((volatile unsigned int*)(0x422E06A4UL)))
#define bM4_TMR41_OCMRHWH_OPZRH0                  (*((volatile unsigned int*)(0x422E06A8UL)))
#define bM4_TMR41_OCMRHWH_OPZRH1                  (*((volatile unsigned int*)(0x422E06ACUL)))
#define bM4_TMR41_OCMRHWH_OPNPKH0                 (*((volatile unsigned int*)(0x422E06B0UL)))
#define bM4_TMR41_OCMRHWH_OPNPKH1                 (*((volatile unsigned int*)(0x422E06B4UL)))
#define bM4_TMR41_OCMRHWH_OPNZRH0                 (*((volatile unsigned int*)(0x422E06B8UL)))
#define bM4_TMR41_OCMRHWH_OPNZRH1                 (*((volatile unsigned int*)(0x422E06BCUL)))
#define bM4_TMR41_OCMRLWL_OCFDCL                  (*((volatile unsigned int*)(0x422E0700UL)))
#define bM4_TMR41_OCMRLWL_OCFPKL                  (*((volatile unsigned int*)(0x422E0704UL)))
#define bM4_TMR41_OCMRLWL_OCFUCL                  (*((volatile unsigned int*)(0x422E0708UL)))
#define bM4_TMR41_OCMRLWL_OCFZRL                  (*((volatile unsigned int*)(0x422E070CUL)))
#define bM4_TMR41_OCMRLWL_OPDCL0                  (*((volatile unsigned int*)(0x422E0710UL)))
#define bM4_TMR41_OCMRLWL_OPDCL1                  (*((volatile unsigned int*)(0x422E0714UL)))
#define bM4_TMR41_OCMRLWL_OPPKL0                  (*((volatile unsigned int*)(0x422E0718UL)))
#define bM4_TMR41_OCMRLWL_OPPKL1                  (*((volatile unsigned int*)(0x422E071CUL)))
#define bM4_TMR41_OCMRLWL_OPUCL0                  (*((volatile unsigned int*)(0x422E0720UL)))
#define bM4_TMR41_OCMRLWL_OPUCL1                  (*((volatile unsigned int*)(0x422E0724UL)))
#define bM4_TMR41_OCMRLWL_OPZRL0                  (*((volatile unsigned int*)(0x422E0728UL)))
#define bM4_TMR41_OCMRLWL_OPZRL1                  (*((volatile unsigned int*)(0x422E072CUL)))
#define bM4_TMR41_OCMRLWL_OPNPKL0                 (*((volatile unsigned int*)(0x422E0730UL)))
#define bM4_TMR41_OCMRLWL_OPNPKL1                 (*((volatile unsigned int*)(0x422E0734UL)))
#define bM4_TMR41_OCMRLWL_OPNZRL0                 (*((volatile unsigned int*)(0x422E0738UL)))
#define bM4_TMR41_OCMRLWL_OPNZRL1                 (*((volatile unsigned int*)(0x422E073CUL)))
#define bM4_TMR41_OCMRLWL_EOPNDCL0                (*((volatile unsigned int*)(0x422E0740UL)))
#define bM4_TMR41_OCMRLWL_EOPNDCL1                (*((volatile unsigned int*)(0x422E0744UL)))
#define bM4_TMR41_OCMRLWL_EOPNUCL0                (*((volatile unsigned int*)(0x422E0748UL)))
#define bM4_TMR41_OCMRLWL_EOPNUCL1                (*((volatile unsigned int*)(0x422E074CUL)))
#define bM4_TMR41_OCMRLWL_EOPDCL0                 (*((volatile unsigned int*)(0x422E0750UL)))
#define bM4_TMR41_OCMRLWL_EOPDCL1                 (*((volatile unsigned int*)(0x422E0754UL)))
#define bM4_TMR41_OCMRLWL_EOPPKL0                 (*((volatile unsigned int*)(0x422E0758UL)))
#define bM4_TMR41_OCMRLWL_EOPPKL1                 (*((volatile unsigned int*)(0x422E075CUL)))
#define bM4_TMR41_OCMRLWL_EOPUCL0                 (*((volatile unsigned int*)(0x422E0760UL)))
#define bM4_TMR41_OCMRLWL_EOPUCL1                 (*((volatile unsigned int*)(0x422E0764UL)))
#define bM4_TMR41_OCMRLWL_EOPZRL0                 (*((volatile unsigned int*)(0x422E0768UL)))
#define bM4_TMR41_OCMRLWL_EOPZRL1                 (*((volatile unsigned int*)(0x422E076CUL)))
#define bM4_TMR41_OCMRLWL_EOPNPKL0                (*((volatile unsigned int*)(0x422E0770UL)))
#define bM4_TMR41_OCMRLWL_EOPNPKL1                (*((volatile unsigned int*)(0x422E0774UL)))
#define bM4_TMR41_OCMRLWL_EOPNZRL0                (*((volatile unsigned int*)(0x422E0778UL)))
#define bM4_TMR41_OCMRLWL_EOPNZRL1                (*((volatile unsigned int*)(0x422E077CUL)))
#define bM4_TMR41_CCSR_CKDIV0                     (*((volatile unsigned int*)(0x422E0900UL)))
#define bM4_TMR41_CCSR_CKDIV1                     (*((volatile unsigned int*)(0x422E0904UL)))
#define bM4_TMR41_CCSR_CKDIV2                     (*((volatile unsigned int*)(0x422E0908UL)))
#define bM4_TMR41_CCSR_CKDIV3                     (*((volatile unsigned int*)(0x422E090CUL)))
#define bM4_TMR41_CCSR_CLEAR                      (*((volatile unsigned int*)(0x422E0910UL)))
#define bM4_TMR41_CCSR_MODE                       (*((volatile unsigned int*)(0x422E0914UL)))
#define bM4_TMR41_CCSR_STOP                       (*((volatile unsigned int*)(0x422E0918UL)))
#define bM4_TMR41_CCSR_BUFEN                      (*((volatile unsigned int*)(0x422E091CUL)))
#define bM4_TMR41_CCSR_IRQPEN                     (*((volatile unsigned int*)(0x422E0920UL)))
#define bM4_TMR41_CCSR_IRQPF                      (*((volatile unsigned int*)(0x422E0924UL)))
#define bM4_TMR41_CCSR_IRQZEN                     (*((volatile unsigned int*)(0x422E0934UL)))
#define bM4_TMR41_CCSR_IRQZF                      (*((volatile unsigned int*)(0x422E0938UL)))
#define bM4_TMR41_CCSR_ECKEN                      (*((volatile unsigned int*)(0x422E093CUL)))
#define bM4_TMR41_CVPR_ZIM0                       (*((volatile unsigned int*)(0x422E0940UL)))
#define bM4_TMR41_CVPR_ZIM1                       (*((volatile unsigned int*)(0x422E0944UL)))
#define bM4_TMR41_CVPR_ZIM2                       (*((volatile unsigned int*)(0x422E0948UL)))
#define bM4_TMR41_CVPR_ZIM3                       (*((volatile unsigned int*)(0x422E094CUL)))
#define bM4_TMR41_CVPR_PIM0                       (*((volatile unsigned int*)(0x422E0950UL)))
#define bM4_TMR41_CVPR_PIM1                       (*((volatile unsigned int*)(0x422E0954UL)))
#define bM4_TMR41_CVPR_PIM2                       (*((volatile unsigned int*)(0x422E0958UL)))
#define bM4_TMR41_CVPR_PIM3                       (*((volatile unsigned int*)(0x422E095CUL)))
#define bM4_TMR41_CVPR_ZIC0                       (*((volatile unsigned int*)(0x422E0960UL)))
#define bM4_TMR41_CVPR_ZIC1                       (*((volatile unsigned int*)(0x422E0964UL)))
#define bM4_TMR41_CVPR_ZIC2                       (*((volatile unsigned int*)(0x422E0968UL)))
#define bM4_TMR41_CVPR_ZIC3                       (*((volatile unsigned int*)(0x422E096CUL)))
#define bM4_TMR41_CVPR_PIC0                       (*((volatile unsigned int*)(0x422E0970UL)))
#define bM4_TMR41_CVPR_PIC1                       (*((volatile unsigned int*)(0x422E0974UL)))
#define bM4_TMR41_CVPR_PIC2                       (*((volatile unsigned int*)(0x422E0978UL)))
#define bM4_TMR41_CVPR_PIC3                       (*((volatile unsigned int*)(0x422E097CUL)))
#define bM4_TMR41_POCRU_DIVCK0                    (*((volatile unsigned int*)(0x422E1300UL)))
#define bM4_TMR41_POCRU_DIVCK1                    (*((volatile unsigned int*)(0x422E1304UL)))
#define bM4_TMR41_POCRU_DIVCK2                    (*((volatile unsigned int*)(0x422E1308UL)))
#define bM4_TMR41_POCRU_DIVCK3                    (*((volatile unsigned int*)(0x422E130CUL)))
#define bM4_TMR41_POCRU_PWMMD0                    (*((volatile unsigned int*)(0x422E1310UL)))
#define bM4_TMR41_POCRU_PWMMD1                    (*((volatile unsigned int*)(0x422E1314UL)))
#define bM4_TMR41_POCRU_LVLS0                     (*((volatile unsigned int*)(0x422E1318UL)))
#define bM4_TMR41_POCRU_LVLS1                     (*((volatile unsigned int*)(0x422E131CUL)))
#define bM4_TMR41_POCRV_DIVCK0                    (*((volatile unsigned int*)(0x422E1380UL)))
#define bM4_TMR41_POCRV_DIVCK1                    (*((volatile unsigned int*)(0x422E1384UL)))
#define bM4_TMR41_POCRV_DIVCK2                    (*((volatile unsigned int*)(0x422E1388UL)))
#define bM4_TMR41_POCRV_DIVCK3                    (*((volatile unsigned int*)(0x422E138CUL)))
#define bM4_TMR41_POCRV_PWMMD0                    (*((volatile unsigned int*)(0x422E1390UL)))
#define bM4_TMR41_POCRV_PWMMD1                    (*((volatile unsigned int*)(0x422E1394UL)))
#define bM4_TMR41_POCRV_LVLS0                     (*((volatile unsigned int*)(0x422E1398UL)))
#define bM4_TMR41_POCRV_LVLS1                     (*((volatile unsigned int*)(0x422E139CUL)))
#define bM4_TMR41_POCRW_DIVCK0                    (*((volatile unsigned int*)(0x422E1400UL)))
#define bM4_TMR41_POCRW_DIVCK1                    (*((volatile unsigned int*)(0x422E1404UL)))
#define bM4_TMR41_POCRW_DIVCK2                    (*((volatile unsigned int*)(0x422E1408UL)))
#define bM4_TMR41_POCRW_DIVCK3                    (*((volatile unsigned int*)(0x422E140CUL)))
#define bM4_TMR41_POCRW_PWMMD0                    (*((volatile unsigned int*)(0x422E1410UL)))
#define bM4_TMR41_POCRW_PWMMD1                    (*((volatile unsigned int*)(0x422E1414UL)))
#define bM4_TMR41_POCRW_LVLS0                     (*((volatile unsigned int*)(0x422E1418UL)))
#define bM4_TMR41_POCRW_LVLS1                     (*((volatile unsigned int*)(0x422E141CUL)))
#define bM4_TMR41_RCSR_RTIDU                      (*((volatile unsigned int*)(0x422E1480UL)))
#define bM4_TMR41_RCSR_RTIDV                      (*((volatile unsigned int*)(0x422E1484UL)))
#define bM4_TMR41_RCSR_RTIDW                      (*((volatile unsigned int*)(0x422E1488UL)))
#define bM4_TMR41_RCSR_RTIFU                      (*((volatile unsigned int*)(0x422E1490UL)))
#define bM4_TMR41_RCSR_RTICU                      (*((volatile unsigned int*)(0x422E1494UL)))
#define bM4_TMR41_RCSR_RTEU                       (*((volatile unsigned int*)(0x422E1498UL)))
#define bM4_TMR41_RCSR_RTSU                       (*((volatile unsigned int*)(0x422E149CUL)))
#define bM4_TMR41_RCSR_RTIFV                      (*((volatile unsigned int*)(0x422E14A0UL)))
#define bM4_TMR41_RCSR_RTICV                      (*((volatile unsigned int*)(0x422E14A4UL)))
#define bM4_TMR41_RCSR_RTEV                       (*((volatile unsigned int*)(0x422E14A8UL)))
#define bM4_TMR41_RCSR_RTSV                       (*((volatile unsigned int*)(0x422E14ACUL)))
#define bM4_TMR41_RCSR_RTIFW                      (*((volatile unsigned int*)(0x422E14B0UL)))
#define bM4_TMR41_RCSR_RTICW                      (*((volatile unsigned int*)(0x422E14B4UL)))
#define bM4_TMR41_RCSR_RTEW                       (*((volatile unsigned int*)(0x422E14B8UL)))
#define bM4_TMR41_RCSR_RTSW                       (*((volatile unsigned int*)(0x422E14BCUL)))
#define bM4_TMR41_SCSRUH_BUFEN0                   (*((volatile unsigned int*)(0x422E1900UL)))
#define bM4_TMR41_SCSRUH_BUFEN1                   (*((volatile unsigned int*)(0x422E1904UL)))
#define bM4_TMR41_SCSRUH_EVTOS0                   (*((volatile unsigned int*)(0x422E1908UL)))
#define bM4_TMR41_SCSRUH_EVTOS1                   (*((volatile unsigned int*)(0x422E190CUL)))
#define bM4_TMR41_SCSRUH_EVTOS2                   (*((volatile unsigned int*)(0x422E1910UL)))
#define bM4_TMR41_SCSRUH_LMC                      (*((volatile unsigned int*)(0x422E1914UL)))
#define bM4_TMR41_SCSRUH_EVTMS                    (*((volatile unsigned int*)(0x422E1920UL)))
#define bM4_TMR41_SCSRUH_EVTDS                    (*((volatile unsigned int*)(0x422E1924UL)))
#define bM4_TMR41_SCSRUH_DEN                      (*((volatile unsigned int*)(0x422E1930UL)))
#define bM4_TMR41_SCSRUH_PEN                      (*((volatile unsigned int*)(0x422E1934UL)))
#define bM4_TMR41_SCSRUH_UEN                      (*((volatile unsigned int*)(0x422E1938UL)))
#define bM4_TMR41_SCSRUH_ZEN                      (*((volatile unsigned int*)(0x422E193CUL)))
#define bM4_TMR41_SCMRUH_AMC0                     (*((volatile unsigned int*)(0x422E1940UL)))
#define bM4_TMR41_SCMRUH_AMC1                     (*((volatile unsigned int*)(0x422E1944UL)))
#define bM4_TMR41_SCMRUH_AMC2                     (*((volatile unsigned int*)(0x422E1948UL)))
#define bM4_TMR41_SCMRUH_AMC3                     (*((volatile unsigned int*)(0x422E194CUL)))
#define bM4_TMR41_SCMRUH_MZCE                     (*((volatile unsigned int*)(0x422E1958UL)))
#define bM4_TMR41_SCMRUH_MPCE                     (*((volatile unsigned int*)(0x422E195CUL)))
#define bM4_TMR41_SCSRUL_BUFEN0                   (*((volatile unsigned int*)(0x422E1980UL)))
#define bM4_TMR41_SCSRUL_BUFEN1                   (*((volatile unsigned int*)(0x422E1984UL)))
#define bM4_TMR41_SCSRUL_EVTOS0                   (*((volatile unsigned int*)(0x422E1988UL)))
#define bM4_TMR41_SCSRUL_EVTOS1                   (*((volatile unsigned int*)(0x422E198CUL)))
#define bM4_TMR41_SCSRUL_EVTOS2                   (*((volatile unsigned int*)(0x422E1990UL)))
#define bM4_TMR41_SCSRUL_LMC                      (*((volatile unsigned int*)(0x422E1994UL)))
#define bM4_TMR41_SCSRUL_EVTMS                    (*((volatile unsigned int*)(0x422E19A0UL)))
#define bM4_TMR41_SCSRUL_EVTDS                    (*((volatile unsigned int*)(0x422E19A4UL)))
#define bM4_TMR41_SCSRUL_DEN                      (*((volatile unsigned int*)(0x422E19B0UL)))
#define bM4_TMR41_SCSRUL_PEN                      (*((volatile unsigned int*)(0x422E19B4UL)))
#define bM4_TMR41_SCSRUL_UEN                      (*((volatile unsigned int*)(0x422E19B8UL)))
#define bM4_TMR41_SCSRUL_ZEN                      (*((volatile unsigned int*)(0x422E19BCUL)))
#define bM4_TMR41_SCMRUL_AMC0                     (*((volatile unsigned int*)(0x422E19C0UL)))
#define bM4_TMR41_SCMRUL_AMC1                     (*((volatile unsigned int*)(0x422E19C4UL)))
#define bM4_TMR41_SCMRUL_AMC2                     (*((volatile unsigned int*)(0x422E19C8UL)))
#define bM4_TMR41_SCMRUL_AMC3                     (*((volatile unsigned int*)(0x422E19CCUL)))
#define bM4_TMR41_SCMRUL_MZCE                     (*((volatile unsigned int*)(0x422E19D8UL)))
#define bM4_TMR41_SCMRUL_MPCE                     (*((volatile unsigned int*)(0x422E19DCUL)))
#define bM4_TMR41_SCSRVH_BUFEN0                   (*((volatile unsigned int*)(0x422E1A00UL)))
#define bM4_TMR41_SCSRVH_BUFEN1                   (*((volatile unsigned int*)(0x422E1A04UL)))
#define bM4_TMR41_SCSRVH_EVTOS0                   (*((volatile unsigned int*)(0x422E1A08UL)))
#define bM4_TMR41_SCSRVH_EVTOS1                   (*((volatile unsigned int*)(0x422E1A0CUL)))
#define bM4_TMR41_SCSRVH_EVTOS2                   (*((volatile unsigned int*)(0x422E1A10UL)))
#define bM4_TMR41_SCSRVH_LMC                      (*((volatile unsigned int*)(0x422E1A14UL)))
#define bM4_TMR41_SCSRVH_EVTMS                    (*((volatile unsigned int*)(0x422E1A20UL)))
#define bM4_TMR41_SCSRVH_EVTDS                    (*((volatile unsigned int*)(0x422E1A24UL)))
#define bM4_TMR41_SCSRVH_DEN                      (*((volatile unsigned int*)(0x422E1A30UL)))
#define bM4_TMR41_SCSRVH_PEN                      (*((volatile unsigned int*)(0x422E1A34UL)))
#define bM4_TMR41_SCSRVH_UEN                      (*((volatile unsigned int*)(0x422E1A38UL)))
#define bM4_TMR41_SCSRVH_ZEN                      (*((volatile unsigned int*)(0x422E1A3CUL)))
#define bM4_TMR41_SCMRVH_AMC0                     (*((volatile unsigned int*)(0x422E1A40UL)))
#define bM4_TMR41_SCMRVH_AMC1                     (*((volatile unsigned int*)(0x422E1A44UL)))
#define bM4_TMR41_SCMRVH_AMC2                     (*((volatile unsigned int*)(0x422E1A48UL)))
#define bM4_TMR41_SCMRVH_AMC3                     (*((volatile unsigned int*)(0x422E1A4CUL)))
#define bM4_TMR41_SCMRVH_MZCE                     (*((volatile unsigned int*)(0x422E1A58UL)))
#define bM4_TMR41_SCMRVH_MPCE                     (*((volatile unsigned int*)(0x422E1A5CUL)))
#define bM4_TMR41_SCSRVL_BUFEN0                   (*((volatile unsigned int*)(0x422E1A80UL)))
#define bM4_TMR41_SCSRVL_BUFEN1                   (*((volatile unsigned int*)(0x422E1A84UL)))
#define bM4_TMR41_SCSRVL_EVTOS0                   (*((volatile unsigned int*)(0x422E1A88UL)))
#define bM4_TMR41_SCSRVL_EVTOS1                   (*((volatile unsigned int*)(0x422E1A8CUL)))
#define bM4_TMR41_SCSRVL_EVTOS2                   (*((volatile unsigned int*)(0x422E1A90UL)))
#define bM4_TMR41_SCSRVL_LMC                      (*((volatile unsigned int*)(0x422E1A94UL)))
#define bM4_TMR41_SCSRVL_EVTMS                    (*((volatile unsigned int*)(0x422E1AA0UL)))
#define bM4_TMR41_SCSRVL_EVTDS                    (*((volatile unsigned int*)(0x422E1AA4UL)))
#define bM4_TMR41_SCSRVL_DEN                      (*((volatile unsigned int*)(0x422E1AB0UL)))
#define bM4_TMR41_SCSRVL_PEN                      (*((volatile unsigned int*)(0x422E1AB4UL)))
#define bM4_TMR41_SCSRVL_UEN                      (*((volatile unsigned int*)(0x422E1AB8UL)))
#define bM4_TMR41_SCSRVL_ZEN                      (*((volatile unsigned int*)(0x422E1ABCUL)))
#define bM4_TMR41_SCMRVL_AMC0                     (*((volatile unsigned int*)(0x422E1AC0UL)))
#define bM4_TMR41_SCMRVL_AMC1                     (*((volatile unsigned int*)(0x422E1AC4UL)))
#define bM4_TMR41_SCMRVL_AMC2                     (*((volatile unsigned int*)(0x422E1AC8UL)))
#define bM4_TMR41_SCMRVL_AMC3                     (*((volatile unsigned int*)(0x422E1ACCUL)))
#define bM4_TMR41_SCMRVL_MZCE                     (*((volatile unsigned int*)(0x422E1AD8UL)))
#define bM4_TMR41_SCMRVL_MPCE                     (*((volatile unsigned int*)(0x422E1ADCUL)))
#define bM4_TMR41_SCSRWH_BUFEN0                   (*((volatile unsigned int*)(0x422E1B00UL)))
#define bM4_TMR41_SCSRWH_BUFEN1                   (*((volatile unsigned int*)(0x422E1B04UL)))
#define bM4_TMR41_SCSRWH_EVTOS0                   (*((volatile unsigned int*)(0x422E1B08UL)))
#define bM4_TMR41_SCSRWH_EVTOS1                   (*((volatile unsigned int*)(0x422E1B0CUL)))
#define bM4_TMR41_SCSRWH_EVTOS2                   (*((volatile unsigned int*)(0x422E1B10UL)))
#define bM4_TMR41_SCSRWH_LMC                      (*((volatile unsigned int*)(0x422E1B14UL)))
#define bM4_TMR41_SCSRWH_EVTMS                    (*((volatile unsigned int*)(0x422E1B20UL)))
#define bM4_TMR41_SCSRWH_EVTDS                    (*((volatile unsigned int*)(0x422E1B24UL)))
#define bM4_TMR41_SCSRWH_DEN                      (*((volatile unsigned int*)(0x422E1B30UL)))
#define bM4_TMR41_SCSRWH_PEN                      (*((volatile unsigned int*)(0x422E1B34UL)))
#define bM4_TMR41_SCSRWH_UEN                      (*((volatile unsigned int*)(0x422E1B38UL)))
#define bM4_TMR41_SCSRWH_ZEN                      (*((volatile unsigned int*)(0x422E1B3CUL)))
#define bM4_TMR41_SCMRWH_AMC0                     (*((volatile unsigned int*)(0x422E1B40UL)))
#define bM4_TMR41_SCMRWH_AMC1                     (*((volatile unsigned int*)(0x422E1B44UL)))
#define bM4_TMR41_SCMRWH_AMC2                     (*((volatile unsigned int*)(0x422E1B48UL)))
#define bM4_TMR41_SCMRWH_AMC3                     (*((volatile unsigned int*)(0x422E1B4CUL)))
#define bM4_TMR41_SCMRWH_MZCE                     (*((volatile unsigned int*)(0x422E1B58UL)))
#define bM4_TMR41_SCMRWH_MPCE                     (*((volatile unsigned int*)(0x422E1B5CUL)))
#define bM4_TMR41_SCSRWL_BUFEN0                   (*((volatile unsigned int*)(0x422E1B80UL)))
#define bM4_TMR41_SCSRWL_BUFEN1                   (*((volatile unsigned int*)(0x422E1B84UL)))
#define bM4_TMR41_SCSRWL_EVTOS0                   (*((volatile unsigned int*)(0x422E1B88UL)))
#define bM4_TMR41_SCSRWL_EVTOS1                   (*((volatile unsigned int*)(0x422E1B8CUL)))
#define bM4_TMR41_SCSRWL_EVTOS2                   (*((volatile unsigned int*)(0x422E1B90UL)))
#define bM4_TMR41_SCSRWL_LMC                      (*((volatile unsigned int*)(0x422E1B94UL)))
#define bM4_TMR41_SCSRWL_EVTMS                    (*((volatile unsigned int*)(0x422E1BA0UL)))
#define bM4_TMR41_SCSRWL_EVTDS                    (*((volatile unsigned int*)(0x422E1BA4UL)))
#define bM4_TMR41_SCSRWL_DEN                      (*((volatile unsigned int*)(0x422E1BB0UL)))
#define bM4_TMR41_SCSRWL_PEN                      (*((volatile unsigned int*)(0x422E1BB4UL)))
#define bM4_TMR41_SCSRWL_UEN                      (*((volatile unsigned int*)(0x422E1BB8UL)))
#define bM4_TMR41_SCSRWL_ZEN                      (*((volatile unsigned int*)(0x422E1BBCUL)))
#define bM4_TMR41_SCMRWL_AMC0                     (*((volatile unsigned int*)(0x422E1BC0UL)))
#define bM4_TMR41_SCMRWL_AMC1                     (*((volatile unsigned int*)(0x422E1BC4UL)))
#define bM4_TMR41_SCMRWL_AMC2                     (*((volatile unsigned int*)(0x422E1BC8UL)))
#define bM4_TMR41_SCMRWL_AMC3                     (*((volatile unsigned int*)(0x422E1BCCUL)))
#define bM4_TMR41_SCMRWL_MZCE                     (*((volatile unsigned int*)(0x422E1BD8UL)))
#define bM4_TMR41_SCMRWL_MPCE                     (*((volatile unsigned int*)(0x422E1BDCUL)))
#define bM4_TMR41_ECSR_HOLD                       (*((volatile unsigned int*)(0x422E1E1CUL)))
#define bM4_TMR42_OCSRU_OCEH                      (*((volatile unsigned int*)(0x42490300UL)))
#define bM4_TMR42_OCSRU_OCEL                      (*((volatile unsigned int*)(0x42490304UL)))
#define bM4_TMR42_OCSRU_OCPH                      (*((volatile unsigned int*)(0x42490308UL)))
#define bM4_TMR42_OCSRU_OCPL                      (*((volatile unsigned int*)(0x4249030CUL)))
#define bM4_TMR42_OCSRU_OCIEH                     (*((volatile unsigned int*)(0x42490310UL)))
#define bM4_TMR42_OCSRU_OCIEL                     (*((volatile unsigned int*)(0x42490314UL)))
#define bM4_TMR42_OCSRU_OCFH                      (*((volatile unsigned int*)(0x42490318UL)))
#define bM4_TMR42_OCSRU_OCFL                      (*((volatile unsigned int*)(0x4249031CUL)))
#define bM4_TMR42_OCERU_CHBUFEN0                  (*((volatile unsigned int*)(0x42490340UL)))
#define bM4_TMR42_OCERU_CHBUFEN1                  (*((volatile unsigned int*)(0x42490344UL)))
#define bM4_TMR42_OCERU_CLBUFEN0                  (*((volatile unsigned int*)(0x42490348UL)))
#define bM4_TMR42_OCERU_CLBUFEN1                  (*((volatile unsigned int*)(0x4249034CUL)))
#define bM4_TMR42_OCERU_MHBUFEN0                  (*((volatile unsigned int*)(0x42490350UL)))
#define bM4_TMR42_OCERU_MHBUFEN1                  (*((volatile unsigned int*)(0x42490354UL)))
#define bM4_TMR42_OCERU_MLBUFEN0                  (*((volatile unsigned int*)(0x42490358UL)))
#define bM4_TMR42_OCERU_MLBUFEN1                  (*((volatile unsigned int*)(0x4249035CUL)))
#define bM4_TMR42_OCERU_LMCH                      (*((volatile unsigned int*)(0x42490360UL)))
#define bM4_TMR42_OCERU_LMCL                      (*((volatile unsigned int*)(0x42490364UL)))
#define bM4_TMR42_OCERU_LMMH                      (*((volatile unsigned int*)(0x42490368UL)))
#define bM4_TMR42_OCERU_LMML                      (*((volatile unsigned int*)(0x4249036CUL)))
#define bM4_TMR42_OCERU_MCECH                     (*((volatile unsigned int*)(0x42490370UL)))
#define bM4_TMR42_OCERU_MCECL                     (*((volatile unsigned int*)(0x42490374UL)))
#define bM4_TMR42_OCSRV_OCEH                      (*((volatile unsigned int*)(0x42490380UL)))
#define bM4_TMR42_OCSRV_OCEL                      (*((volatile unsigned int*)(0x42490384UL)))
#define bM4_TMR42_OCSRV_OCPH                      (*((volatile unsigned int*)(0x42490388UL)))
#define bM4_TMR42_OCSRV_OCPL                      (*((volatile unsigned int*)(0x4249038CUL)))
#define bM4_TMR42_OCSRV_OCIEH                     (*((volatile unsigned int*)(0x42490390UL)))
#define bM4_TMR42_OCSRV_OCIEL                     (*((volatile unsigned int*)(0x42490394UL)))
#define bM4_TMR42_OCSRV_OCFH                      (*((volatile unsigned int*)(0x42490398UL)))
#define bM4_TMR42_OCSRV_OCFL                      (*((volatile unsigned int*)(0x4249039CUL)))
#define bM4_TMR42_OCERV_CHBUFEN0                  (*((volatile unsigned int*)(0x424903C0UL)))
#define bM4_TMR42_OCERV_CHBUFEN1                  (*((volatile unsigned int*)(0x424903C4UL)))
#define bM4_TMR42_OCERV_CLBUFEN0                  (*((volatile unsigned int*)(0x424903C8UL)))
#define bM4_TMR42_OCERV_CLBUFEN1                  (*((volatile unsigned int*)(0x424903CCUL)))
#define bM4_TMR42_OCERV_MHBUFEN0                  (*((volatile unsigned int*)(0x424903D0UL)))
#define bM4_TMR42_OCERV_MHBUFEN1                  (*((volatile unsigned int*)(0x424903D4UL)))
#define bM4_TMR42_OCERV_MLBUFEN0                  (*((volatile unsigned int*)(0x424903D8UL)))
#define bM4_TMR42_OCERV_MLBUFEN1                  (*((volatile unsigned int*)(0x424903DCUL)))
#define bM4_TMR42_OCERV_LMCH                      (*((volatile unsigned int*)(0x424903E0UL)))
#define bM4_TMR42_OCERV_LMCL                      (*((volatile unsigned int*)(0x424903E4UL)))
#define bM4_TMR42_OCERV_LMMH                      (*((volatile unsigned int*)(0x424903E8UL)))
#define bM4_TMR42_OCERV_LMML                      (*((volatile unsigned int*)(0x424903ECUL)))
#define bM4_TMR42_OCERV_MCECH                     (*((volatile unsigned int*)(0x424903F0UL)))
#define bM4_TMR42_OCERV_MCECL                     (*((volatile unsigned int*)(0x424903F4UL)))
#define bM4_TMR42_OCSRW_OCEH                      (*((volatile unsigned int*)(0x42490400UL)))
#define bM4_TMR42_OCSRW_OCEL                      (*((volatile unsigned int*)(0x42490404UL)))
#define bM4_TMR42_OCSRW_OCPH                      (*((volatile unsigned int*)(0x42490408UL)))
#define bM4_TMR42_OCSRW_OCPL                      (*((volatile unsigned int*)(0x4249040CUL)))
#define bM4_TMR42_OCSRW_OCIEH                     (*((volatile unsigned int*)(0x42490410UL)))
#define bM4_TMR42_OCSRW_OCIEL                     (*((volatile unsigned int*)(0x42490414UL)))
#define bM4_TMR42_OCSRW_OCFH                      (*((volatile unsigned int*)(0x42490418UL)))
#define bM4_TMR42_OCSRW_OCFL                      (*((volatile unsigned int*)(0x4249041CUL)))
#define bM4_TMR42_OCERW_CHBUFEN0                  (*((volatile unsigned int*)(0x42490440UL)))
#define bM4_TMR42_OCERW_CHBUFEN1                  (*((volatile unsigned int*)(0x42490444UL)))
#define bM4_TMR42_OCERW_CLBUFEN0                  (*((volatile unsigned int*)(0x42490448UL)))
#define bM4_TMR42_OCERW_CLBUFEN1                  (*((volatile unsigned int*)(0x4249044CUL)))
#define bM4_TMR42_OCERW_MHBUFEN0                  (*((volatile unsigned int*)(0x42490450UL)))
#define bM4_TMR42_OCERW_MHBUFEN1                  (*((volatile unsigned int*)(0x42490454UL)))
#define bM4_TMR42_OCERW_MLBUFEN0                  (*((volatile unsigned int*)(0x42490458UL)))
#define bM4_TMR42_OCERW_MLBUFEN1                  (*((volatile unsigned int*)(0x4249045CUL)))
#define bM4_TMR42_OCERW_LMCH                      (*((volatile unsigned int*)(0x42490460UL)))
#define bM4_TMR42_OCERW_LMCL                      (*((volatile unsigned int*)(0x42490464UL)))
#define bM4_TMR42_OCERW_LMMH                      (*((volatile unsigned int*)(0x42490468UL)))
#define bM4_TMR42_OCERW_LMML                      (*((volatile unsigned int*)(0x4249046CUL)))
#define bM4_TMR42_OCERW_MCECH                     (*((volatile unsigned int*)(0x42490470UL)))
#define bM4_TMR42_OCERW_MCECL                     (*((volatile unsigned int*)(0x42490474UL)))
#define bM4_TMR42_OCMRHUH_OCFDCH                  (*((volatile unsigned int*)(0x42490480UL)))
#define bM4_TMR42_OCMRHUH_OCFPKH                  (*((volatile unsigned int*)(0x42490484UL)))
#define bM4_TMR42_OCMRHUH_OCFUCH                  (*((volatile unsigned int*)(0x42490488UL)))
#define bM4_TMR42_OCMRHUH_OCFZRH                  (*((volatile unsigned int*)(0x4249048CUL)))
#define bM4_TMR42_OCMRHUH_OPDCH0                  (*((volatile unsigned int*)(0x42490490UL)))
#define bM4_TMR42_OCMRHUH_OPDCH1                  (*((volatile unsigned int*)(0x42490494UL)))
#define bM4_TMR42_OCMRHUH_OPPKH0                  (*((volatile unsigned int*)(0x42490498UL)))
#define bM4_TMR42_OCMRHUH_OPPKH1                  (*((volatile unsigned int*)(0x4249049CUL)))
#define bM4_TMR42_OCMRHUH_OPUCH0                  (*((volatile unsigned int*)(0x424904A0UL)))
#define bM4_TMR42_OCMRHUH_OPUCH1                  (*((volatile unsigned int*)(0x424904A4UL)))
#define bM4_TMR42_OCMRHUH_OPZRH0                  (*((volatile unsigned int*)(0x424904A8UL)))
#define bM4_TMR42_OCMRHUH_OPZRH1                  (*((volatile unsigned int*)(0x424904ACUL)))
#define bM4_TMR42_OCMRHUH_OPNPKH0                 (*((volatile unsigned int*)(0x424904B0UL)))
#define bM4_TMR42_OCMRHUH_OPNPKH1                 (*((volatile unsigned int*)(0x424904B4UL)))
#define bM4_TMR42_OCMRHUH_OPNZRH0                 (*((volatile unsigned int*)(0x424904B8UL)))
#define bM4_TMR42_OCMRHUH_OPNZRH1                 (*((volatile unsigned int*)(0x424904BCUL)))
#define bM4_TMR42_OCMRLUL_OCFDCL                  (*((volatile unsigned int*)(0x42490500UL)))
#define bM4_TMR42_OCMRLUL_OCFPKL                  (*((volatile unsigned int*)(0x42490504UL)))
#define bM4_TMR42_OCMRLUL_OCFUCL                  (*((volatile unsigned int*)(0x42490508UL)))
#define bM4_TMR42_OCMRLUL_OCFZRL                  (*((volatile unsigned int*)(0x4249050CUL)))
#define bM4_TMR42_OCMRLUL_OPDCL0                  (*((volatile unsigned int*)(0x42490510UL)))
#define bM4_TMR42_OCMRLUL_OPDCL1                  (*((volatile unsigned int*)(0x42490514UL)))
#define bM4_TMR42_OCMRLUL_OPPKL0                  (*((volatile unsigned int*)(0x42490518UL)))
#define bM4_TMR42_OCMRLUL_OPPKL1                  (*((volatile unsigned int*)(0x4249051CUL)))
#define bM4_TMR42_OCMRLUL_OPUCL0                  (*((volatile unsigned int*)(0x42490520UL)))
#define bM4_TMR42_OCMRLUL_OPUCL1                  (*((volatile unsigned int*)(0x42490524UL)))
#define bM4_TMR42_OCMRLUL_OPZRL0                  (*((volatile unsigned int*)(0x42490528UL)))
#define bM4_TMR42_OCMRLUL_OPZRL1                  (*((volatile unsigned int*)(0x4249052CUL)))
#define bM4_TMR42_OCMRLUL_OPNPKL0                 (*((volatile unsigned int*)(0x42490530UL)))
#define bM4_TMR42_OCMRLUL_OPNPKL1                 (*((volatile unsigned int*)(0x42490534UL)))
#define bM4_TMR42_OCMRLUL_OPNZRL0                 (*((volatile unsigned int*)(0x42490538UL)))
#define bM4_TMR42_OCMRLUL_OPNZRL1                 (*((volatile unsigned int*)(0x4249053CUL)))
#define bM4_TMR42_OCMRLUL_EOPNDCL0                (*((volatile unsigned int*)(0x42490540UL)))
#define bM4_TMR42_OCMRLUL_EOPNDCL1                (*((volatile unsigned int*)(0x42490544UL)))
#define bM4_TMR42_OCMRLUL_EOPNUCL0                (*((volatile unsigned int*)(0x42490548UL)))
#define bM4_TMR42_OCMRLUL_EOPNUCL1                (*((volatile unsigned int*)(0x4249054CUL)))
#define bM4_TMR42_OCMRLUL_EOPDCL0                 (*((volatile unsigned int*)(0x42490550UL)))
#define bM4_TMR42_OCMRLUL_EOPDCL1                 (*((volatile unsigned int*)(0x42490554UL)))
#define bM4_TMR42_OCMRLUL_EOPPKL0                 (*((volatile unsigned int*)(0x42490558UL)))
#define bM4_TMR42_OCMRLUL_EOPPKL1                 (*((volatile unsigned int*)(0x4249055CUL)))
#define bM4_TMR42_OCMRLUL_EOPUCL0                 (*((volatile unsigned int*)(0x42490560UL)))
#define bM4_TMR42_OCMRLUL_EOPUCL1                 (*((volatile unsigned int*)(0x42490564UL)))
#define bM4_TMR42_OCMRLUL_EOPZRL0                 (*((volatile unsigned int*)(0x42490568UL)))
#define bM4_TMR42_OCMRLUL_EOPZRL1                 (*((volatile unsigned int*)(0x4249056CUL)))
#define bM4_TMR42_OCMRLUL_EOPNPKL0                (*((volatile unsigned int*)(0x42490570UL)))
#define bM4_TMR42_OCMRLUL_EOPNPKL1                (*((volatile unsigned int*)(0x42490574UL)))
#define bM4_TMR42_OCMRLUL_EOPNZRL0                (*((volatile unsigned int*)(0x42490578UL)))
#define bM4_TMR42_OCMRLUL_EOPNZRL1                (*((volatile unsigned int*)(0x4249057CUL)))
#define bM4_TMR42_OCMRHVH_OCFDCH                  (*((volatile unsigned int*)(0x42490580UL)))
#define bM4_TMR42_OCMRHVH_OCFPKH                  (*((volatile unsigned int*)(0x42490584UL)))
#define bM4_TMR42_OCMRHVH_OCFUCH                  (*((volatile unsigned int*)(0x42490588UL)))
#define bM4_TMR42_OCMRHVH_OCFZRH                  (*((volatile unsigned int*)(0x4249058CUL)))
#define bM4_TMR42_OCMRHVH_OPDCH0                  (*((volatile unsigned int*)(0x42490590UL)))
#define bM4_TMR42_OCMRHVH_OPDCH1                  (*((volatile unsigned int*)(0x42490594UL)))
#define bM4_TMR42_OCMRHVH_OPPKH0                  (*((volatile unsigned int*)(0x42490598UL)))
#define bM4_TMR42_OCMRHVH_OPPKH1                  (*((volatile unsigned int*)(0x4249059CUL)))
#define bM4_TMR42_OCMRHVH_OPUCH0                  (*((volatile unsigned int*)(0x424905A0UL)))
#define bM4_TMR42_OCMRHVH_OPUCH1                  (*((volatile unsigned int*)(0x424905A4UL)))
#define bM4_TMR42_OCMRHVH_OPZRH0                  (*((volatile unsigned int*)(0x424905A8UL)))
#define bM4_TMR42_OCMRHVH_OPZRH1                  (*((volatile unsigned int*)(0x424905ACUL)))
#define bM4_TMR42_OCMRHVH_OPNPKH0                 (*((volatile unsigned int*)(0x424905B0UL)))
#define bM4_TMR42_OCMRHVH_OPNPKH1                 (*((volatile unsigned int*)(0x424905B4UL)))
#define bM4_TMR42_OCMRHVH_OPNZRH0                 (*((volatile unsigned int*)(0x424905B8UL)))
#define bM4_TMR42_OCMRHVH_OPNZRH1                 (*((volatile unsigned int*)(0x424905BCUL)))
#define bM4_TMR42_OCMRLVL_OCFDCL                  (*((volatile unsigned int*)(0x42490600UL)))
#define bM4_TMR42_OCMRLVL_OCFPKL                  (*((volatile unsigned int*)(0x42490604UL)))
#define bM4_TMR42_OCMRLVL_OCFUCL                  (*((volatile unsigned int*)(0x42490608UL)))
#define bM4_TMR42_OCMRLVL_OCFZRL                  (*((volatile unsigned int*)(0x4249060CUL)))
#define bM4_TMR42_OCMRLVL_OPDCL0                  (*((volatile unsigned int*)(0x42490610UL)))
#define bM4_TMR42_OCMRLVL_OPDCL1                  (*((volatile unsigned int*)(0x42490614UL)))
#define bM4_TMR42_OCMRLVL_OPPKL0                  (*((volatile unsigned int*)(0x42490618UL)))
#define bM4_TMR42_OCMRLVL_OPPKL1                  (*((volatile unsigned int*)(0x4249061CUL)))
#define bM4_TMR42_OCMRLVL_OPUCL0                  (*((volatile unsigned int*)(0x42490620UL)))
#define bM4_TMR42_OCMRLVL_OPUCL1                  (*((volatile unsigned int*)(0x42490624UL)))
#define bM4_TMR42_OCMRLVL_OPZRL0                  (*((volatile unsigned int*)(0x42490628UL)))
#define bM4_TMR42_OCMRLVL_OPZRL1                  (*((volatile unsigned int*)(0x4249062CUL)))
#define bM4_TMR42_OCMRLVL_OPNPKL0                 (*((volatile unsigned int*)(0x42490630UL)))
#define bM4_TMR42_OCMRLVL_OPNPKL1                 (*((volatile unsigned int*)(0x42490634UL)))
#define bM4_TMR42_OCMRLVL_OPNZRL0                 (*((volatile unsigned int*)(0x42490638UL)))
#define bM4_TMR42_OCMRLVL_OPNZRL1                 (*((volatile unsigned int*)(0x4249063CUL)))
#define bM4_TMR42_OCMRLVL_EOPNDCL0                (*((volatile unsigned int*)(0x42490640UL)))
#define bM4_TMR42_OCMRLVL_EOPNDCL1                (*((volatile unsigned int*)(0x42490644UL)))
#define bM4_TMR42_OCMRLVL_EOPNUCL0                (*((volatile unsigned int*)(0x42490648UL)))
#define bM4_TMR42_OCMRLVL_EOPNUCL1                (*((volatile unsigned int*)(0x4249064CUL)))
#define bM4_TMR42_OCMRLVL_EOPDCL0                 (*((volatile unsigned int*)(0x42490650UL)))
#define bM4_TMR42_OCMRLVL_EOPDCL1                 (*((volatile unsigned int*)(0x42490654UL)))
#define bM4_TMR42_OCMRLVL_EOPPKL0                 (*((volatile unsigned int*)(0x42490658UL)))
#define bM4_TMR42_OCMRLVL_EOPPKL1                 (*((volatile unsigned int*)(0x4249065CUL)))
#define bM4_TMR42_OCMRLVL_EOPUCL0                 (*((volatile unsigned int*)(0x42490660UL)))
#define bM4_TMR42_OCMRLVL_EOPUCL1                 (*((volatile unsigned int*)(0x42490664UL)))
#define bM4_TMR42_OCMRLVL_EOPZRL0                 (*((volatile unsigned int*)(0x42490668UL)))
#define bM4_TMR42_OCMRLVL_EOPZRL1                 (*((volatile unsigned int*)(0x4249066CUL)))
#define bM4_TMR42_OCMRLVL_EOPNPKL0                (*((volatile unsigned int*)(0x42490670UL)))
#define bM4_TMR42_OCMRLVL_EOPNPKL1                (*((volatile unsigned int*)(0x42490674UL)))
#define bM4_TMR42_OCMRLVL_EOPNZRL0                (*((volatile unsigned int*)(0x42490678UL)))
#define bM4_TMR42_OCMRLVL_EOPNZRL1                (*((volatile unsigned int*)(0x4249067CUL)))
#define bM4_TMR42_OCMRHWH_OCFDCH                  (*((volatile unsigned int*)(0x42490680UL)))
#define bM4_TMR42_OCMRHWH_OCFPKH                  (*((volatile unsigned int*)(0x42490684UL)))
#define bM4_TMR42_OCMRHWH_OCFUCH                  (*((volatile unsigned int*)(0x42490688UL)))
#define bM4_TMR42_OCMRHWH_OCFZRH                  (*((volatile unsigned int*)(0x4249068CUL)))
#define bM4_TMR42_OCMRHWH_OPDCH0                  (*((volatile unsigned int*)(0x42490690UL)))
#define bM4_TMR42_OCMRHWH_OPDCH1                  (*((volatile unsigned int*)(0x42490694UL)))
#define bM4_TMR42_OCMRHWH_OPPKH0                  (*((volatile unsigned int*)(0x42490698UL)))
#define bM4_TMR42_OCMRHWH_OPPKH1                  (*((volatile unsigned int*)(0x4249069CUL)))
#define bM4_TMR42_OCMRHWH_OPUCH0                  (*((volatile unsigned int*)(0x424906A0UL)))
#define bM4_TMR42_OCMRHWH_OPUCH1                  (*((volatile unsigned int*)(0x424906A4UL)))
#define bM4_TMR42_OCMRHWH_OPZRH0                  (*((volatile unsigned int*)(0x424906A8UL)))
#define bM4_TMR42_OCMRHWH_OPZRH1                  (*((volatile unsigned int*)(0x424906ACUL)))
#define bM4_TMR42_OCMRHWH_OPNPKH0                 (*((volatile unsigned int*)(0x424906B0UL)))
#define bM4_TMR42_OCMRHWH_OPNPKH1                 (*((volatile unsigned int*)(0x424906B4UL)))
#define bM4_TMR42_OCMRHWH_OPNZRH0                 (*((volatile unsigned int*)(0x424906B8UL)))
#define bM4_TMR42_OCMRHWH_OPNZRH1                 (*((volatile unsigned int*)(0x424906BCUL)))
#define bM4_TMR42_OCMRLWL_OCFDCL                  (*((volatile unsigned int*)(0x42490700UL)))
#define bM4_TMR42_OCMRLWL_OCFPKL                  (*((volatile unsigned int*)(0x42490704UL)))
#define bM4_TMR42_OCMRLWL_OCFUCL                  (*((volatile unsigned int*)(0x42490708UL)))
#define bM4_TMR42_OCMRLWL_OCFZRL                  (*((volatile unsigned int*)(0x4249070CUL)))
#define bM4_TMR42_OCMRLWL_OPDCL0                  (*((volatile unsigned int*)(0x42490710UL)))
#define bM4_TMR42_OCMRLWL_OPDCL1                  (*((volatile unsigned int*)(0x42490714UL)))
#define bM4_TMR42_OCMRLWL_OPPKL0                  (*((volatile unsigned int*)(0x42490718UL)))
#define bM4_TMR42_OCMRLWL_OPPKL1                  (*((volatile unsigned int*)(0x4249071CUL)))
#define bM4_TMR42_OCMRLWL_OPUCL0                  (*((volatile unsigned int*)(0x42490720UL)))
#define bM4_TMR42_OCMRLWL_OPUCL1                  (*((volatile unsigned int*)(0x42490724UL)))
#define bM4_TMR42_OCMRLWL_OPZRL0                  (*((volatile unsigned int*)(0x42490728UL)))
#define bM4_TMR42_OCMRLWL_OPZRL1                  (*((volatile unsigned int*)(0x4249072CUL)))
#define bM4_TMR42_OCMRLWL_OPNPKL0                 (*((volatile unsigned int*)(0x42490730UL)))
#define bM4_TMR42_OCMRLWL_OPNPKL1                 (*((volatile unsigned int*)(0x42490734UL)))
#define bM4_TMR42_OCMRLWL_OPNZRL0                 (*((volatile unsigned int*)(0x42490738UL)))
#define bM4_TMR42_OCMRLWL_OPNZRL1                 (*((volatile unsigned int*)(0x4249073CUL)))
#define bM4_TMR42_OCMRLWL_EOPNDCL0                (*((volatile unsigned int*)(0x42490740UL)))
#define bM4_TMR42_OCMRLWL_EOPNDCL1                (*((volatile unsigned int*)(0x42490744UL)))
#define bM4_TMR42_OCMRLWL_EOPNUCL0                (*((volatile unsigned int*)(0x42490748UL)))
#define bM4_TMR42_OCMRLWL_EOPNUCL1                (*((volatile unsigned int*)(0x4249074CUL)))
#define bM4_TMR42_OCMRLWL_EOPDCL0                 (*((volatile unsigned int*)(0x42490750UL)))
#define bM4_TMR42_OCMRLWL_EOPDCL1                 (*((volatile unsigned int*)(0x42490754UL)))
#define bM4_TMR42_OCMRLWL_EOPPKL0                 (*((volatile unsigned int*)(0x42490758UL)))
#define bM4_TMR42_OCMRLWL_EOPPKL1                 (*((volatile unsigned int*)(0x4249075CUL)))
#define bM4_TMR42_OCMRLWL_EOPUCL0                 (*((volatile unsigned int*)(0x42490760UL)))
#define bM4_TMR42_OCMRLWL_EOPUCL1                 (*((volatile unsigned int*)(0x42490764UL)))
#define bM4_TMR42_OCMRLWL_EOPZRL0                 (*((volatile unsigned int*)(0x42490768UL)))
#define bM4_TMR42_OCMRLWL_EOPZRL1                 (*((volatile unsigned int*)(0x4249076CUL)))
#define bM4_TMR42_OCMRLWL_EOPNPKL0                (*((volatile unsigned int*)(0x42490770UL)))
#define bM4_TMR42_OCMRLWL_EOPNPKL1                (*((volatile unsigned int*)(0x42490774UL)))
#define bM4_TMR42_OCMRLWL_EOPNZRL0                (*((volatile unsigned int*)(0x42490778UL)))
#define bM4_TMR42_OCMRLWL_EOPNZRL1                (*((volatile unsigned int*)(0x4249077CUL)))
#define bM4_TMR42_CCSR_CKDIV0                     (*((volatile unsigned int*)(0x42490900UL)))
#define bM4_TMR42_CCSR_CKDIV1                     (*((volatile unsigned int*)(0x42490904UL)))
#define bM4_TMR42_CCSR_CKDIV2                     (*((volatile unsigned int*)(0x42490908UL)))
#define bM4_TMR42_CCSR_CKDIV3                     (*((volatile unsigned int*)(0x4249090CUL)))
#define bM4_TMR42_CCSR_CLEAR                      (*((volatile unsigned int*)(0x42490910UL)))
#define bM4_TMR42_CCSR_MODE                       (*((volatile unsigned int*)(0x42490914UL)))
#define bM4_TMR42_CCSR_STOP                       (*((volatile unsigned int*)(0x42490918UL)))
#define bM4_TMR42_CCSR_BUFEN                      (*((volatile unsigned int*)(0x4249091CUL)))
#define bM4_TMR42_CCSR_IRQPEN                     (*((volatile unsigned int*)(0x42490920UL)))
#define bM4_TMR42_CCSR_IRQPF                      (*((volatile unsigned int*)(0x42490924UL)))
#define bM4_TMR42_CCSR_IRQZEN                     (*((volatile unsigned int*)(0x42490934UL)))
#define bM4_TMR42_CCSR_IRQZF                      (*((volatile unsigned int*)(0x42490938UL)))
#define bM4_TMR42_CCSR_ECKEN                      (*((volatile unsigned int*)(0x4249093CUL)))
#define bM4_TMR42_CVPR_ZIM0                       (*((volatile unsigned int*)(0x42490940UL)))
#define bM4_TMR42_CVPR_ZIM1                       (*((volatile unsigned int*)(0x42490944UL)))
#define bM4_TMR42_CVPR_ZIM2                       (*((volatile unsigned int*)(0x42490948UL)))
#define bM4_TMR42_CVPR_ZIM3                       (*((volatile unsigned int*)(0x4249094CUL)))
#define bM4_TMR42_CVPR_PIM0                       (*((volatile unsigned int*)(0x42490950UL)))
#define bM4_TMR42_CVPR_PIM1                       (*((volatile unsigned int*)(0x42490954UL)))
#define bM4_TMR42_CVPR_PIM2                       (*((volatile unsigned int*)(0x42490958UL)))
#define bM4_TMR42_CVPR_PIM3                       (*((volatile unsigned int*)(0x4249095CUL)))
#define bM4_TMR42_CVPR_ZIC0                       (*((volatile unsigned int*)(0x42490960UL)))
#define bM4_TMR42_CVPR_ZIC1                       (*((volatile unsigned int*)(0x42490964UL)))
#define bM4_TMR42_CVPR_ZIC2                       (*((volatile unsigned int*)(0x42490968UL)))
#define bM4_TMR42_CVPR_ZIC3                       (*((volatile unsigned int*)(0x4249096CUL)))
#define bM4_TMR42_CVPR_PIC0                       (*((volatile unsigned int*)(0x42490970UL)))
#define bM4_TMR42_CVPR_PIC1                       (*((volatile unsigned int*)(0x42490974UL)))
#define bM4_TMR42_CVPR_PIC2                       (*((volatile unsigned int*)(0x42490978UL)))
#define bM4_TMR42_CVPR_PIC3                       (*((volatile unsigned int*)(0x4249097CUL)))
#define bM4_TMR42_POCRU_DIVCK0                    (*((volatile unsigned int*)(0x42491300UL)))
#define bM4_TMR42_POCRU_DIVCK1                    (*((volatile unsigned int*)(0x42491304UL)))
#define bM4_TMR42_POCRU_DIVCK2                    (*((volatile unsigned int*)(0x42491308UL)))
#define bM4_TMR42_POCRU_DIVCK3                    (*((volatile unsigned int*)(0x4249130CUL)))
#define bM4_TMR42_POCRU_PWMMD0                    (*((volatile unsigned int*)(0x42491310UL)))
#define bM4_TMR42_POCRU_PWMMD1                    (*((volatile unsigned int*)(0x42491314UL)))
#define bM4_TMR42_POCRU_LVLS0                     (*((volatile unsigned int*)(0x42491318UL)))
#define bM4_TMR42_POCRU_LVLS1                     (*((volatile unsigned int*)(0x4249131CUL)))
#define bM4_TMR42_POCRV_DIVCK0                    (*((volatile unsigned int*)(0x42491380UL)))
#define bM4_TMR42_POCRV_DIVCK1                    (*((volatile unsigned int*)(0x42491384UL)))
#define bM4_TMR42_POCRV_DIVCK2                    (*((volatile unsigned int*)(0x42491388UL)))
#define bM4_TMR42_POCRV_DIVCK3                    (*((volatile unsigned int*)(0x4249138CUL)))
#define bM4_TMR42_POCRV_PWMMD0                    (*((volatile unsigned int*)(0x42491390UL)))
#define bM4_TMR42_POCRV_PWMMD1                    (*((volatile unsigned int*)(0x42491394UL)))
#define bM4_TMR42_POCRV_LVLS0                     (*((volatile unsigned int*)(0x42491398UL)))
#define bM4_TMR42_POCRV_LVLS1                     (*((volatile unsigned int*)(0x4249139CUL)))
#define bM4_TMR42_POCRW_DIVCK0                    (*((volatile unsigned int*)(0x42491400UL)))
#define bM4_TMR42_POCRW_DIVCK1                    (*((volatile unsigned int*)(0x42491404UL)))
#define bM4_TMR42_POCRW_DIVCK2                    (*((volatile unsigned int*)(0x42491408UL)))
#define bM4_TMR42_POCRW_DIVCK3                    (*((volatile unsigned int*)(0x4249140CUL)))
#define bM4_TMR42_POCRW_PWMMD0                    (*((volatile unsigned int*)(0x42491410UL)))
#define bM4_TMR42_POCRW_PWMMD1                    (*((volatile unsigned int*)(0x42491414UL)))
#define bM4_TMR42_POCRW_LVLS0                     (*((volatile unsigned int*)(0x42491418UL)))
#define bM4_TMR42_POCRW_LVLS1                     (*((volatile unsigned int*)(0x4249141CUL)))
#define bM4_TMR42_RCSR_RTIDU                      (*((volatile unsigned int*)(0x42491480UL)))
#define bM4_TMR42_RCSR_RTIDV                      (*((volatile unsigned int*)(0x42491484UL)))
#define bM4_TMR42_RCSR_RTIDW                      (*((volatile unsigned int*)(0x42491488UL)))
#define bM4_TMR42_RCSR_RTIFU                      (*((volatile unsigned int*)(0x42491490UL)))
#define bM4_TMR42_RCSR_RTICU                      (*((volatile unsigned int*)(0x42491494UL)))
#define bM4_TMR42_RCSR_RTEU                       (*((volatile unsigned int*)(0x42491498UL)))
#define bM4_TMR42_RCSR_RTSU                       (*((volatile unsigned int*)(0x4249149CUL)))
#define bM4_TMR42_RCSR_RTIFV                      (*((volatile unsigned int*)(0x424914A0UL)))
#define bM4_TMR42_RCSR_RTICV                      (*((volatile unsigned int*)(0x424914A4UL)))
#define bM4_TMR42_RCSR_RTEV                       (*((volatile unsigned int*)(0x424914A8UL)))
#define bM4_TMR42_RCSR_RTSV                       (*((volatile unsigned int*)(0x424914ACUL)))
#define bM4_TMR42_RCSR_RTIFW                      (*((volatile unsigned int*)(0x424914B0UL)))
#define bM4_TMR42_RCSR_RTICW                      (*((volatile unsigned int*)(0x424914B4UL)))
#define bM4_TMR42_RCSR_RTEW                       (*((volatile unsigned int*)(0x424914B8UL)))
#define bM4_TMR42_RCSR_RTSW                       (*((volatile unsigned int*)(0x424914BCUL)))
#define bM4_TMR42_SCSRUH_BUFEN0                   (*((volatile unsigned int*)(0x42491900UL)))
#define bM4_TMR42_SCSRUH_BUFEN1                   (*((volatile unsigned int*)(0x42491904UL)))
#define bM4_TMR42_SCSRUH_EVTOS0                   (*((volatile unsigned int*)(0x42491908UL)))
#define bM4_TMR42_SCSRUH_EVTOS1                   (*((volatile unsigned int*)(0x4249190CUL)))
#define bM4_TMR42_SCSRUH_EVTOS2                   (*((volatile unsigned int*)(0x42491910UL)))
#define bM4_TMR42_SCSRUH_LMC                      (*((volatile unsigned int*)(0x42491914UL)))
#define bM4_TMR42_SCSRUH_EVTMS                    (*((volatile unsigned int*)(0x42491920UL)))
#define bM4_TMR42_SCSRUH_EVTDS                    (*((volatile unsigned int*)(0x42491924UL)))
#define bM4_TMR42_SCSRUH_DEN                      (*((volatile unsigned int*)(0x42491930UL)))
#define bM4_TMR42_SCSRUH_PEN                      (*((volatile unsigned int*)(0x42491934UL)))
#define bM4_TMR42_SCSRUH_UEN                      (*((volatile unsigned int*)(0x42491938UL)))
#define bM4_TMR42_SCSRUH_ZEN                      (*((volatile unsigned int*)(0x4249193CUL)))
#define bM4_TMR42_SCMRUH_AMC0                     (*((volatile unsigned int*)(0x42491940UL)))
#define bM4_TMR42_SCMRUH_AMC1                     (*((volatile unsigned int*)(0x42491944UL)))
#define bM4_TMR42_SCMRUH_AMC2                     (*((volatile unsigned int*)(0x42491948UL)))
#define bM4_TMR42_SCMRUH_AMC3                     (*((volatile unsigned int*)(0x4249194CUL)))
#define bM4_TMR42_SCMRUH_MZCE                     (*((volatile unsigned int*)(0x42491958UL)))
#define bM4_TMR42_SCMRUH_MPCE                     (*((volatile unsigned int*)(0x4249195CUL)))
#define bM4_TMR42_SCSRUL_BUFEN0                   (*((volatile unsigned int*)(0x42491980UL)))
#define bM4_TMR42_SCSRUL_BUFEN1                   (*((volatile unsigned int*)(0x42491984UL)))
#define bM4_TMR42_SCSRUL_EVTOS0                   (*((volatile unsigned int*)(0x42491988UL)))
#define bM4_TMR42_SCSRUL_EVTOS1                   (*((volatile unsigned int*)(0x4249198CUL)))
#define bM4_TMR42_SCSRUL_EVTOS2                   (*((volatile unsigned int*)(0x42491990UL)))
#define bM4_TMR42_SCSRUL_LMC                      (*((volatile unsigned int*)(0x42491994UL)))
#define bM4_TMR42_SCSRUL_EVTMS                    (*((volatile unsigned int*)(0x424919A0UL)))
#define bM4_TMR42_SCSRUL_EVTDS                    (*((volatile unsigned int*)(0x424919A4UL)))
#define bM4_TMR42_SCSRUL_DEN                      (*((volatile unsigned int*)(0x424919B0UL)))
#define bM4_TMR42_SCSRUL_PEN                      (*((volatile unsigned int*)(0x424919B4UL)))
#define bM4_TMR42_SCSRUL_UEN                      (*((volatile unsigned int*)(0x424919B8UL)))
#define bM4_TMR42_SCSRUL_ZEN                      (*((volatile unsigned int*)(0x424919BCUL)))
#define bM4_TMR42_SCMRUL_AMC0                     (*((volatile unsigned int*)(0x424919C0UL)))
#define bM4_TMR42_SCMRUL_AMC1                     (*((volatile unsigned int*)(0x424919C4UL)))
#define bM4_TMR42_SCMRUL_AMC2                     (*((volatile unsigned int*)(0x424919C8UL)))
#define bM4_TMR42_SCMRUL_AMC3                     (*((volatile unsigned int*)(0x424919CCUL)))
#define bM4_TMR42_SCMRUL_MZCE                     (*((volatile unsigned int*)(0x424919D8UL)))
#define bM4_TMR42_SCMRUL_MPCE                     (*((volatile unsigned int*)(0x424919DCUL)))
#define bM4_TMR42_SCSRVH_BUFEN0                   (*((volatile unsigned int*)(0x42491A00UL)))
#define bM4_TMR42_SCSRVH_BUFEN1                   (*((volatile unsigned int*)(0x42491A04UL)))
#define bM4_TMR42_SCSRVH_EVTOS0                   (*((volatile unsigned int*)(0x42491A08UL)))
#define bM4_TMR42_SCSRVH_EVTOS1                   (*((volatile unsigned int*)(0x42491A0CUL)))
#define bM4_TMR42_SCSRVH_EVTOS2                   (*((volatile unsigned int*)(0x42491A10UL)))
#define bM4_TMR42_SCSRVH_LMC                      (*((volatile unsigned int*)(0x42491A14UL)))
#define bM4_TMR42_SCSRVH_EVTMS                    (*((volatile unsigned int*)(0x42491A20UL)))
#define bM4_TMR42_SCSRVH_EVTDS                    (*((volatile unsigned int*)(0x42491A24UL)))
#define bM4_TMR42_SCSRVH_DEN                      (*((volatile unsigned int*)(0x42491A30UL)))
#define bM4_TMR42_SCSRVH_PEN                      (*((volatile unsigned int*)(0x42491A34UL)))
#define bM4_TMR42_SCSRVH_UEN                      (*((volatile unsigned int*)(0x42491A38UL)))
#define bM4_TMR42_SCSRVH_ZEN                      (*((volatile unsigned int*)(0x42491A3CUL)))
#define bM4_TMR42_SCMRVH_AMC0                     (*((volatile unsigned int*)(0x42491A40UL)))
#define bM4_TMR42_SCMRVH_AMC1                     (*((volatile unsigned int*)(0x42491A44UL)))
#define bM4_TMR42_SCMRVH_AMC2                     (*((volatile unsigned int*)(0x42491A48UL)))
#define bM4_TMR42_SCMRVH_AMC3                     (*((volatile unsigned int*)(0x42491A4CUL)))
#define bM4_TMR42_SCMRVH_MZCE                     (*((volatile unsigned int*)(0x42491A58UL)))
#define bM4_TMR42_SCMRVH_MPCE                     (*((volatile unsigned int*)(0x42491A5CUL)))
#define bM4_TMR42_SCSRVL_BUFEN0                   (*((volatile unsigned int*)(0x42491A80UL)))
#define bM4_TMR42_SCSRVL_BUFEN1                   (*((volatile unsigned int*)(0x42491A84UL)))
#define bM4_TMR42_SCSRVL_EVTOS0                   (*((volatile unsigned int*)(0x42491A88UL)))
#define bM4_TMR42_SCSRVL_EVTOS1                   (*((volatile unsigned int*)(0x42491A8CUL)))
#define bM4_TMR42_SCSRVL_EVTOS2                   (*((volatile unsigned int*)(0x42491A90UL)))
#define bM4_TMR42_SCSRVL_LMC                      (*((volatile unsigned int*)(0x42491A94UL)))
#define bM4_TMR42_SCSRVL_EVTMS                    (*((volatile unsigned int*)(0x42491AA0UL)))
#define bM4_TMR42_SCSRVL_EVTDS                    (*((volatile unsigned int*)(0x42491AA4UL)))
#define bM4_TMR42_SCSRVL_DEN                      (*((volatile unsigned int*)(0x42491AB0UL)))
#define bM4_TMR42_SCSRVL_PEN                      (*((volatile unsigned int*)(0x42491AB4UL)))
#define bM4_TMR42_SCSRVL_UEN                      (*((volatile unsigned int*)(0x42491AB8UL)))
#define bM4_TMR42_SCSRVL_ZEN                      (*((volatile unsigned int*)(0x42491ABCUL)))
#define bM4_TMR42_SCMRVL_AMC0                     (*((volatile unsigned int*)(0x42491AC0UL)))
#define bM4_TMR42_SCMRVL_AMC1                     (*((volatile unsigned int*)(0x42491AC4UL)))
#define bM4_TMR42_SCMRVL_AMC2                     (*((volatile unsigned int*)(0x42491AC8UL)))
#define bM4_TMR42_SCMRVL_AMC3                     (*((volatile unsigned int*)(0x42491ACCUL)))
#define bM4_TMR42_SCMRVL_MZCE                     (*((volatile unsigned int*)(0x42491AD8UL)))
#define bM4_TMR42_SCMRVL_MPCE                     (*((volatile unsigned int*)(0x42491ADCUL)))
#define bM4_TMR42_SCSRWH_BUFEN0                   (*((volatile unsigned int*)(0x42491B00UL)))
#define bM4_TMR42_SCSRWH_BUFEN1                   (*((volatile unsigned int*)(0x42491B04UL)))
#define bM4_TMR42_SCSRWH_EVTOS0                   (*((volatile unsigned int*)(0x42491B08UL)))
#define bM4_TMR42_SCSRWH_EVTOS1                   (*((volatile unsigned int*)(0x42491B0CUL)))
#define bM4_TMR42_SCSRWH_EVTOS2                   (*((volatile unsigned int*)(0x42491B10UL)))
#define bM4_TMR42_SCSRWH_LMC                      (*((volatile unsigned int*)(0x42491B14UL)))
#define bM4_TMR42_SCSRWH_EVTMS                    (*((volatile unsigned int*)(0x42491B20UL)))
#define bM4_TMR42_SCSRWH_EVTDS                    (*((volatile unsigned int*)(0x42491B24UL)))
#define bM4_TMR42_SCSRWH_DEN                      (*((volatile unsigned int*)(0x42491B30UL)))
#define bM4_TMR42_SCSRWH_PEN                      (*((volatile unsigned int*)(0x42491B34UL)))
#define bM4_TMR42_SCSRWH_UEN                      (*((volatile unsigned int*)(0x42491B38UL)))
#define bM4_TMR42_SCSRWH_ZEN                      (*((volatile unsigned int*)(0x42491B3CUL)))
#define bM4_TMR42_SCMRWH_AMC0                     (*((volatile unsigned int*)(0x42491B40UL)))
#define bM4_TMR42_SCMRWH_AMC1                     (*((volatile unsigned int*)(0x42491B44UL)))
#define bM4_TMR42_SCMRWH_AMC2                     (*((volatile unsigned int*)(0x42491B48UL)))
#define bM4_TMR42_SCMRWH_AMC3                     (*((volatile unsigned int*)(0x42491B4CUL)))
#define bM4_TMR42_SCMRWH_MZCE                     (*((volatile unsigned int*)(0x42491B58UL)))
#define bM4_TMR42_SCMRWH_MPCE                     (*((volatile unsigned int*)(0x42491B5CUL)))
#define bM4_TMR42_SCSRWL_BUFEN0                   (*((volatile unsigned int*)(0x42491B80UL)))
#define bM4_TMR42_SCSRWL_BUFEN1                   (*((volatile unsigned int*)(0x42491B84UL)))
#define bM4_TMR42_SCSRWL_EVTOS0                   (*((volatile unsigned int*)(0x42491B88UL)))
#define bM4_TMR42_SCSRWL_EVTOS1                   (*((volatile unsigned int*)(0x42491B8CUL)))
#define bM4_TMR42_SCSRWL_EVTOS2                   (*((volatile unsigned int*)(0x42491B90UL)))
#define bM4_TMR42_SCSRWL_LMC                      (*((volatile unsigned int*)(0x42491B94UL)))
#define bM4_TMR42_SCSRWL_EVTMS                    (*((volatile unsigned int*)(0x42491BA0UL)))
#define bM4_TMR42_SCSRWL_EVTDS                    (*((volatile unsigned int*)(0x42491BA4UL)))
#define bM4_TMR42_SCSRWL_DEN                      (*((volatile unsigned int*)(0x42491BB0UL)))
#define bM4_TMR42_SCSRWL_PEN                      (*((volatile unsigned int*)(0x42491BB4UL)))
#define bM4_TMR42_SCSRWL_UEN                      (*((volatile unsigned int*)(0x42491BB8UL)))
#define bM4_TMR42_SCSRWL_ZEN                      (*((volatile unsigned int*)(0x42491BBCUL)))
#define bM4_TMR42_SCMRWL_AMC0                     (*((volatile unsigned int*)(0x42491BC0UL)))
#define bM4_TMR42_SCMRWL_AMC1                     (*((volatile unsigned int*)(0x42491BC4UL)))
#define bM4_TMR42_SCMRWL_AMC2                     (*((volatile unsigned int*)(0x42491BC8UL)))
#define bM4_TMR42_SCMRWL_AMC3                     (*((volatile unsigned int*)(0x42491BCCUL)))
#define bM4_TMR42_SCMRWL_MZCE                     (*((volatile unsigned int*)(0x42491BD8UL)))
#define bM4_TMR42_SCMRWL_MPCE                     (*((volatile unsigned int*)(0x42491BDCUL)))
#define bM4_TMR42_ECSR_HOLD                       (*((volatile unsigned int*)(0x42491E1CUL)))
#define bM4_TMR43_OCSRU_OCEH                      (*((volatile unsigned int*)(0x42498300UL)))
#define bM4_TMR43_OCSRU_OCEL                      (*((volatile unsigned int*)(0x42498304UL)))
#define bM4_TMR43_OCSRU_OCPH                      (*((volatile unsigned int*)(0x42498308UL)))
#define bM4_TMR43_OCSRU_OCPL                      (*((volatile unsigned int*)(0x4249830CUL)))
#define bM4_TMR43_OCSRU_OCIEH                     (*((volatile unsigned int*)(0x42498310UL)))
#define bM4_TMR43_OCSRU_OCIEL                     (*((volatile unsigned int*)(0x42498314UL)))
#define bM4_TMR43_OCSRU_OCFH                      (*((volatile unsigned int*)(0x42498318UL)))
#define bM4_TMR43_OCSRU_OCFL                      (*((volatile unsigned int*)(0x4249831CUL)))
#define bM4_TMR43_OCERU_CHBUFEN0                  (*((volatile unsigned int*)(0x42498340UL)))
#define bM4_TMR43_OCERU_CHBUFEN1                  (*((volatile unsigned int*)(0x42498344UL)))
#define bM4_TMR43_OCERU_CLBUFEN0                  (*((volatile unsigned int*)(0x42498348UL)))
#define bM4_TMR43_OCERU_CLBUFEN1                  (*((volatile unsigned int*)(0x4249834CUL)))
#define bM4_TMR43_OCERU_MHBUFEN0                  (*((volatile unsigned int*)(0x42498350UL)))
#define bM4_TMR43_OCERU_MHBUFEN1                  (*((volatile unsigned int*)(0x42498354UL)))
#define bM4_TMR43_OCERU_MLBUFEN0                  (*((volatile unsigned int*)(0x42498358UL)))
#define bM4_TMR43_OCERU_MLBUFEN1                  (*((volatile unsigned int*)(0x4249835CUL)))
#define bM4_TMR43_OCERU_LMCH                      (*((volatile unsigned int*)(0x42498360UL)))
#define bM4_TMR43_OCERU_LMCL                      (*((volatile unsigned int*)(0x42498364UL)))
#define bM4_TMR43_OCERU_LMMH                      (*((volatile unsigned int*)(0x42498368UL)))
#define bM4_TMR43_OCERU_LMML                      (*((volatile unsigned int*)(0x4249836CUL)))
#define bM4_TMR43_OCERU_MCECH                     (*((volatile unsigned int*)(0x42498370UL)))
#define bM4_TMR43_OCERU_MCECL                     (*((volatile unsigned int*)(0x42498374UL)))
#define bM4_TMR43_OCSRV_OCEH                      (*((volatile unsigned int*)(0x42498380UL)))
#define bM4_TMR43_OCSRV_OCEL                      (*((volatile unsigned int*)(0x42498384UL)))
#define bM4_TMR43_OCSRV_OCPH                      (*((volatile unsigned int*)(0x42498388UL)))
#define bM4_TMR43_OCSRV_OCPL                      (*((volatile unsigned int*)(0x4249838CUL)))
#define bM4_TMR43_OCSRV_OCIEH                     (*((volatile unsigned int*)(0x42498390UL)))
#define bM4_TMR43_OCSRV_OCIEL                     (*((volatile unsigned int*)(0x42498394UL)))
#define bM4_TMR43_OCSRV_OCFH                      (*((volatile unsigned int*)(0x42498398UL)))
#define bM4_TMR43_OCSRV_OCFL                      (*((volatile unsigned int*)(0x4249839CUL)))
#define bM4_TMR43_OCERV_CHBUFEN0                  (*((volatile unsigned int*)(0x424983C0UL)))
#define bM4_TMR43_OCERV_CHBUFEN1                  (*((volatile unsigned int*)(0x424983C4UL)))
#define bM4_TMR43_OCERV_CLBUFEN0                  (*((volatile unsigned int*)(0x424983C8UL)))
#define bM4_TMR43_OCERV_CLBUFEN1                  (*((volatile unsigned int*)(0x424983CCUL)))
#define bM4_TMR43_OCERV_MHBUFEN0                  (*((volatile unsigned int*)(0x424983D0UL)))
#define bM4_TMR43_OCERV_MHBUFEN1                  (*((volatile unsigned int*)(0x424983D4UL)))
#define bM4_TMR43_OCERV_MLBUFEN0                  (*((volatile unsigned int*)(0x424983D8UL)))
#define bM4_TMR43_OCERV_MLBUFEN1                  (*((volatile unsigned int*)(0x424983DCUL)))
#define bM4_TMR43_OCERV_LMCH                      (*((volatile unsigned int*)(0x424983E0UL)))
#define bM4_TMR43_OCERV_LMCL                      (*((volatile unsigned int*)(0x424983E4UL)))
#define bM4_TMR43_OCERV_LMMH                      (*((volatile unsigned int*)(0x424983E8UL)))
#define bM4_TMR43_OCERV_LMML                      (*((volatile unsigned int*)(0x424983ECUL)))
#define bM4_TMR43_OCERV_MCECH                     (*((volatile unsigned int*)(0x424983F0UL)))
#define bM4_TMR43_OCERV_MCECL                     (*((volatile unsigned int*)(0x424983F4UL)))
#define bM4_TMR43_OCSRW_OCEH                      (*((volatile unsigned int*)(0x42498400UL)))
#define bM4_TMR43_OCSRW_OCEL                      (*((volatile unsigned int*)(0x42498404UL)))
#define bM4_TMR43_OCSRW_OCPH                      (*((volatile unsigned int*)(0x42498408UL)))
#define bM4_TMR43_OCSRW_OCPL                      (*((volatile unsigned int*)(0x4249840CUL)))
#define bM4_TMR43_OCSRW_OCIEH                     (*((volatile unsigned int*)(0x42498410UL)))
#define bM4_TMR43_OCSRW_OCIEL                     (*((volatile unsigned int*)(0x42498414UL)))
#define bM4_TMR43_OCSRW_OCFH                      (*((volatile unsigned int*)(0x42498418UL)))
#define bM4_TMR43_OCSRW_OCFL                      (*((volatile unsigned int*)(0x4249841CUL)))
#define bM4_TMR43_OCERW_CHBUFEN0                  (*((volatile unsigned int*)(0x42498440UL)))
#define bM4_TMR43_OCERW_CHBUFEN1                  (*((volatile unsigned int*)(0x42498444UL)))
#define bM4_TMR43_OCERW_CLBUFEN0                  (*((volatile unsigned int*)(0x42498448UL)))
#define bM4_TMR43_OCERW_CLBUFEN1                  (*((volatile unsigned int*)(0x4249844CUL)))
#define bM4_TMR43_OCERW_MHBUFEN0                  (*((volatile unsigned int*)(0x42498450UL)))
#define bM4_TMR43_OCERW_MHBUFEN1                  (*((volatile unsigned int*)(0x42498454UL)))
#define bM4_TMR43_OCERW_MLBUFEN0                  (*((volatile unsigned int*)(0x42498458UL)))
#define bM4_TMR43_OCERW_MLBUFEN1                  (*((volatile unsigned int*)(0x4249845CUL)))
#define bM4_TMR43_OCERW_LMCH                      (*((volatile unsigned int*)(0x42498460UL)))
#define bM4_TMR43_OCERW_LMCL                      (*((volatile unsigned int*)(0x42498464UL)))
#define bM4_TMR43_OCERW_LMMH                      (*((volatile unsigned int*)(0x42498468UL)))
#define bM4_TMR43_OCERW_LMML                      (*((volatile unsigned int*)(0x4249846CUL)))
#define bM4_TMR43_OCERW_MCECH                     (*((volatile unsigned int*)(0x42498470UL)))
#define bM4_TMR43_OCERW_MCECL                     (*((volatile unsigned int*)(0x42498474UL)))
#define bM4_TMR43_OCMRHUH_OCFDCH                  (*((volatile unsigned int*)(0x42498480UL)))
#define bM4_TMR43_OCMRHUH_OCFPKH                  (*((volatile unsigned int*)(0x42498484UL)))
#define bM4_TMR43_OCMRHUH_OCFUCH                  (*((volatile unsigned int*)(0x42498488UL)))
#define bM4_TMR43_OCMRHUH_OCFZRH                  (*((volatile unsigned int*)(0x4249848CUL)))
#define bM4_TMR43_OCMRHUH_OPDCH0                  (*((volatile unsigned int*)(0x42498490UL)))
#define bM4_TMR43_OCMRHUH_OPDCH1                  (*((volatile unsigned int*)(0x42498494UL)))
#define bM4_TMR43_OCMRHUH_OPPKH0                  (*((volatile unsigned int*)(0x42498498UL)))
#define bM4_TMR43_OCMRHUH_OPPKH1                  (*((volatile unsigned int*)(0x4249849CUL)))
#define bM4_TMR43_OCMRHUH_OPUCH0                  (*((volatile unsigned int*)(0x424984A0UL)))
#define bM4_TMR43_OCMRHUH_OPUCH1                  (*((volatile unsigned int*)(0x424984A4UL)))
#define bM4_TMR43_OCMRHUH_OPZRH0                  (*((volatile unsigned int*)(0x424984A8UL)))
#define bM4_TMR43_OCMRHUH_OPZRH1                  (*((volatile unsigned int*)(0x424984ACUL)))
#define bM4_TMR43_OCMRHUH_OPNPKH0                 (*((volatile unsigned int*)(0x424984B0UL)))
#define bM4_TMR43_OCMRHUH_OPNPKH1                 (*((volatile unsigned int*)(0x424984B4UL)))
#define bM4_TMR43_OCMRHUH_OPNZRH0                 (*((volatile unsigned int*)(0x424984B8UL)))
#define bM4_TMR43_OCMRHUH_OPNZRH1                 (*((volatile unsigned int*)(0x424984BCUL)))
#define bM4_TMR43_OCMRLUL_OCFDCL                  (*((volatile unsigned int*)(0x42498500UL)))
#define bM4_TMR43_OCMRLUL_OCFPKL                  (*((volatile unsigned int*)(0x42498504UL)))
#define bM4_TMR43_OCMRLUL_OCFUCL                  (*((volatile unsigned int*)(0x42498508UL)))
#define bM4_TMR43_OCMRLUL_OCFZRL                  (*((volatile unsigned int*)(0x4249850CUL)))
#define bM4_TMR43_OCMRLUL_OPDCL0                  (*((volatile unsigned int*)(0x42498510UL)))
#define bM4_TMR43_OCMRLUL_OPDCL1                  (*((volatile unsigned int*)(0x42498514UL)))
#define bM4_TMR43_OCMRLUL_OPPKL0                  (*((volatile unsigned int*)(0x42498518UL)))
#define bM4_TMR43_OCMRLUL_OPPKL1                  (*((volatile unsigned int*)(0x4249851CUL)))
#define bM4_TMR43_OCMRLUL_OPUCL0                  (*((volatile unsigned int*)(0x42498520UL)))
#define bM4_TMR43_OCMRLUL_OPUCL1                  (*((volatile unsigned int*)(0x42498524UL)))
#define bM4_TMR43_OCMRLUL_OPZRL0                  (*((volatile unsigned int*)(0x42498528UL)))
#define bM4_TMR43_OCMRLUL_OPZRL1                  (*((volatile unsigned int*)(0x4249852CUL)))
#define bM4_TMR43_OCMRLUL_OPNPKL0                 (*((volatile unsigned int*)(0x42498530UL)))
#define bM4_TMR43_OCMRLUL_OPNPKL1                 (*((volatile unsigned int*)(0x42498534UL)))
#define bM4_TMR43_OCMRLUL_OPNZRL0                 (*((volatile unsigned int*)(0x42498538UL)))
#define bM4_TMR43_OCMRLUL_OPNZRL1                 (*((volatile unsigned int*)(0x4249853CUL)))
#define bM4_TMR43_OCMRLUL_EOPNDCL0                (*((volatile unsigned int*)(0x42498540UL)))
#define bM4_TMR43_OCMRLUL_EOPNDCL1                (*((volatile unsigned int*)(0x42498544UL)))
#define bM4_TMR43_OCMRLUL_EOPNUCL0                (*((volatile unsigned int*)(0x42498548UL)))
#define bM4_TMR43_OCMRLUL_EOPNUCL1                (*((volatile unsigned int*)(0x4249854CUL)))
#define bM4_TMR43_OCMRLUL_EOPDCL0                 (*((volatile unsigned int*)(0x42498550UL)))
#define bM4_TMR43_OCMRLUL_EOPDCL1                 (*((volatile unsigned int*)(0x42498554UL)))
#define bM4_TMR43_OCMRLUL_EOPPKL0                 (*((volatile unsigned int*)(0x42498558UL)))
#define bM4_TMR43_OCMRLUL_EOPPKL1                 (*((volatile unsigned int*)(0x4249855CUL)))
#define bM4_TMR43_OCMRLUL_EOPUCL0                 (*((volatile unsigned int*)(0x42498560UL)))
#define bM4_TMR43_OCMRLUL_EOPUCL1                 (*((volatile unsigned int*)(0x42498564UL)))
#define bM4_TMR43_OCMRLUL_EOPZRL0                 (*((volatile unsigned int*)(0x42498568UL)))
#define bM4_TMR43_OCMRLUL_EOPZRL1                 (*((volatile unsigned int*)(0x4249856CUL)))
#define bM4_TMR43_OCMRLUL_EOPNPKL0                (*((volatile unsigned int*)(0x42498570UL)))
#define bM4_TMR43_OCMRLUL_EOPNPKL1                (*((volatile unsigned int*)(0x42498574UL)))
#define bM4_TMR43_OCMRLUL_EOPNZRL0                (*((volatile unsigned int*)(0x42498578UL)))
#define bM4_TMR43_OCMRLUL_EOPNZRL1                (*((volatile unsigned int*)(0x4249857CUL)))
#define bM4_TMR43_OCMRHVH_OCFDCH                  (*((volatile unsigned int*)(0x42498580UL)))
#define bM4_TMR43_OCMRHVH_OCFPKH                  (*((volatile unsigned int*)(0x42498584UL)))
#define bM4_TMR43_OCMRHVH_OCFUCH                  (*((volatile unsigned int*)(0x42498588UL)))
#define bM4_TMR43_OCMRHVH_OCFZRH                  (*((volatile unsigned int*)(0x4249858CUL)))
#define bM4_TMR43_OCMRHVH_OPDCH0                  (*((volatile unsigned int*)(0x42498590UL)))
#define bM4_TMR43_OCMRHVH_OPDCH1                  (*((volatile unsigned int*)(0x42498594UL)))
#define bM4_TMR43_OCMRHVH_OPPKH0                  (*((volatile unsigned int*)(0x42498598UL)))
#define bM4_TMR43_OCMRHVH_OPPKH1                  (*((volatile unsigned int*)(0x4249859CUL)))
#define bM4_TMR43_OCMRHVH_OPUCH0                  (*((volatile unsigned int*)(0x424985A0UL)))
#define bM4_TMR43_OCMRHVH_OPUCH1                  (*((volatile unsigned int*)(0x424985A4UL)))
#define bM4_TMR43_OCMRHVH_OPZRH0                  (*((volatile unsigned int*)(0x424985A8UL)))
#define bM4_TMR43_OCMRHVH_OPZRH1                  (*((volatile unsigned int*)(0x424985ACUL)))
#define bM4_TMR43_OCMRHVH_OPNPKH0                 (*((volatile unsigned int*)(0x424985B0UL)))
#define bM4_TMR43_OCMRHVH_OPNPKH1                 (*((volatile unsigned int*)(0x424985B4UL)))
#define bM4_TMR43_OCMRHVH_OPNZRH0                 (*((volatile unsigned int*)(0x424985B8UL)))
#define bM4_TMR43_OCMRHVH_OPNZRH1                 (*((volatile unsigned int*)(0x424985BCUL)))
#define bM4_TMR43_OCMRLVL_OCFDCL                  (*((volatile unsigned int*)(0x42498600UL)))
#define bM4_TMR43_OCMRLVL_OCFPKL                  (*((volatile unsigned int*)(0x42498604UL)))
#define bM4_TMR43_OCMRLVL_OCFUCL                  (*((volatile unsigned int*)(0x42498608UL)))
#define bM4_TMR43_OCMRLVL_OCFZRL                  (*((volatile unsigned int*)(0x4249860CUL)))
#define bM4_TMR43_OCMRLVL_OPDCL0                  (*((volatile unsigned int*)(0x42498610UL)))
#define bM4_TMR43_OCMRLVL_OPDCL1                  (*((volatile unsigned int*)(0x42498614UL)))
#define bM4_TMR43_OCMRLVL_OPPKL0                  (*((volatile unsigned int*)(0x42498618UL)))
#define bM4_TMR43_OCMRLVL_OPPKL1                  (*((volatile unsigned int*)(0x4249861CUL)))
#define bM4_TMR43_OCMRLVL_OPUCL0                  (*((volatile unsigned int*)(0x42498620UL)))
#define bM4_TMR43_OCMRLVL_OPUCL1                  (*((volatile unsigned int*)(0x42498624UL)))
#define bM4_TMR43_OCMRLVL_OPZRL0                  (*((volatile unsigned int*)(0x42498628UL)))
#define bM4_TMR43_OCMRLVL_OPZRL1                  (*((volatile unsigned int*)(0x4249862CUL)))
#define bM4_TMR43_OCMRLVL_OPNPKL0                 (*((volatile unsigned int*)(0x42498630UL)))
#define bM4_TMR43_OCMRLVL_OPNPKL1                 (*((volatile unsigned int*)(0x42498634UL)))
#define bM4_TMR43_OCMRLVL_OPNZRL0                 (*((volatile unsigned int*)(0x42498638UL)))
#define bM4_TMR43_OCMRLVL_OPNZRL1                 (*((volatile unsigned int*)(0x4249863CUL)))
#define bM4_TMR43_OCMRLVL_EOPNDCL0                (*((volatile unsigned int*)(0x42498640UL)))
#define bM4_TMR43_OCMRLVL_EOPNDCL1                (*((volatile unsigned int*)(0x42498644UL)))
#define bM4_TMR43_OCMRLVL_EOPNUCL0                (*((volatile unsigned int*)(0x42498648UL)))
#define bM4_TMR43_OCMRLVL_EOPNUCL1                (*((volatile unsigned int*)(0x4249864CUL)))
#define bM4_TMR43_OCMRLVL_EOPDCL0                 (*((volatile unsigned int*)(0x42498650UL)))
#define bM4_TMR43_OCMRLVL_EOPDCL1                 (*((volatile unsigned int*)(0x42498654UL)))
#define bM4_TMR43_OCMRLVL_EOPPKL0                 (*((volatile unsigned int*)(0x42498658UL)))
#define bM4_TMR43_OCMRLVL_EOPPKL1                 (*((volatile unsigned int*)(0x4249865CUL)))
#define bM4_TMR43_OCMRLVL_EOPUCL0                 (*((volatile unsigned int*)(0x42498660UL)))
#define bM4_TMR43_OCMRLVL_EOPUCL1                 (*((volatile unsigned int*)(0x42498664UL)))
#define bM4_TMR43_OCMRLVL_EOPZRL0                 (*((volatile unsigned int*)(0x42498668UL)))
#define bM4_TMR43_OCMRLVL_EOPZRL1                 (*((volatile unsigned int*)(0x4249866CUL)))
#define bM4_TMR43_OCMRLVL_EOPNPKL0                (*((volatile unsigned int*)(0x42498670UL)))
#define bM4_TMR43_OCMRLVL_EOPNPKL1                (*((volatile unsigned int*)(0x42498674UL)))
#define bM4_TMR43_OCMRLVL_EOPNZRL0                (*((volatile unsigned int*)(0x42498678UL)))
#define bM4_TMR43_OCMRLVL_EOPNZRL1                (*((volatile unsigned int*)(0x4249867CUL)))
#define bM4_TMR43_OCMRHWH_OCFDCH                  (*((volatile unsigned int*)(0x42498680UL)))
#define bM4_TMR43_OCMRHWH_OCFPKH                  (*((volatile unsigned int*)(0x42498684UL)))
#define bM4_TMR43_OCMRHWH_OCFUCH                  (*((volatile unsigned int*)(0x42498688UL)))
#define bM4_TMR43_OCMRHWH_OCFZRH                  (*((volatile unsigned int*)(0x4249868CUL)))
#define bM4_TMR43_OCMRHWH_OPDCH0                  (*((volatile unsigned int*)(0x42498690UL)))
#define bM4_TMR43_OCMRHWH_OPDCH1                  (*((volatile unsigned int*)(0x42498694UL)))
#define bM4_TMR43_OCMRHWH_OPPKH0                  (*((volatile unsigned int*)(0x42498698UL)))
#define bM4_TMR43_OCMRHWH_OPPKH1                  (*((volatile unsigned int*)(0x4249869CUL)))
#define bM4_TMR43_OCMRHWH_OPUCH0                  (*((volatile unsigned int*)(0x424986A0UL)))
#define bM4_TMR43_OCMRHWH_OPUCH1                  (*((volatile unsigned int*)(0x424986A4UL)))
#define bM4_TMR43_OCMRHWH_OPZRH0                  (*((volatile unsigned int*)(0x424986A8UL)))
#define bM4_TMR43_OCMRHWH_OPZRH1                  (*((volatile unsigned int*)(0x424986ACUL)))
#define bM4_TMR43_OCMRHWH_OPNPKH0                 (*((volatile unsigned int*)(0x424986B0UL)))
#define bM4_TMR43_OCMRHWH_OPNPKH1                 (*((volatile unsigned int*)(0x424986B4UL)))
#define bM4_TMR43_OCMRHWH_OPNZRH0                 (*((volatile unsigned int*)(0x424986B8UL)))
#define bM4_TMR43_OCMRHWH_OPNZRH1                 (*((volatile unsigned int*)(0x424986BCUL)))
#define bM4_TMR43_OCMRLWL_OCFDCL                  (*((volatile unsigned int*)(0x42498700UL)))
#define bM4_TMR43_OCMRLWL_OCFPKL                  (*((volatile unsigned int*)(0x42498704UL)))
#define bM4_TMR43_OCMRLWL_OCFUCL                  (*((volatile unsigned int*)(0x42498708UL)))
#define bM4_TMR43_OCMRLWL_OCFZRL                  (*((volatile unsigned int*)(0x4249870CUL)))
#define bM4_TMR43_OCMRLWL_OPDCL0                  (*((volatile unsigned int*)(0x42498710UL)))
#define bM4_TMR43_OCMRLWL_OPDCL1                  (*((volatile unsigned int*)(0x42498714UL)))
#define bM4_TMR43_OCMRLWL_OPPKL0                  (*((volatile unsigned int*)(0x42498718UL)))
#define bM4_TMR43_OCMRLWL_OPPKL1                  (*((volatile unsigned int*)(0x4249871CUL)))
#define bM4_TMR43_OCMRLWL_OPUCL0                  (*((volatile unsigned int*)(0x42498720UL)))
#define bM4_TMR43_OCMRLWL_OPUCL1                  (*((volatile unsigned int*)(0x42498724UL)))
#define bM4_TMR43_OCMRLWL_OPZRL0                  (*((volatile unsigned int*)(0x42498728UL)))
#define bM4_TMR43_OCMRLWL_OPZRL1                  (*((volatile unsigned int*)(0x4249872CUL)))
#define bM4_TMR43_OCMRLWL_OPNPKL0                 (*((volatile unsigned int*)(0x42498730UL)))
#define bM4_TMR43_OCMRLWL_OPNPKL1                 (*((volatile unsigned int*)(0x42498734UL)))
#define bM4_TMR43_OCMRLWL_OPNZRL0                 (*((volatile unsigned int*)(0x42498738UL)))
#define bM4_TMR43_OCMRLWL_OPNZRL1                 (*((volatile unsigned int*)(0x4249873CUL)))
#define bM4_TMR43_OCMRLWL_EOPNDCL0                (*((volatile unsigned int*)(0x42498740UL)))
#define bM4_TMR43_OCMRLWL_EOPNDCL1                (*((volatile unsigned int*)(0x42498744UL)))
#define bM4_TMR43_OCMRLWL_EOPNUCL0                (*((volatile unsigned int*)(0x42498748UL)))
#define bM4_TMR43_OCMRLWL_EOPNUCL1                (*((volatile unsigned int*)(0x4249874CUL)))
#define bM4_TMR43_OCMRLWL_EOPDCL0                 (*((volatile unsigned int*)(0x42498750UL)))
#define bM4_TMR43_OCMRLWL_EOPDCL1                 (*((volatile unsigned int*)(0x42498754UL)))
#define bM4_TMR43_OCMRLWL_EOPPKL0                 (*((volatile unsigned int*)(0x42498758UL)))
#define bM4_TMR43_OCMRLWL_EOPPKL1                 (*((volatile unsigned int*)(0x4249875CUL)))
#define bM4_TMR43_OCMRLWL_EOPUCL0                 (*((volatile unsigned int*)(0x42498760UL)))
#define bM4_TMR43_OCMRLWL_EOPUCL1                 (*((volatile unsigned int*)(0x42498764UL)))
#define bM4_TMR43_OCMRLWL_EOPZRL0                 (*((volatile unsigned int*)(0x42498768UL)))
#define bM4_TMR43_OCMRLWL_EOPZRL1                 (*((volatile unsigned int*)(0x4249876CUL)))
#define bM4_TMR43_OCMRLWL_EOPNPKL0                (*((volatile unsigned int*)(0x42498770UL)))
#define bM4_TMR43_OCMRLWL_EOPNPKL1                (*((volatile unsigned int*)(0x42498774UL)))
#define bM4_TMR43_OCMRLWL_EOPNZRL0                (*((volatile unsigned int*)(0x42498778UL)))
#define bM4_TMR43_OCMRLWL_EOPNZRL1                (*((volatile unsigned int*)(0x4249877CUL)))
#define bM4_TMR43_CCSR_CKDIV0                     (*((volatile unsigned int*)(0x42498900UL)))
#define bM4_TMR43_CCSR_CKDIV1                     (*((volatile unsigned int*)(0x42498904UL)))
#define bM4_TMR43_CCSR_CKDIV2                     (*((volatile unsigned int*)(0x42498908UL)))
#define bM4_TMR43_CCSR_CKDIV3                     (*((volatile unsigned int*)(0x4249890CUL)))
#define bM4_TMR43_CCSR_CLEAR                      (*((volatile unsigned int*)(0x42498910UL)))
#define bM4_TMR43_CCSR_MODE                       (*((volatile unsigned int*)(0x42498914UL)))
#define bM4_TMR43_CCSR_STOP                       (*((volatile unsigned int*)(0x42498918UL)))
#define bM4_TMR43_CCSR_BUFEN                      (*((volatile unsigned int*)(0x4249891CUL)))
#define bM4_TMR43_CCSR_IRQPEN                     (*((volatile unsigned int*)(0x42498920UL)))
#define bM4_TMR43_CCSR_IRQPF                      (*((volatile unsigned int*)(0x42498924UL)))
#define bM4_TMR43_CCSR_IRQZEN                     (*((volatile unsigned int*)(0x42498934UL)))
#define bM4_TMR43_CCSR_IRQZF                      (*((volatile unsigned int*)(0x42498938UL)))
#define bM4_TMR43_CCSR_ECKEN                      (*((volatile unsigned int*)(0x4249893CUL)))
#define bM4_TMR43_CVPR_ZIM0                       (*((volatile unsigned int*)(0x42498940UL)))
#define bM4_TMR43_CVPR_ZIM1                       (*((volatile unsigned int*)(0x42498944UL)))
#define bM4_TMR43_CVPR_ZIM2                       (*((volatile unsigned int*)(0x42498948UL)))
#define bM4_TMR43_CVPR_ZIM3                       (*((volatile unsigned int*)(0x4249894CUL)))
#define bM4_TMR43_CVPR_PIM0                       (*((volatile unsigned int*)(0x42498950UL)))
#define bM4_TMR43_CVPR_PIM1                       (*((volatile unsigned int*)(0x42498954UL)))
#define bM4_TMR43_CVPR_PIM2                       (*((volatile unsigned int*)(0x42498958UL)))
#define bM4_TMR43_CVPR_PIM3                       (*((volatile unsigned int*)(0x4249895CUL)))
#define bM4_TMR43_CVPR_ZIC0                       (*((volatile unsigned int*)(0x42498960UL)))
#define bM4_TMR43_CVPR_ZIC1                       (*((volatile unsigned int*)(0x42498964UL)))
#define bM4_TMR43_CVPR_ZIC2                       (*((volatile unsigned int*)(0x42498968UL)))
#define bM4_TMR43_CVPR_ZIC3                       (*((volatile unsigned int*)(0x4249896CUL)))
#define bM4_TMR43_CVPR_PIC0                       (*((volatile unsigned int*)(0x42498970UL)))
#define bM4_TMR43_CVPR_PIC1                       (*((volatile unsigned int*)(0x42498974UL)))
#define bM4_TMR43_CVPR_PIC2                       (*((volatile unsigned int*)(0x42498978UL)))
#define bM4_TMR43_CVPR_PIC3                       (*((volatile unsigned int*)(0x4249897CUL)))
#define bM4_TMR43_POCRU_DIVCK0                    (*((volatile unsigned int*)(0x42499300UL)))
#define bM4_TMR43_POCRU_DIVCK1                    (*((volatile unsigned int*)(0x42499304UL)))
#define bM4_TMR43_POCRU_DIVCK2                    (*((volatile unsigned int*)(0x42499308UL)))
#define bM4_TMR43_POCRU_DIVCK3                    (*((volatile unsigned int*)(0x4249930CUL)))
#define bM4_TMR43_POCRU_PWMMD0                    (*((volatile unsigned int*)(0x42499310UL)))
#define bM4_TMR43_POCRU_PWMMD1                    (*((volatile unsigned int*)(0x42499314UL)))
#define bM4_TMR43_POCRU_LVLS0                     (*((volatile unsigned int*)(0x42499318UL)))
#define bM4_TMR43_POCRU_LVLS1                     (*((volatile unsigned int*)(0x4249931CUL)))
#define bM4_TMR43_POCRV_DIVCK0                    (*((volatile unsigned int*)(0x42499380UL)))
#define bM4_TMR43_POCRV_DIVCK1                    (*((volatile unsigned int*)(0x42499384UL)))
#define bM4_TMR43_POCRV_DIVCK2                    (*((volatile unsigned int*)(0x42499388UL)))
#define bM4_TMR43_POCRV_DIVCK3                    (*((volatile unsigned int*)(0x4249938CUL)))
#define bM4_TMR43_POCRV_PWMMD0                    (*((volatile unsigned int*)(0x42499390UL)))
#define bM4_TMR43_POCRV_PWMMD1                    (*((volatile unsigned int*)(0x42499394UL)))
#define bM4_TMR43_POCRV_LVLS0                     (*((volatile unsigned int*)(0x42499398UL)))
#define bM4_TMR43_POCRV_LVLS1                     (*((volatile unsigned int*)(0x4249939CUL)))
#define bM4_TMR43_POCRW_DIVCK0                    (*((volatile unsigned int*)(0x42499400UL)))
#define bM4_TMR43_POCRW_DIVCK1                    (*((volatile unsigned int*)(0x42499404UL)))
#define bM4_TMR43_POCRW_DIVCK2                    (*((volatile unsigned int*)(0x42499408UL)))
#define bM4_TMR43_POCRW_DIVCK3                    (*((volatile unsigned int*)(0x4249940CUL)))
#define bM4_TMR43_POCRW_PWMMD0                    (*((volatile unsigned int*)(0x42499410UL)))
#define bM4_TMR43_POCRW_PWMMD1                    (*((volatile unsigned int*)(0x42499414UL)))
#define bM4_TMR43_POCRW_LVLS0                     (*((volatile unsigned int*)(0x42499418UL)))
#define bM4_TMR43_POCRW_LVLS1                     (*((volatile unsigned int*)(0x4249941CUL)))
#define bM4_TMR43_RCSR_RTIDU                      (*((volatile unsigned int*)(0x42499480UL)))
#define bM4_TMR43_RCSR_RTIDV                      (*((volatile unsigned int*)(0x42499484UL)))
#define bM4_TMR43_RCSR_RTIDW                      (*((volatile unsigned int*)(0x42499488UL)))
#define bM4_TMR43_RCSR_RTIFU                      (*((volatile unsigned int*)(0x42499490UL)))
#define bM4_TMR43_RCSR_RTICU                      (*((volatile unsigned int*)(0x42499494UL)))
#define bM4_TMR43_RCSR_RTEU                       (*((volatile unsigned int*)(0x42499498UL)))
#define bM4_TMR43_RCSR_RTSU                       (*((volatile unsigned int*)(0x4249949CUL)))
#define bM4_TMR43_RCSR_RTIFV                      (*((volatile unsigned int*)(0x424994A0UL)))
#define bM4_TMR43_RCSR_RTICV                      (*((volatile unsigned int*)(0x424994A4UL)))
#define bM4_TMR43_RCSR_RTEV                       (*((volatile unsigned int*)(0x424994A8UL)))
#define bM4_TMR43_RCSR_RTSV                       (*((volatile unsigned int*)(0x424994ACUL)))
#define bM4_TMR43_RCSR_RTIFW                      (*((volatile unsigned int*)(0x424994B0UL)))
#define bM4_TMR43_RCSR_RTICW                      (*((volatile unsigned int*)(0x424994B4UL)))
#define bM4_TMR43_RCSR_RTEW                       (*((volatile unsigned int*)(0x424994B8UL)))
#define bM4_TMR43_RCSR_RTSW                       (*((volatile unsigned int*)(0x424994BCUL)))
#define bM4_TMR43_SCSRUH_BUFEN0                   (*((volatile unsigned int*)(0x42499900UL)))
#define bM4_TMR43_SCSRUH_BUFEN1                   (*((volatile unsigned int*)(0x42499904UL)))
#define bM4_TMR43_SCSRUH_EVTOS0                   (*((volatile unsigned int*)(0x42499908UL)))
#define bM4_TMR43_SCSRUH_EVTOS1                   (*((volatile unsigned int*)(0x4249990CUL)))
#define bM4_TMR43_SCSRUH_EVTOS2                   (*((volatile unsigned int*)(0x42499910UL)))
#define bM4_TMR43_SCSRUH_LMC                      (*((volatile unsigned int*)(0x42499914UL)))
#define bM4_TMR43_SCSRUH_EVTMS                    (*((volatile unsigned int*)(0x42499920UL)))
#define bM4_TMR43_SCSRUH_EVTDS                    (*((volatile unsigned int*)(0x42499924UL)))
#define bM4_TMR43_SCSRUH_DEN                      (*((volatile unsigned int*)(0x42499930UL)))
#define bM4_TMR43_SCSRUH_PEN                      (*((volatile unsigned int*)(0x42499934UL)))
#define bM4_TMR43_SCSRUH_UEN                      (*((volatile unsigned int*)(0x42499938UL)))
#define bM4_TMR43_SCSRUH_ZEN                      (*((volatile unsigned int*)(0x4249993CUL)))
#define bM4_TMR43_SCMRUH_AMC0                     (*((volatile unsigned int*)(0x42499940UL)))
#define bM4_TMR43_SCMRUH_AMC1                     (*((volatile unsigned int*)(0x42499944UL)))
#define bM4_TMR43_SCMRUH_AMC2                     (*((volatile unsigned int*)(0x42499948UL)))
#define bM4_TMR43_SCMRUH_AMC3                     (*((volatile unsigned int*)(0x4249994CUL)))
#define bM4_TMR43_SCMRUH_MZCE                     (*((volatile unsigned int*)(0x42499958UL)))
#define bM4_TMR43_SCMRUH_MPCE                     (*((volatile unsigned int*)(0x4249995CUL)))
#define bM4_TMR43_SCSRUL_BUFEN0                   (*((volatile unsigned int*)(0x42499980UL)))
#define bM4_TMR43_SCSRUL_BUFEN1                   (*((volatile unsigned int*)(0x42499984UL)))
#define bM4_TMR43_SCSRUL_EVTOS0                   (*((volatile unsigned int*)(0x42499988UL)))
#define bM4_TMR43_SCSRUL_EVTOS1                   (*((volatile unsigned int*)(0x4249998CUL)))
#define bM4_TMR43_SCSRUL_EVTOS2                   (*((volatile unsigned int*)(0x42499990UL)))
#define bM4_TMR43_SCSRUL_LMC                      (*((volatile unsigned int*)(0x42499994UL)))
#define bM4_TMR43_SCSRUL_EVTMS                    (*((volatile unsigned int*)(0x424999A0UL)))
#define bM4_TMR43_SCSRUL_EVTDS                    (*((volatile unsigned int*)(0x424999A4UL)))
#define bM4_TMR43_SCSRUL_DEN                      (*((volatile unsigned int*)(0x424999B0UL)))
#define bM4_TMR43_SCSRUL_PEN                      (*((volatile unsigned int*)(0x424999B4UL)))
#define bM4_TMR43_SCSRUL_UEN                      (*((volatile unsigned int*)(0x424999B8UL)))
#define bM4_TMR43_SCSRUL_ZEN                      (*((volatile unsigned int*)(0x424999BCUL)))
#define bM4_TMR43_SCMRUL_AMC0                     (*((volatile unsigned int*)(0x424999C0UL)))
#define bM4_TMR43_SCMRUL_AMC1                     (*((volatile unsigned int*)(0x424999C4UL)))
#define bM4_TMR43_SCMRUL_AMC2                     (*((volatile unsigned int*)(0x424999C8UL)))
#define bM4_TMR43_SCMRUL_AMC3                     (*((volatile unsigned int*)(0x424999CCUL)))
#define bM4_TMR43_SCMRUL_MZCE                     (*((volatile unsigned int*)(0x424999D8UL)))
#define bM4_TMR43_SCMRUL_MPCE                     (*((volatile unsigned int*)(0x424999DCUL)))
#define bM4_TMR43_SCSRVH_BUFEN0                   (*((volatile unsigned int*)(0x42499A00UL)))
#define bM4_TMR43_SCSRVH_BUFEN1                   (*((volatile unsigned int*)(0x42499A04UL)))
#define bM4_TMR43_SCSRVH_EVTOS0                   (*((volatile unsigned int*)(0x42499A08UL)))
#define bM4_TMR43_SCSRVH_EVTOS1                   (*((volatile unsigned int*)(0x42499A0CUL)))
#define bM4_TMR43_SCSRVH_EVTOS2                   (*((volatile unsigned int*)(0x42499A10UL)))
#define bM4_TMR43_SCSRVH_LMC                      (*((volatile unsigned int*)(0x42499A14UL)))
#define bM4_TMR43_SCSRVH_EVTMS                    (*((volatile unsigned int*)(0x42499A20UL)))
#define bM4_TMR43_SCSRVH_EVTDS                    (*((volatile unsigned int*)(0x42499A24UL)))
#define bM4_TMR43_SCSRVH_DEN                      (*((volatile unsigned int*)(0x42499A30UL)))
#define bM4_TMR43_SCSRVH_PEN                      (*((volatile unsigned int*)(0x42499A34UL)))
#define bM4_TMR43_SCSRVH_UEN                      (*((volatile unsigned int*)(0x42499A38UL)))
#define bM4_TMR43_SCSRVH_ZEN                      (*((volatile unsigned int*)(0x42499A3CUL)))
#define bM4_TMR43_SCMRVH_AMC0                     (*((volatile unsigned int*)(0x42499A40UL)))
#define bM4_TMR43_SCMRVH_AMC1                     (*((volatile unsigned int*)(0x42499A44UL)))
#define bM4_TMR43_SCMRVH_AMC2                     (*((volatile unsigned int*)(0x42499A48UL)))
#define bM4_TMR43_SCMRVH_AMC3                     (*((volatile unsigned int*)(0x42499A4CUL)))
#define bM4_TMR43_SCMRVH_MZCE                     (*((volatile unsigned int*)(0x42499A58UL)))
#define bM4_TMR43_SCMRVH_MPCE                     (*((volatile unsigned int*)(0x42499A5CUL)))
#define bM4_TMR43_SCSRVL_BUFEN0                   (*((volatile unsigned int*)(0x42499A80UL)))
#define bM4_TMR43_SCSRVL_BUFEN1                   (*((volatile unsigned int*)(0x42499A84UL)))
#define bM4_TMR43_SCSRVL_EVTOS0                   (*((volatile unsigned int*)(0x42499A88UL)))
#define bM4_TMR43_SCSRVL_EVTOS1                   (*((volatile unsigned int*)(0x42499A8CUL)))
#define bM4_TMR43_SCSRVL_EVTOS2                   (*((volatile unsigned int*)(0x42499A90UL)))
#define bM4_TMR43_SCSRVL_LMC                      (*((volatile unsigned int*)(0x42499A94UL)))
#define bM4_TMR43_SCSRVL_EVTMS                    (*((volatile unsigned int*)(0x42499AA0UL)))
#define bM4_TMR43_SCSRVL_EVTDS                    (*((volatile unsigned int*)(0x42499AA4UL)))
#define bM4_TMR43_SCSRVL_DEN                      (*((volatile unsigned int*)(0x42499AB0UL)))
#define bM4_TMR43_SCSRVL_PEN                      (*((volatile unsigned int*)(0x42499AB4UL)))
#define bM4_TMR43_SCSRVL_UEN                      (*((volatile unsigned int*)(0x42499AB8UL)))
#define bM4_TMR43_SCSRVL_ZEN                      (*((volatile unsigned int*)(0x42499ABCUL)))
#define bM4_TMR43_SCMRVL_AMC0                     (*((volatile unsigned int*)(0x42499AC0UL)))
#define bM4_TMR43_SCMRVL_AMC1                     (*((volatile unsigned int*)(0x42499AC4UL)))
#define bM4_TMR43_SCMRVL_AMC2                     (*((volatile unsigned int*)(0x42499AC8UL)))
#define bM4_TMR43_SCMRVL_AMC3                     (*((volatile unsigned int*)(0x42499ACCUL)))
#define bM4_TMR43_SCMRVL_MZCE                     (*((volatile unsigned int*)(0x42499AD8UL)))
#define bM4_TMR43_SCMRVL_MPCE                     (*((volatile unsigned int*)(0x42499ADCUL)))
#define bM4_TMR43_SCSRWH_BUFEN0                   (*((volatile unsigned int*)(0x42499B00UL)))
#define bM4_TMR43_SCSRWH_BUFEN1                   (*((volatile unsigned int*)(0x42499B04UL)))
#define bM4_TMR43_SCSRWH_EVTOS0                   (*((volatile unsigned int*)(0x42499B08UL)))
#define bM4_TMR43_SCSRWH_EVTOS1                   (*((volatile unsigned int*)(0x42499B0CUL)))
#define bM4_TMR43_SCSRWH_EVTOS2                   (*((volatile unsigned int*)(0x42499B10UL)))
#define bM4_TMR43_SCSRWH_LMC                      (*((volatile unsigned int*)(0x42499B14UL)))
#define bM4_TMR43_SCSRWH_EVTMS                    (*((volatile unsigned int*)(0x42499B20UL)))
#define bM4_TMR43_SCSRWH_EVTDS                    (*((volatile unsigned int*)(0x42499B24UL)))
#define bM4_TMR43_SCSRWH_DEN                      (*((volatile unsigned int*)(0x42499B30UL)))
#define bM4_TMR43_SCSRWH_PEN                      (*((volatile unsigned int*)(0x42499B34UL)))
#define bM4_TMR43_SCSRWH_UEN                      (*((volatile unsigned int*)(0x42499B38UL)))
#define bM4_TMR43_SCSRWH_ZEN                      (*((volatile unsigned int*)(0x42499B3CUL)))
#define bM4_TMR43_SCMRWH_AMC0                     (*((volatile unsigned int*)(0x42499B40UL)))
#define bM4_TMR43_SCMRWH_AMC1                     (*((volatile unsigned int*)(0x42499B44UL)))
#define bM4_TMR43_SCMRWH_AMC2                     (*((volatile unsigned int*)(0x42499B48UL)))
#define bM4_TMR43_SCMRWH_AMC3                     (*((volatile unsigned int*)(0x42499B4CUL)))
#define bM4_TMR43_SCMRWH_MZCE                     (*((volatile unsigned int*)(0x42499B58UL)))
#define bM4_TMR43_SCMRWH_MPCE                     (*((volatile unsigned int*)(0x42499B5CUL)))
#define bM4_TMR43_SCSRWL_BUFEN0                   (*((volatile unsigned int*)(0x42499B80UL)))
#define bM4_TMR43_SCSRWL_BUFEN1                   (*((volatile unsigned int*)(0x42499B84UL)))
#define bM4_TMR43_SCSRWL_EVTOS0                   (*((volatile unsigned int*)(0x42499B88UL)))
#define bM4_TMR43_SCSRWL_EVTOS1                   (*((volatile unsigned int*)(0x42499B8CUL)))
#define bM4_TMR43_SCSRWL_EVTOS2                   (*((volatile unsigned int*)(0x42499B90UL)))
#define bM4_TMR43_SCSRWL_LMC                      (*((volatile unsigned int*)(0x42499B94UL)))
#define bM4_TMR43_SCSRWL_EVTMS                    (*((volatile unsigned int*)(0x42499BA0UL)))
#define bM4_TMR43_SCSRWL_EVTDS                    (*((volatile unsigned int*)(0x42499BA4UL)))
#define bM4_TMR43_SCSRWL_DEN                      (*((volatile unsigned int*)(0x42499BB0UL)))
#define bM4_TMR43_SCSRWL_PEN                      (*((volatile unsigned int*)(0x42499BB4UL)))
#define bM4_TMR43_SCSRWL_UEN                      (*((volatile unsigned int*)(0x42499BB8UL)))
#define bM4_TMR43_SCSRWL_ZEN                      (*((volatile unsigned int*)(0x42499BBCUL)))
#define bM4_TMR43_SCMRWL_AMC0                     (*((volatile unsigned int*)(0x42499BC0UL)))
#define bM4_TMR43_SCMRWL_AMC1                     (*((volatile unsigned int*)(0x42499BC4UL)))
#define bM4_TMR43_SCMRWL_AMC2                     (*((volatile unsigned int*)(0x42499BC8UL)))
#define bM4_TMR43_SCMRWL_AMC3                     (*((volatile unsigned int*)(0x42499BCCUL)))
#define bM4_TMR43_SCMRWL_MZCE                     (*((volatile unsigned int*)(0x42499BD8UL)))
#define bM4_TMR43_SCMRWL_MPCE                     (*((volatile unsigned int*)(0x42499BDCUL)))
#define bM4_TMR43_ECSR_HOLD                       (*((volatile unsigned int*)(0x42499E1CUL)))
#define bM4_TMR4_CR_ECER1_EMBVAL0                 (*((volatile unsigned int*)(0x42AA8100UL)))
#define bM4_TMR4_CR_ECER1_EMBVAL1                 (*((volatile unsigned int*)(0x42AA8104UL)))
#define bM4_TMR4_CR_ECER2_EMBVAL0                 (*((volatile unsigned int*)(0x42AA8180UL)))
#define bM4_TMR4_CR_ECER2_EMBVAL1                 (*((volatile unsigned int*)(0x42AA8184UL)))
#define bM4_TMR4_CR_ECER3_EMBVAL0                 (*((volatile unsigned int*)(0x42AA8200UL)))
#define bM4_TMR4_CR_ECER3_EMBVAL1                 (*((volatile unsigned int*)(0x42AA8204UL)))
#define bM4_TMR61_CNTER_CNT0                      (*((volatile unsigned int*)(0x42300000UL)))
#define bM4_TMR61_CNTER_CNT1                      (*((volatile unsigned int*)(0x42300004UL)))
#define bM4_TMR61_CNTER_CNT2                      (*((volatile unsigned int*)(0x42300008UL)))
#define bM4_TMR61_CNTER_CNT3                      (*((volatile unsigned int*)(0x4230000CUL)))
#define bM4_TMR61_CNTER_CNT4                      (*((volatile unsigned int*)(0x42300010UL)))
#define bM4_TMR61_CNTER_CNT5                      (*((volatile unsigned int*)(0x42300014UL)))
#define bM4_TMR61_CNTER_CNT6                      (*((volatile unsigned int*)(0x42300018UL)))
#define bM4_TMR61_CNTER_CNT7                      (*((volatile unsigned int*)(0x4230001CUL)))
#define bM4_TMR61_CNTER_CNT8                      (*((volatile unsigned int*)(0x42300020UL)))
#define bM4_TMR61_CNTER_CNT9                      (*((volatile unsigned int*)(0x42300024UL)))
#define bM4_TMR61_CNTER_CNT10                     (*((volatile unsigned int*)(0x42300028UL)))
#define bM4_TMR61_CNTER_CNT11                     (*((volatile unsigned int*)(0x4230002CUL)))
#define bM4_TMR61_CNTER_CNT12                     (*((volatile unsigned int*)(0x42300030UL)))
#define bM4_TMR61_CNTER_CNT13                     (*((volatile unsigned int*)(0x42300034UL)))
#define bM4_TMR61_CNTER_CNT14                     (*((volatile unsigned int*)(0x42300038UL)))
#define bM4_TMR61_CNTER_CNT15                     (*((volatile unsigned int*)(0x4230003CUL)))
#define bM4_TMR61_PERAR_PERA0                     (*((volatile unsigned int*)(0x42300080UL)))
#define bM4_TMR61_PERAR_PERA1                     (*((volatile unsigned int*)(0x42300084UL)))
#define bM4_TMR61_PERAR_PERA2                     (*((volatile unsigned int*)(0x42300088UL)))
#define bM4_TMR61_PERAR_PERA3                     (*((volatile unsigned int*)(0x4230008CUL)))
#define bM4_TMR61_PERAR_PERA4                     (*((volatile unsigned int*)(0x42300090UL)))
#define bM4_TMR61_PERAR_PERA5                     (*((volatile unsigned int*)(0x42300094UL)))
#define bM4_TMR61_PERAR_PERA6                     (*((volatile unsigned int*)(0x42300098UL)))
#define bM4_TMR61_PERAR_PERA7                     (*((volatile unsigned int*)(0x4230009CUL)))
#define bM4_TMR61_PERAR_PERA8                     (*((volatile unsigned int*)(0x423000A0UL)))
#define bM4_TMR61_PERAR_PERA9                     (*((volatile unsigned int*)(0x423000A4UL)))
#define bM4_TMR61_PERAR_PERA10                    (*((volatile unsigned int*)(0x423000A8UL)))
#define bM4_TMR61_PERAR_PERA11                    (*((volatile unsigned int*)(0x423000ACUL)))
#define bM4_TMR61_PERAR_PERA12                    (*((volatile unsigned int*)(0x423000B0UL)))
#define bM4_TMR61_PERAR_PERA13                    (*((volatile unsigned int*)(0x423000B4UL)))
#define bM4_TMR61_PERAR_PERA14                    (*((volatile unsigned int*)(0x423000B8UL)))
#define bM4_TMR61_PERAR_PERA15                    (*((volatile unsigned int*)(0x423000BCUL)))
#define bM4_TMR61_PERBR_PERB0                     (*((volatile unsigned int*)(0x42300100UL)))
#define bM4_TMR61_PERBR_PERB1                     (*((volatile unsigned int*)(0x42300104UL)))
#define bM4_TMR61_PERBR_PERB2                     (*((volatile unsigned int*)(0x42300108UL)))
#define bM4_TMR61_PERBR_PERB3                     (*((volatile unsigned int*)(0x4230010CUL)))
#define bM4_TMR61_PERBR_PERB4                     (*((volatile unsigned int*)(0x42300110UL)))
#define bM4_TMR61_PERBR_PERB5                     (*((volatile unsigned int*)(0x42300114UL)))
#define bM4_TMR61_PERBR_PERB6                     (*((volatile unsigned int*)(0x42300118UL)))
#define bM4_TMR61_PERBR_PERB7                     (*((volatile unsigned int*)(0x4230011CUL)))
#define bM4_TMR61_PERBR_PERB8                     (*((volatile unsigned int*)(0x42300120UL)))
#define bM4_TMR61_PERBR_PERB9                     (*((volatile unsigned int*)(0x42300124UL)))
#define bM4_TMR61_PERBR_PERB10                    (*((volatile unsigned int*)(0x42300128UL)))
#define bM4_TMR61_PERBR_PERB11                    (*((volatile unsigned int*)(0x4230012CUL)))
#define bM4_TMR61_PERBR_PERB12                    (*((volatile unsigned int*)(0x42300130UL)))
#define bM4_TMR61_PERBR_PERB13                    (*((volatile unsigned int*)(0x42300134UL)))
#define bM4_TMR61_PERBR_PERB14                    (*((volatile unsigned int*)(0x42300138UL)))
#define bM4_TMR61_PERBR_PERB15                    (*((volatile unsigned int*)(0x4230013CUL)))
#define bM4_TMR61_PERCR_PERC0                     (*((volatile unsigned int*)(0x42300180UL)))
#define bM4_TMR61_PERCR_PERC1                     (*((volatile unsigned int*)(0x42300184UL)))
#define bM4_TMR61_PERCR_PERC2                     (*((volatile unsigned int*)(0x42300188UL)))
#define bM4_TMR61_PERCR_PERC3                     (*((volatile unsigned int*)(0x4230018CUL)))
#define bM4_TMR61_PERCR_PERC4                     (*((volatile unsigned int*)(0x42300190UL)))
#define bM4_TMR61_PERCR_PERC5                     (*((volatile unsigned int*)(0x42300194UL)))
#define bM4_TMR61_PERCR_PERC6                     (*((volatile unsigned int*)(0x42300198UL)))
#define bM4_TMR61_PERCR_PERC7                     (*((volatile unsigned int*)(0x4230019CUL)))
#define bM4_TMR61_PERCR_PERC8                     (*((volatile unsigned int*)(0x423001A0UL)))
#define bM4_TMR61_PERCR_PERC9                     (*((volatile unsigned int*)(0x423001A4UL)))
#define bM4_TMR61_PERCR_PERC10                    (*((volatile unsigned int*)(0x423001A8UL)))
#define bM4_TMR61_PERCR_PERC11                    (*((volatile unsigned int*)(0x423001ACUL)))
#define bM4_TMR61_PERCR_PERC12                    (*((volatile unsigned int*)(0x423001B0UL)))
#define bM4_TMR61_PERCR_PERC13                    (*((volatile unsigned int*)(0x423001B4UL)))
#define bM4_TMR61_PERCR_PERC14                    (*((volatile unsigned int*)(0x423001B8UL)))
#define bM4_TMR61_PERCR_PERC15                    (*((volatile unsigned int*)(0x423001BCUL)))
#define bM4_TMR61_GCMAR_GCMA0                     (*((volatile unsigned int*)(0x42300200UL)))
#define bM4_TMR61_GCMAR_GCMA1                     (*((volatile unsigned int*)(0x42300204UL)))
#define bM4_TMR61_GCMAR_GCMA2                     (*((volatile unsigned int*)(0x42300208UL)))
#define bM4_TMR61_GCMAR_GCMA3                     (*((volatile unsigned int*)(0x4230020CUL)))
#define bM4_TMR61_GCMAR_GCMA4                     (*((volatile unsigned int*)(0x42300210UL)))
#define bM4_TMR61_GCMAR_GCMA5                     (*((volatile unsigned int*)(0x42300214UL)))
#define bM4_TMR61_GCMAR_GCMA6                     (*((volatile unsigned int*)(0x42300218UL)))
#define bM4_TMR61_GCMAR_GCMA7                     (*((volatile unsigned int*)(0x4230021CUL)))
#define bM4_TMR61_GCMAR_GCMA8                     (*((volatile unsigned int*)(0x42300220UL)))
#define bM4_TMR61_GCMAR_GCMA9                     (*((volatile unsigned int*)(0x42300224UL)))
#define bM4_TMR61_GCMAR_GCMA10                    (*((volatile unsigned int*)(0x42300228UL)))
#define bM4_TMR61_GCMAR_GCMA11                    (*((volatile unsigned int*)(0x4230022CUL)))
#define bM4_TMR61_GCMAR_GCMA12                    (*((volatile unsigned int*)(0x42300230UL)))
#define bM4_TMR61_GCMAR_GCMA13                    (*((volatile unsigned int*)(0x42300234UL)))
#define bM4_TMR61_GCMAR_GCMA14                    (*((volatile unsigned int*)(0x42300238UL)))
#define bM4_TMR61_GCMAR_GCMA15                    (*((volatile unsigned int*)(0x4230023CUL)))
#define bM4_TMR61_GCMBR_GCMB0                     (*((volatile unsigned int*)(0x42300280UL)))
#define bM4_TMR61_GCMBR_GCMB1                     (*((volatile unsigned int*)(0x42300284UL)))
#define bM4_TMR61_GCMBR_GCMB2                     (*((volatile unsigned int*)(0x42300288UL)))
#define bM4_TMR61_GCMBR_GCMB3                     (*((volatile unsigned int*)(0x4230028CUL)))
#define bM4_TMR61_GCMBR_GCMB4                     (*((volatile unsigned int*)(0x42300290UL)))
#define bM4_TMR61_GCMBR_GCMB5                     (*((volatile unsigned int*)(0x42300294UL)))
#define bM4_TMR61_GCMBR_GCMB6                     (*((volatile unsigned int*)(0x42300298UL)))
#define bM4_TMR61_GCMBR_GCMB7                     (*((volatile unsigned int*)(0x4230029CUL)))
#define bM4_TMR61_GCMBR_GCMB8                     (*((volatile unsigned int*)(0x423002A0UL)))
#define bM4_TMR61_GCMBR_GCMB9                     (*((volatile unsigned int*)(0x423002A4UL)))
#define bM4_TMR61_GCMBR_GCMB10                    (*((volatile unsigned int*)(0x423002A8UL)))
#define bM4_TMR61_GCMBR_GCMB11                    (*((volatile unsigned int*)(0x423002ACUL)))
#define bM4_TMR61_GCMBR_GCMB12                    (*((volatile unsigned int*)(0x423002B0UL)))
#define bM4_TMR61_GCMBR_GCMB13                    (*((volatile unsigned int*)(0x423002B4UL)))
#define bM4_TMR61_GCMBR_GCMB14                    (*((volatile unsigned int*)(0x423002B8UL)))
#define bM4_TMR61_GCMBR_GCMB15                    (*((volatile unsigned int*)(0x423002BCUL)))
#define bM4_TMR61_GCMCR_GCMC0                     (*((volatile unsigned int*)(0x42300300UL)))
#define bM4_TMR61_GCMCR_GCMC1                     (*((volatile unsigned int*)(0x42300304UL)))
#define bM4_TMR61_GCMCR_GCMC2                     (*((volatile unsigned int*)(0x42300308UL)))
#define bM4_TMR61_GCMCR_GCMC3                     (*((volatile unsigned int*)(0x4230030CUL)))
#define bM4_TMR61_GCMCR_GCMC4                     (*((volatile unsigned int*)(0x42300310UL)))
#define bM4_TMR61_GCMCR_GCMC5                     (*((volatile unsigned int*)(0x42300314UL)))
#define bM4_TMR61_GCMCR_GCMC6                     (*((volatile unsigned int*)(0x42300318UL)))
#define bM4_TMR61_GCMCR_GCMC7                     (*((volatile unsigned int*)(0x4230031CUL)))
#define bM4_TMR61_GCMCR_GCMC8                     (*((volatile unsigned int*)(0x42300320UL)))
#define bM4_TMR61_GCMCR_GCMC9                     (*((volatile unsigned int*)(0x42300324UL)))
#define bM4_TMR61_GCMCR_GCMC10                    (*((volatile unsigned int*)(0x42300328UL)))
#define bM4_TMR61_GCMCR_GCMC11                    (*((volatile unsigned int*)(0x4230032CUL)))
#define bM4_TMR61_GCMCR_GCMC12                    (*((volatile unsigned int*)(0x42300330UL)))
#define bM4_TMR61_GCMCR_GCMC13                    (*((volatile unsigned int*)(0x42300334UL)))
#define bM4_TMR61_GCMCR_GCMC14                    (*((volatile unsigned int*)(0x42300338UL)))
#define bM4_TMR61_GCMCR_GCMC15                    (*((volatile unsigned int*)(0x4230033CUL)))
#define bM4_TMR61_GCMDR_GCMD0                     (*((volatile unsigned int*)(0x42300380UL)))
#define bM4_TMR61_GCMDR_GCMD1                     (*((volatile unsigned int*)(0x42300384UL)))
#define bM4_TMR61_GCMDR_GCMD2                     (*((volatile unsigned int*)(0x42300388UL)))
#define bM4_TMR61_GCMDR_GCMD3                     (*((volatile unsigned int*)(0x4230038CUL)))
#define bM4_TMR61_GCMDR_GCMD4                     (*((volatile unsigned int*)(0x42300390UL)))
#define bM4_TMR61_GCMDR_GCMD5                     (*((volatile unsigned int*)(0x42300394UL)))
#define bM4_TMR61_GCMDR_GCMD6                     (*((volatile unsigned int*)(0x42300398UL)))
#define bM4_TMR61_GCMDR_GCMD7                     (*((volatile unsigned int*)(0x4230039CUL)))
#define bM4_TMR61_GCMDR_GCMD8                     (*((volatile unsigned int*)(0x423003A0UL)))
#define bM4_TMR61_GCMDR_GCMD9                     (*((volatile unsigned int*)(0x423003A4UL)))
#define bM4_TMR61_GCMDR_GCMD10                    (*((volatile unsigned int*)(0x423003A8UL)))
#define bM4_TMR61_GCMDR_GCMD11                    (*((volatile unsigned int*)(0x423003ACUL)))
#define bM4_TMR61_GCMDR_GCMD12                    (*((volatile unsigned int*)(0x423003B0UL)))
#define bM4_TMR61_GCMDR_GCMD13                    (*((volatile unsigned int*)(0x423003B4UL)))
#define bM4_TMR61_GCMDR_GCMD14                    (*((volatile unsigned int*)(0x423003B8UL)))
#define bM4_TMR61_GCMDR_GCMD15                    (*((volatile unsigned int*)(0x423003BCUL)))
#define bM4_TMR61_GCMER_GCME0                     (*((volatile unsigned int*)(0x42300400UL)))
#define bM4_TMR61_GCMER_GCME1                     (*((volatile unsigned int*)(0x42300404UL)))
#define bM4_TMR61_GCMER_GCME2                     (*((volatile unsigned int*)(0x42300408UL)))
#define bM4_TMR61_GCMER_GCME3                     (*((volatile unsigned int*)(0x4230040CUL)))
#define bM4_TMR61_GCMER_GCME4                     (*((volatile unsigned int*)(0x42300410UL)))
#define bM4_TMR61_GCMER_GCME5                     (*((volatile unsigned int*)(0x42300414UL)))
#define bM4_TMR61_GCMER_GCME6                     (*((volatile unsigned int*)(0x42300418UL)))
#define bM4_TMR61_GCMER_GCME7                     (*((volatile unsigned int*)(0x4230041CUL)))
#define bM4_TMR61_GCMER_GCME8                     (*((volatile unsigned int*)(0x42300420UL)))
#define bM4_TMR61_GCMER_GCME9                     (*((volatile unsigned int*)(0x42300424UL)))
#define bM4_TMR61_GCMER_GCME10                    (*((volatile unsigned int*)(0x42300428UL)))
#define bM4_TMR61_GCMER_GCME11                    (*((volatile unsigned int*)(0x4230042CUL)))
#define bM4_TMR61_GCMER_GCME12                    (*((volatile unsigned int*)(0x42300430UL)))
#define bM4_TMR61_GCMER_GCME13                    (*((volatile unsigned int*)(0x42300434UL)))
#define bM4_TMR61_GCMER_GCME14                    (*((volatile unsigned int*)(0x42300438UL)))
#define bM4_TMR61_GCMER_GCME15                    (*((volatile unsigned int*)(0x4230043CUL)))
#define bM4_TMR61_GCMFR_GCMF0                     (*((volatile unsigned int*)(0x42300480UL)))
#define bM4_TMR61_GCMFR_GCMF1                     (*((volatile unsigned int*)(0x42300484UL)))
#define bM4_TMR61_GCMFR_GCMF2                     (*((volatile unsigned int*)(0x42300488UL)))
#define bM4_TMR61_GCMFR_GCMF3                     (*((volatile unsigned int*)(0x4230048CUL)))
#define bM4_TMR61_GCMFR_GCMF4                     (*((volatile unsigned int*)(0x42300490UL)))
#define bM4_TMR61_GCMFR_GCMF5                     (*((volatile unsigned int*)(0x42300494UL)))
#define bM4_TMR61_GCMFR_GCMF6                     (*((volatile unsigned int*)(0x42300498UL)))
#define bM4_TMR61_GCMFR_GCMF7                     (*((volatile unsigned int*)(0x4230049CUL)))
#define bM4_TMR61_GCMFR_GCMF8                     (*((volatile unsigned int*)(0x423004A0UL)))
#define bM4_TMR61_GCMFR_GCMF9                     (*((volatile unsigned int*)(0x423004A4UL)))
#define bM4_TMR61_GCMFR_GCMF10                    (*((volatile unsigned int*)(0x423004A8UL)))
#define bM4_TMR61_GCMFR_GCMF11                    (*((volatile unsigned int*)(0x423004ACUL)))
#define bM4_TMR61_GCMFR_GCMF12                    (*((volatile unsigned int*)(0x423004B0UL)))
#define bM4_TMR61_GCMFR_GCMF13                    (*((volatile unsigned int*)(0x423004B4UL)))
#define bM4_TMR61_GCMFR_GCMF14                    (*((volatile unsigned int*)(0x423004B8UL)))
#define bM4_TMR61_GCMFR_GCMF15                    (*((volatile unsigned int*)(0x423004BCUL)))
#define bM4_TMR61_SCMAR_SCMA0                     (*((volatile unsigned int*)(0x42300500UL)))
#define bM4_TMR61_SCMAR_SCMA1                     (*((volatile unsigned int*)(0x42300504UL)))
#define bM4_TMR61_SCMAR_SCMA2                     (*((volatile unsigned int*)(0x42300508UL)))
#define bM4_TMR61_SCMAR_SCMA3                     (*((volatile unsigned int*)(0x4230050CUL)))
#define bM4_TMR61_SCMAR_SCMA4                     (*((volatile unsigned int*)(0x42300510UL)))
#define bM4_TMR61_SCMAR_SCMA5                     (*((volatile unsigned int*)(0x42300514UL)))
#define bM4_TMR61_SCMAR_SCMA6                     (*((volatile unsigned int*)(0x42300518UL)))
#define bM4_TMR61_SCMAR_SCMA7                     (*((volatile unsigned int*)(0x4230051CUL)))
#define bM4_TMR61_SCMAR_SCMA8                     (*((volatile unsigned int*)(0x42300520UL)))
#define bM4_TMR61_SCMAR_SCMA9                     (*((volatile unsigned int*)(0x42300524UL)))
#define bM4_TMR61_SCMAR_SCMA10                    (*((volatile unsigned int*)(0x42300528UL)))
#define bM4_TMR61_SCMAR_SCMA11                    (*((volatile unsigned int*)(0x4230052CUL)))
#define bM4_TMR61_SCMAR_SCMA12                    (*((volatile unsigned int*)(0x42300530UL)))
#define bM4_TMR61_SCMAR_SCMA13                    (*((volatile unsigned int*)(0x42300534UL)))
#define bM4_TMR61_SCMAR_SCMA14                    (*((volatile unsigned int*)(0x42300538UL)))
#define bM4_TMR61_SCMAR_SCMA15                    (*((volatile unsigned int*)(0x4230053CUL)))
#define bM4_TMR61_SCMBR_SCMB0                     (*((volatile unsigned int*)(0x42300580UL)))
#define bM4_TMR61_SCMBR_SCMB1                     (*((volatile unsigned int*)(0x42300584UL)))
#define bM4_TMR61_SCMBR_SCMB2                     (*((volatile unsigned int*)(0x42300588UL)))
#define bM4_TMR61_SCMBR_SCMB3                     (*((volatile unsigned int*)(0x4230058CUL)))
#define bM4_TMR61_SCMBR_SCMB4                     (*((volatile unsigned int*)(0x42300590UL)))
#define bM4_TMR61_SCMBR_SCMB5                     (*((volatile unsigned int*)(0x42300594UL)))
#define bM4_TMR61_SCMBR_SCMB6                     (*((volatile unsigned int*)(0x42300598UL)))
#define bM4_TMR61_SCMBR_SCMB7                     (*((volatile unsigned int*)(0x4230059CUL)))
#define bM4_TMR61_SCMBR_SCMB8                     (*((volatile unsigned int*)(0x423005A0UL)))
#define bM4_TMR61_SCMBR_SCMB9                     (*((volatile unsigned int*)(0x423005A4UL)))
#define bM4_TMR61_SCMBR_SCMB10                    (*((volatile unsigned int*)(0x423005A8UL)))
#define bM4_TMR61_SCMBR_SCMB11                    (*((volatile unsigned int*)(0x423005ACUL)))
#define bM4_TMR61_SCMBR_SCMB12                    (*((volatile unsigned int*)(0x423005B0UL)))
#define bM4_TMR61_SCMBR_SCMB13                    (*((volatile unsigned int*)(0x423005B4UL)))
#define bM4_TMR61_SCMBR_SCMB14                    (*((volatile unsigned int*)(0x423005B8UL)))
#define bM4_TMR61_SCMBR_SCMB15                    (*((volatile unsigned int*)(0x423005BCUL)))
#define bM4_TMR61_SCMCR_SCMC0                     (*((volatile unsigned int*)(0x42300600UL)))
#define bM4_TMR61_SCMCR_SCMC1                     (*((volatile unsigned int*)(0x42300604UL)))
#define bM4_TMR61_SCMCR_SCMC2                     (*((volatile unsigned int*)(0x42300608UL)))
#define bM4_TMR61_SCMCR_SCMC3                     (*((volatile unsigned int*)(0x4230060CUL)))
#define bM4_TMR61_SCMCR_SCMC4                     (*((volatile unsigned int*)(0x42300610UL)))
#define bM4_TMR61_SCMCR_SCMC5                     (*((volatile unsigned int*)(0x42300614UL)))
#define bM4_TMR61_SCMCR_SCMC6                     (*((volatile unsigned int*)(0x42300618UL)))
#define bM4_TMR61_SCMCR_SCMC7                     (*((volatile unsigned int*)(0x4230061CUL)))
#define bM4_TMR61_SCMCR_SCMC8                     (*((volatile unsigned int*)(0x42300620UL)))
#define bM4_TMR61_SCMCR_SCMC9                     (*((volatile unsigned int*)(0x42300624UL)))
#define bM4_TMR61_SCMCR_SCMC10                    (*((volatile unsigned int*)(0x42300628UL)))
#define bM4_TMR61_SCMCR_SCMC11                    (*((volatile unsigned int*)(0x4230062CUL)))
#define bM4_TMR61_SCMCR_SCMC12                    (*((volatile unsigned int*)(0x42300630UL)))
#define bM4_TMR61_SCMCR_SCMC13                    (*((volatile unsigned int*)(0x42300634UL)))
#define bM4_TMR61_SCMCR_SCMC14                    (*((volatile unsigned int*)(0x42300638UL)))
#define bM4_TMR61_SCMCR_SCMC15                    (*((volatile unsigned int*)(0x4230063CUL)))
#define bM4_TMR61_SCMDR_SCMD0                     (*((volatile unsigned int*)(0x42300680UL)))
#define bM4_TMR61_SCMDR_SCMD1                     (*((volatile unsigned int*)(0x42300684UL)))
#define bM4_TMR61_SCMDR_SCMD2                     (*((volatile unsigned int*)(0x42300688UL)))
#define bM4_TMR61_SCMDR_SCMD3                     (*((volatile unsigned int*)(0x4230068CUL)))
#define bM4_TMR61_SCMDR_SCMD4                     (*((volatile unsigned int*)(0x42300690UL)))
#define bM4_TMR61_SCMDR_SCMD5                     (*((volatile unsigned int*)(0x42300694UL)))
#define bM4_TMR61_SCMDR_SCMD6                     (*((volatile unsigned int*)(0x42300698UL)))
#define bM4_TMR61_SCMDR_SCMD7                     (*((volatile unsigned int*)(0x4230069CUL)))
#define bM4_TMR61_SCMDR_SCMD8                     (*((volatile unsigned int*)(0x423006A0UL)))
#define bM4_TMR61_SCMDR_SCMD9                     (*((volatile unsigned int*)(0x423006A4UL)))
#define bM4_TMR61_SCMDR_SCMD10                    (*((volatile unsigned int*)(0x423006A8UL)))
#define bM4_TMR61_SCMDR_SCMD11                    (*((volatile unsigned int*)(0x423006ACUL)))
#define bM4_TMR61_SCMDR_SCMD12                    (*((volatile unsigned int*)(0x423006B0UL)))
#define bM4_TMR61_SCMDR_SCMD13                    (*((volatile unsigned int*)(0x423006B4UL)))
#define bM4_TMR61_SCMDR_SCMD14                    (*((volatile unsigned int*)(0x423006B8UL)))
#define bM4_TMR61_SCMDR_SCMD15                    (*((volatile unsigned int*)(0x423006BCUL)))
#define bM4_TMR61_SCMER_SCME0                     (*((volatile unsigned int*)(0x42300700UL)))
#define bM4_TMR61_SCMER_SCME1                     (*((volatile unsigned int*)(0x42300704UL)))
#define bM4_TMR61_SCMER_SCME2                     (*((volatile unsigned int*)(0x42300708UL)))
#define bM4_TMR61_SCMER_SCME3                     (*((volatile unsigned int*)(0x4230070CUL)))
#define bM4_TMR61_SCMER_SCME4                     (*((volatile unsigned int*)(0x42300710UL)))
#define bM4_TMR61_SCMER_SCME5                     (*((volatile unsigned int*)(0x42300714UL)))
#define bM4_TMR61_SCMER_SCME6                     (*((volatile unsigned int*)(0x42300718UL)))
#define bM4_TMR61_SCMER_SCME7                     (*((volatile unsigned int*)(0x4230071CUL)))
#define bM4_TMR61_SCMER_SCME8                     (*((volatile unsigned int*)(0x42300720UL)))
#define bM4_TMR61_SCMER_SCME9                     (*((volatile unsigned int*)(0x42300724UL)))
#define bM4_TMR61_SCMER_SCME10                    (*((volatile unsigned int*)(0x42300728UL)))
#define bM4_TMR61_SCMER_SCME11                    (*((volatile unsigned int*)(0x4230072CUL)))
#define bM4_TMR61_SCMER_SCME12                    (*((volatile unsigned int*)(0x42300730UL)))
#define bM4_TMR61_SCMER_SCME13                    (*((volatile unsigned int*)(0x42300734UL)))
#define bM4_TMR61_SCMER_SCME14                    (*((volatile unsigned int*)(0x42300738UL)))
#define bM4_TMR61_SCMER_SCME15                    (*((volatile unsigned int*)(0x4230073CUL)))
#define bM4_TMR61_SCMFR_SCMF0                     (*((volatile unsigned int*)(0x42300780UL)))
#define bM4_TMR61_SCMFR_SCMF1                     (*((volatile unsigned int*)(0x42300784UL)))
#define bM4_TMR61_SCMFR_SCMF2                     (*((volatile unsigned int*)(0x42300788UL)))
#define bM4_TMR61_SCMFR_SCMF3                     (*((volatile unsigned int*)(0x4230078CUL)))
#define bM4_TMR61_SCMFR_SCMF4                     (*((volatile unsigned int*)(0x42300790UL)))
#define bM4_TMR61_SCMFR_SCMF5                     (*((volatile unsigned int*)(0x42300794UL)))
#define bM4_TMR61_SCMFR_SCMF6                     (*((volatile unsigned int*)(0x42300798UL)))
#define bM4_TMR61_SCMFR_SCMF7                     (*((volatile unsigned int*)(0x4230079CUL)))
#define bM4_TMR61_SCMFR_SCMF8                     (*((volatile unsigned int*)(0x423007A0UL)))
#define bM4_TMR61_SCMFR_SCMF9                     (*((volatile unsigned int*)(0x423007A4UL)))
#define bM4_TMR61_SCMFR_SCMF10                    (*((volatile unsigned int*)(0x423007A8UL)))
#define bM4_TMR61_SCMFR_SCMF11                    (*((volatile unsigned int*)(0x423007ACUL)))
#define bM4_TMR61_SCMFR_SCMF12                    (*((volatile unsigned int*)(0x423007B0UL)))
#define bM4_TMR61_SCMFR_SCMF13                    (*((volatile unsigned int*)(0x423007B4UL)))
#define bM4_TMR61_SCMFR_SCMF14                    (*((volatile unsigned int*)(0x423007B8UL)))
#define bM4_TMR61_SCMFR_SCMF15                    (*((volatile unsigned int*)(0x423007BCUL)))
#define bM4_TMR61_DTUAR_DTUA0                     (*((volatile unsigned int*)(0x42300800UL)))
#define bM4_TMR61_DTUAR_DTUA1                     (*((volatile unsigned int*)(0x42300804UL)))
#define bM4_TMR61_DTUAR_DTUA2                     (*((volatile unsigned int*)(0x42300808UL)))
#define bM4_TMR61_DTUAR_DTUA3                     (*((volatile unsigned int*)(0x4230080CUL)))
#define bM4_TMR61_DTUAR_DTUA4                     (*((volatile unsigned int*)(0x42300810UL)))
#define bM4_TMR61_DTUAR_DTUA5                     (*((volatile unsigned int*)(0x42300814UL)))
#define bM4_TMR61_DTUAR_DTUA6                     (*((volatile unsigned int*)(0x42300818UL)))
#define bM4_TMR61_DTUAR_DTUA7                     (*((volatile unsigned int*)(0x4230081CUL)))
#define bM4_TMR61_DTUAR_DTUA8                     (*((volatile unsigned int*)(0x42300820UL)))
#define bM4_TMR61_DTUAR_DTUA9                     (*((volatile unsigned int*)(0x42300824UL)))
#define bM4_TMR61_DTUAR_DTUA10                    (*((volatile unsigned int*)(0x42300828UL)))
#define bM4_TMR61_DTUAR_DTUA11                    (*((volatile unsigned int*)(0x4230082CUL)))
#define bM4_TMR61_DTUAR_DTUA12                    (*((volatile unsigned int*)(0x42300830UL)))
#define bM4_TMR61_DTUAR_DTUA13                    (*((volatile unsigned int*)(0x42300834UL)))
#define bM4_TMR61_DTUAR_DTUA14                    (*((volatile unsigned int*)(0x42300838UL)))
#define bM4_TMR61_DTUAR_DTUA15                    (*((volatile unsigned int*)(0x4230083CUL)))
#define bM4_TMR61_DTDAR_DTDA0                     (*((volatile unsigned int*)(0x42300880UL)))
#define bM4_TMR61_DTDAR_DTDA1                     (*((volatile unsigned int*)(0x42300884UL)))
#define bM4_TMR61_DTDAR_DTDA2                     (*((volatile unsigned int*)(0x42300888UL)))
#define bM4_TMR61_DTDAR_DTDA3                     (*((volatile unsigned int*)(0x4230088CUL)))
#define bM4_TMR61_DTDAR_DTDA4                     (*((volatile unsigned int*)(0x42300890UL)))
#define bM4_TMR61_DTDAR_DTDA5                     (*((volatile unsigned int*)(0x42300894UL)))
#define bM4_TMR61_DTDAR_DTDA6                     (*((volatile unsigned int*)(0x42300898UL)))
#define bM4_TMR61_DTDAR_DTDA7                     (*((volatile unsigned int*)(0x4230089CUL)))
#define bM4_TMR61_DTDAR_DTDA8                     (*((volatile unsigned int*)(0x423008A0UL)))
#define bM4_TMR61_DTDAR_DTDA9                     (*((volatile unsigned int*)(0x423008A4UL)))
#define bM4_TMR61_DTDAR_DTDA10                    (*((volatile unsigned int*)(0x423008A8UL)))
#define bM4_TMR61_DTDAR_DTDA11                    (*((volatile unsigned int*)(0x423008ACUL)))
#define bM4_TMR61_DTDAR_DTDA12                    (*((volatile unsigned int*)(0x423008B0UL)))
#define bM4_TMR61_DTDAR_DTDA13                    (*((volatile unsigned int*)(0x423008B4UL)))
#define bM4_TMR61_DTDAR_DTDA14                    (*((volatile unsigned int*)(0x423008B8UL)))
#define bM4_TMR61_DTDAR_DTDA15                    (*((volatile unsigned int*)(0x423008BCUL)))
#define bM4_TMR61_DTUBR_DTUB0                     (*((volatile unsigned int*)(0x42300900UL)))
#define bM4_TMR61_DTUBR_DTUB1                     (*((volatile unsigned int*)(0x42300904UL)))
#define bM4_TMR61_DTUBR_DTUB2                     (*((volatile unsigned int*)(0x42300908UL)))
#define bM4_TMR61_DTUBR_DTUB3                     (*((volatile unsigned int*)(0x4230090CUL)))
#define bM4_TMR61_DTUBR_DTUB4                     (*((volatile unsigned int*)(0x42300910UL)))
#define bM4_TMR61_DTUBR_DTUB5                     (*((volatile unsigned int*)(0x42300914UL)))
#define bM4_TMR61_DTUBR_DTUB6                     (*((volatile unsigned int*)(0x42300918UL)))
#define bM4_TMR61_DTUBR_DTUB7                     (*((volatile unsigned int*)(0x4230091CUL)))
#define bM4_TMR61_DTUBR_DTUB8                     (*((volatile unsigned int*)(0x42300920UL)))
#define bM4_TMR61_DTUBR_DTUB9                     (*((volatile unsigned int*)(0x42300924UL)))
#define bM4_TMR61_DTUBR_DTUB10                    (*((volatile unsigned int*)(0x42300928UL)))
#define bM4_TMR61_DTUBR_DTUB11                    (*((volatile unsigned int*)(0x4230092CUL)))
#define bM4_TMR61_DTUBR_DTUB12                    (*((volatile unsigned int*)(0x42300930UL)))
#define bM4_TMR61_DTUBR_DTUB13                    (*((volatile unsigned int*)(0x42300934UL)))
#define bM4_TMR61_DTUBR_DTUB14                    (*((volatile unsigned int*)(0x42300938UL)))
#define bM4_TMR61_DTUBR_DTUB15                    (*((volatile unsigned int*)(0x4230093CUL)))
#define bM4_TMR61_DTDBR_DTDB0                     (*((volatile unsigned int*)(0x42300980UL)))
#define bM4_TMR61_DTDBR_DTDB1                     (*((volatile unsigned int*)(0x42300984UL)))
#define bM4_TMR61_DTDBR_DTDB2                     (*((volatile unsigned int*)(0x42300988UL)))
#define bM4_TMR61_DTDBR_DTDB3                     (*((volatile unsigned int*)(0x4230098CUL)))
#define bM4_TMR61_DTDBR_DTDB4                     (*((volatile unsigned int*)(0x42300990UL)))
#define bM4_TMR61_DTDBR_DTDB5                     (*((volatile unsigned int*)(0x42300994UL)))
#define bM4_TMR61_DTDBR_DTDB6                     (*((volatile unsigned int*)(0x42300998UL)))
#define bM4_TMR61_DTDBR_DTDB7                     (*((volatile unsigned int*)(0x4230099CUL)))
#define bM4_TMR61_DTDBR_DTDB8                     (*((volatile unsigned int*)(0x423009A0UL)))
#define bM4_TMR61_DTDBR_DTDB9                     (*((volatile unsigned int*)(0x423009A4UL)))
#define bM4_TMR61_DTDBR_DTDB10                    (*((volatile unsigned int*)(0x423009A8UL)))
#define bM4_TMR61_DTDBR_DTDB11                    (*((volatile unsigned int*)(0x423009ACUL)))
#define bM4_TMR61_DTDBR_DTDB12                    (*((volatile unsigned int*)(0x423009B0UL)))
#define bM4_TMR61_DTDBR_DTDB13                    (*((volatile unsigned int*)(0x423009B4UL)))
#define bM4_TMR61_DTDBR_DTDB14                    (*((volatile unsigned int*)(0x423009B8UL)))
#define bM4_TMR61_DTDBR_DTDB15                    (*((volatile unsigned int*)(0x423009BCUL)))
#define bM4_TMR61_GCONR_START                     (*((volatile unsigned int*)(0x42300A00UL)))
#define bM4_TMR61_GCONR_MODE0                     (*((volatile unsigned int*)(0x42300A04UL)))
#define bM4_TMR61_GCONR_MODE1                     (*((volatile unsigned int*)(0x42300A08UL)))
#define bM4_TMR61_GCONR_MODE2                     (*((volatile unsigned int*)(0x42300A0CUL)))
#define bM4_TMR61_GCONR_CKDIV0                    (*((volatile unsigned int*)(0x42300A10UL)))
#define bM4_TMR61_GCONR_CKDIV1                    (*((volatile unsigned int*)(0x42300A14UL)))
#define bM4_TMR61_GCONR_CKDIV2                    (*((volatile unsigned int*)(0x42300A18UL)))
#define bM4_TMR61_GCONR_DIR                       (*((volatile unsigned int*)(0x42300A20UL)))
#define bM4_TMR61_GCONR_ZMSKREV                   (*((volatile unsigned int*)(0x42300A40UL)))
#define bM4_TMR61_GCONR_ZMSKPOS                   (*((volatile unsigned int*)(0x42300A44UL)))
#define bM4_TMR61_GCONR_ZMSKVAL0                  (*((volatile unsigned int*)(0x42300A48UL)))
#define bM4_TMR61_GCONR_ZMSKVAL1                  (*((volatile unsigned int*)(0x42300A4CUL)))
#define bM4_TMR61_ICONR_INTENA                    (*((volatile unsigned int*)(0x42300A80UL)))
#define bM4_TMR61_ICONR_INTENB                    (*((volatile unsigned int*)(0x42300A84UL)))
#define bM4_TMR61_ICONR_INTENC                    (*((volatile unsigned int*)(0x42300A88UL)))
#define bM4_TMR61_ICONR_INTEND                    (*((volatile unsigned int*)(0x42300A8CUL)))
#define bM4_TMR61_ICONR_INTENE                    (*((volatile unsigned int*)(0x42300A90UL)))
#define bM4_TMR61_ICONR_INTENF                    (*((volatile unsigned int*)(0x42300A94UL)))
#define bM4_TMR61_ICONR_INTENOVF                  (*((volatile unsigned int*)(0x42300A98UL)))
#define bM4_TMR61_ICONR_INTENUDF                  (*((volatile unsigned int*)(0x42300A9CUL)))
#define bM4_TMR61_ICONR_INTENDTE                  (*((volatile unsigned int*)(0x42300AA0UL)))
#define bM4_TMR61_ICONR_INTENSAU                  (*((volatile unsigned int*)(0x42300AC0UL)))
#define bM4_TMR61_ICONR_INTENSAD                  (*((volatile unsigned int*)(0x42300AC4UL)))
#define bM4_TMR61_ICONR_INTENSBU                  (*((volatile unsigned int*)(0x42300AC8UL)))
#define bM4_TMR61_ICONR_INTENSBD                  (*((volatile unsigned int*)(0x42300ACCUL)))
#define bM4_TMR61_PCONR_CAPMDA                    (*((volatile unsigned int*)(0x42300B00UL)))
#define bM4_TMR61_PCONR_STACA                     (*((volatile unsigned int*)(0x42300B04UL)))
#define bM4_TMR61_PCONR_STPCA                     (*((volatile unsigned int*)(0x42300B08UL)))
#define bM4_TMR61_PCONR_STASTPSA                  (*((volatile unsigned int*)(0x42300B0CUL)))
#define bM4_TMR61_PCONR_CMPCA0                    (*((volatile unsigned int*)(0x42300B10UL)))
#define bM4_TMR61_PCONR_CMPCA1                    (*((volatile unsigned int*)(0x42300B14UL)))
#define bM4_TMR61_PCONR_PERCA0                    (*((volatile unsigned int*)(0x42300B18UL)))
#define bM4_TMR61_PCONR_PERCA1                    (*((volatile unsigned int*)(0x42300B1CUL)))
#define bM4_TMR61_PCONR_OUTENA                    (*((volatile unsigned int*)(0x42300B20UL)))
#define bM4_TMR61_PCONR_EMBVALA0                  (*((volatile unsigned int*)(0x42300B2CUL)))
#define bM4_TMR61_PCONR_EMBVALA1                  (*((volatile unsigned int*)(0x42300B30UL)))
#define bM4_TMR61_PCONR_CAPMDB                    (*((volatile unsigned int*)(0x42300B40UL)))
#define bM4_TMR61_PCONR_STACB                     (*((volatile unsigned int*)(0x42300B44UL)))
#define bM4_TMR61_PCONR_STPCB                     (*((volatile unsigned int*)(0x42300B48UL)))
#define bM4_TMR61_PCONR_STASTPSB                  (*((volatile unsigned int*)(0x42300B4CUL)))
#define bM4_TMR61_PCONR_CMPCB0                    (*((volatile unsigned int*)(0x42300B50UL)))
#define bM4_TMR61_PCONR_CMPCB1                    (*((volatile unsigned int*)(0x42300B54UL)))
#define bM4_TMR61_PCONR_PERCB0                    (*((volatile unsigned int*)(0x42300B58UL)))
#define bM4_TMR61_PCONR_PERCB1                    (*((volatile unsigned int*)(0x42300B5CUL)))
#define bM4_TMR61_PCONR_OUTENB                    (*((volatile unsigned int*)(0x42300B60UL)))
#define bM4_TMR61_PCONR_EMBVALB0                  (*((volatile unsigned int*)(0x42300B6CUL)))
#define bM4_TMR61_PCONR_EMBVALB1                  (*((volatile unsigned int*)(0x42300B70UL)))
#define bM4_TMR61_BCONR_BENA                      (*((volatile unsigned int*)(0x42300B80UL)))
#define bM4_TMR61_BCONR_BSEA                      (*((volatile unsigned int*)(0x42300B84UL)))
#define bM4_TMR61_BCONR_BENB                      (*((volatile unsigned int*)(0x42300B88UL)))
#define bM4_TMR61_BCONR_BSEB                      (*((volatile unsigned int*)(0x42300B8CUL)))
#define bM4_TMR61_BCONR_BENP                      (*((volatile unsigned int*)(0x42300BA0UL)))
#define bM4_TMR61_BCONR_BSEP                      (*((volatile unsigned int*)(0x42300BA4UL)))
#define bM4_TMR61_BCONR_BENSPA                    (*((volatile unsigned int*)(0x42300BC0UL)))
#define bM4_TMR61_BCONR_BSESPA                    (*((volatile unsigned int*)(0x42300BC4UL)))
#define bM4_TMR61_BCONR_BTRSPA0                   (*((volatile unsigned int*)(0x42300BD0UL)))
#define bM4_TMR61_BCONR_BTRSPA1                   (*((volatile unsigned int*)(0x42300BD4UL)))
#define bM4_TMR61_BCONR_BENSPB                    (*((volatile unsigned int*)(0x42300BE0UL)))
#define bM4_TMR61_BCONR_BSESPB                    (*((volatile unsigned int*)(0x42300BE4UL)))
#define bM4_TMR61_BCONR_BTRSPB0                   (*((volatile unsigned int*)(0x42300BF0UL)))
#define bM4_TMR61_BCONR_BTRSPB1                   (*((volatile unsigned int*)(0x42300BF4UL)))
#define bM4_TMR61_DCONR_DTCEN                     (*((volatile unsigned int*)(0x42300C00UL)))
#define bM4_TMR61_DCONR_DTBENU                    (*((volatile unsigned int*)(0x42300C10UL)))
#define bM4_TMR61_DCONR_DTBEND                    (*((volatile unsigned int*)(0x42300C14UL)))
#define bM4_TMR61_DCONR_SEPA                      (*((volatile unsigned int*)(0x42300C20UL)))
#define bM4_TMR61_FCONR_NOFIENGA                  (*((volatile unsigned int*)(0x42300D00UL)))
#define bM4_TMR61_FCONR_NOFICKGA0                 (*((volatile unsigned int*)(0x42300D04UL)))
#define bM4_TMR61_FCONR_NOFICKGA1                 (*((volatile unsigned int*)(0x42300D08UL)))
#define bM4_TMR61_FCONR_NOFIENGB                  (*((volatile unsigned int*)(0x42300D10UL)))
#define bM4_TMR61_FCONR_NOFICKGB0                 (*((volatile unsigned int*)(0x42300D14UL)))
#define bM4_TMR61_FCONR_NOFICKGB1                 (*((volatile unsigned int*)(0x42300D18UL)))
#define bM4_TMR61_FCONR_NOFIENTA                  (*((volatile unsigned int*)(0x42300D40UL)))
#define bM4_TMR61_FCONR_NOFICKTA0                 (*((volatile unsigned int*)(0x42300D44UL)))
#define bM4_TMR61_FCONR_NOFICKTA1                 (*((volatile unsigned int*)(0x42300D48UL)))
#define bM4_TMR61_FCONR_NOFIENTB                  (*((volatile unsigned int*)(0x42300D50UL)))
#define bM4_TMR61_FCONR_NOFICKTB0                 (*((volatile unsigned int*)(0x42300D54UL)))
#define bM4_TMR61_FCONR_NOFICKTB1                 (*((volatile unsigned int*)(0x42300D58UL)))
#define bM4_TMR61_VPERR_SPPERIA                   (*((volatile unsigned int*)(0x42300DA0UL)))
#define bM4_TMR61_VPERR_SPPERIB                   (*((volatile unsigned int*)(0x42300DA4UL)))
#define bM4_TMR61_VPERR_PCNTE0                    (*((volatile unsigned int*)(0x42300DC0UL)))
#define bM4_TMR61_VPERR_PCNTE1                    (*((volatile unsigned int*)(0x42300DC4UL)))
#define bM4_TMR61_VPERR_PCNTS0                    (*((volatile unsigned int*)(0x42300DC8UL)))
#define bM4_TMR61_VPERR_PCNTS1                    (*((volatile unsigned int*)(0x42300DCCUL)))
#define bM4_TMR61_VPERR_PCNTS2                    (*((volatile unsigned int*)(0x42300DD0UL)))
#define bM4_TMR61_STFLR_CMAF                      (*((volatile unsigned int*)(0x42300E00UL)))
#define bM4_TMR61_STFLR_CMBF                      (*((volatile unsigned int*)(0x42300E04UL)))
#define bM4_TMR61_STFLR_CMCF                      (*((volatile unsigned int*)(0x42300E08UL)))
#define bM4_TMR61_STFLR_CMDF                      (*((volatile unsigned int*)(0x42300E0CUL)))
#define bM4_TMR61_STFLR_CMEF                      (*((volatile unsigned int*)(0x42300E10UL)))
#define bM4_TMR61_STFLR_CMFF                      (*((volatile unsigned int*)(0x42300E14UL)))
#define bM4_TMR61_STFLR_OVFF                      (*((volatile unsigned int*)(0x42300E18UL)))
#define bM4_TMR61_STFLR_UDFF                      (*((volatile unsigned int*)(0x42300E1CUL)))
#define bM4_TMR61_STFLR_DTEF                      (*((volatile unsigned int*)(0x42300E20UL)))
#define bM4_TMR61_STFLR_CMSAUF                    (*((volatile unsigned int*)(0x42300E24UL)))
#define bM4_TMR61_STFLR_CMSADF                    (*((volatile unsigned int*)(0x42300E28UL)))
#define bM4_TMR61_STFLR_CMSBUF                    (*((volatile unsigned int*)(0x42300E2CUL)))
#define bM4_TMR61_STFLR_CMSBDF                    (*((volatile unsigned int*)(0x42300E30UL)))
#define bM4_TMR61_STFLR_VPERNUM0                  (*((volatile unsigned int*)(0x42300E54UL)))
#define bM4_TMR61_STFLR_VPERNUM1                  (*((volatile unsigned int*)(0x42300E58UL)))
#define bM4_TMR61_STFLR_VPERNUM2                  (*((volatile unsigned int*)(0x42300E5CUL)))
#define bM4_TMR61_STFLR_DIRF                      (*((volatile unsigned int*)(0x42300E7CUL)))
#define bM4_TMR61_HSTAR_HSTA0                     (*((volatile unsigned int*)(0x42300E80UL)))
#define bM4_TMR61_HSTAR_HSTA1                     (*((volatile unsigned int*)(0x42300E84UL)))
#define bM4_TMR61_HSTAR_HSTA4                     (*((volatile unsigned int*)(0x42300E90UL)))
#define bM4_TMR61_HSTAR_HSTA5                     (*((volatile unsigned int*)(0x42300E94UL)))
#define bM4_TMR61_HSTAR_HSTA6                     (*((volatile unsigned int*)(0x42300E98UL)))
#define bM4_TMR61_HSTAR_HSTA7                     (*((volatile unsigned int*)(0x42300E9CUL)))
#define bM4_TMR61_HSTAR_HSTA8                     (*((volatile unsigned int*)(0x42300EA0UL)))
#define bM4_TMR61_HSTAR_HSTA9                     (*((volatile unsigned int*)(0x42300EA4UL)))
#define bM4_TMR61_HSTAR_HSTA10                    (*((volatile unsigned int*)(0x42300EA8UL)))
#define bM4_TMR61_HSTAR_HSTA11                    (*((volatile unsigned int*)(0x42300EACUL)))
#define bM4_TMR61_HSTAR_STARTS                    (*((volatile unsigned int*)(0x42300EFCUL)))
#define bM4_TMR61_HSTPR_HSTP0                     (*((volatile unsigned int*)(0x42300F00UL)))
#define bM4_TMR61_HSTPR_HSTP1                     (*((volatile unsigned int*)(0x42300F04UL)))
#define bM4_TMR61_HSTPR_HSTP4                     (*((volatile unsigned int*)(0x42300F10UL)))
#define bM4_TMR61_HSTPR_HSTP5                     (*((volatile unsigned int*)(0x42300F14UL)))
#define bM4_TMR61_HSTPR_HSTP6                     (*((volatile unsigned int*)(0x42300F18UL)))
#define bM4_TMR61_HSTPR_HSTP7                     (*((volatile unsigned int*)(0x42300F1CUL)))
#define bM4_TMR61_HSTPR_HSTP8                     (*((volatile unsigned int*)(0x42300F20UL)))
#define bM4_TMR61_HSTPR_HSTP9                     (*((volatile unsigned int*)(0x42300F24UL)))
#define bM4_TMR61_HSTPR_HSTP10                    (*((volatile unsigned int*)(0x42300F28UL)))
#define bM4_TMR61_HSTPR_HSTP11                    (*((volatile unsigned int*)(0x42300F2CUL)))
#define bM4_TMR61_HSTPR_STOPS                     (*((volatile unsigned int*)(0x42300F7CUL)))
#define bM4_TMR61_HCLRR_HCLE0                     (*((volatile unsigned int*)(0x42300F80UL)))
#define bM4_TMR61_HCLRR_HCLE1                     (*((volatile unsigned int*)(0x42300F84UL)))
#define bM4_TMR61_HCLRR_HCLE4                     (*((volatile unsigned int*)(0x42300F90UL)))
#define bM4_TMR61_HCLRR_HCLE5                     (*((volatile unsigned int*)(0x42300F94UL)))
#define bM4_TMR61_HCLRR_HCLE6                     (*((volatile unsigned int*)(0x42300F98UL)))
#define bM4_TMR61_HCLRR_HCLE7                     (*((volatile unsigned int*)(0x42300F9CUL)))
#define bM4_TMR61_HCLRR_HCLE8                     (*((volatile unsigned int*)(0x42300FA0UL)))
#define bM4_TMR61_HCLRR_HCLE9                     (*((volatile unsigned int*)(0x42300FA4UL)))
#define bM4_TMR61_HCLRR_HCLE10                    (*((volatile unsigned int*)(0x42300FA8UL)))
#define bM4_TMR61_HCLRR_HCLE11                    (*((volatile unsigned int*)(0x42300FACUL)))
#define bM4_TMR61_HCLRR_CLEARS                    (*((volatile unsigned int*)(0x42300FFCUL)))
#define bM4_TMR61_HCPAR_HCPA0                     (*((volatile unsigned int*)(0x42301000UL)))
#define bM4_TMR61_HCPAR_HCPA1                     (*((volatile unsigned int*)(0x42301004UL)))
#define bM4_TMR61_HCPAR_HCPA4                     (*((volatile unsigned int*)(0x42301010UL)))
#define bM4_TMR61_HCPAR_HCPA5                     (*((volatile unsigned int*)(0x42301014UL)))
#define bM4_TMR61_HCPAR_HCPA6                     (*((volatile unsigned int*)(0x42301018UL)))
#define bM4_TMR61_HCPAR_HCPA7                     (*((volatile unsigned int*)(0x4230101CUL)))
#define bM4_TMR61_HCPAR_HCPA8                     (*((volatile unsigned int*)(0x42301020UL)))
#define bM4_TMR61_HCPAR_HCPA9                     (*((volatile unsigned int*)(0x42301024UL)))
#define bM4_TMR61_HCPAR_HCPA10                    (*((volatile unsigned int*)(0x42301028UL)))
#define bM4_TMR61_HCPAR_HCPA11                    (*((volatile unsigned int*)(0x4230102CUL)))
#define bM4_TMR61_HCPBR_HCPB0                     (*((volatile unsigned int*)(0x42301080UL)))
#define bM4_TMR61_HCPBR_HCPB1                     (*((volatile unsigned int*)(0x42301084UL)))
#define bM4_TMR61_HCPBR_HCPB4                     (*((volatile unsigned int*)(0x42301090UL)))
#define bM4_TMR61_HCPBR_HCPB5                     (*((volatile unsigned int*)(0x42301094UL)))
#define bM4_TMR61_HCPBR_HCPB6                     (*((volatile unsigned int*)(0x42301098UL)))
#define bM4_TMR61_HCPBR_HCPB7                     (*((volatile unsigned int*)(0x4230109CUL)))
#define bM4_TMR61_HCPBR_HCPB8                     (*((volatile unsigned int*)(0x423010A0UL)))
#define bM4_TMR61_HCPBR_HCPB9                     (*((volatile unsigned int*)(0x423010A4UL)))
#define bM4_TMR61_HCPBR_HCPB10                    (*((volatile unsigned int*)(0x423010A8UL)))
#define bM4_TMR61_HCPBR_HCPB11                    (*((volatile unsigned int*)(0x423010ACUL)))
#define bM4_TMR61_HCUPR_HCUP0                     (*((volatile unsigned int*)(0x42301100UL)))
#define bM4_TMR61_HCUPR_HCUP1                     (*((volatile unsigned int*)(0x42301104UL)))
#define bM4_TMR61_HCUPR_HCUP2                     (*((volatile unsigned int*)(0x42301108UL)))
#define bM4_TMR61_HCUPR_HCUP3                     (*((volatile unsigned int*)(0x4230110CUL)))
#define bM4_TMR61_HCUPR_HCUP4                     (*((volatile unsigned int*)(0x42301110UL)))
#define bM4_TMR61_HCUPR_HCUP5                     (*((volatile unsigned int*)(0x42301114UL)))
#define bM4_TMR61_HCUPR_HCUP6                     (*((volatile unsigned int*)(0x42301118UL)))
#define bM4_TMR61_HCUPR_HCUP7                     (*((volatile unsigned int*)(0x4230111CUL)))
#define bM4_TMR61_HCUPR_HCUP8                     (*((volatile unsigned int*)(0x42301120UL)))
#define bM4_TMR61_HCUPR_HCUP9                     (*((volatile unsigned int*)(0x42301124UL)))
#define bM4_TMR61_HCUPR_HCUP10                    (*((volatile unsigned int*)(0x42301128UL)))
#define bM4_TMR61_HCUPR_HCUP11                    (*((volatile unsigned int*)(0x4230112CUL)))
#define bM4_TMR61_HCUPR_HCUP16                    (*((volatile unsigned int*)(0x42301140UL)))
#define bM4_TMR61_HCUPR_HCUP17                    (*((volatile unsigned int*)(0x42301144UL)))
#define bM4_TMR61_HCDOR_HCDO0                     (*((volatile unsigned int*)(0x42301180UL)))
#define bM4_TMR61_HCDOR_HCDO1                     (*((volatile unsigned int*)(0x42301184UL)))
#define bM4_TMR61_HCDOR_HCDO2                     (*((volatile unsigned int*)(0x42301188UL)))
#define bM4_TMR61_HCDOR_HCDO3                     (*((volatile unsigned int*)(0x4230118CUL)))
#define bM4_TMR61_HCDOR_HCDO4                     (*((volatile unsigned int*)(0x42301190UL)))
#define bM4_TMR61_HCDOR_HCDO5                     (*((volatile unsigned int*)(0x42301194UL)))
#define bM4_TMR61_HCDOR_HCDO6                     (*((volatile unsigned int*)(0x42301198UL)))
#define bM4_TMR61_HCDOR_HCDO7                     (*((volatile unsigned int*)(0x4230119CUL)))
#define bM4_TMR61_HCDOR_HCDO8                     (*((volatile unsigned int*)(0x423011A0UL)))
#define bM4_TMR61_HCDOR_HCDO9                     (*((volatile unsigned int*)(0x423011A4UL)))
#define bM4_TMR61_HCDOR_HCDO10                    (*((volatile unsigned int*)(0x423011A8UL)))
#define bM4_TMR61_HCDOR_HCDO11                    (*((volatile unsigned int*)(0x423011ACUL)))
#define bM4_TMR61_HCDOR_HCDO16                    (*((volatile unsigned int*)(0x423011C0UL)))
#define bM4_TMR61_HCDOR_HCDO17                    (*((volatile unsigned int*)(0x423011C4UL)))
#define bM4_TMR62_CNTER_CNT0                      (*((volatile unsigned int*)(0x42308000UL)))
#define bM4_TMR62_CNTER_CNT1                      (*((volatile unsigned int*)(0x42308004UL)))
#define bM4_TMR62_CNTER_CNT2                      (*((volatile unsigned int*)(0x42308008UL)))
#define bM4_TMR62_CNTER_CNT3                      (*((volatile unsigned int*)(0x4230800CUL)))
#define bM4_TMR62_CNTER_CNT4                      (*((volatile unsigned int*)(0x42308010UL)))
#define bM4_TMR62_CNTER_CNT5                      (*((volatile unsigned int*)(0x42308014UL)))
#define bM4_TMR62_CNTER_CNT6                      (*((volatile unsigned int*)(0x42308018UL)))
#define bM4_TMR62_CNTER_CNT7                      (*((volatile unsigned int*)(0x4230801CUL)))
#define bM4_TMR62_CNTER_CNT8                      (*((volatile unsigned int*)(0x42308020UL)))
#define bM4_TMR62_CNTER_CNT9                      (*((volatile unsigned int*)(0x42308024UL)))
#define bM4_TMR62_CNTER_CNT10                     (*((volatile unsigned int*)(0x42308028UL)))
#define bM4_TMR62_CNTER_CNT11                     (*((volatile unsigned int*)(0x4230802CUL)))
#define bM4_TMR62_CNTER_CNT12                     (*((volatile unsigned int*)(0x42308030UL)))
#define bM4_TMR62_CNTER_CNT13                     (*((volatile unsigned int*)(0x42308034UL)))
#define bM4_TMR62_CNTER_CNT14                     (*((volatile unsigned int*)(0x42308038UL)))
#define bM4_TMR62_CNTER_CNT15                     (*((volatile unsigned int*)(0x4230803CUL)))
#define bM4_TMR62_PERAR_PERA0                     (*((volatile unsigned int*)(0x42308080UL)))
#define bM4_TMR62_PERAR_PERA1                     (*((volatile unsigned int*)(0x42308084UL)))
#define bM4_TMR62_PERAR_PERA2                     (*((volatile unsigned int*)(0x42308088UL)))
#define bM4_TMR62_PERAR_PERA3                     (*((volatile unsigned int*)(0x4230808CUL)))
#define bM4_TMR62_PERAR_PERA4                     (*((volatile unsigned int*)(0x42308090UL)))
#define bM4_TMR62_PERAR_PERA5                     (*((volatile unsigned int*)(0x42308094UL)))
#define bM4_TMR62_PERAR_PERA6                     (*((volatile unsigned int*)(0x42308098UL)))
#define bM4_TMR62_PERAR_PERA7                     (*((volatile unsigned int*)(0x4230809CUL)))
#define bM4_TMR62_PERAR_PERA8                     (*((volatile unsigned int*)(0x423080A0UL)))
#define bM4_TMR62_PERAR_PERA9                     (*((volatile unsigned int*)(0x423080A4UL)))
#define bM4_TMR62_PERAR_PERA10                    (*((volatile unsigned int*)(0x423080A8UL)))
#define bM4_TMR62_PERAR_PERA11                    (*((volatile unsigned int*)(0x423080ACUL)))
#define bM4_TMR62_PERAR_PERA12                    (*((volatile unsigned int*)(0x423080B0UL)))
#define bM4_TMR62_PERAR_PERA13                    (*((volatile unsigned int*)(0x423080B4UL)))
#define bM4_TMR62_PERAR_PERA14                    (*((volatile unsigned int*)(0x423080B8UL)))
#define bM4_TMR62_PERAR_PERA15                    (*((volatile unsigned int*)(0x423080BCUL)))
#define bM4_TMR62_PERBR_PERB0                     (*((volatile unsigned int*)(0x42308100UL)))
#define bM4_TMR62_PERBR_PERB1                     (*((volatile unsigned int*)(0x42308104UL)))
#define bM4_TMR62_PERBR_PERB2                     (*((volatile unsigned int*)(0x42308108UL)))
#define bM4_TMR62_PERBR_PERB3                     (*((volatile unsigned int*)(0x4230810CUL)))
#define bM4_TMR62_PERBR_PERB4                     (*((volatile unsigned int*)(0x42308110UL)))
#define bM4_TMR62_PERBR_PERB5                     (*((volatile unsigned int*)(0x42308114UL)))
#define bM4_TMR62_PERBR_PERB6                     (*((volatile unsigned int*)(0x42308118UL)))
#define bM4_TMR62_PERBR_PERB7                     (*((volatile unsigned int*)(0x4230811CUL)))
#define bM4_TMR62_PERBR_PERB8                     (*((volatile unsigned int*)(0x42308120UL)))
#define bM4_TMR62_PERBR_PERB9                     (*((volatile unsigned int*)(0x42308124UL)))
#define bM4_TMR62_PERBR_PERB10                    (*((volatile unsigned int*)(0x42308128UL)))
#define bM4_TMR62_PERBR_PERB11                    (*((volatile unsigned int*)(0x4230812CUL)))
#define bM4_TMR62_PERBR_PERB12                    (*((volatile unsigned int*)(0x42308130UL)))
#define bM4_TMR62_PERBR_PERB13                    (*((volatile unsigned int*)(0x42308134UL)))
#define bM4_TMR62_PERBR_PERB14                    (*((volatile unsigned int*)(0x42308138UL)))
#define bM4_TMR62_PERBR_PERB15                    (*((volatile unsigned int*)(0x4230813CUL)))
#define bM4_TMR62_PERCR_PERC0                     (*((volatile unsigned int*)(0x42308180UL)))
#define bM4_TMR62_PERCR_PERC1                     (*((volatile unsigned int*)(0x42308184UL)))
#define bM4_TMR62_PERCR_PERC2                     (*((volatile unsigned int*)(0x42308188UL)))
#define bM4_TMR62_PERCR_PERC3                     (*((volatile unsigned int*)(0x4230818CUL)))
#define bM4_TMR62_PERCR_PERC4                     (*((volatile unsigned int*)(0x42308190UL)))
#define bM4_TMR62_PERCR_PERC5                     (*((volatile unsigned int*)(0x42308194UL)))
#define bM4_TMR62_PERCR_PERC6                     (*((volatile unsigned int*)(0x42308198UL)))
#define bM4_TMR62_PERCR_PERC7                     (*((volatile unsigned int*)(0x4230819CUL)))
#define bM4_TMR62_PERCR_PERC8                     (*((volatile unsigned int*)(0x423081A0UL)))
#define bM4_TMR62_PERCR_PERC9                     (*((volatile unsigned int*)(0x423081A4UL)))
#define bM4_TMR62_PERCR_PERC10                    (*((volatile unsigned int*)(0x423081A8UL)))
#define bM4_TMR62_PERCR_PERC11                    (*((volatile unsigned int*)(0x423081ACUL)))
#define bM4_TMR62_PERCR_PERC12                    (*((volatile unsigned int*)(0x423081B0UL)))
#define bM4_TMR62_PERCR_PERC13                    (*((volatile unsigned int*)(0x423081B4UL)))
#define bM4_TMR62_PERCR_PERC14                    (*((volatile unsigned int*)(0x423081B8UL)))
#define bM4_TMR62_PERCR_PERC15                    (*((volatile unsigned int*)(0x423081BCUL)))
#define bM4_TMR62_GCMAR_GCMA0                     (*((volatile unsigned int*)(0x42308200UL)))
#define bM4_TMR62_GCMAR_GCMA1                     (*((volatile unsigned int*)(0x42308204UL)))
#define bM4_TMR62_GCMAR_GCMA2                     (*((volatile unsigned int*)(0x42308208UL)))
#define bM4_TMR62_GCMAR_GCMA3                     (*((volatile unsigned int*)(0x4230820CUL)))
#define bM4_TMR62_GCMAR_GCMA4                     (*((volatile unsigned int*)(0x42308210UL)))
#define bM4_TMR62_GCMAR_GCMA5                     (*((volatile unsigned int*)(0x42308214UL)))
#define bM4_TMR62_GCMAR_GCMA6                     (*((volatile unsigned int*)(0x42308218UL)))
#define bM4_TMR62_GCMAR_GCMA7                     (*((volatile unsigned int*)(0x4230821CUL)))
#define bM4_TMR62_GCMAR_GCMA8                     (*((volatile unsigned int*)(0x42308220UL)))
#define bM4_TMR62_GCMAR_GCMA9                     (*((volatile unsigned int*)(0x42308224UL)))
#define bM4_TMR62_GCMAR_GCMA10                    (*((volatile unsigned int*)(0x42308228UL)))
#define bM4_TMR62_GCMAR_GCMA11                    (*((volatile unsigned int*)(0x4230822CUL)))
#define bM4_TMR62_GCMAR_GCMA12                    (*((volatile unsigned int*)(0x42308230UL)))
#define bM4_TMR62_GCMAR_GCMA13                    (*((volatile unsigned int*)(0x42308234UL)))
#define bM4_TMR62_GCMAR_GCMA14                    (*((volatile unsigned int*)(0x42308238UL)))
#define bM4_TMR62_GCMAR_GCMA15                    (*((volatile unsigned int*)(0x4230823CUL)))
#define bM4_TMR62_GCMBR_GCMB0                     (*((volatile unsigned int*)(0x42308280UL)))
#define bM4_TMR62_GCMBR_GCMB1                     (*((volatile unsigned int*)(0x42308284UL)))
#define bM4_TMR62_GCMBR_GCMB2                     (*((volatile unsigned int*)(0x42308288UL)))
#define bM4_TMR62_GCMBR_GCMB3                     (*((volatile unsigned int*)(0x4230828CUL)))
#define bM4_TMR62_GCMBR_GCMB4                     (*((volatile unsigned int*)(0x42308290UL)))
#define bM4_TMR62_GCMBR_GCMB5                     (*((volatile unsigned int*)(0x42308294UL)))
#define bM4_TMR62_GCMBR_GCMB6                     (*((volatile unsigned int*)(0x42308298UL)))
#define bM4_TMR62_GCMBR_GCMB7                     (*((volatile unsigned int*)(0x4230829CUL)))
#define bM4_TMR62_GCMBR_GCMB8                     (*((volatile unsigned int*)(0x423082A0UL)))
#define bM4_TMR62_GCMBR_GCMB9                     (*((volatile unsigned int*)(0x423082A4UL)))
#define bM4_TMR62_GCMBR_GCMB10                    (*((volatile unsigned int*)(0x423082A8UL)))
#define bM4_TMR62_GCMBR_GCMB11                    (*((volatile unsigned int*)(0x423082ACUL)))
#define bM4_TMR62_GCMBR_GCMB12                    (*((volatile unsigned int*)(0x423082B0UL)))
#define bM4_TMR62_GCMBR_GCMB13                    (*((volatile unsigned int*)(0x423082B4UL)))
#define bM4_TMR62_GCMBR_GCMB14                    (*((volatile unsigned int*)(0x423082B8UL)))
#define bM4_TMR62_GCMBR_GCMB15                    (*((volatile unsigned int*)(0x423082BCUL)))
#define bM4_TMR62_GCMCR_GCMC0                     (*((volatile unsigned int*)(0x42308300UL)))
#define bM4_TMR62_GCMCR_GCMC1                     (*((volatile unsigned int*)(0x42308304UL)))
#define bM4_TMR62_GCMCR_GCMC2                     (*((volatile unsigned int*)(0x42308308UL)))
#define bM4_TMR62_GCMCR_GCMC3                     (*((volatile unsigned int*)(0x4230830CUL)))
#define bM4_TMR62_GCMCR_GCMC4                     (*((volatile unsigned int*)(0x42308310UL)))
#define bM4_TMR62_GCMCR_GCMC5                     (*((volatile unsigned int*)(0x42308314UL)))
#define bM4_TMR62_GCMCR_GCMC6                     (*((volatile unsigned int*)(0x42308318UL)))
#define bM4_TMR62_GCMCR_GCMC7                     (*((volatile unsigned int*)(0x4230831CUL)))
#define bM4_TMR62_GCMCR_GCMC8                     (*((volatile unsigned int*)(0x42308320UL)))
#define bM4_TMR62_GCMCR_GCMC9                     (*((volatile unsigned int*)(0x42308324UL)))
#define bM4_TMR62_GCMCR_GCMC10                    (*((volatile unsigned int*)(0x42308328UL)))
#define bM4_TMR62_GCMCR_GCMC11                    (*((volatile unsigned int*)(0x4230832CUL)))
#define bM4_TMR62_GCMCR_GCMC12                    (*((volatile unsigned int*)(0x42308330UL)))
#define bM4_TMR62_GCMCR_GCMC13                    (*((volatile unsigned int*)(0x42308334UL)))
#define bM4_TMR62_GCMCR_GCMC14                    (*((volatile unsigned int*)(0x42308338UL)))
#define bM4_TMR62_GCMCR_GCMC15                    (*((volatile unsigned int*)(0x4230833CUL)))
#define bM4_TMR62_GCMDR_GCMD0                     (*((volatile unsigned int*)(0x42308380UL)))
#define bM4_TMR62_GCMDR_GCMD1                     (*((volatile unsigned int*)(0x42308384UL)))
#define bM4_TMR62_GCMDR_GCMD2                     (*((volatile unsigned int*)(0x42308388UL)))
#define bM4_TMR62_GCMDR_GCMD3                     (*((volatile unsigned int*)(0x4230838CUL)))
#define bM4_TMR62_GCMDR_GCMD4                     (*((volatile unsigned int*)(0x42308390UL)))
#define bM4_TMR62_GCMDR_GCMD5                     (*((volatile unsigned int*)(0x42308394UL)))
#define bM4_TMR62_GCMDR_GCMD6                     (*((volatile unsigned int*)(0x42308398UL)))
#define bM4_TMR62_GCMDR_GCMD7                     (*((volatile unsigned int*)(0x4230839CUL)))
#define bM4_TMR62_GCMDR_GCMD8                     (*((volatile unsigned int*)(0x423083A0UL)))
#define bM4_TMR62_GCMDR_GCMD9                     (*((volatile unsigned int*)(0x423083A4UL)))
#define bM4_TMR62_GCMDR_GCMD10                    (*((volatile unsigned int*)(0x423083A8UL)))
#define bM4_TMR62_GCMDR_GCMD11                    (*((volatile unsigned int*)(0x423083ACUL)))
#define bM4_TMR62_GCMDR_GCMD12                    (*((volatile unsigned int*)(0x423083B0UL)))
#define bM4_TMR62_GCMDR_GCMD13                    (*((volatile unsigned int*)(0x423083B4UL)))
#define bM4_TMR62_GCMDR_GCMD14                    (*((volatile unsigned int*)(0x423083B8UL)))
#define bM4_TMR62_GCMDR_GCMD15                    (*((volatile unsigned int*)(0x423083BCUL)))
#define bM4_TMR62_GCMER_GCME0                     (*((volatile unsigned int*)(0x42308400UL)))
#define bM4_TMR62_GCMER_GCME1                     (*((volatile unsigned int*)(0x42308404UL)))
#define bM4_TMR62_GCMER_GCME2                     (*((volatile unsigned int*)(0x42308408UL)))
#define bM4_TMR62_GCMER_GCME3                     (*((volatile unsigned int*)(0x4230840CUL)))
#define bM4_TMR62_GCMER_GCME4                     (*((volatile unsigned int*)(0x42308410UL)))
#define bM4_TMR62_GCMER_GCME5                     (*((volatile unsigned int*)(0x42308414UL)))
#define bM4_TMR62_GCMER_GCME6                     (*((volatile unsigned int*)(0x42308418UL)))
#define bM4_TMR62_GCMER_GCME7                     (*((volatile unsigned int*)(0x4230841CUL)))
#define bM4_TMR62_GCMER_GCME8                     (*((volatile unsigned int*)(0x42308420UL)))
#define bM4_TMR62_GCMER_GCME9                     (*((volatile unsigned int*)(0x42308424UL)))
#define bM4_TMR62_GCMER_GCME10                    (*((volatile unsigned int*)(0x42308428UL)))
#define bM4_TMR62_GCMER_GCME11                    (*((volatile unsigned int*)(0x4230842CUL)))
#define bM4_TMR62_GCMER_GCME12                    (*((volatile unsigned int*)(0x42308430UL)))
#define bM4_TMR62_GCMER_GCME13                    (*((volatile unsigned int*)(0x42308434UL)))
#define bM4_TMR62_GCMER_GCME14                    (*((volatile unsigned int*)(0x42308438UL)))
#define bM4_TMR62_GCMER_GCME15                    (*((volatile unsigned int*)(0x4230843CUL)))
#define bM4_TMR62_GCMFR_GCMF0                     (*((volatile unsigned int*)(0x42308480UL)))
#define bM4_TMR62_GCMFR_GCMF1                     (*((volatile unsigned int*)(0x42308484UL)))
#define bM4_TMR62_GCMFR_GCMF2                     (*((volatile unsigned int*)(0x42308488UL)))
#define bM4_TMR62_GCMFR_GCMF3                     (*((volatile unsigned int*)(0x4230848CUL)))
#define bM4_TMR62_GCMFR_GCMF4                     (*((volatile unsigned int*)(0x42308490UL)))
#define bM4_TMR62_GCMFR_GCMF5                     (*((volatile unsigned int*)(0x42308494UL)))
#define bM4_TMR62_GCMFR_GCMF6                     (*((volatile unsigned int*)(0x42308498UL)))
#define bM4_TMR62_GCMFR_GCMF7                     (*((volatile unsigned int*)(0x4230849CUL)))
#define bM4_TMR62_GCMFR_GCMF8                     (*((volatile unsigned int*)(0x423084A0UL)))
#define bM4_TMR62_GCMFR_GCMF9                     (*((volatile unsigned int*)(0x423084A4UL)))
#define bM4_TMR62_GCMFR_GCMF10                    (*((volatile unsigned int*)(0x423084A8UL)))
#define bM4_TMR62_GCMFR_GCMF11                    (*((volatile unsigned int*)(0x423084ACUL)))
#define bM4_TMR62_GCMFR_GCMF12                    (*((volatile unsigned int*)(0x423084B0UL)))
#define bM4_TMR62_GCMFR_GCMF13                    (*((volatile unsigned int*)(0x423084B4UL)))
#define bM4_TMR62_GCMFR_GCMF14                    (*((volatile unsigned int*)(0x423084B8UL)))
#define bM4_TMR62_GCMFR_GCMF15                    (*((volatile unsigned int*)(0x423084BCUL)))
#define bM4_TMR62_SCMAR_SCMA0                     (*((volatile unsigned int*)(0x42308500UL)))
#define bM4_TMR62_SCMAR_SCMA1                     (*((volatile unsigned int*)(0x42308504UL)))
#define bM4_TMR62_SCMAR_SCMA2                     (*((volatile unsigned int*)(0x42308508UL)))
#define bM4_TMR62_SCMAR_SCMA3                     (*((volatile unsigned int*)(0x4230850CUL)))
#define bM4_TMR62_SCMAR_SCMA4                     (*((volatile unsigned int*)(0x42308510UL)))
#define bM4_TMR62_SCMAR_SCMA5                     (*((volatile unsigned int*)(0x42308514UL)))
#define bM4_TMR62_SCMAR_SCMA6                     (*((volatile unsigned int*)(0x42308518UL)))
#define bM4_TMR62_SCMAR_SCMA7                     (*((volatile unsigned int*)(0x4230851CUL)))
#define bM4_TMR62_SCMAR_SCMA8                     (*((volatile unsigned int*)(0x42308520UL)))
#define bM4_TMR62_SCMAR_SCMA9                     (*((volatile unsigned int*)(0x42308524UL)))
#define bM4_TMR62_SCMAR_SCMA10                    (*((volatile unsigned int*)(0x42308528UL)))
#define bM4_TMR62_SCMAR_SCMA11                    (*((volatile unsigned int*)(0x4230852CUL)))
#define bM4_TMR62_SCMAR_SCMA12                    (*((volatile unsigned int*)(0x42308530UL)))
#define bM4_TMR62_SCMAR_SCMA13                    (*((volatile unsigned int*)(0x42308534UL)))
#define bM4_TMR62_SCMAR_SCMA14                    (*((volatile unsigned int*)(0x42308538UL)))
#define bM4_TMR62_SCMAR_SCMA15                    (*((volatile unsigned int*)(0x4230853CUL)))
#define bM4_TMR62_SCMBR_SCMB0                     (*((volatile unsigned int*)(0x42308580UL)))
#define bM4_TMR62_SCMBR_SCMB1                     (*((volatile unsigned int*)(0x42308584UL)))
#define bM4_TMR62_SCMBR_SCMB2                     (*((volatile unsigned int*)(0x42308588UL)))
#define bM4_TMR62_SCMBR_SCMB3                     (*((volatile unsigned int*)(0x4230858CUL)))
#define bM4_TMR62_SCMBR_SCMB4                     (*((volatile unsigned int*)(0x42308590UL)))
#define bM4_TMR62_SCMBR_SCMB5                     (*((volatile unsigned int*)(0x42308594UL)))
#define bM4_TMR62_SCMBR_SCMB6                     (*((volatile unsigned int*)(0x42308598UL)))
#define bM4_TMR62_SCMBR_SCMB7                     (*((volatile unsigned int*)(0x4230859CUL)))
#define bM4_TMR62_SCMBR_SCMB8                     (*((volatile unsigned int*)(0x423085A0UL)))
#define bM4_TMR62_SCMBR_SCMB9                     (*((volatile unsigned int*)(0x423085A4UL)))
#define bM4_TMR62_SCMBR_SCMB10                    (*((volatile unsigned int*)(0x423085A8UL)))
#define bM4_TMR62_SCMBR_SCMB11                    (*((volatile unsigned int*)(0x423085ACUL)))
#define bM4_TMR62_SCMBR_SCMB12                    (*((volatile unsigned int*)(0x423085B0UL)))
#define bM4_TMR62_SCMBR_SCMB13                    (*((volatile unsigned int*)(0x423085B4UL)))
#define bM4_TMR62_SCMBR_SCMB14                    (*((volatile unsigned int*)(0x423085B8UL)))
#define bM4_TMR62_SCMBR_SCMB15                    (*((volatile unsigned int*)(0x423085BCUL)))
#define bM4_TMR62_SCMCR_SCMC0                     (*((volatile unsigned int*)(0x42308600UL)))
#define bM4_TMR62_SCMCR_SCMC1                     (*((volatile unsigned int*)(0x42308604UL)))
#define bM4_TMR62_SCMCR_SCMC2                     (*((volatile unsigned int*)(0x42308608UL)))
#define bM4_TMR62_SCMCR_SCMC3                     (*((volatile unsigned int*)(0x4230860CUL)))
#define bM4_TMR62_SCMCR_SCMC4                     (*((volatile unsigned int*)(0x42308610UL)))
#define bM4_TMR62_SCMCR_SCMC5                     (*((volatile unsigned int*)(0x42308614UL)))
#define bM4_TMR62_SCMCR_SCMC6                     (*((volatile unsigned int*)(0x42308618UL)))
#define bM4_TMR62_SCMCR_SCMC7                     (*((volatile unsigned int*)(0x4230861CUL)))
#define bM4_TMR62_SCMCR_SCMC8                     (*((volatile unsigned int*)(0x42308620UL)))
#define bM4_TMR62_SCMCR_SCMC9                     (*((volatile unsigned int*)(0x42308624UL)))
#define bM4_TMR62_SCMCR_SCMC10                    (*((volatile unsigned int*)(0x42308628UL)))
#define bM4_TMR62_SCMCR_SCMC11                    (*((volatile unsigned int*)(0x4230862CUL)))
#define bM4_TMR62_SCMCR_SCMC12                    (*((volatile unsigned int*)(0x42308630UL)))
#define bM4_TMR62_SCMCR_SCMC13                    (*((volatile unsigned int*)(0x42308634UL)))
#define bM4_TMR62_SCMCR_SCMC14                    (*((volatile unsigned int*)(0x42308638UL)))
#define bM4_TMR62_SCMCR_SCMC15                    (*((volatile unsigned int*)(0x4230863CUL)))
#define bM4_TMR62_SCMDR_SCMD0                     (*((volatile unsigned int*)(0x42308680UL)))
#define bM4_TMR62_SCMDR_SCMD1                     (*((volatile unsigned int*)(0x42308684UL)))
#define bM4_TMR62_SCMDR_SCMD2                     (*((volatile unsigned int*)(0x42308688UL)))
#define bM4_TMR62_SCMDR_SCMD3                     (*((volatile unsigned int*)(0x4230868CUL)))
#define bM4_TMR62_SCMDR_SCMD4                     (*((volatile unsigned int*)(0x42308690UL)))
#define bM4_TMR62_SCMDR_SCMD5                     (*((volatile unsigned int*)(0x42308694UL)))
#define bM4_TMR62_SCMDR_SCMD6                     (*((volatile unsigned int*)(0x42308698UL)))
#define bM4_TMR62_SCMDR_SCMD7                     (*((volatile unsigned int*)(0x4230869CUL)))
#define bM4_TMR62_SCMDR_SCMD8                     (*((volatile unsigned int*)(0x423086A0UL)))
#define bM4_TMR62_SCMDR_SCMD9                     (*((volatile unsigned int*)(0x423086A4UL)))
#define bM4_TMR62_SCMDR_SCMD10                    (*((volatile unsigned int*)(0x423086A8UL)))
#define bM4_TMR62_SCMDR_SCMD11                    (*((volatile unsigned int*)(0x423086ACUL)))
#define bM4_TMR62_SCMDR_SCMD12                    (*((volatile unsigned int*)(0x423086B0UL)))
#define bM4_TMR62_SCMDR_SCMD13                    (*((volatile unsigned int*)(0x423086B4UL)))
#define bM4_TMR62_SCMDR_SCMD14                    (*((volatile unsigned int*)(0x423086B8UL)))
#define bM4_TMR62_SCMDR_SCMD15                    (*((volatile unsigned int*)(0x423086BCUL)))
#define bM4_TMR62_SCMER_SCME0                     (*((volatile unsigned int*)(0x42308700UL)))
#define bM4_TMR62_SCMER_SCME1                     (*((volatile unsigned int*)(0x42308704UL)))
#define bM4_TMR62_SCMER_SCME2                     (*((volatile unsigned int*)(0x42308708UL)))
#define bM4_TMR62_SCMER_SCME3                     (*((volatile unsigned int*)(0x4230870CUL)))
#define bM4_TMR62_SCMER_SCME4                     (*((volatile unsigned int*)(0x42308710UL)))
#define bM4_TMR62_SCMER_SCME5                     (*((volatile unsigned int*)(0x42308714UL)))
#define bM4_TMR62_SCMER_SCME6                     (*((volatile unsigned int*)(0x42308718UL)))
#define bM4_TMR62_SCMER_SCME7                     (*((volatile unsigned int*)(0x4230871CUL)))
#define bM4_TMR62_SCMER_SCME8                     (*((volatile unsigned int*)(0x42308720UL)))
#define bM4_TMR62_SCMER_SCME9                     (*((volatile unsigned int*)(0x42308724UL)))
#define bM4_TMR62_SCMER_SCME10                    (*((volatile unsigned int*)(0x42308728UL)))
#define bM4_TMR62_SCMER_SCME11                    (*((volatile unsigned int*)(0x4230872CUL)))
#define bM4_TMR62_SCMER_SCME12                    (*((volatile unsigned int*)(0x42308730UL)))
#define bM4_TMR62_SCMER_SCME13                    (*((volatile unsigned int*)(0x42308734UL)))
#define bM4_TMR62_SCMER_SCME14                    (*((volatile unsigned int*)(0x42308738UL)))
#define bM4_TMR62_SCMER_SCME15                    (*((volatile unsigned int*)(0x4230873CUL)))
#define bM4_TMR62_SCMFR_SCMF0                     (*((volatile unsigned int*)(0x42308780UL)))
#define bM4_TMR62_SCMFR_SCMF1                     (*((volatile unsigned int*)(0x42308784UL)))
#define bM4_TMR62_SCMFR_SCMF2                     (*((volatile unsigned int*)(0x42308788UL)))
#define bM4_TMR62_SCMFR_SCMF3                     (*((volatile unsigned int*)(0x4230878CUL)))
#define bM4_TMR62_SCMFR_SCMF4                     (*((volatile unsigned int*)(0x42308790UL)))
#define bM4_TMR62_SCMFR_SCMF5                     (*((volatile unsigned int*)(0x42308794UL)))
#define bM4_TMR62_SCMFR_SCMF6                     (*((volatile unsigned int*)(0x42308798UL)))
#define bM4_TMR62_SCMFR_SCMF7                     (*((volatile unsigned int*)(0x4230879CUL)))
#define bM4_TMR62_SCMFR_SCMF8                     (*((volatile unsigned int*)(0x423087A0UL)))
#define bM4_TMR62_SCMFR_SCMF9                     (*((volatile unsigned int*)(0x423087A4UL)))
#define bM4_TMR62_SCMFR_SCMF10                    (*((volatile unsigned int*)(0x423087A8UL)))
#define bM4_TMR62_SCMFR_SCMF11                    (*((volatile unsigned int*)(0x423087ACUL)))
#define bM4_TMR62_SCMFR_SCMF12                    (*((volatile unsigned int*)(0x423087B0UL)))
#define bM4_TMR62_SCMFR_SCMF13                    (*((volatile unsigned int*)(0x423087B4UL)))
#define bM4_TMR62_SCMFR_SCMF14                    (*((volatile unsigned int*)(0x423087B8UL)))
#define bM4_TMR62_SCMFR_SCMF15                    (*((volatile unsigned int*)(0x423087BCUL)))
#define bM4_TMR62_DTUAR_DTUA0                     (*((volatile unsigned int*)(0x42308800UL)))
#define bM4_TMR62_DTUAR_DTUA1                     (*((volatile unsigned int*)(0x42308804UL)))
#define bM4_TMR62_DTUAR_DTUA2                     (*((volatile unsigned int*)(0x42308808UL)))
#define bM4_TMR62_DTUAR_DTUA3                     (*((volatile unsigned int*)(0x4230880CUL)))
#define bM4_TMR62_DTUAR_DTUA4                     (*((volatile unsigned int*)(0x42308810UL)))
#define bM4_TMR62_DTUAR_DTUA5                     (*((volatile unsigned int*)(0x42308814UL)))
#define bM4_TMR62_DTUAR_DTUA6                     (*((volatile unsigned int*)(0x42308818UL)))
#define bM4_TMR62_DTUAR_DTUA7                     (*((volatile unsigned int*)(0x4230881CUL)))
#define bM4_TMR62_DTUAR_DTUA8                     (*((volatile unsigned int*)(0x42308820UL)))
#define bM4_TMR62_DTUAR_DTUA9                     (*((volatile unsigned int*)(0x42308824UL)))
#define bM4_TMR62_DTUAR_DTUA10                    (*((volatile unsigned int*)(0x42308828UL)))
#define bM4_TMR62_DTUAR_DTUA11                    (*((volatile unsigned int*)(0x4230882CUL)))
#define bM4_TMR62_DTUAR_DTUA12                    (*((volatile unsigned int*)(0x42308830UL)))
#define bM4_TMR62_DTUAR_DTUA13                    (*((volatile unsigned int*)(0x42308834UL)))
#define bM4_TMR62_DTUAR_DTUA14                    (*((volatile unsigned int*)(0x42308838UL)))
#define bM4_TMR62_DTUAR_DTUA15                    (*((volatile unsigned int*)(0x4230883CUL)))
#define bM4_TMR62_DTDAR_DTDA0                     (*((volatile unsigned int*)(0x42308880UL)))
#define bM4_TMR62_DTDAR_DTDA1                     (*((volatile unsigned int*)(0x42308884UL)))
#define bM4_TMR62_DTDAR_DTDA2                     (*((volatile unsigned int*)(0x42308888UL)))
#define bM4_TMR62_DTDAR_DTDA3                     (*((volatile unsigned int*)(0x4230888CUL)))
#define bM4_TMR62_DTDAR_DTDA4                     (*((volatile unsigned int*)(0x42308890UL)))
#define bM4_TMR62_DTDAR_DTDA5                     (*((volatile unsigned int*)(0x42308894UL)))
#define bM4_TMR62_DTDAR_DTDA6                     (*((volatile unsigned int*)(0x42308898UL)))
#define bM4_TMR62_DTDAR_DTDA7                     (*((volatile unsigned int*)(0x4230889CUL)))
#define bM4_TMR62_DTDAR_DTDA8                     (*((volatile unsigned int*)(0x423088A0UL)))
#define bM4_TMR62_DTDAR_DTDA9                     (*((volatile unsigned int*)(0x423088A4UL)))
#define bM4_TMR62_DTDAR_DTDA10                    (*((volatile unsigned int*)(0x423088A8UL)))
#define bM4_TMR62_DTDAR_DTDA11                    (*((volatile unsigned int*)(0x423088ACUL)))
#define bM4_TMR62_DTDAR_DTDA12                    (*((volatile unsigned int*)(0x423088B0UL)))
#define bM4_TMR62_DTDAR_DTDA13                    (*((volatile unsigned int*)(0x423088B4UL)))
#define bM4_TMR62_DTDAR_DTDA14                    (*((volatile unsigned int*)(0x423088B8UL)))
#define bM4_TMR62_DTDAR_DTDA15                    (*((volatile unsigned int*)(0x423088BCUL)))
#define bM4_TMR62_DTUBR_DTUB0                     (*((volatile unsigned int*)(0x42308900UL)))
#define bM4_TMR62_DTUBR_DTUB1                     (*((volatile unsigned int*)(0x42308904UL)))
#define bM4_TMR62_DTUBR_DTUB2                     (*((volatile unsigned int*)(0x42308908UL)))
#define bM4_TMR62_DTUBR_DTUB3                     (*((volatile unsigned int*)(0x4230890CUL)))
#define bM4_TMR62_DTUBR_DTUB4                     (*((volatile unsigned int*)(0x42308910UL)))
#define bM4_TMR62_DTUBR_DTUB5                     (*((volatile unsigned int*)(0x42308914UL)))
#define bM4_TMR62_DTUBR_DTUB6                     (*((volatile unsigned int*)(0x42308918UL)))
#define bM4_TMR62_DTUBR_DTUB7                     (*((volatile unsigned int*)(0x4230891CUL)))
#define bM4_TMR62_DTUBR_DTUB8                     (*((volatile unsigned int*)(0x42308920UL)))
#define bM4_TMR62_DTUBR_DTUB9                     (*((volatile unsigned int*)(0x42308924UL)))
#define bM4_TMR62_DTUBR_DTUB10                    (*((volatile unsigned int*)(0x42308928UL)))
#define bM4_TMR62_DTUBR_DTUB11                    (*((volatile unsigned int*)(0x4230892CUL)))
#define bM4_TMR62_DTUBR_DTUB12                    (*((volatile unsigned int*)(0x42308930UL)))
#define bM4_TMR62_DTUBR_DTUB13                    (*((volatile unsigned int*)(0x42308934UL)))
#define bM4_TMR62_DTUBR_DTUB14                    (*((volatile unsigned int*)(0x42308938UL)))
#define bM4_TMR62_DTUBR_DTUB15                    (*((volatile unsigned int*)(0x4230893CUL)))
#define bM4_TMR62_DTDBR_DTDB0                     (*((volatile unsigned int*)(0x42308980UL)))
#define bM4_TMR62_DTDBR_DTDB1                     (*((volatile unsigned int*)(0x42308984UL)))
#define bM4_TMR62_DTDBR_DTDB2                     (*((volatile unsigned int*)(0x42308988UL)))
#define bM4_TMR62_DTDBR_DTDB3                     (*((volatile unsigned int*)(0x4230898CUL)))
#define bM4_TMR62_DTDBR_DTDB4                     (*((volatile unsigned int*)(0x42308990UL)))
#define bM4_TMR62_DTDBR_DTDB5                     (*((volatile unsigned int*)(0x42308994UL)))
#define bM4_TMR62_DTDBR_DTDB6                     (*((volatile unsigned int*)(0x42308998UL)))
#define bM4_TMR62_DTDBR_DTDB7                     (*((volatile unsigned int*)(0x4230899CUL)))
#define bM4_TMR62_DTDBR_DTDB8                     (*((volatile unsigned int*)(0x423089A0UL)))
#define bM4_TMR62_DTDBR_DTDB9                     (*((volatile unsigned int*)(0x423089A4UL)))
#define bM4_TMR62_DTDBR_DTDB10                    (*((volatile unsigned int*)(0x423089A8UL)))
#define bM4_TMR62_DTDBR_DTDB11                    (*((volatile unsigned int*)(0x423089ACUL)))
#define bM4_TMR62_DTDBR_DTDB12                    (*((volatile unsigned int*)(0x423089B0UL)))
#define bM4_TMR62_DTDBR_DTDB13                    (*((volatile unsigned int*)(0x423089B4UL)))
#define bM4_TMR62_DTDBR_DTDB14                    (*((volatile unsigned int*)(0x423089B8UL)))
#define bM4_TMR62_DTDBR_DTDB15                    (*((volatile unsigned int*)(0x423089BCUL)))
#define bM4_TMR62_GCONR_START                     (*((volatile unsigned int*)(0x42308A00UL)))
#define bM4_TMR62_GCONR_MODE0                     (*((volatile unsigned int*)(0x42308A04UL)))
#define bM4_TMR62_GCONR_MODE1                     (*((volatile unsigned int*)(0x42308A08UL)))
#define bM4_TMR62_GCONR_MODE2                     (*((volatile unsigned int*)(0x42308A0CUL)))
#define bM4_TMR62_GCONR_CKDIV0                    (*((volatile unsigned int*)(0x42308A10UL)))
#define bM4_TMR62_GCONR_CKDIV1                    (*((volatile unsigned int*)(0x42308A14UL)))
#define bM4_TMR62_GCONR_CKDIV2                    (*((volatile unsigned int*)(0x42308A18UL)))
#define bM4_TMR62_GCONR_DIR                       (*((volatile unsigned int*)(0x42308A20UL)))
#define bM4_TMR62_GCONR_ZMSKREV                   (*((volatile unsigned int*)(0x42308A40UL)))
#define bM4_TMR62_GCONR_ZMSKPOS                   (*((volatile unsigned int*)(0x42308A44UL)))
#define bM4_TMR62_GCONR_ZMSKVAL0                  (*((volatile unsigned int*)(0x42308A48UL)))
#define bM4_TMR62_GCONR_ZMSKVAL1                  (*((volatile unsigned int*)(0x42308A4CUL)))
#define bM4_TMR62_ICONR_INTENA                    (*((volatile unsigned int*)(0x42308A80UL)))
#define bM4_TMR62_ICONR_INTENB                    (*((volatile unsigned int*)(0x42308A84UL)))
#define bM4_TMR62_ICONR_INTENC                    (*((volatile unsigned int*)(0x42308A88UL)))
#define bM4_TMR62_ICONR_INTEND                    (*((volatile unsigned int*)(0x42308A8CUL)))
#define bM4_TMR62_ICONR_INTENE                    (*((volatile unsigned int*)(0x42308A90UL)))
#define bM4_TMR62_ICONR_INTENF                    (*((volatile unsigned int*)(0x42308A94UL)))
#define bM4_TMR62_ICONR_INTENOVF                  (*((volatile unsigned int*)(0x42308A98UL)))
#define bM4_TMR62_ICONR_INTENUDF                  (*((volatile unsigned int*)(0x42308A9CUL)))
#define bM4_TMR62_ICONR_INTENDTE                  (*((volatile unsigned int*)(0x42308AA0UL)))
#define bM4_TMR62_ICONR_INTENSAU                  (*((volatile unsigned int*)(0x42308AC0UL)))
#define bM4_TMR62_ICONR_INTENSAD                  (*((volatile unsigned int*)(0x42308AC4UL)))
#define bM4_TMR62_ICONR_INTENSBU                  (*((volatile unsigned int*)(0x42308AC8UL)))
#define bM4_TMR62_ICONR_INTENSBD                  (*((volatile unsigned int*)(0x42308ACCUL)))
#define bM4_TMR62_PCONR_CAPMDA                    (*((volatile unsigned int*)(0x42308B00UL)))
#define bM4_TMR62_PCONR_STACA                     (*((volatile unsigned int*)(0x42308B04UL)))
#define bM4_TMR62_PCONR_STPCA                     (*((volatile unsigned int*)(0x42308B08UL)))
#define bM4_TMR62_PCONR_STASTPSA                  (*((volatile unsigned int*)(0x42308B0CUL)))
#define bM4_TMR62_PCONR_CMPCA0                    (*((volatile unsigned int*)(0x42308B10UL)))
#define bM4_TMR62_PCONR_CMPCA1                    (*((volatile unsigned int*)(0x42308B14UL)))
#define bM4_TMR62_PCONR_PERCA0                    (*((volatile unsigned int*)(0x42308B18UL)))
#define bM4_TMR62_PCONR_PERCA1                    (*((volatile unsigned int*)(0x42308B1CUL)))
#define bM4_TMR62_PCONR_OUTENA                    (*((volatile unsigned int*)(0x42308B20UL)))
#define bM4_TMR62_PCONR_EMBVALA0                  (*((volatile unsigned int*)(0x42308B2CUL)))
#define bM4_TMR62_PCONR_EMBVALA1                  (*((volatile unsigned int*)(0x42308B30UL)))
#define bM4_TMR62_PCONR_CAPMDB                    (*((volatile unsigned int*)(0x42308B40UL)))
#define bM4_TMR62_PCONR_STACB                     (*((volatile unsigned int*)(0x42308B44UL)))
#define bM4_TMR62_PCONR_STPCB                     (*((volatile unsigned int*)(0x42308B48UL)))
#define bM4_TMR62_PCONR_STASTPSB                  (*((volatile unsigned int*)(0x42308B4CUL)))
#define bM4_TMR62_PCONR_CMPCB0                    (*((volatile unsigned int*)(0x42308B50UL)))
#define bM4_TMR62_PCONR_CMPCB1                    (*((volatile unsigned int*)(0x42308B54UL)))
#define bM4_TMR62_PCONR_PERCB0                    (*((volatile unsigned int*)(0x42308B58UL)))
#define bM4_TMR62_PCONR_PERCB1                    (*((volatile unsigned int*)(0x42308B5CUL)))
#define bM4_TMR62_PCONR_OUTENB                    (*((volatile unsigned int*)(0x42308B60UL)))
#define bM4_TMR62_PCONR_EMBVALB0                  (*((volatile unsigned int*)(0x42308B6CUL)))
#define bM4_TMR62_PCONR_EMBVALB1                  (*((volatile unsigned int*)(0x42308B70UL)))
#define bM4_TMR62_BCONR_BENA                      (*((volatile unsigned int*)(0x42308B80UL)))
#define bM4_TMR62_BCONR_BSEA                      (*((volatile unsigned int*)(0x42308B84UL)))
#define bM4_TMR62_BCONR_BENB                      (*((volatile unsigned int*)(0x42308B88UL)))
#define bM4_TMR62_BCONR_BSEB                      (*((volatile unsigned int*)(0x42308B8CUL)))
#define bM4_TMR62_BCONR_BENP                      (*((volatile unsigned int*)(0x42308BA0UL)))
#define bM4_TMR62_BCONR_BSEP                      (*((volatile unsigned int*)(0x42308BA4UL)))
#define bM4_TMR62_BCONR_BENSPA                    (*((volatile unsigned int*)(0x42308BC0UL)))
#define bM4_TMR62_BCONR_BSESPA                    (*((volatile unsigned int*)(0x42308BC4UL)))
#define bM4_TMR62_BCONR_BTRSPA0                   (*((volatile unsigned int*)(0x42308BD0UL)))
#define bM4_TMR62_BCONR_BTRSPA1                   (*((volatile unsigned int*)(0x42308BD4UL)))
#define bM4_TMR62_BCONR_BENSPB                    (*((volatile unsigned int*)(0x42308BE0UL)))
#define bM4_TMR62_BCONR_BSESPB                    (*((volatile unsigned int*)(0x42308BE4UL)))
#define bM4_TMR62_BCONR_BTRSPB0                   (*((volatile unsigned int*)(0x42308BF0UL)))
#define bM4_TMR62_BCONR_BTRSPB1                   (*((volatile unsigned int*)(0x42308BF4UL)))
#define bM4_TMR62_DCONR_DTCEN                     (*((volatile unsigned int*)(0x42308C00UL)))
#define bM4_TMR62_DCONR_DTBENU                    (*((volatile unsigned int*)(0x42308C10UL)))
#define bM4_TMR62_DCONR_DTBEND                    (*((volatile unsigned int*)(0x42308C14UL)))
#define bM4_TMR62_DCONR_SEPA                      (*((volatile unsigned int*)(0x42308C20UL)))
#define bM4_TMR62_FCONR_NOFIENGA                  (*((volatile unsigned int*)(0x42308D00UL)))
#define bM4_TMR62_FCONR_NOFICKGA0                 (*((volatile unsigned int*)(0x42308D04UL)))
#define bM4_TMR62_FCONR_NOFICKGA1                 (*((volatile unsigned int*)(0x42308D08UL)))
#define bM4_TMR62_FCONR_NOFIENGB                  (*((volatile unsigned int*)(0x42308D10UL)))
#define bM4_TMR62_FCONR_NOFICKGB0                 (*((volatile unsigned int*)(0x42308D14UL)))
#define bM4_TMR62_FCONR_NOFICKGB1                 (*((volatile unsigned int*)(0x42308D18UL)))
#define bM4_TMR62_FCONR_NOFIENTA                  (*((volatile unsigned int*)(0x42308D40UL)))
#define bM4_TMR62_FCONR_NOFICKTA0                 (*((volatile unsigned int*)(0x42308D44UL)))
#define bM4_TMR62_FCONR_NOFICKTA1                 (*((volatile unsigned int*)(0x42308D48UL)))
#define bM4_TMR62_FCONR_NOFIENTB                  (*((volatile unsigned int*)(0x42308D50UL)))
#define bM4_TMR62_FCONR_NOFICKTB0                 (*((volatile unsigned int*)(0x42308D54UL)))
#define bM4_TMR62_FCONR_NOFICKTB1                 (*((volatile unsigned int*)(0x42308D58UL)))
#define bM4_TMR62_VPERR_SPPERIA                   (*((volatile unsigned int*)(0x42308DA0UL)))
#define bM4_TMR62_VPERR_SPPERIB                   (*((volatile unsigned int*)(0x42308DA4UL)))
#define bM4_TMR62_VPERR_PCNTE0                    (*((volatile unsigned int*)(0x42308DC0UL)))
#define bM4_TMR62_VPERR_PCNTE1                    (*((volatile unsigned int*)(0x42308DC4UL)))
#define bM4_TMR62_VPERR_PCNTS0                    (*((volatile unsigned int*)(0x42308DC8UL)))
#define bM4_TMR62_VPERR_PCNTS1                    (*((volatile unsigned int*)(0x42308DCCUL)))
#define bM4_TMR62_VPERR_PCNTS2                    (*((volatile unsigned int*)(0x42308DD0UL)))
#define bM4_TMR62_STFLR_CMAF                      (*((volatile unsigned int*)(0x42308E00UL)))
#define bM4_TMR62_STFLR_CMBF                      (*((volatile unsigned int*)(0x42308E04UL)))
#define bM4_TMR62_STFLR_CMCF                      (*((volatile unsigned int*)(0x42308E08UL)))
#define bM4_TMR62_STFLR_CMDF                      (*((volatile unsigned int*)(0x42308E0CUL)))
#define bM4_TMR62_STFLR_CMEF                      (*((volatile unsigned int*)(0x42308E10UL)))
#define bM4_TMR62_STFLR_CMFF                      (*((volatile unsigned int*)(0x42308E14UL)))
#define bM4_TMR62_STFLR_OVFF                      (*((volatile unsigned int*)(0x42308E18UL)))
#define bM4_TMR62_STFLR_UDFF                      (*((volatile unsigned int*)(0x42308E1CUL)))
#define bM4_TMR62_STFLR_DTEF                      (*((volatile unsigned int*)(0x42308E20UL)))
#define bM4_TMR62_STFLR_CMSAUF                    (*((volatile unsigned int*)(0x42308E24UL)))
#define bM4_TMR62_STFLR_CMSADF                    (*((volatile unsigned int*)(0x42308E28UL)))
#define bM4_TMR62_STFLR_CMSBUF                    (*((volatile unsigned int*)(0x42308E2CUL)))
#define bM4_TMR62_STFLR_CMSBDF                    (*((volatile unsigned int*)(0x42308E30UL)))
#define bM4_TMR62_STFLR_VPERNUM0                  (*((volatile unsigned int*)(0x42308E54UL)))
#define bM4_TMR62_STFLR_VPERNUM1                  (*((volatile unsigned int*)(0x42308E58UL)))
#define bM4_TMR62_STFLR_VPERNUM2                  (*((volatile unsigned int*)(0x42308E5CUL)))
#define bM4_TMR62_STFLR_DIRF                      (*((volatile unsigned int*)(0x42308E7CUL)))
#define bM4_TMR62_HSTAR_HSTA0                     (*((volatile unsigned int*)(0x42308E80UL)))
#define bM4_TMR62_HSTAR_HSTA1                     (*((volatile unsigned int*)(0x42308E84UL)))
#define bM4_TMR62_HSTAR_HSTA4                     (*((volatile unsigned int*)(0x42308E90UL)))
#define bM4_TMR62_HSTAR_HSTA5                     (*((volatile unsigned int*)(0x42308E94UL)))
#define bM4_TMR62_HSTAR_HSTA6                     (*((volatile unsigned int*)(0x42308E98UL)))
#define bM4_TMR62_HSTAR_HSTA7                     (*((volatile unsigned int*)(0x42308E9CUL)))
#define bM4_TMR62_HSTAR_HSTA8                     (*((volatile unsigned int*)(0x42308EA0UL)))
#define bM4_TMR62_HSTAR_HSTA9                     (*((volatile unsigned int*)(0x42308EA4UL)))
#define bM4_TMR62_HSTAR_HSTA10                    (*((volatile unsigned int*)(0x42308EA8UL)))
#define bM4_TMR62_HSTAR_HSTA11                    (*((volatile unsigned int*)(0x42308EACUL)))
#define bM4_TMR62_HSTAR_STARTS                    (*((volatile unsigned int*)(0x42308EFCUL)))
#define bM4_TMR62_HSTPR_HSTP0                     (*((volatile unsigned int*)(0x42308F00UL)))
#define bM4_TMR62_HSTPR_HSTP1                     (*((volatile unsigned int*)(0x42308F04UL)))
#define bM4_TMR62_HSTPR_HSTP4                     (*((volatile unsigned int*)(0x42308F10UL)))
#define bM4_TMR62_HSTPR_HSTP5                     (*((volatile unsigned int*)(0x42308F14UL)))
#define bM4_TMR62_HSTPR_HSTP6                     (*((volatile unsigned int*)(0x42308F18UL)))
#define bM4_TMR62_HSTPR_HSTP7                     (*((volatile unsigned int*)(0x42308F1CUL)))
#define bM4_TMR62_HSTPR_HSTP8                     (*((volatile unsigned int*)(0x42308F20UL)))
#define bM4_TMR62_HSTPR_HSTP9                     (*((volatile unsigned int*)(0x42308F24UL)))
#define bM4_TMR62_HSTPR_HSTP10                    (*((volatile unsigned int*)(0x42308F28UL)))
#define bM4_TMR62_HSTPR_HSTP11                    (*((volatile unsigned int*)(0x42308F2CUL)))
#define bM4_TMR62_HSTPR_STOPS                     (*((volatile unsigned int*)(0x42308F7CUL)))
#define bM4_TMR62_HCLRR_HCLE0                     (*((volatile unsigned int*)(0x42308F80UL)))
#define bM4_TMR62_HCLRR_HCLE1                     (*((volatile unsigned int*)(0x42308F84UL)))
#define bM4_TMR62_HCLRR_HCLE4                     (*((volatile unsigned int*)(0x42308F90UL)))
#define bM4_TMR62_HCLRR_HCLE5                     (*((volatile unsigned int*)(0x42308F94UL)))
#define bM4_TMR62_HCLRR_HCLE6                     (*((volatile unsigned int*)(0x42308F98UL)))
#define bM4_TMR62_HCLRR_HCLE7                     (*((volatile unsigned int*)(0x42308F9CUL)))
#define bM4_TMR62_HCLRR_HCLE8                     (*((volatile unsigned int*)(0x42308FA0UL)))
#define bM4_TMR62_HCLRR_HCLE9                     (*((volatile unsigned int*)(0x42308FA4UL)))
#define bM4_TMR62_HCLRR_HCLE10                    (*((volatile unsigned int*)(0x42308FA8UL)))
#define bM4_TMR62_HCLRR_HCLE11                    (*((volatile unsigned int*)(0x42308FACUL)))
#define bM4_TMR62_HCLRR_CLEARS                    (*((volatile unsigned int*)(0x42308FFCUL)))
#define bM4_TMR62_HCPAR_HCPA0                     (*((volatile unsigned int*)(0x42309000UL)))
#define bM4_TMR62_HCPAR_HCPA1                     (*((volatile unsigned int*)(0x42309004UL)))
#define bM4_TMR62_HCPAR_HCPA4                     (*((volatile unsigned int*)(0x42309010UL)))
#define bM4_TMR62_HCPAR_HCPA5                     (*((volatile unsigned int*)(0x42309014UL)))
#define bM4_TMR62_HCPAR_HCPA6                     (*((volatile unsigned int*)(0x42309018UL)))
#define bM4_TMR62_HCPAR_HCPA7                     (*((volatile unsigned int*)(0x4230901CUL)))
#define bM4_TMR62_HCPAR_HCPA8                     (*((volatile unsigned int*)(0x42309020UL)))
#define bM4_TMR62_HCPAR_HCPA9                     (*((volatile unsigned int*)(0x42309024UL)))
#define bM4_TMR62_HCPAR_HCPA10                    (*((volatile unsigned int*)(0x42309028UL)))
#define bM4_TMR62_HCPAR_HCPA11                    (*((volatile unsigned int*)(0x4230902CUL)))
#define bM4_TMR62_HCPBR_HCPB0                     (*((volatile unsigned int*)(0x42309080UL)))
#define bM4_TMR62_HCPBR_HCPB1                     (*((volatile unsigned int*)(0x42309084UL)))
#define bM4_TMR62_HCPBR_HCPB4                     (*((volatile unsigned int*)(0x42309090UL)))
#define bM4_TMR62_HCPBR_HCPB5                     (*((volatile unsigned int*)(0x42309094UL)))
#define bM4_TMR62_HCPBR_HCPB6                     (*((volatile unsigned int*)(0x42309098UL)))
#define bM4_TMR62_HCPBR_HCPB7                     (*((volatile unsigned int*)(0x4230909CUL)))
#define bM4_TMR62_HCPBR_HCPB8                     (*((volatile unsigned int*)(0x423090A0UL)))
#define bM4_TMR62_HCPBR_HCPB9                     (*((volatile unsigned int*)(0x423090A4UL)))
#define bM4_TMR62_HCPBR_HCPB10                    (*((volatile unsigned int*)(0x423090A8UL)))
#define bM4_TMR62_HCPBR_HCPB11                    (*((volatile unsigned int*)(0x423090ACUL)))
#define bM4_TMR62_HCUPR_HCUP0                     (*((volatile unsigned int*)(0x42309100UL)))
#define bM4_TMR62_HCUPR_HCUP1                     (*((volatile unsigned int*)(0x42309104UL)))
#define bM4_TMR62_HCUPR_HCUP2                     (*((volatile unsigned int*)(0x42309108UL)))
#define bM4_TMR62_HCUPR_HCUP3                     (*((volatile unsigned int*)(0x4230910CUL)))
#define bM4_TMR62_HCUPR_HCUP4                     (*((volatile unsigned int*)(0x42309110UL)))
#define bM4_TMR62_HCUPR_HCUP5                     (*((volatile unsigned int*)(0x42309114UL)))
#define bM4_TMR62_HCUPR_HCUP6                     (*((volatile unsigned int*)(0x42309118UL)))
#define bM4_TMR62_HCUPR_HCUP7                     (*((volatile unsigned int*)(0x4230911CUL)))
#define bM4_TMR62_HCUPR_HCUP8                     (*((volatile unsigned int*)(0x42309120UL)))
#define bM4_TMR62_HCUPR_HCUP9                     (*((volatile unsigned int*)(0x42309124UL)))
#define bM4_TMR62_HCUPR_HCUP10                    (*((volatile unsigned int*)(0x42309128UL)))
#define bM4_TMR62_HCUPR_HCUP11                    (*((volatile unsigned int*)(0x4230912CUL)))
#define bM4_TMR62_HCUPR_HCUP16                    (*((volatile unsigned int*)(0x42309140UL)))
#define bM4_TMR62_HCUPR_HCUP17                    (*((volatile unsigned int*)(0x42309144UL)))
#define bM4_TMR62_HCDOR_HCDO0                     (*((volatile unsigned int*)(0x42309180UL)))
#define bM4_TMR62_HCDOR_HCDO1                     (*((volatile unsigned int*)(0x42309184UL)))
#define bM4_TMR62_HCDOR_HCDO2                     (*((volatile unsigned int*)(0x42309188UL)))
#define bM4_TMR62_HCDOR_HCDO3                     (*((volatile unsigned int*)(0x4230918CUL)))
#define bM4_TMR62_HCDOR_HCDO4                     (*((volatile unsigned int*)(0x42309190UL)))
#define bM4_TMR62_HCDOR_HCDO5                     (*((volatile unsigned int*)(0x42309194UL)))
#define bM4_TMR62_HCDOR_HCDO6                     (*((volatile unsigned int*)(0x42309198UL)))
#define bM4_TMR62_HCDOR_HCDO7                     (*((volatile unsigned int*)(0x4230919CUL)))
#define bM4_TMR62_HCDOR_HCDO8                     (*((volatile unsigned int*)(0x423091A0UL)))
#define bM4_TMR62_HCDOR_HCDO9                     (*((volatile unsigned int*)(0x423091A4UL)))
#define bM4_TMR62_HCDOR_HCDO10                    (*((volatile unsigned int*)(0x423091A8UL)))
#define bM4_TMR62_HCDOR_HCDO11                    (*((volatile unsigned int*)(0x423091ACUL)))
#define bM4_TMR62_HCDOR_HCDO16                    (*((volatile unsigned int*)(0x423091C0UL)))
#define bM4_TMR62_HCDOR_HCDO17                    (*((volatile unsigned int*)(0x423091C4UL)))
#define bM4_TMR63_CNTER_CNT0                      (*((volatile unsigned int*)(0x42310000UL)))
#define bM4_TMR63_CNTER_CNT1                      (*((volatile unsigned int*)(0x42310004UL)))
#define bM4_TMR63_CNTER_CNT2                      (*((volatile unsigned int*)(0x42310008UL)))
#define bM4_TMR63_CNTER_CNT3                      (*((volatile unsigned int*)(0x4231000CUL)))
#define bM4_TMR63_CNTER_CNT4                      (*((volatile unsigned int*)(0x42310010UL)))
#define bM4_TMR63_CNTER_CNT5                      (*((volatile unsigned int*)(0x42310014UL)))
#define bM4_TMR63_CNTER_CNT6                      (*((volatile unsigned int*)(0x42310018UL)))
#define bM4_TMR63_CNTER_CNT7                      (*((volatile unsigned int*)(0x4231001CUL)))
#define bM4_TMR63_CNTER_CNT8                      (*((volatile unsigned int*)(0x42310020UL)))
#define bM4_TMR63_CNTER_CNT9                      (*((volatile unsigned int*)(0x42310024UL)))
#define bM4_TMR63_CNTER_CNT10                     (*((volatile unsigned int*)(0x42310028UL)))
#define bM4_TMR63_CNTER_CNT11                     (*((volatile unsigned int*)(0x4231002CUL)))
#define bM4_TMR63_CNTER_CNT12                     (*((volatile unsigned int*)(0x42310030UL)))
#define bM4_TMR63_CNTER_CNT13                     (*((volatile unsigned int*)(0x42310034UL)))
#define bM4_TMR63_CNTER_CNT14                     (*((volatile unsigned int*)(0x42310038UL)))
#define bM4_TMR63_CNTER_CNT15                     (*((volatile unsigned int*)(0x4231003CUL)))
#define bM4_TMR63_PERAR_PERA0                     (*((volatile unsigned int*)(0x42310080UL)))
#define bM4_TMR63_PERAR_PERA1                     (*((volatile unsigned int*)(0x42310084UL)))
#define bM4_TMR63_PERAR_PERA2                     (*((volatile unsigned int*)(0x42310088UL)))
#define bM4_TMR63_PERAR_PERA3                     (*((volatile unsigned int*)(0x4231008CUL)))
#define bM4_TMR63_PERAR_PERA4                     (*((volatile unsigned int*)(0x42310090UL)))
#define bM4_TMR63_PERAR_PERA5                     (*((volatile unsigned int*)(0x42310094UL)))
#define bM4_TMR63_PERAR_PERA6                     (*((volatile unsigned int*)(0x42310098UL)))
#define bM4_TMR63_PERAR_PERA7                     (*((volatile unsigned int*)(0x4231009CUL)))
#define bM4_TMR63_PERAR_PERA8                     (*((volatile unsigned int*)(0x423100A0UL)))
#define bM4_TMR63_PERAR_PERA9                     (*((volatile unsigned int*)(0x423100A4UL)))
#define bM4_TMR63_PERAR_PERA10                    (*((volatile unsigned int*)(0x423100A8UL)))
#define bM4_TMR63_PERAR_PERA11                    (*((volatile unsigned int*)(0x423100ACUL)))
#define bM4_TMR63_PERAR_PERA12                    (*((volatile unsigned int*)(0x423100B0UL)))
#define bM4_TMR63_PERAR_PERA13                    (*((volatile unsigned int*)(0x423100B4UL)))
#define bM4_TMR63_PERAR_PERA14                    (*((volatile unsigned int*)(0x423100B8UL)))
#define bM4_TMR63_PERAR_PERA15                    (*((volatile unsigned int*)(0x423100BCUL)))
#define bM4_TMR63_PERBR_PERB0                     (*((volatile unsigned int*)(0x42310100UL)))
#define bM4_TMR63_PERBR_PERB1                     (*((volatile unsigned int*)(0x42310104UL)))
#define bM4_TMR63_PERBR_PERB2                     (*((volatile unsigned int*)(0x42310108UL)))
#define bM4_TMR63_PERBR_PERB3                     (*((volatile unsigned int*)(0x4231010CUL)))
#define bM4_TMR63_PERBR_PERB4                     (*((volatile unsigned int*)(0x42310110UL)))
#define bM4_TMR63_PERBR_PERB5                     (*((volatile unsigned int*)(0x42310114UL)))
#define bM4_TMR63_PERBR_PERB6                     (*((volatile unsigned int*)(0x42310118UL)))
#define bM4_TMR63_PERBR_PERB7                     (*((volatile unsigned int*)(0x4231011CUL)))
#define bM4_TMR63_PERBR_PERB8                     (*((volatile unsigned int*)(0x42310120UL)))
#define bM4_TMR63_PERBR_PERB9                     (*((volatile unsigned int*)(0x42310124UL)))
#define bM4_TMR63_PERBR_PERB10                    (*((volatile unsigned int*)(0x42310128UL)))
#define bM4_TMR63_PERBR_PERB11                    (*((volatile unsigned int*)(0x4231012CUL)))
#define bM4_TMR63_PERBR_PERB12                    (*((volatile unsigned int*)(0x42310130UL)))
#define bM4_TMR63_PERBR_PERB13                    (*((volatile unsigned int*)(0x42310134UL)))
#define bM4_TMR63_PERBR_PERB14                    (*((volatile unsigned int*)(0x42310138UL)))
#define bM4_TMR63_PERBR_PERB15                    (*((volatile unsigned int*)(0x4231013CUL)))
#define bM4_TMR63_PERCR_PERC0                     (*((volatile unsigned int*)(0x42310180UL)))
#define bM4_TMR63_PERCR_PERC1                     (*((volatile unsigned int*)(0x42310184UL)))
#define bM4_TMR63_PERCR_PERC2                     (*((volatile unsigned int*)(0x42310188UL)))
#define bM4_TMR63_PERCR_PERC3                     (*((volatile unsigned int*)(0x4231018CUL)))
#define bM4_TMR63_PERCR_PERC4                     (*((volatile unsigned int*)(0x42310190UL)))
#define bM4_TMR63_PERCR_PERC5                     (*((volatile unsigned int*)(0x42310194UL)))
#define bM4_TMR63_PERCR_PERC6                     (*((volatile unsigned int*)(0x42310198UL)))
#define bM4_TMR63_PERCR_PERC7                     (*((volatile unsigned int*)(0x4231019CUL)))
#define bM4_TMR63_PERCR_PERC8                     (*((volatile unsigned int*)(0x423101A0UL)))
#define bM4_TMR63_PERCR_PERC9                     (*((volatile unsigned int*)(0x423101A4UL)))
#define bM4_TMR63_PERCR_PERC10                    (*((volatile unsigned int*)(0x423101A8UL)))
#define bM4_TMR63_PERCR_PERC11                    (*((volatile unsigned int*)(0x423101ACUL)))
#define bM4_TMR63_PERCR_PERC12                    (*((volatile unsigned int*)(0x423101B0UL)))
#define bM4_TMR63_PERCR_PERC13                    (*((volatile unsigned int*)(0x423101B4UL)))
#define bM4_TMR63_PERCR_PERC14                    (*((volatile unsigned int*)(0x423101B8UL)))
#define bM4_TMR63_PERCR_PERC15                    (*((volatile unsigned int*)(0x423101BCUL)))
#define bM4_TMR63_GCMAR_GCMA0                     (*((volatile unsigned int*)(0x42310200UL)))
#define bM4_TMR63_GCMAR_GCMA1                     (*((volatile unsigned int*)(0x42310204UL)))
#define bM4_TMR63_GCMAR_GCMA2                     (*((volatile unsigned int*)(0x42310208UL)))
#define bM4_TMR63_GCMAR_GCMA3                     (*((volatile unsigned int*)(0x4231020CUL)))
#define bM4_TMR63_GCMAR_GCMA4                     (*((volatile unsigned int*)(0x42310210UL)))
#define bM4_TMR63_GCMAR_GCMA5                     (*((volatile unsigned int*)(0x42310214UL)))
#define bM4_TMR63_GCMAR_GCMA6                     (*((volatile unsigned int*)(0x42310218UL)))
#define bM4_TMR63_GCMAR_GCMA7                     (*((volatile unsigned int*)(0x4231021CUL)))
#define bM4_TMR63_GCMAR_GCMA8                     (*((volatile unsigned int*)(0x42310220UL)))
#define bM4_TMR63_GCMAR_GCMA9                     (*((volatile unsigned int*)(0x42310224UL)))
#define bM4_TMR63_GCMAR_GCMA10                    (*((volatile unsigned int*)(0x42310228UL)))
#define bM4_TMR63_GCMAR_GCMA11                    (*((volatile unsigned int*)(0x4231022CUL)))
#define bM4_TMR63_GCMAR_GCMA12                    (*((volatile unsigned int*)(0x42310230UL)))
#define bM4_TMR63_GCMAR_GCMA13                    (*((volatile unsigned int*)(0x42310234UL)))
#define bM4_TMR63_GCMAR_GCMA14                    (*((volatile unsigned int*)(0x42310238UL)))
#define bM4_TMR63_GCMAR_GCMA15                    (*((volatile unsigned int*)(0x4231023CUL)))
#define bM4_TMR63_GCMBR_GCMB0                     (*((volatile unsigned int*)(0x42310280UL)))
#define bM4_TMR63_GCMBR_GCMB1                     (*((volatile unsigned int*)(0x42310284UL)))
#define bM4_TMR63_GCMBR_GCMB2                     (*((volatile unsigned int*)(0x42310288UL)))
#define bM4_TMR63_GCMBR_GCMB3                     (*((volatile unsigned int*)(0x4231028CUL)))
#define bM4_TMR63_GCMBR_GCMB4                     (*((volatile unsigned int*)(0x42310290UL)))
#define bM4_TMR63_GCMBR_GCMB5                     (*((volatile unsigned int*)(0x42310294UL)))
#define bM4_TMR63_GCMBR_GCMB6                     (*((volatile unsigned int*)(0x42310298UL)))
#define bM4_TMR63_GCMBR_GCMB7                     (*((volatile unsigned int*)(0x4231029CUL)))
#define bM4_TMR63_GCMBR_GCMB8                     (*((volatile unsigned int*)(0x423102A0UL)))
#define bM4_TMR63_GCMBR_GCMB9                     (*((volatile unsigned int*)(0x423102A4UL)))
#define bM4_TMR63_GCMBR_GCMB10                    (*((volatile unsigned int*)(0x423102A8UL)))
#define bM4_TMR63_GCMBR_GCMB11                    (*((volatile unsigned int*)(0x423102ACUL)))
#define bM4_TMR63_GCMBR_GCMB12                    (*((volatile unsigned int*)(0x423102B0UL)))
#define bM4_TMR63_GCMBR_GCMB13                    (*((volatile unsigned int*)(0x423102B4UL)))
#define bM4_TMR63_GCMBR_GCMB14                    (*((volatile unsigned int*)(0x423102B8UL)))
#define bM4_TMR63_GCMBR_GCMB15                    (*((volatile unsigned int*)(0x423102BCUL)))
#define bM4_TMR63_GCMCR_GCMC0                     (*((volatile unsigned int*)(0x42310300UL)))
#define bM4_TMR63_GCMCR_GCMC1                     (*((volatile unsigned int*)(0x42310304UL)))
#define bM4_TMR63_GCMCR_GCMC2                     (*((volatile unsigned int*)(0x42310308UL)))
#define bM4_TMR63_GCMCR_GCMC3                     (*((volatile unsigned int*)(0x4231030CUL)))
#define bM4_TMR63_GCMCR_GCMC4                     (*((volatile unsigned int*)(0x42310310UL)))
#define bM4_TMR63_GCMCR_GCMC5                     (*((volatile unsigned int*)(0x42310314UL)))
#define bM4_TMR63_GCMCR_GCMC6                     (*((volatile unsigned int*)(0x42310318UL)))
#define bM4_TMR63_GCMCR_GCMC7                     (*((volatile unsigned int*)(0x4231031CUL)))
#define bM4_TMR63_GCMCR_GCMC8                     (*((volatile unsigned int*)(0x42310320UL)))
#define bM4_TMR63_GCMCR_GCMC9                     (*((volatile unsigned int*)(0x42310324UL)))
#define bM4_TMR63_GCMCR_GCMC10                    (*((volatile unsigned int*)(0x42310328UL)))
#define bM4_TMR63_GCMCR_GCMC11                    (*((volatile unsigned int*)(0x4231032CUL)))
#define bM4_TMR63_GCMCR_GCMC12                    (*((volatile unsigned int*)(0x42310330UL)))
#define bM4_TMR63_GCMCR_GCMC13                    (*((volatile unsigned int*)(0x42310334UL)))
#define bM4_TMR63_GCMCR_GCMC14                    (*((volatile unsigned int*)(0x42310338UL)))
#define bM4_TMR63_GCMCR_GCMC15                    (*((volatile unsigned int*)(0x4231033CUL)))
#define bM4_TMR63_GCMDR_GCMD0                     (*((volatile unsigned int*)(0x42310380UL)))
#define bM4_TMR63_GCMDR_GCMD1                     (*((volatile unsigned int*)(0x42310384UL)))
#define bM4_TMR63_GCMDR_GCMD2                     (*((volatile unsigned int*)(0x42310388UL)))
#define bM4_TMR63_GCMDR_GCMD3                     (*((volatile unsigned int*)(0x4231038CUL)))
#define bM4_TMR63_GCMDR_GCMD4                     (*((volatile unsigned int*)(0x42310390UL)))
#define bM4_TMR63_GCMDR_GCMD5                     (*((volatile unsigned int*)(0x42310394UL)))
#define bM4_TMR63_GCMDR_GCMD6                     (*((volatile unsigned int*)(0x42310398UL)))
#define bM4_TMR63_GCMDR_GCMD7                     (*((volatile unsigned int*)(0x4231039CUL)))
#define bM4_TMR63_GCMDR_GCMD8                     (*((volatile unsigned int*)(0x423103A0UL)))
#define bM4_TMR63_GCMDR_GCMD9                     (*((volatile unsigned int*)(0x423103A4UL)))
#define bM4_TMR63_GCMDR_GCMD10                    (*((volatile unsigned int*)(0x423103A8UL)))
#define bM4_TMR63_GCMDR_GCMD11                    (*((volatile unsigned int*)(0x423103ACUL)))
#define bM4_TMR63_GCMDR_GCMD12                    (*((volatile unsigned int*)(0x423103B0UL)))
#define bM4_TMR63_GCMDR_GCMD13                    (*((volatile unsigned int*)(0x423103B4UL)))
#define bM4_TMR63_GCMDR_GCMD14                    (*((volatile unsigned int*)(0x423103B8UL)))
#define bM4_TMR63_GCMDR_GCMD15                    (*((volatile unsigned int*)(0x423103BCUL)))
#define bM4_TMR63_GCMER_GCME0                     (*((volatile unsigned int*)(0x42310400UL)))
#define bM4_TMR63_GCMER_GCME1                     (*((volatile unsigned int*)(0x42310404UL)))
#define bM4_TMR63_GCMER_GCME2                     (*((volatile unsigned int*)(0x42310408UL)))
#define bM4_TMR63_GCMER_GCME3                     (*((volatile unsigned int*)(0x4231040CUL)))
#define bM4_TMR63_GCMER_GCME4                     (*((volatile unsigned int*)(0x42310410UL)))
#define bM4_TMR63_GCMER_GCME5                     (*((volatile unsigned int*)(0x42310414UL)))
#define bM4_TMR63_GCMER_GCME6                     (*((volatile unsigned int*)(0x42310418UL)))
#define bM4_TMR63_GCMER_GCME7                     (*((volatile unsigned int*)(0x4231041CUL)))
#define bM4_TMR63_GCMER_GCME8                     (*((volatile unsigned int*)(0x42310420UL)))
#define bM4_TMR63_GCMER_GCME9                     (*((volatile unsigned int*)(0x42310424UL)))
#define bM4_TMR63_GCMER_GCME10                    (*((volatile unsigned int*)(0x42310428UL)))
#define bM4_TMR63_GCMER_GCME11                    (*((volatile unsigned int*)(0x4231042CUL)))
#define bM4_TMR63_GCMER_GCME12                    (*((volatile unsigned int*)(0x42310430UL)))
#define bM4_TMR63_GCMER_GCME13                    (*((volatile unsigned int*)(0x42310434UL)))
#define bM4_TMR63_GCMER_GCME14                    (*((volatile unsigned int*)(0x42310438UL)))
#define bM4_TMR63_GCMER_GCME15                    (*((volatile unsigned int*)(0x4231043CUL)))
#define bM4_TMR63_GCMFR_GCMF0                     (*((volatile unsigned int*)(0x42310480UL)))
#define bM4_TMR63_GCMFR_GCMF1                     (*((volatile unsigned int*)(0x42310484UL)))
#define bM4_TMR63_GCMFR_GCMF2                     (*((volatile unsigned int*)(0x42310488UL)))
#define bM4_TMR63_GCMFR_GCMF3                     (*((volatile unsigned int*)(0x4231048CUL)))
#define bM4_TMR63_GCMFR_GCMF4                     (*((volatile unsigned int*)(0x42310490UL)))
#define bM4_TMR63_GCMFR_GCMF5                     (*((volatile unsigned int*)(0x42310494UL)))
#define bM4_TMR63_GCMFR_GCMF6                     (*((volatile unsigned int*)(0x42310498UL)))
#define bM4_TMR63_GCMFR_GCMF7                     (*((volatile unsigned int*)(0x4231049CUL)))
#define bM4_TMR63_GCMFR_GCMF8                     (*((volatile unsigned int*)(0x423104A0UL)))
#define bM4_TMR63_GCMFR_GCMF9                     (*((volatile unsigned int*)(0x423104A4UL)))
#define bM4_TMR63_GCMFR_GCMF10                    (*((volatile unsigned int*)(0x423104A8UL)))
#define bM4_TMR63_GCMFR_GCMF11                    (*((volatile unsigned int*)(0x423104ACUL)))
#define bM4_TMR63_GCMFR_GCMF12                    (*((volatile unsigned int*)(0x423104B0UL)))
#define bM4_TMR63_GCMFR_GCMF13                    (*((volatile unsigned int*)(0x423104B4UL)))
#define bM4_TMR63_GCMFR_GCMF14                    (*((volatile unsigned int*)(0x423104B8UL)))
#define bM4_TMR63_GCMFR_GCMF15                    (*((volatile unsigned int*)(0x423104BCUL)))
#define bM4_TMR63_SCMAR_SCMA0                     (*((volatile unsigned int*)(0x42310500UL)))
#define bM4_TMR63_SCMAR_SCMA1                     (*((volatile unsigned int*)(0x42310504UL)))
#define bM4_TMR63_SCMAR_SCMA2                     (*((volatile unsigned int*)(0x42310508UL)))
#define bM4_TMR63_SCMAR_SCMA3                     (*((volatile unsigned int*)(0x4231050CUL)))
#define bM4_TMR63_SCMAR_SCMA4                     (*((volatile unsigned int*)(0x42310510UL)))
#define bM4_TMR63_SCMAR_SCMA5                     (*((volatile unsigned int*)(0x42310514UL)))
#define bM4_TMR63_SCMAR_SCMA6                     (*((volatile unsigned int*)(0x42310518UL)))
#define bM4_TMR63_SCMAR_SCMA7                     (*((volatile unsigned int*)(0x4231051CUL)))
#define bM4_TMR63_SCMAR_SCMA8                     (*((volatile unsigned int*)(0x42310520UL)))
#define bM4_TMR63_SCMAR_SCMA9                     (*((volatile unsigned int*)(0x42310524UL)))
#define bM4_TMR63_SCMAR_SCMA10                    (*((volatile unsigned int*)(0x42310528UL)))
#define bM4_TMR63_SCMAR_SCMA11                    (*((volatile unsigned int*)(0x4231052CUL)))
#define bM4_TMR63_SCMAR_SCMA12                    (*((volatile unsigned int*)(0x42310530UL)))
#define bM4_TMR63_SCMAR_SCMA13                    (*((volatile unsigned int*)(0x42310534UL)))
#define bM4_TMR63_SCMAR_SCMA14                    (*((volatile unsigned int*)(0x42310538UL)))
#define bM4_TMR63_SCMAR_SCMA15                    (*((volatile unsigned int*)(0x4231053CUL)))
#define bM4_TMR63_SCMBR_SCMB0                     (*((volatile unsigned int*)(0x42310580UL)))
#define bM4_TMR63_SCMBR_SCMB1                     (*((volatile unsigned int*)(0x42310584UL)))
#define bM4_TMR63_SCMBR_SCMB2                     (*((volatile unsigned int*)(0x42310588UL)))
#define bM4_TMR63_SCMBR_SCMB3                     (*((volatile unsigned int*)(0x4231058CUL)))
#define bM4_TMR63_SCMBR_SCMB4                     (*((volatile unsigned int*)(0x42310590UL)))
#define bM4_TMR63_SCMBR_SCMB5                     (*((volatile unsigned int*)(0x42310594UL)))
#define bM4_TMR63_SCMBR_SCMB6                     (*((volatile unsigned int*)(0x42310598UL)))
#define bM4_TMR63_SCMBR_SCMB7                     (*((volatile unsigned int*)(0x4231059CUL)))
#define bM4_TMR63_SCMBR_SCMB8                     (*((volatile unsigned int*)(0x423105A0UL)))
#define bM4_TMR63_SCMBR_SCMB9                     (*((volatile unsigned int*)(0x423105A4UL)))
#define bM4_TMR63_SCMBR_SCMB10                    (*((volatile unsigned int*)(0x423105A8UL)))
#define bM4_TMR63_SCMBR_SCMB11                    (*((volatile unsigned int*)(0x423105ACUL)))
#define bM4_TMR63_SCMBR_SCMB12                    (*((volatile unsigned int*)(0x423105B0UL)))
#define bM4_TMR63_SCMBR_SCMB13                    (*((volatile unsigned int*)(0x423105B4UL)))
#define bM4_TMR63_SCMBR_SCMB14                    (*((volatile unsigned int*)(0x423105B8UL)))
#define bM4_TMR63_SCMBR_SCMB15                    (*((volatile unsigned int*)(0x423105BCUL)))
#define bM4_TMR63_SCMCR_SCMC0                     (*((volatile unsigned int*)(0x42310600UL)))
#define bM4_TMR63_SCMCR_SCMC1                     (*((volatile unsigned int*)(0x42310604UL)))
#define bM4_TMR63_SCMCR_SCMC2                     (*((volatile unsigned int*)(0x42310608UL)))
#define bM4_TMR63_SCMCR_SCMC3                     (*((volatile unsigned int*)(0x4231060CUL)))
#define bM4_TMR63_SCMCR_SCMC4                     (*((volatile unsigned int*)(0x42310610UL)))
#define bM4_TMR63_SCMCR_SCMC5                     (*((volatile unsigned int*)(0x42310614UL)))
#define bM4_TMR63_SCMCR_SCMC6                     (*((volatile unsigned int*)(0x42310618UL)))
#define bM4_TMR63_SCMCR_SCMC7                     (*((volatile unsigned int*)(0x4231061CUL)))
#define bM4_TMR63_SCMCR_SCMC8                     (*((volatile unsigned int*)(0x42310620UL)))
#define bM4_TMR63_SCMCR_SCMC9                     (*((volatile unsigned int*)(0x42310624UL)))
#define bM4_TMR63_SCMCR_SCMC10                    (*((volatile unsigned int*)(0x42310628UL)))
#define bM4_TMR63_SCMCR_SCMC11                    (*((volatile unsigned int*)(0x4231062CUL)))
#define bM4_TMR63_SCMCR_SCMC12                    (*((volatile unsigned int*)(0x42310630UL)))
#define bM4_TMR63_SCMCR_SCMC13                    (*((volatile unsigned int*)(0x42310634UL)))
#define bM4_TMR63_SCMCR_SCMC14                    (*((volatile unsigned int*)(0x42310638UL)))
#define bM4_TMR63_SCMCR_SCMC15                    (*((volatile unsigned int*)(0x4231063CUL)))
#define bM4_TMR63_SCMDR_SCMD0                     (*((volatile unsigned int*)(0x42310680UL)))
#define bM4_TMR63_SCMDR_SCMD1                     (*((volatile unsigned int*)(0x42310684UL)))
#define bM4_TMR63_SCMDR_SCMD2                     (*((volatile unsigned int*)(0x42310688UL)))
#define bM4_TMR63_SCMDR_SCMD3                     (*((volatile unsigned int*)(0x4231068CUL)))
#define bM4_TMR63_SCMDR_SCMD4                     (*((volatile unsigned int*)(0x42310690UL)))
#define bM4_TMR63_SCMDR_SCMD5                     (*((volatile unsigned int*)(0x42310694UL)))
#define bM4_TMR63_SCMDR_SCMD6                     (*((volatile unsigned int*)(0x42310698UL)))
#define bM4_TMR63_SCMDR_SCMD7                     (*((volatile unsigned int*)(0x4231069CUL)))
#define bM4_TMR63_SCMDR_SCMD8                     (*((volatile unsigned int*)(0x423106A0UL)))
#define bM4_TMR63_SCMDR_SCMD9                     (*((volatile unsigned int*)(0x423106A4UL)))
#define bM4_TMR63_SCMDR_SCMD10                    (*((volatile unsigned int*)(0x423106A8UL)))
#define bM4_TMR63_SCMDR_SCMD11                    (*((volatile unsigned int*)(0x423106ACUL)))
#define bM4_TMR63_SCMDR_SCMD12                    (*((volatile unsigned int*)(0x423106B0UL)))
#define bM4_TMR63_SCMDR_SCMD13                    (*((volatile unsigned int*)(0x423106B4UL)))
#define bM4_TMR63_SCMDR_SCMD14                    (*((volatile unsigned int*)(0x423106B8UL)))
#define bM4_TMR63_SCMDR_SCMD15                    (*((volatile unsigned int*)(0x423106BCUL)))
#define bM4_TMR63_SCMER_SCME0                     (*((volatile unsigned int*)(0x42310700UL)))
#define bM4_TMR63_SCMER_SCME1                     (*((volatile unsigned int*)(0x42310704UL)))
#define bM4_TMR63_SCMER_SCME2                     (*((volatile unsigned int*)(0x42310708UL)))
#define bM4_TMR63_SCMER_SCME3                     (*((volatile unsigned int*)(0x4231070CUL)))
#define bM4_TMR63_SCMER_SCME4                     (*((volatile unsigned int*)(0x42310710UL)))
#define bM4_TMR63_SCMER_SCME5                     (*((volatile unsigned int*)(0x42310714UL)))
#define bM4_TMR63_SCMER_SCME6                     (*((volatile unsigned int*)(0x42310718UL)))
#define bM4_TMR63_SCMER_SCME7                     (*((volatile unsigned int*)(0x4231071CUL)))
#define bM4_TMR63_SCMER_SCME8                     (*((volatile unsigned int*)(0x42310720UL)))
#define bM4_TMR63_SCMER_SCME9                     (*((volatile unsigned int*)(0x42310724UL)))
#define bM4_TMR63_SCMER_SCME10                    (*((volatile unsigned int*)(0x42310728UL)))
#define bM4_TMR63_SCMER_SCME11                    (*((volatile unsigned int*)(0x4231072CUL)))
#define bM4_TMR63_SCMER_SCME12                    (*((volatile unsigned int*)(0x42310730UL)))
#define bM4_TMR63_SCMER_SCME13                    (*((volatile unsigned int*)(0x42310734UL)))
#define bM4_TMR63_SCMER_SCME14                    (*((volatile unsigned int*)(0x42310738UL)))
#define bM4_TMR63_SCMER_SCME15                    (*((volatile unsigned int*)(0x4231073CUL)))
#define bM4_TMR63_SCMFR_SCMF0                     (*((volatile unsigned int*)(0x42310780UL)))
#define bM4_TMR63_SCMFR_SCMF1                     (*((volatile unsigned int*)(0x42310784UL)))
#define bM4_TMR63_SCMFR_SCMF2                     (*((volatile unsigned int*)(0x42310788UL)))
#define bM4_TMR63_SCMFR_SCMF3                     (*((volatile unsigned int*)(0x4231078CUL)))
#define bM4_TMR63_SCMFR_SCMF4                     (*((volatile unsigned int*)(0x42310790UL)))
#define bM4_TMR63_SCMFR_SCMF5                     (*((volatile unsigned int*)(0x42310794UL)))
#define bM4_TMR63_SCMFR_SCMF6                     (*((volatile unsigned int*)(0x42310798UL)))
#define bM4_TMR63_SCMFR_SCMF7                     (*((volatile unsigned int*)(0x4231079CUL)))
#define bM4_TMR63_SCMFR_SCMF8                     (*((volatile unsigned int*)(0x423107A0UL)))
#define bM4_TMR63_SCMFR_SCMF9                     (*((volatile unsigned int*)(0x423107A4UL)))
#define bM4_TMR63_SCMFR_SCMF10                    (*((volatile unsigned int*)(0x423107A8UL)))
#define bM4_TMR63_SCMFR_SCMF11                    (*((volatile unsigned int*)(0x423107ACUL)))
#define bM4_TMR63_SCMFR_SCMF12                    (*((volatile unsigned int*)(0x423107B0UL)))
#define bM4_TMR63_SCMFR_SCMF13                    (*((volatile unsigned int*)(0x423107B4UL)))
#define bM4_TMR63_SCMFR_SCMF14                    (*((volatile unsigned int*)(0x423107B8UL)))
#define bM4_TMR63_SCMFR_SCMF15                    (*((volatile unsigned int*)(0x423107BCUL)))
#define bM4_TMR63_DTUAR_DTUA0                     (*((volatile unsigned int*)(0x42310800UL)))
#define bM4_TMR63_DTUAR_DTUA1                     (*((volatile unsigned int*)(0x42310804UL)))
#define bM4_TMR63_DTUAR_DTUA2                     (*((volatile unsigned int*)(0x42310808UL)))
#define bM4_TMR63_DTUAR_DTUA3                     (*((volatile unsigned int*)(0x4231080CUL)))
#define bM4_TMR63_DTUAR_DTUA4                     (*((volatile unsigned int*)(0x42310810UL)))
#define bM4_TMR63_DTUAR_DTUA5                     (*((volatile unsigned int*)(0x42310814UL)))
#define bM4_TMR63_DTUAR_DTUA6                     (*((volatile unsigned int*)(0x42310818UL)))
#define bM4_TMR63_DTUAR_DTUA7                     (*((volatile unsigned int*)(0x4231081CUL)))
#define bM4_TMR63_DTUAR_DTUA8                     (*((volatile unsigned int*)(0x42310820UL)))
#define bM4_TMR63_DTUAR_DTUA9                     (*((volatile unsigned int*)(0x42310824UL)))
#define bM4_TMR63_DTUAR_DTUA10                    (*((volatile unsigned int*)(0x42310828UL)))
#define bM4_TMR63_DTUAR_DTUA11                    (*((volatile unsigned int*)(0x4231082CUL)))
#define bM4_TMR63_DTUAR_DTUA12                    (*((volatile unsigned int*)(0x42310830UL)))
#define bM4_TMR63_DTUAR_DTUA13                    (*((volatile unsigned int*)(0x42310834UL)))
#define bM4_TMR63_DTUAR_DTUA14                    (*((volatile unsigned int*)(0x42310838UL)))
#define bM4_TMR63_DTUAR_DTUA15                    (*((volatile unsigned int*)(0x4231083CUL)))
#define bM4_TMR63_DTDAR_DTDA0                     (*((volatile unsigned int*)(0x42310880UL)))
#define bM4_TMR63_DTDAR_DTDA1                     (*((volatile unsigned int*)(0x42310884UL)))
#define bM4_TMR63_DTDAR_DTDA2                     (*((volatile unsigned int*)(0x42310888UL)))
#define bM4_TMR63_DTDAR_DTDA3                     (*((volatile unsigned int*)(0x4231088CUL)))
#define bM4_TMR63_DTDAR_DTDA4                     (*((volatile unsigned int*)(0x42310890UL)))
#define bM4_TMR63_DTDAR_DTDA5                     (*((volatile unsigned int*)(0x42310894UL)))
#define bM4_TMR63_DTDAR_DTDA6                     (*((volatile unsigned int*)(0x42310898UL)))
#define bM4_TMR63_DTDAR_DTDA7                     (*((volatile unsigned int*)(0x4231089CUL)))
#define bM4_TMR63_DTDAR_DTDA8                     (*((volatile unsigned int*)(0x423108A0UL)))
#define bM4_TMR63_DTDAR_DTDA9                     (*((volatile unsigned int*)(0x423108A4UL)))
#define bM4_TMR63_DTDAR_DTDA10                    (*((volatile unsigned int*)(0x423108A8UL)))
#define bM4_TMR63_DTDAR_DTDA11                    (*((volatile unsigned int*)(0x423108ACUL)))
#define bM4_TMR63_DTDAR_DTDA12                    (*((volatile unsigned int*)(0x423108B0UL)))
#define bM4_TMR63_DTDAR_DTDA13                    (*((volatile unsigned int*)(0x423108B4UL)))
#define bM4_TMR63_DTDAR_DTDA14                    (*((volatile unsigned int*)(0x423108B8UL)))
#define bM4_TMR63_DTDAR_DTDA15                    (*((volatile unsigned int*)(0x423108BCUL)))
#define bM4_TMR63_DTUBR_DTUB0                     (*((volatile unsigned int*)(0x42310900UL)))
#define bM4_TMR63_DTUBR_DTUB1                     (*((volatile unsigned int*)(0x42310904UL)))
#define bM4_TMR63_DTUBR_DTUB2                     (*((volatile unsigned int*)(0x42310908UL)))
#define bM4_TMR63_DTUBR_DTUB3                     (*((volatile unsigned int*)(0x4231090CUL)))
#define bM4_TMR63_DTUBR_DTUB4                     (*((volatile unsigned int*)(0x42310910UL)))
#define bM4_TMR63_DTUBR_DTUB5                     (*((volatile unsigned int*)(0x42310914UL)))
#define bM4_TMR63_DTUBR_DTUB6                     (*((volatile unsigned int*)(0x42310918UL)))
#define bM4_TMR63_DTUBR_DTUB7                     (*((volatile unsigned int*)(0x4231091CUL)))
#define bM4_TMR63_DTUBR_DTUB8                     (*((volatile unsigned int*)(0x42310920UL)))
#define bM4_TMR63_DTUBR_DTUB9                     (*((volatile unsigned int*)(0x42310924UL)))
#define bM4_TMR63_DTUBR_DTUB10                    (*((volatile unsigned int*)(0x42310928UL)))
#define bM4_TMR63_DTUBR_DTUB11                    (*((volatile unsigned int*)(0x4231092CUL)))
#define bM4_TMR63_DTUBR_DTUB12                    (*((volatile unsigned int*)(0x42310930UL)))
#define bM4_TMR63_DTUBR_DTUB13                    (*((volatile unsigned int*)(0x42310934UL)))
#define bM4_TMR63_DTUBR_DTUB14                    (*((volatile unsigned int*)(0x42310938UL)))
#define bM4_TMR63_DTUBR_DTUB15                    (*((volatile unsigned int*)(0x4231093CUL)))
#define bM4_TMR63_DTDBR_DTDB0                     (*((volatile unsigned int*)(0x42310980UL)))
#define bM4_TMR63_DTDBR_DTDB1                     (*((volatile unsigned int*)(0x42310984UL)))
#define bM4_TMR63_DTDBR_DTDB2                     (*((volatile unsigned int*)(0x42310988UL)))
#define bM4_TMR63_DTDBR_DTDB3                     (*((volatile unsigned int*)(0x4231098CUL)))
#define bM4_TMR63_DTDBR_DTDB4                     (*((volatile unsigned int*)(0x42310990UL)))
#define bM4_TMR63_DTDBR_DTDB5                     (*((volatile unsigned int*)(0x42310994UL)))
#define bM4_TMR63_DTDBR_DTDB6                     (*((volatile unsigned int*)(0x42310998UL)))
#define bM4_TMR63_DTDBR_DTDB7                     (*((volatile unsigned int*)(0x4231099CUL)))
#define bM4_TMR63_DTDBR_DTDB8                     (*((volatile unsigned int*)(0x423109A0UL)))
#define bM4_TMR63_DTDBR_DTDB9                     (*((volatile unsigned int*)(0x423109A4UL)))
#define bM4_TMR63_DTDBR_DTDB10                    (*((volatile unsigned int*)(0x423109A8UL)))
#define bM4_TMR63_DTDBR_DTDB11                    (*((volatile unsigned int*)(0x423109ACUL)))
#define bM4_TMR63_DTDBR_DTDB12                    (*((volatile unsigned int*)(0x423109B0UL)))
#define bM4_TMR63_DTDBR_DTDB13                    (*((volatile unsigned int*)(0x423109B4UL)))
#define bM4_TMR63_DTDBR_DTDB14                    (*((volatile unsigned int*)(0x423109B8UL)))
#define bM4_TMR63_DTDBR_DTDB15                    (*((volatile unsigned int*)(0x423109BCUL)))
#define bM4_TMR63_GCONR_START                     (*((volatile unsigned int*)(0x42310A00UL)))
#define bM4_TMR63_GCONR_MODE0                     (*((volatile unsigned int*)(0x42310A04UL)))
#define bM4_TMR63_GCONR_MODE1                     (*((volatile unsigned int*)(0x42310A08UL)))
#define bM4_TMR63_GCONR_MODE2                     (*((volatile unsigned int*)(0x42310A0CUL)))
#define bM4_TMR63_GCONR_CKDIV0                    (*((volatile unsigned int*)(0x42310A10UL)))
#define bM4_TMR63_GCONR_CKDIV1                    (*((volatile unsigned int*)(0x42310A14UL)))
#define bM4_TMR63_GCONR_CKDIV2                    (*((volatile unsigned int*)(0x42310A18UL)))
#define bM4_TMR63_GCONR_DIR                       (*((volatile unsigned int*)(0x42310A20UL)))
#define bM4_TMR63_GCONR_ZMSKREV                   (*((volatile unsigned int*)(0x42310A40UL)))
#define bM4_TMR63_GCONR_ZMSKPOS                   (*((volatile unsigned int*)(0x42310A44UL)))
#define bM4_TMR63_GCONR_ZMSKVAL0                  (*((volatile unsigned int*)(0x42310A48UL)))
#define bM4_TMR63_GCONR_ZMSKVAL1                  (*((volatile unsigned int*)(0x42310A4CUL)))
#define bM4_TMR63_ICONR_INTENA                    (*((volatile unsigned int*)(0x42310A80UL)))
#define bM4_TMR63_ICONR_INTENB                    (*((volatile unsigned int*)(0x42310A84UL)))
#define bM4_TMR63_ICONR_INTENC                    (*((volatile unsigned int*)(0x42310A88UL)))
#define bM4_TMR63_ICONR_INTEND                    (*((volatile unsigned int*)(0x42310A8CUL)))
#define bM4_TMR63_ICONR_INTENE                    (*((volatile unsigned int*)(0x42310A90UL)))
#define bM4_TMR63_ICONR_INTENF                    (*((volatile unsigned int*)(0x42310A94UL)))
#define bM4_TMR63_ICONR_INTENOVF                  (*((volatile unsigned int*)(0x42310A98UL)))
#define bM4_TMR63_ICONR_INTENUDF                  (*((volatile unsigned int*)(0x42310A9CUL)))
#define bM4_TMR63_ICONR_INTENDTE                  (*((volatile unsigned int*)(0x42310AA0UL)))
#define bM4_TMR63_ICONR_INTENSAU                  (*((volatile unsigned int*)(0x42310AC0UL)))
#define bM4_TMR63_ICONR_INTENSAD                  (*((volatile unsigned int*)(0x42310AC4UL)))
#define bM4_TMR63_ICONR_INTENSBU                  (*((volatile unsigned int*)(0x42310AC8UL)))
#define bM4_TMR63_ICONR_INTENSBD                  (*((volatile unsigned int*)(0x42310ACCUL)))
#define bM4_TMR63_PCONR_CAPMDA                    (*((volatile unsigned int*)(0x42310B00UL)))
#define bM4_TMR63_PCONR_STACA                     (*((volatile unsigned int*)(0x42310B04UL)))
#define bM4_TMR63_PCONR_STPCA                     (*((volatile unsigned int*)(0x42310B08UL)))
#define bM4_TMR63_PCONR_STASTPSA                  (*((volatile unsigned int*)(0x42310B0CUL)))
#define bM4_TMR63_PCONR_CMPCA0                    (*((volatile unsigned int*)(0x42310B10UL)))
#define bM4_TMR63_PCONR_CMPCA1                    (*((volatile unsigned int*)(0x42310B14UL)))
#define bM4_TMR63_PCONR_PERCA0                    (*((volatile unsigned int*)(0x42310B18UL)))
#define bM4_TMR63_PCONR_PERCA1                    (*((volatile unsigned int*)(0x42310B1CUL)))
#define bM4_TMR63_PCONR_OUTENA                    (*((volatile unsigned int*)(0x42310B20UL)))
#define bM4_TMR63_PCONR_EMBVALA0                  (*((volatile unsigned int*)(0x42310B2CUL)))
#define bM4_TMR63_PCONR_EMBVALA1                  (*((volatile unsigned int*)(0x42310B30UL)))
#define bM4_TMR63_PCONR_CAPMDB                    (*((volatile unsigned int*)(0x42310B40UL)))
#define bM4_TMR63_PCONR_STACB                     (*((volatile unsigned int*)(0x42310B44UL)))
#define bM4_TMR63_PCONR_STPCB                     (*((volatile unsigned int*)(0x42310B48UL)))
#define bM4_TMR63_PCONR_STASTPSB                  (*((volatile unsigned int*)(0x42310B4CUL)))
#define bM4_TMR63_PCONR_CMPCB0                    (*((volatile unsigned int*)(0x42310B50UL)))
#define bM4_TMR63_PCONR_CMPCB1                    (*((volatile unsigned int*)(0x42310B54UL)))
#define bM4_TMR63_PCONR_PERCB0                    (*((volatile unsigned int*)(0x42310B58UL)))
#define bM4_TMR63_PCONR_PERCB1                    (*((volatile unsigned int*)(0x42310B5CUL)))
#define bM4_TMR63_PCONR_OUTENB                    (*((volatile unsigned int*)(0x42310B60UL)))
#define bM4_TMR63_PCONR_EMBVALB0                  (*((volatile unsigned int*)(0x42310B6CUL)))
#define bM4_TMR63_PCONR_EMBVALB1                  (*((volatile unsigned int*)(0x42310B70UL)))
#define bM4_TMR63_BCONR_BENA                      (*((volatile unsigned int*)(0x42310B80UL)))
#define bM4_TMR63_BCONR_BSEA                      (*((volatile unsigned int*)(0x42310B84UL)))
#define bM4_TMR63_BCONR_BENB                      (*((volatile unsigned int*)(0x42310B88UL)))
#define bM4_TMR63_BCONR_BSEB                      (*((volatile unsigned int*)(0x42310B8CUL)))
#define bM4_TMR63_BCONR_BENP                      (*((volatile unsigned int*)(0x42310BA0UL)))
#define bM4_TMR63_BCONR_BSEP                      (*((volatile unsigned int*)(0x42310BA4UL)))
#define bM4_TMR63_BCONR_BENSPA                    (*((volatile unsigned int*)(0x42310BC0UL)))
#define bM4_TMR63_BCONR_BSESPA                    (*((volatile unsigned int*)(0x42310BC4UL)))
#define bM4_TMR63_BCONR_BTRSPA0                   (*((volatile unsigned int*)(0x42310BD0UL)))
#define bM4_TMR63_BCONR_BTRSPA1                   (*((volatile unsigned int*)(0x42310BD4UL)))
#define bM4_TMR63_BCONR_BENSPB                    (*((volatile unsigned int*)(0x42310BE0UL)))
#define bM4_TMR63_BCONR_BSESPB                    (*((volatile unsigned int*)(0x42310BE4UL)))
#define bM4_TMR63_BCONR_BTRSPB0                   (*((volatile unsigned int*)(0x42310BF0UL)))
#define bM4_TMR63_BCONR_BTRSPB1                   (*((volatile unsigned int*)(0x42310BF4UL)))
#define bM4_TMR63_DCONR_DTCEN                     (*((volatile unsigned int*)(0x42310C00UL)))
#define bM4_TMR63_DCONR_DTBENU                    (*((volatile unsigned int*)(0x42310C10UL)))
#define bM4_TMR63_DCONR_DTBEND                    (*((volatile unsigned int*)(0x42310C14UL)))
#define bM4_TMR63_DCONR_SEPA                      (*((volatile unsigned int*)(0x42310C20UL)))
#define bM4_TMR63_FCONR_NOFIENGA                  (*((volatile unsigned int*)(0x42310D00UL)))
#define bM4_TMR63_FCONR_NOFICKGA0                 (*((volatile unsigned int*)(0x42310D04UL)))
#define bM4_TMR63_FCONR_NOFICKGA1                 (*((volatile unsigned int*)(0x42310D08UL)))
#define bM4_TMR63_FCONR_NOFIENGB                  (*((volatile unsigned int*)(0x42310D10UL)))
#define bM4_TMR63_FCONR_NOFICKGB0                 (*((volatile unsigned int*)(0x42310D14UL)))
#define bM4_TMR63_FCONR_NOFICKGB1                 (*((volatile unsigned int*)(0x42310D18UL)))
#define bM4_TMR63_FCONR_NOFIENTA                  (*((volatile unsigned int*)(0x42310D40UL)))
#define bM4_TMR63_FCONR_NOFICKTA0                 (*((volatile unsigned int*)(0x42310D44UL)))
#define bM4_TMR63_FCONR_NOFICKTA1                 (*((volatile unsigned int*)(0x42310D48UL)))
#define bM4_TMR63_FCONR_NOFIENTB                  (*((volatile unsigned int*)(0x42310D50UL)))
#define bM4_TMR63_FCONR_NOFICKTB0                 (*((volatile unsigned int*)(0x42310D54UL)))
#define bM4_TMR63_FCONR_NOFICKTB1                 (*((volatile unsigned int*)(0x42310D58UL)))
#define bM4_TMR63_VPERR_SPPERIA                   (*((volatile unsigned int*)(0x42310DA0UL)))
#define bM4_TMR63_VPERR_SPPERIB                   (*((volatile unsigned int*)(0x42310DA4UL)))
#define bM4_TMR63_VPERR_PCNTE0                    (*((volatile unsigned int*)(0x42310DC0UL)))
#define bM4_TMR63_VPERR_PCNTE1                    (*((volatile unsigned int*)(0x42310DC4UL)))
#define bM4_TMR63_VPERR_PCNTS0                    (*((volatile unsigned int*)(0x42310DC8UL)))
#define bM4_TMR63_VPERR_PCNTS1                    (*((volatile unsigned int*)(0x42310DCCUL)))
#define bM4_TMR63_VPERR_PCNTS2                    (*((volatile unsigned int*)(0x42310DD0UL)))
#define bM4_TMR63_STFLR_CMAF                      (*((volatile unsigned int*)(0x42310E00UL)))
#define bM4_TMR63_STFLR_CMBF                      (*((volatile unsigned int*)(0x42310E04UL)))
#define bM4_TMR63_STFLR_CMCF                      (*((volatile unsigned int*)(0x42310E08UL)))
#define bM4_TMR63_STFLR_CMDF                      (*((volatile unsigned int*)(0x42310E0CUL)))
#define bM4_TMR63_STFLR_CMEF                      (*((volatile unsigned int*)(0x42310E10UL)))
#define bM4_TMR63_STFLR_CMFF                      (*((volatile unsigned int*)(0x42310E14UL)))
#define bM4_TMR63_STFLR_OVFF                      (*((volatile unsigned int*)(0x42310E18UL)))
#define bM4_TMR63_STFLR_UDFF                      (*((volatile unsigned int*)(0x42310E1CUL)))
#define bM4_TMR63_STFLR_DTEF                      (*((volatile unsigned int*)(0x42310E20UL)))
#define bM4_TMR63_STFLR_CMSAUF                    (*((volatile unsigned int*)(0x42310E24UL)))
#define bM4_TMR63_STFLR_CMSADF                    (*((volatile unsigned int*)(0x42310E28UL)))
#define bM4_TMR63_STFLR_CMSBUF                    (*((volatile unsigned int*)(0x42310E2CUL)))
#define bM4_TMR63_STFLR_CMSBDF                    (*((volatile unsigned int*)(0x42310E30UL)))
#define bM4_TMR63_STFLR_VPERNUM0                  (*((volatile unsigned int*)(0x42310E54UL)))
#define bM4_TMR63_STFLR_VPERNUM1                  (*((volatile unsigned int*)(0x42310E58UL)))
#define bM4_TMR63_STFLR_VPERNUM2                  (*((volatile unsigned int*)(0x42310E5CUL)))
#define bM4_TMR63_STFLR_DIRF                      (*((volatile unsigned int*)(0x42310E7CUL)))
#define bM4_TMR63_HSTAR_HSTA0                     (*((volatile unsigned int*)(0x42310E80UL)))
#define bM4_TMR63_HSTAR_HSTA1                     (*((volatile unsigned int*)(0x42310E84UL)))
#define bM4_TMR63_HSTAR_HSTA4                     (*((volatile unsigned int*)(0x42310E90UL)))
#define bM4_TMR63_HSTAR_HSTA5                     (*((volatile unsigned int*)(0x42310E94UL)))
#define bM4_TMR63_HSTAR_HSTA6                     (*((volatile unsigned int*)(0x42310E98UL)))
#define bM4_TMR63_HSTAR_HSTA7                     (*((volatile unsigned int*)(0x42310E9CUL)))
#define bM4_TMR63_HSTAR_HSTA8                     (*((volatile unsigned int*)(0x42310EA0UL)))
#define bM4_TMR63_HSTAR_HSTA9                     (*((volatile unsigned int*)(0x42310EA4UL)))
#define bM4_TMR63_HSTAR_HSTA10                    (*((volatile unsigned int*)(0x42310EA8UL)))
#define bM4_TMR63_HSTAR_HSTA11                    (*((volatile unsigned int*)(0x42310EACUL)))
#define bM4_TMR63_HSTAR_STARTS                    (*((volatile unsigned int*)(0x42310EFCUL)))
#define bM4_TMR63_HSTPR_HSTP0                     (*((volatile unsigned int*)(0x42310F00UL)))
#define bM4_TMR63_HSTPR_HSTP1                     (*((volatile unsigned int*)(0x42310F04UL)))
#define bM4_TMR63_HSTPR_HSTP4                     (*((volatile unsigned int*)(0x42310F10UL)))
#define bM4_TMR63_HSTPR_HSTP5                     (*((volatile unsigned int*)(0x42310F14UL)))
#define bM4_TMR63_HSTPR_HSTP6                     (*((volatile unsigned int*)(0x42310F18UL)))
#define bM4_TMR63_HSTPR_HSTP7                     (*((volatile unsigned int*)(0x42310F1CUL)))
#define bM4_TMR63_HSTPR_HSTP8                     (*((volatile unsigned int*)(0x42310F20UL)))
#define bM4_TMR63_HSTPR_HSTP9                     (*((volatile unsigned int*)(0x42310F24UL)))
#define bM4_TMR63_HSTPR_HSTP10                    (*((volatile unsigned int*)(0x42310F28UL)))
#define bM4_TMR63_HSTPR_HSTP11                    (*((volatile unsigned int*)(0x42310F2CUL)))
#define bM4_TMR63_HSTPR_STOPS                     (*((volatile unsigned int*)(0x42310F7CUL)))
#define bM4_TMR63_HCLRR_HCLE0                     (*((volatile unsigned int*)(0x42310F80UL)))
#define bM4_TMR63_HCLRR_HCLE1                     (*((volatile unsigned int*)(0x42310F84UL)))
#define bM4_TMR63_HCLRR_HCLE4                     (*((volatile unsigned int*)(0x42310F90UL)))
#define bM4_TMR63_HCLRR_HCLE5                     (*((volatile unsigned int*)(0x42310F94UL)))
#define bM4_TMR63_HCLRR_HCLE6                     (*((volatile unsigned int*)(0x42310F98UL)))
#define bM4_TMR63_HCLRR_HCLE7                     (*((volatile unsigned int*)(0x42310F9CUL)))
#define bM4_TMR63_HCLRR_HCLE8                     (*((volatile unsigned int*)(0x42310FA0UL)))
#define bM4_TMR63_HCLRR_HCLE9                     (*((volatile unsigned int*)(0x42310FA4UL)))
#define bM4_TMR63_HCLRR_HCLE10                    (*((volatile unsigned int*)(0x42310FA8UL)))
#define bM4_TMR63_HCLRR_HCLE11                    (*((volatile unsigned int*)(0x42310FACUL)))
#define bM4_TMR63_HCLRR_CLEARS                    (*((volatile unsigned int*)(0x42310FFCUL)))
#define bM4_TMR63_HCPAR_HCPA0                     (*((volatile unsigned int*)(0x42311000UL)))
#define bM4_TMR63_HCPAR_HCPA1                     (*((volatile unsigned int*)(0x42311004UL)))
#define bM4_TMR63_HCPAR_HCPA4                     (*((volatile unsigned int*)(0x42311010UL)))
#define bM4_TMR63_HCPAR_HCPA5                     (*((volatile unsigned int*)(0x42311014UL)))
#define bM4_TMR63_HCPAR_HCPA6                     (*((volatile unsigned int*)(0x42311018UL)))
#define bM4_TMR63_HCPAR_HCPA7                     (*((volatile unsigned int*)(0x4231101CUL)))
#define bM4_TMR63_HCPAR_HCPA8                     (*((volatile unsigned int*)(0x42311020UL)))
#define bM4_TMR63_HCPAR_HCPA9                     (*((volatile unsigned int*)(0x42311024UL)))
#define bM4_TMR63_HCPAR_HCPA10                    (*((volatile unsigned int*)(0x42311028UL)))
#define bM4_TMR63_HCPAR_HCPA11                    (*((volatile unsigned int*)(0x4231102CUL)))
#define bM4_TMR63_HCPBR_HCPB0                     (*((volatile unsigned int*)(0x42311080UL)))
#define bM4_TMR63_HCPBR_HCPB1                     (*((volatile unsigned int*)(0x42311084UL)))
#define bM4_TMR63_HCPBR_HCPB4                     (*((volatile unsigned int*)(0x42311090UL)))
#define bM4_TMR63_HCPBR_HCPB5                     (*((volatile unsigned int*)(0x42311094UL)))
#define bM4_TMR63_HCPBR_HCPB6                     (*((volatile unsigned int*)(0x42311098UL)))
#define bM4_TMR63_HCPBR_HCPB7                     (*((volatile unsigned int*)(0x4231109CUL)))
#define bM4_TMR63_HCPBR_HCPB8                     (*((volatile unsigned int*)(0x423110A0UL)))
#define bM4_TMR63_HCPBR_HCPB9                     (*((volatile unsigned int*)(0x423110A4UL)))
#define bM4_TMR63_HCPBR_HCPB10                    (*((volatile unsigned int*)(0x423110A8UL)))
#define bM4_TMR63_HCPBR_HCPB11                    (*((volatile unsigned int*)(0x423110ACUL)))
#define bM4_TMR63_HCUPR_HCUP0                     (*((volatile unsigned int*)(0x42311100UL)))
#define bM4_TMR63_HCUPR_HCUP1                     (*((volatile unsigned int*)(0x42311104UL)))
#define bM4_TMR63_HCUPR_HCUP2                     (*((volatile unsigned int*)(0x42311108UL)))
#define bM4_TMR63_HCUPR_HCUP3                     (*((volatile unsigned int*)(0x4231110CUL)))
#define bM4_TMR63_HCUPR_HCUP4                     (*((volatile unsigned int*)(0x42311110UL)))
#define bM4_TMR63_HCUPR_HCUP5                     (*((volatile unsigned int*)(0x42311114UL)))
#define bM4_TMR63_HCUPR_HCUP6                     (*((volatile unsigned int*)(0x42311118UL)))
#define bM4_TMR63_HCUPR_HCUP7                     (*((volatile unsigned int*)(0x4231111CUL)))
#define bM4_TMR63_HCUPR_HCUP8                     (*((volatile unsigned int*)(0x42311120UL)))
#define bM4_TMR63_HCUPR_HCUP9                     (*((volatile unsigned int*)(0x42311124UL)))
#define bM4_TMR63_HCUPR_HCUP10                    (*((volatile unsigned int*)(0x42311128UL)))
#define bM4_TMR63_HCUPR_HCUP11                    (*((volatile unsigned int*)(0x4231112CUL)))
#define bM4_TMR63_HCUPR_HCUP16                    (*((volatile unsigned int*)(0x42311140UL)))
#define bM4_TMR63_HCUPR_HCUP17                    (*((volatile unsigned int*)(0x42311144UL)))
#define bM4_TMR63_HCDOR_HCDO0                     (*((volatile unsigned int*)(0x42311180UL)))
#define bM4_TMR63_HCDOR_HCDO1                     (*((volatile unsigned int*)(0x42311184UL)))
#define bM4_TMR63_HCDOR_HCDO2                     (*((volatile unsigned int*)(0x42311188UL)))
#define bM4_TMR63_HCDOR_HCDO3                     (*((volatile unsigned int*)(0x4231118CUL)))
#define bM4_TMR63_HCDOR_HCDO4                     (*((volatile unsigned int*)(0x42311190UL)))
#define bM4_TMR63_HCDOR_HCDO5                     (*((volatile unsigned int*)(0x42311194UL)))
#define bM4_TMR63_HCDOR_HCDO6                     (*((volatile unsigned int*)(0x42311198UL)))
#define bM4_TMR63_HCDOR_HCDO7                     (*((volatile unsigned int*)(0x4231119CUL)))
#define bM4_TMR63_HCDOR_HCDO8                     (*((volatile unsigned int*)(0x423111A0UL)))
#define bM4_TMR63_HCDOR_HCDO9                     (*((volatile unsigned int*)(0x423111A4UL)))
#define bM4_TMR63_HCDOR_HCDO10                    (*((volatile unsigned int*)(0x423111A8UL)))
#define bM4_TMR63_HCDOR_HCDO11                    (*((volatile unsigned int*)(0x423111ACUL)))
#define bM4_TMR63_HCDOR_HCDO16                    (*((volatile unsigned int*)(0x423111C0UL)))
#define bM4_TMR63_HCDOR_HCDO17                    (*((volatile unsigned int*)(0x423111C4UL)))
#define bM4_TMR6_CR_SSTAR_SSTA1                   (*((volatile unsigned int*)(0x42307E80UL)))
#define bM4_TMR6_CR_SSTAR_SSTA2                   (*((volatile unsigned int*)(0x42307E84UL)))
#define bM4_TMR6_CR_SSTAR_SSTA3                   (*((volatile unsigned int*)(0x42307E88UL)))
#define bM4_TMR6_CR_SSTAR_RESV0                   (*((volatile unsigned int*)(0x42307EC0UL)))
#define bM4_TMR6_CR_SSTAR_RESV                    (*((volatile unsigned int*)(0x42307EE0UL)))
#define bM4_TMR6_CR_SSTPR_SSTP1                   (*((volatile unsigned int*)(0x42307F00UL)))
#define bM4_TMR6_CR_SSTPR_SSTP2                   (*((volatile unsigned int*)(0x42307F04UL)))
#define bM4_TMR6_CR_SSTPR_SSTP3                   (*((volatile unsigned int*)(0x42307F08UL)))
#define bM4_TMR6_CR_SCLRR_SCLE1                   (*((volatile unsigned int*)(0x42307F80UL)))
#define bM4_TMR6_CR_SCLRR_SCLE2                   (*((volatile unsigned int*)(0x42307F84UL)))
#define bM4_TMR6_CR_SCLRR_SCLE3                   (*((volatile unsigned int*)(0x42307F88UL)))
#define bM4_TMRA1_CNTER_CNT0                      (*((volatile unsigned int*)(0x422A0000UL)))
#define bM4_TMRA1_CNTER_CNT1                      (*((volatile unsigned int*)(0x422A0004UL)))
#define bM4_TMRA1_CNTER_CNT2                      (*((volatile unsigned int*)(0x422A0008UL)))
#define bM4_TMRA1_CNTER_CNT3                      (*((volatile unsigned int*)(0x422A000CUL)))
#define bM4_TMRA1_CNTER_CNT4                      (*((volatile unsigned int*)(0x422A0010UL)))
#define bM4_TMRA1_CNTER_CNT5                      (*((volatile unsigned int*)(0x422A0014UL)))
#define bM4_TMRA1_CNTER_CNT6                      (*((volatile unsigned int*)(0x422A0018UL)))
#define bM4_TMRA1_CNTER_CNT7                      (*((volatile unsigned int*)(0x422A001CUL)))
#define bM4_TMRA1_CNTER_CNT8                      (*((volatile unsigned int*)(0x422A0020UL)))
#define bM4_TMRA1_CNTER_CNT9                      (*((volatile unsigned int*)(0x422A0024UL)))
#define bM4_TMRA1_CNTER_CNT10                     (*((volatile unsigned int*)(0x422A0028UL)))
#define bM4_TMRA1_CNTER_CNT11                     (*((volatile unsigned int*)(0x422A002CUL)))
#define bM4_TMRA1_CNTER_CNT12                     (*((volatile unsigned int*)(0x422A0030UL)))
#define bM4_TMRA1_CNTER_CNT13                     (*((volatile unsigned int*)(0x422A0034UL)))
#define bM4_TMRA1_CNTER_CNT14                     (*((volatile unsigned int*)(0x422A0038UL)))
#define bM4_TMRA1_CNTER_CNT15                     (*((volatile unsigned int*)(0x422A003CUL)))
#define bM4_TMRA1_PERAR_PER0                      (*((volatile unsigned int*)(0x422A0080UL)))
#define bM4_TMRA1_PERAR_PER1                      (*((volatile unsigned int*)(0x422A0084UL)))
#define bM4_TMRA1_PERAR_PER2                      (*((volatile unsigned int*)(0x422A0088UL)))
#define bM4_TMRA1_PERAR_PER3                      (*((volatile unsigned int*)(0x422A008CUL)))
#define bM4_TMRA1_PERAR_PER4                      (*((volatile unsigned int*)(0x422A0090UL)))
#define bM4_TMRA1_PERAR_PER5                      (*((volatile unsigned int*)(0x422A0094UL)))
#define bM4_TMRA1_PERAR_PER6                      (*((volatile unsigned int*)(0x422A0098UL)))
#define bM4_TMRA1_PERAR_PER7                      (*((volatile unsigned int*)(0x422A009CUL)))
#define bM4_TMRA1_PERAR_PER8                      (*((volatile unsigned int*)(0x422A00A0UL)))
#define bM4_TMRA1_PERAR_PER9                      (*((volatile unsigned int*)(0x422A00A4UL)))
#define bM4_TMRA1_PERAR_PER10                     (*((volatile unsigned int*)(0x422A00A8UL)))
#define bM4_TMRA1_PERAR_PER11                     (*((volatile unsigned int*)(0x422A00ACUL)))
#define bM4_TMRA1_PERAR_PER12                     (*((volatile unsigned int*)(0x422A00B0UL)))
#define bM4_TMRA1_PERAR_PER13                     (*((volatile unsigned int*)(0x422A00B4UL)))
#define bM4_TMRA1_PERAR_PER14                     (*((volatile unsigned int*)(0x422A00B8UL)))
#define bM4_TMRA1_PERAR_PER15                     (*((volatile unsigned int*)(0x422A00BCUL)))
#define bM4_TMRA1_CMPAR1_CMP0                     (*((volatile unsigned int*)(0x422A0800UL)))
#define bM4_TMRA1_CMPAR1_CMP1                     (*((volatile unsigned int*)(0x422A0804UL)))
#define bM4_TMRA1_CMPAR1_CMP2                     (*((volatile unsigned int*)(0x422A0808UL)))
#define bM4_TMRA1_CMPAR1_CMP3                     (*((volatile unsigned int*)(0x422A080CUL)))
#define bM4_TMRA1_CMPAR1_CMP4                     (*((volatile unsigned int*)(0x422A0810UL)))
#define bM4_TMRA1_CMPAR1_CMP5                     (*((volatile unsigned int*)(0x422A0814UL)))
#define bM4_TMRA1_CMPAR1_CMP6                     (*((volatile unsigned int*)(0x422A0818UL)))
#define bM4_TMRA1_CMPAR1_CMP7                     (*((volatile unsigned int*)(0x422A081CUL)))
#define bM4_TMRA1_CMPAR1_CMP8                     (*((volatile unsigned int*)(0x422A0820UL)))
#define bM4_TMRA1_CMPAR1_CMP9                     (*((volatile unsigned int*)(0x422A0824UL)))
#define bM4_TMRA1_CMPAR1_CMP10                    (*((volatile unsigned int*)(0x422A0828UL)))
#define bM4_TMRA1_CMPAR1_CMP11                    (*((volatile unsigned int*)(0x422A082CUL)))
#define bM4_TMRA1_CMPAR1_CMP12                    (*((volatile unsigned int*)(0x422A0830UL)))
#define bM4_TMRA1_CMPAR1_CMP13                    (*((volatile unsigned int*)(0x422A0834UL)))
#define bM4_TMRA1_CMPAR1_CMP14                    (*((volatile unsigned int*)(0x422A0838UL)))
#define bM4_TMRA1_CMPAR1_CMP15                    (*((volatile unsigned int*)(0x422A083CUL)))
#define bM4_TMRA1_CMPAR2_CMP0                     (*((volatile unsigned int*)(0x422A0880UL)))
#define bM4_TMRA1_CMPAR2_CMP1                     (*((volatile unsigned int*)(0x422A0884UL)))
#define bM4_TMRA1_CMPAR2_CMP2                     (*((volatile unsigned int*)(0x422A0888UL)))
#define bM4_TMRA1_CMPAR2_CMP3                     (*((volatile unsigned int*)(0x422A088CUL)))
#define bM4_TMRA1_CMPAR2_CMP4                     (*((volatile unsigned int*)(0x422A0890UL)))
#define bM4_TMRA1_CMPAR2_CMP5                     (*((volatile unsigned int*)(0x422A0894UL)))
#define bM4_TMRA1_CMPAR2_CMP6                     (*((volatile unsigned int*)(0x422A0898UL)))
#define bM4_TMRA1_CMPAR2_CMP7                     (*((volatile unsigned int*)(0x422A089CUL)))
#define bM4_TMRA1_CMPAR2_CMP8                     (*((volatile unsigned int*)(0x422A08A0UL)))
#define bM4_TMRA1_CMPAR2_CMP9                     (*((volatile unsigned int*)(0x422A08A4UL)))
#define bM4_TMRA1_CMPAR2_CMP10                    (*((volatile unsigned int*)(0x422A08A8UL)))
#define bM4_TMRA1_CMPAR2_CMP11                    (*((volatile unsigned int*)(0x422A08ACUL)))
#define bM4_TMRA1_CMPAR2_CMP12                    (*((volatile unsigned int*)(0x422A08B0UL)))
#define bM4_TMRA1_CMPAR2_CMP13                    (*((volatile unsigned int*)(0x422A08B4UL)))
#define bM4_TMRA1_CMPAR2_CMP14                    (*((volatile unsigned int*)(0x422A08B8UL)))
#define bM4_TMRA1_CMPAR2_CMP15                    (*((volatile unsigned int*)(0x422A08BCUL)))
#define bM4_TMRA1_CMPAR3_CMP0                     (*((volatile unsigned int*)(0x422A0900UL)))
#define bM4_TMRA1_CMPAR3_CMP1                     (*((volatile unsigned int*)(0x422A0904UL)))
#define bM4_TMRA1_CMPAR3_CMP2                     (*((volatile unsigned int*)(0x422A0908UL)))
#define bM4_TMRA1_CMPAR3_CMP3                     (*((volatile unsigned int*)(0x422A090CUL)))
#define bM4_TMRA1_CMPAR3_CMP4                     (*((volatile unsigned int*)(0x422A0910UL)))
#define bM4_TMRA1_CMPAR3_CMP5                     (*((volatile unsigned int*)(0x422A0914UL)))
#define bM4_TMRA1_CMPAR3_CMP6                     (*((volatile unsigned int*)(0x422A0918UL)))
#define bM4_TMRA1_CMPAR3_CMP7                     (*((volatile unsigned int*)(0x422A091CUL)))
#define bM4_TMRA1_CMPAR3_CMP8                     (*((volatile unsigned int*)(0x422A0920UL)))
#define bM4_TMRA1_CMPAR3_CMP9                     (*((volatile unsigned int*)(0x422A0924UL)))
#define bM4_TMRA1_CMPAR3_CMP10                    (*((volatile unsigned int*)(0x422A0928UL)))
#define bM4_TMRA1_CMPAR3_CMP11                    (*((volatile unsigned int*)(0x422A092CUL)))
#define bM4_TMRA1_CMPAR3_CMP12                    (*((volatile unsigned int*)(0x422A0930UL)))
#define bM4_TMRA1_CMPAR3_CMP13                    (*((volatile unsigned int*)(0x422A0934UL)))
#define bM4_TMRA1_CMPAR3_CMP14                    (*((volatile unsigned int*)(0x422A0938UL)))
#define bM4_TMRA1_CMPAR3_CMP15                    (*((volatile unsigned int*)(0x422A093CUL)))
#define bM4_TMRA1_CMPAR4_CMP0                     (*((volatile unsigned int*)(0x422A0980UL)))
#define bM4_TMRA1_CMPAR4_CMP1                     (*((volatile unsigned int*)(0x422A0984UL)))
#define bM4_TMRA1_CMPAR4_CMP2                     (*((volatile unsigned int*)(0x422A0988UL)))
#define bM4_TMRA1_CMPAR4_CMP3                     (*((volatile unsigned int*)(0x422A098CUL)))
#define bM4_TMRA1_CMPAR4_CMP4                     (*((volatile unsigned int*)(0x422A0990UL)))
#define bM4_TMRA1_CMPAR4_CMP5                     (*((volatile unsigned int*)(0x422A0994UL)))
#define bM4_TMRA1_CMPAR4_CMP6                     (*((volatile unsigned int*)(0x422A0998UL)))
#define bM4_TMRA1_CMPAR4_CMP7                     (*((volatile unsigned int*)(0x422A099CUL)))
#define bM4_TMRA1_CMPAR4_CMP8                     (*((volatile unsigned int*)(0x422A09A0UL)))
#define bM4_TMRA1_CMPAR4_CMP9                     (*((volatile unsigned int*)(0x422A09A4UL)))
#define bM4_TMRA1_CMPAR4_CMP10                    (*((volatile unsigned int*)(0x422A09A8UL)))
#define bM4_TMRA1_CMPAR4_CMP11                    (*((volatile unsigned int*)(0x422A09ACUL)))
#define bM4_TMRA1_CMPAR4_CMP12                    (*((volatile unsigned int*)(0x422A09B0UL)))
#define bM4_TMRA1_CMPAR4_CMP13                    (*((volatile unsigned int*)(0x422A09B4UL)))
#define bM4_TMRA1_CMPAR4_CMP14                    (*((volatile unsigned int*)(0x422A09B8UL)))
#define bM4_TMRA1_CMPAR4_CMP15                    (*((volatile unsigned int*)(0x422A09BCUL)))
#define bM4_TMRA1_CMPAR5_CMP0                     (*((volatile unsigned int*)(0x422A0A00UL)))
#define bM4_TMRA1_CMPAR5_CMP1                     (*((volatile unsigned int*)(0x422A0A04UL)))
#define bM4_TMRA1_CMPAR5_CMP2                     (*((volatile unsigned int*)(0x422A0A08UL)))
#define bM4_TMRA1_CMPAR5_CMP3                     (*((volatile unsigned int*)(0x422A0A0CUL)))
#define bM4_TMRA1_CMPAR5_CMP4                     (*((volatile unsigned int*)(0x422A0A10UL)))
#define bM4_TMRA1_CMPAR5_CMP5                     (*((volatile unsigned int*)(0x422A0A14UL)))
#define bM4_TMRA1_CMPAR5_CMP6                     (*((volatile unsigned int*)(0x422A0A18UL)))
#define bM4_TMRA1_CMPAR5_CMP7                     (*((volatile unsigned int*)(0x422A0A1CUL)))
#define bM4_TMRA1_CMPAR5_CMP8                     (*((volatile unsigned int*)(0x422A0A20UL)))
#define bM4_TMRA1_CMPAR5_CMP9                     (*((volatile unsigned int*)(0x422A0A24UL)))
#define bM4_TMRA1_CMPAR5_CMP10                    (*((volatile unsigned int*)(0x422A0A28UL)))
#define bM4_TMRA1_CMPAR5_CMP11                    (*((volatile unsigned int*)(0x422A0A2CUL)))
#define bM4_TMRA1_CMPAR5_CMP12                    (*((volatile unsigned int*)(0x422A0A30UL)))
#define bM4_TMRA1_CMPAR5_CMP13                    (*((volatile unsigned int*)(0x422A0A34UL)))
#define bM4_TMRA1_CMPAR5_CMP14                    (*((volatile unsigned int*)(0x422A0A38UL)))
#define bM4_TMRA1_CMPAR5_CMP15                    (*((volatile unsigned int*)(0x422A0A3CUL)))
#define bM4_TMRA1_CMPAR6_CMP0                     (*((volatile unsigned int*)(0x422A0A80UL)))
#define bM4_TMRA1_CMPAR6_CMP1                     (*((volatile unsigned int*)(0x422A0A84UL)))
#define bM4_TMRA1_CMPAR6_CMP2                     (*((volatile unsigned int*)(0x422A0A88UL)))
#define bM4_TMRA1_CMPAR6_CMP3                     (*((volatile unsigned int*)(0x422A0A8CUL)))
#define bM4_TMRA1_CMPAR6_CMP4                     (*((volatile unsigned int*)(0x422A0A90UL)))
#define bM4_TMRA1_CMPAR6_CMP5                     (*((volatile unsigned int*)(0x422A0A94UL)))
#define bM4_TMRA1_CMPAR6_CMP6                     (*((volatile unsigned int*)(0x422A0A98UL)))
#define bM4_TMRA1_CMPAR6_CMP7                     (*((volatile unsigned int*)(0x422A0A9CUL)))
#define bM4_TMRA1_CMPAR6_CMP8                     (*((volatile unsigned int*)(0x422A0AA0UL)))
#define bM4_TMRA1_CMPAR6_CMP9                     (*((volatile unsigned int*)(0x422A0AA4UL)))
#define bM4_TMRA1_CMPAR6_CMP10                    (*((volatile unsigned int*)(0x422A0AA8UL)))
#define bM4_TMRA1_CMPAR6_CMP11                    (*((volatile unsigned int*)(0x422A0AACUL)))
#define bM4_TMRA1_CMPAR6_CMP12                    (*((volatile unsigned int*)(0x422A0AB0UL)))
#define bM4_TMRA1_CMPAR6_CMP13                    (*((volatile unsigned int*)(0x422A0AB4UL)))
#define bM4_TMRA1_CMPAR6_CMP14                    (*((volatile unsigned int*)(0x422A0AB8UL)))
#define bM4_TMRA1_CMPAR6_CMP15                    (*((volatile unsigned int*)(0x422A0ABCUL)))
#define bM4_TMRA1_CMPAR7_CMP0                     (*((volatile unsigned int*)(0x422A0B00UL)))
#define bM4_TMRA1_CMPAR7_CMP1                     (*((volatile unsigned int*)(0x422A0B04UL)))
#define bM4_TMRA1_CMPAR7_CMP2                     (*((volatile unsigned int*)(0x422A0B08UL)))
#define bM4_TMRA1_CMPAR7_CMP3                     (*((volatile unsigned int*)(0x422A0B0CUL)))
#define bM4_TMRA1_CMPAR7_CMP4                     (*((volatile unsigned int*)(0x422A0B10UL)))
#define bM4_TMRA1_CMPAR7_CMP5                     (*((volatile unsigned int*)(0x422A0B14UL)))
#define bM4_TMRA1_CMPAR7_CMP6                     (*((volatile unsigned int*)(0x422A0B18UL)))
#define bM4_TMRA1_CMPAR7_CMP7                     (*((volatile unsigned int*)(0x422A0B1CUL)))
#define bM4_TMRA1_CMPAR7_CMP8                     (*((volatile unsigned int*)(0x422A0B20UL)))
#define bM4_TMRA1_CMPAR7_CMP9                     (*((volatile unsigned int*)(0x422A0B24UL)))
#define bM4_TMRA1_CMPAR7_CMP10                    (*((volatile unsigned int*)(0x422A0B28UL)))
#define bM4_TMRA1_CMPAR7_CMP11                    (*((volatile unsigned int*)(0x422A0B2CUL)))
#define bM4_TMRA1_CMPAR7_CMP12                    (*((volatile unsigned int*)(0x422A0B30UL)))
#define bM4_TMRA1_CMPAR7_CMP13                    (*((volatile unsigned int*)(0x422A0B34UL)))
#define bM4_TMRA1_CMPAR7_CMP14                    (*((volatile unsigned int*)(0x422A0B38UL)))
#define bM4_TMRA1_CMPAR7_CMP15                    (*((volatile unsigned int*)(0x422A0B3CUL)))
#define bM4_TMRA1_CMPAR8_CMP0                     (*((volatile unsigned int*)(0x422A0B80UL)))
#define bM4_TMRA1_CMPAR8_CMP1                     (*((volatile unsigned int*)(0x422A0B84UL)))
#define bM4_TMRA1_CMPAR8_CMP2                     (*((volatile unsigned int*)(0x422A0B88UL)))
#define bM4_TMRA1_CMPAR8_CMP3                     (*((volatile unsigned int*)(0x422A0B8CUL)))
#define bM4_TMRA1_CMPAR8_CMP4                     (*((volatile unsigned int*)(0x422A0B90UL)))
#define bM4_TMRA1_CMPAR8_CMP5                     (*((volatile unsigned int*)(0x422A0B94UL)))
#define bM4_TMRA1_CMPAR8_CMP6                     (*((volatile unsigned int*)(0x422A0B98UL)))
#define bM4_TMRA1_CMPAR8_CMP7                     (*((volatile unsigned int*)(0x422A0B9CUL)))
#define bM4_TMRA1_CMPAR8_CMP8                     (*((volatile unsigned int*)(0x422A0BA0UL)))
#define bM4_TMRA1_CMPAR8_CMP9                     (*((volatile unsigned int*)(0x422A0BA4UL)))
#define bM4_TMRA1_CMPAR8_CMP10                    (*((volatile unsigned int*)(0x422A0BA8UL)))
#define bM4_TMRA1_CMPAR8_CMP11                    (*((volatile unsigned int*)(0x422A0BACUL)))
#define bM4_TMRA1_CMPAR8_CMP12                    (*((volatile unsigned int*)(0x422A0BB0UL)))
#define bM4_TMRA1_CMPAR8_CMP13                    (*((volatile unsigned int*)(0x422A0BB4UL)))
#define bM4_TMRA1_CMPAR8_CMP14                    (*((volatile unsigned int*)(0x422A0BB8UL)))
#define bM4_TMRA1_CMPAR8_CMP15                    (*((volatile unsigned int*)(0x422A0BBCUL)))
#define bM4_TMRA1_BCSTR_START                     (*((volatile unsigned int*)(0x422A1000UL)))
#define bM4_TMRA1_BCSTR_DIR                       (*((volatile unsigned int*)(0x422A1004UL)))
#define bM4_TMRA1_BCSTR_MODE                      (*((volatile unsigned int*)(0x422A1008UL)))
#define bM4_TMRA1_BCSTR_SYNST                     (*((volatile unsigned int*)(0x422A100CUL)))
#define bM4_TMRA1_BCSTR_CKDIV0                    (*((volatile unsigned int*)(0x422A1010UL)))
#define bM4_TMRA1_BCSTR_CKDIV1                    (*((volatile unsigned int*)(0x422A1014UL)))
#define bM4_TMRA1_BCSTR_CKDIV2                    (*((volatile unsigned int*)(0x422A1018UL)))
#define bM4_TMRA1_BCSTR_CKDIV3                    (*((volatile unsigned int*)(0x422A101CUL)))
#define bM4_TMRA1_BCSTR_ITENOVF                   (*((volatile unsigned int*)(0x422A1030UL)))
#define bM4_TMRA1_BCSTR_ITENUDF                   (*((volatile unsigned int*)(0x422A1034UL)))
#define bM4_TMRA1_BCSTR_OVFF                      (*((volatile unsigned int*)(0x422A1038UL)))
#define bM4_TMRA1_BCSTR_UDFF                      (*((volatile unsigned int*)(0x422A103CUL)))
#define bM4_TMRA1_HCONR_HSTA0                     (*((volatile unsigned int*)(0x422A1080UL)))
#define bM4_TMRA1_HCONR_HSTA1                     (*((volatile unsigned int*)(0x422A1084UL)))
#define bM4_TMRA1_HCONR_HSTA2                     (*((volatile unsigned int*)(0x422A1088UL)))
#define bM4_TMRA1_HCONR_HSTP0                     (*((volatile unsigned int*)(0x422A1090UL)))
#define bM4_TMRA1_HCONR_HSTP1                     (*((volatile unsigned int*)(0x422A1094UL)))
#define bM4_TMRA1_HCONR_HSTP2                     (*((volatile unsigned int*)(0x422A1098UL)))
#define bM4_TMRA1_HCONR_HCLE0                     (*((volatile unsigned int*)(0x422A10A0UL)))
#define bM4_TMRA1_HCONR_HCLE1                     (*((volatile unsigned int*)(0x422A10A4UL)))
#define bM4_TMRA1_HCONR_HCLE2                     (*((volatile unsigned int*)(0x422A10A8UL)))
#define bM4_TMRA1_HCONR_HCLE3                     (*((volatile unsigned int*)(0x422A10B0UL)))
#define bM4_TMRA1_HCONR_HCLE4                     (*((volatile unsigned int*)(0x422A10B4UL)))
#define bM4_TMRA1_HCONR_HCLE5                     (*((volatile unsigned int*)(0x422A10B8UL)))
#define bM4_TMRA1_HCONR_HCLE6                     (*((volatile unsigned int*)(0x422A10BCUL)))
#define bM4_TMRA1_HCUPR_HCUP0                     (*((volatile unsigned int*)(0x422A1100UL)))
#define bM4_TMRA1_HCUPR_HCUP1                     (*((volatile unsigned int*)(0x422A1104UL)))
#define bM4_TMRA1_HCUPR_HCUP2                     (*((volatile unsigned int*)(0x422A1108UL)))
#define bM4_TMRA1_HCUPR_HCUP3                     (*((volatile unsigned int*)(0x422A110CUL)))
#define bM4_TMRA1_HCUPR_HCUP4                     (*((volatile unsigned int*)(0x422A1110UL)))
#define bM4_TMRA1_HCUPR_HCUP5                     (*((volatile unsigned int*)(0x422A1114UL)))
#define bM4_TMRA1_HCUPR_HCUP6                     (*((volatile unsigned int*)(0x422A1118UL)))
#define bM4_TMRA1_HCUPR_HCUP7                     (*((volatile unsigned int*)(0x422A111CUL)))
#define bM4_TMRA1_HCUPR_HCUP8                     (*((volatile unsigned int*)(0x422A1120UL)))
#define bM4_TMRA1_HCUPR_HCUP9                     (*((volatile unsigned int*)(0x422A1124UL)))
#define bM4_TMRA1_HCUPR_HCUP10                    (*((volatile unsigned int*)(0x422A1128UL)))
#define bM4_TMRA1_HCUPR_HCUP11                    (*((volatile unsigned int*)(0x422A112CUL)))
#define bM4_TMRA1_HCUPR_HCUP12                    (*((volatile unsigned int*)(0x422A1130UL)))
#define bM4_TMRA1_HCDOR_HCDO0                     (*((volatile unsigned int*)(0x422A1180UL)))
#define bM4_TMRA1_HCDOR_HCDO1                     (*((volatile unsigned int*)(0x422A1184UL)))
#define bM4_TMRA1_HCDOR_HCDO2                     (*((volatile unsigned int*)(0x422A1188UL)))
#define bM4_TMRA1_HCDOR_HCDO3                     (*((volatile unsigned int*)(0x422A118CUL)))
#define bM4_TMRA1_HCDOR_HCDO4                     (*((volatile unsigned int*)(0x422A1190UL)))
#define bM4_TMRA1_HCDOR_HCDO5                     (*((volatile unsigned int*)(0x422A1194UL)))
#define bM4_TMRA1_HCDOR_HCDO6                     (*((volatile unsigned int*)(0x422A1198UL)))
#define bM4_TMRA1_HCDOR_HCDO7                     (*((volatile unsigned int*)(0x422A119CUL)))
#define bM4_TMRA1_HCDOR_HCDO8                     (*((volatile unsigned int*)(0x422A11A0UL)))
#define bM4_TMRA1_HCDOR_HCDO9                     (*((volatile unsigned int*)(0x422A11A4UL)))
#define bM4_TMRA1_HCDOR_HCDO10                    (*((volatile unsigned int*)(0x422A11A8UL)))
#define bM4_TMRA1_HCDOR_HCDO11                    (*((volatile unsigned int*)(0x422A11ACUL)))
#define bM4_TMRA1_HCDOR_HCDO12                    (*((volatile unsigned int*)(0x422A11B0UL)))
#define bM4_TMRA1_ICONR_ITEN1                     (*((volatile unsigned int*)(0x422A1200UL)))
#define bM4_TMRA1_ICONR_ITEN2                     (*((volatile unsigned int*)(0x422A1204UL)))
#define bM4_TMRA1_ICONR_ITEN3                     (*((volatile unsigned int*)(0x422A1208UL)))
#define bM4_TMRA1_ICONR_ITEN4                     (*((volatile unsigned int*)(0x422A120CUL)))
#define bM4_TMRA1_ICONR_ITEN5                     (*((volatile unsigned int*)(0x422A1210UL)))
#define bM4_TMRA1_ICONR_ITEN6                     (*((volatile unsigned int*)(0x422A1214UL)))
#define bM4_TMRA1_ICONR_ITEN7                     (*((volatile unsigned int*)(0x422A1218UL)))
#define bM4_TMRA1_ICONR_ITEN8                     (*((volatile unsigned int*)(0x422A121CUL)))
#define bM4_TMRA1_ECONR_ETEN1                     (*((volatile unsigned int*)(0x422A1280UL)))
#define bM4_TMRA1_ECONR_ETEN2                     (*((volatile unsigned int*)(0x422A1284UL)))
#define bM4_TMRA1_ECONR_ETEN3                     (*((volatile unsigned int*)(0x422A1288UL)))
#define bM4_TMRA1_ECONR_ETEN4                     (*((volatile unsigned int*)(0x422A128CUL)))
#define bM4_TMRA1_ECONR_ETEN5                     (*((volatile unsigned int*)(0x422A1290UL)))
#define bM4_TMRA1_ECONR_ETEN6                     (*((volatile unsigned int*)(0x422A1294UL)))
#define bM4_TMRA1_ECONR_ETEN7                     (*((volatile unsigned int*)(0x422A1298UL)))
#define bM4_TMRA1_ECONR_ETEN8                     (*((volatile unsigned int*)(0x422A129CUL)))
#define bM4_TMRA1_FCONR_NOFIENTG                  (*((volatile unsigned int*)(0x422A1300UL)))
#define bM4_TMRA1_FCONR_NOFICKTG0                 (*((volatile unsigned int*)(0x422A1304UL)))
#define bM4_TMRA1_FCONR_NOFICKTG1                 (*((volatile unsigned int*)(0x422A1308UL)))
#define bM4_TMRA1_FCONR_NOFIENCA                  (*((volatile unsigned int*)(0x422A1320UL)))
#define bM4_TMRA1_FCONR_NOFICKCA0                 (*((volatile unsigned int*)(0x422A1324UL)))
#define bM4_TMRA1_FCONR_NOFICKCA1                 (*((volatile unsigned int*)(0x422A1328UL)))
#define bM4_TMRA1_FCONR_NOFIENCB                  (*((volatile unsigned int*)(0x422A1330UL)))
#define bM4_TMRA1_FCONR_NOFICKCB0                 (*((volatile unsigned int*)(0x422A1334UL)))
#define bM4_TMRA1_FCONR_NOFICKCB1                 (*((volatile unsigned int*)(0x422A1338UL)))
#define bM4_TMRA1_STFLR_CMPF1                     (*((volatile unsigned int*)(0x422A1380UL)))
#define bM4_TMRA1_STFLR_CMPF2                     (*((volatile unsigned int*)(0x422A1384UL)))
#define bM4_TMRA1_STFLR_CMPF3                     (*((volatile unsigned int*)(0x422A1388UL)))
#define bM4_TMRA1_STFLR_CMPF4                     (*((volatile unsigned int*)(0x422A138CUL)))
#define bM4_TMRA1_STFLR_CMPF5                     (*((volatile unsigned int*)(0x422A1390UL)))
#define bM4_TMRA1_STFLR_CMPF6                     (*((volatile unsigned int*)(0x422A1394UL)))
#define bM4_TMRA1_STFLR_CMPF7                     (*((volatile unsigned int*)(0x422A1398UL)))
#define bM4_TMRA1_STFLR_CMPF8                     (*((volatile unsigned int*)(0x422A139CUL)))
#define bM4_TMRA1_BCONR1_BEN                      (*((volatile unsigned int*)(0x422A1800UL)))
#define bM4_TMRA1_BCONR1_BSE0                     (*((volatile unsigned int*)(0x422A1804UL)))
#define bM4_TMRA1_BCONR1_BSE1                     (*((volatile unsigned int*)(0x422A1808UL)))
#define bM4_TMRA1_BCONR2_BEN                      (*((volatile unsigned int*)(0x422A1900UL)))
#define bM4_TMRA1_BCONR2_BSE0                     (*((volatile unsigned int*)(0x422A1904UL)))
#define bM4_TMRA1_BCONR2_BSE1                     (*((volatile unsigned int*)(0x422A1908UL)))
#define bM4_TMRA1_BCONR3_BEN                      (*((volatile unsigned int*)(0x422A1A00UL)))
#define bM4_TMRA1_BCONR3_BSE0                     (*((volatile unsigned int*)(0x422A1A04UL)))
#define bM4_TMRA1_BCONR3_BSE1                     (*((volatile unsigned int*)(0x422A1A08UL)))
#define bM4_TMRA1_BCONR4_BEN                      (*((volatile unsigned int*)(0x422A1B00UL)))
#define bM4_TMRA1_BCONR4_BSE0                     (*((volatile unsigned int*)(0x422A1B04UL)))
#define bM4_TMRA1_BCONR4_BSE1                     (*((volatile unsigned int*)(0x422A1B08UL)))
#define bM4_TMRA1_CCONR1_CAPMD                    (*((volatile unsigned int*)(0x422A2000UL)))
#define bM4_TMRA1_CCONR1_HICP0                    (*((volatile unsigned int*)(0x422A2010UL)))
#define bM4_TMRA1_CCONR1_HICP1                    (*((volatile unsigned int*)(0x422A2014UL)))
#define bM4_TMRA1_CCONR1_HICP2                    (*((volatile unsigned int*)(0x422A2018UL)))
#define bM4_TMRA1_CCONR1_HICP3                    (*((volatile unsigned int*)(0x422A2020UL)))
#define bM4_TMRA1_CCONR1_HICP4                    (*((volatile unsigned int*)(0x422A2024UL)))
#define bM4_TMRA1_CCONR1_NOFIENCP                 (*((volatile unsigned int*)(0x422A2030UL)))
#define bM4_TMRA1_CCONR1_NOFICKCP0                (*((volatile unsigned int*)(0x422A2034UL)))
#define bM4_TMRA1_CCONR1_NOFICKCP1                (*((volatile unsigned int*)(0x422A2038UL)))
#define bM4_TMRA1_CCONR2_CAPMD                    (*((volatile unsigned int*)(0x422A2080UL)))
#define bM4_TMRA1_CCONR2_HICP0                    (*((volatile unsigned int*)(0x422A2090UL)))
#define bM4_TMRA1_CCONR2_HICP1                    (*((volatile unsigned int*)(0x422A2094UL)))
#define bM4_TMRA1_CCONR2_HICP2                    (*((volatile unsigned int*)(0x422A2098UL)))
#define bM4_TMRA1_CCONR2_HICP3                    (*((volatile unsigned int*)(0x422A20A0UL)))
#define bM4_TMRA1_CCONR2_HICP4                    (*((volatile unsigned int*)(0x422A20A4UL)))
#define bM4_TMRA1_CCONR2_NOFIENCP                 (*((volatile unsigned int*)(0x422A20B0UL)))
#define bM4_TMRA1_CCONR2_NOFICKCP0                (*((volatile unsigned int*)(0x422A20B4UL)))
#define bM4_TMRA1_CCONR2_NOFICKCP1                (*((volatile unsigned int*)(0x422A20B8UL)))
#define bM4_TMRA1_CCONR3_CAPMD                    (*((volatile unsigned int*)(0x422A2100UL)))
#define bM4_TMRA1_CCONR3_HICP0                    (*((volatile unsigned int*)(0x422A2110UL)))
#define bM4_TMRA1_CCONR3_HICP1                    (*((volatile unsigned int*)(0x422A2114UL)))
#define bM4_TMRA1_CCONR3_HICP2                    (*((volatile unsigned int*)(0x422A2118UL)))
#define bM4_TMRA1_CCONR3_HICP3                    (*((volatile unsigned int*)(0x422A2120UL)))
#define bM4_TMRA1_CCONR3_HICP4                    (*((volatile unsigned int*)(0x422A2124UL)))
#define bM4_TMRA1_CCONR3_NOFIENCP                 (*((volatile unsigned int*)(0x422A2130UL)))
#define bM4_TMRA1_CCONR3_NOFICKCP0                (*((volatile unsigned int*)(0x422A2134UL)))
#define bM4_TMRA1_CCONR3_NOFICKCP1                (*((volatile unsigned int*)(0x422A2138UL)))
#define bM4_TMRA1_CCONR4_CAPMD                    (*((volatile unsigned int*)(0x422A2180UL)))
#define bM4_TMRA1_CCONR4_HICP0                    (*((volatile unsigned int*)(0x422A2190UL)))
#define bM4_TMRA1_CCONR4_HICP1                    (*((volatile unsigned int*)(0x422A2194UL)))
#define bM4_TMRA1_CCONR4_HICP2                    (*((volatile unsigned int*)(0x422A2198UL)))
#define bM4_TMRA1_CCONR4_HICP3                    (*((volatile unsigned int*)(0x422A21A0UL)))
#define bM4_TMRA1_CCONR4_HICP4                    (*((volatile unsigned int*)(0x422A21A4UL)))
#define bM4_TMRA1_CCONR4_NOFIENCP                 (*((volatile unsigned int*)(0x422A21B0UL)))
#define bM4_TMRA1_CCONR4_NOFICKCP0                (*((volatile unsigned int*)(0x422A21B4UL)))
#define bM4_TMRA1_CCONR4_NOFICKCP1                (*((volatile unsigned int*)(0x422A21B8UL)))
#define bM4_TMRA1_CCONR5_CAPMD                    (*((volatile unsigned int*)(0x422A2200UL)))
#define bM4_TMRA1_CCONR5_HICP0                    (*((volatile unsigned int*)(0x422A2210UL)))
#define bM4_TMRA1_CCONR5_HICP1                    (*((volatile unsigned int*)(0x422A2214UL)))
#define bM4_TMRA1_CCONR5_HICP2                    (*((volatile unsigned int*)(0x422A2218UL)))
#define bM4_TMRA1_CCONR5_HICP3                    (*((volatile unsigned int*)(0x422A2220UL)))
#define bM4_TMRA1_CCONR5_HICP4                    (*((volatile unsigned int*)(0x422A2224UL)))
#define bM4_TMRA1_CCONR5_NOFIENCP                 (*((volatile unsigned int*)(0x422A2230UL)))
#define bM4_TMRA1_CCONR5_NOFICKCP0                (*((volatile unsigned int*)(0x422A2234UL)))
#define bM4_TMRA1_CCONR5_NOFICKCP1                (*((volatile unsigned int*)(0x422A2238UL)))
#define bM4_TMRA1_CCONR6_CAPMD                    (*((volatile unsigned int*)(0x422A2280UL)))
#define bM4_TMRA1_CCONR6_HICP0                    (*((volatile unsigned int*)(0x422A2290UL)))
#define bM4_TMRA1_CCONR6_HICP1                    (*((volatile unsigned int*)(0x422A2294UL)))
#define bM4_TMRA1_CCONR6_HICP2                    (*((volatile unsigned int*)(0x422A2298UL)))
#define bM4_TMRA1_CCONR6_HICP3                    (*((volatile unsigned int*)(0x422A22A0UL)))
#define bM4_TMRA1_CCONR6_HICP4                    (*((volatile unsigned int*)(0x422A22A4UL)))
#define bM4_TMRA1_CCONR6_NOFIENCP                 (*((volatile unsigned int*)(0x422A22B0UL)))
#define bM4_TMRA1_CCONR6_NOFICKCP0                (*((volatile unsigned int*)(0x422A22B4UL)))
#define bM4_TMRA1_CCONR6_NOFICKCP1                (*((volatile unsigned int*)(0x422A22B8UL)))
#define bM4_TMRA1_CCONR7_CAPMD                    (*((volatile unsigned int*)(0x422A2300UL)))
#define bM4_TMRA1_CCONR7_HICP0                    (*((volatile unsigned int*)(0x422A2310UL)))
#define bM4_TMRA1_CCONR7_HICP1                    (*((volatile unsigned int*)(0x422A2314UL)))
#define bM4_TMRA1_CCONR7_HICP2                    (*((volatile unsigned int*)(0x422A2318UL)))
#define bM4_TMRA1_CCONR7_HICP3                    (*((volatile unsigned int*)(0x422A2320UL)))
#define bM4_TMRA1_CCONR7_HICP4                    (*((volatile unsigned int*)(0x422A2324UL)))
#define bM4_TMRA1_CCONR7_NOFIENCP                 (*((volatile unsigned int*)(0x422A2330UL)))
#define bM4_TMRA1_CCONR7_NOFICKCP0                (*((volatile unsigned int*)(0x422A2334UL)))
#define bM4_TMRA1_CCONR7_NOFICKCP1                (*((volatile unsigned int*)(0x422A2338UL)))
#define bM4_TMRA1_CCONR8_CAPMD                    (*((volatile unsigned int*)(0x422A2380UL)))
#define bM4_TMRA1_CCONR8_HICP0                    (*((volatile unsigned int*)(0x422A2390UL)))
#define bM4_TMRA1_CCONR8_HICP1                    (*((volatile unsigned int*)(0x422A2394UL)))
#define bM4_TMRA1_CCONR8_HICP2                    (*((volatile unsigned int*)(0x422A2398UL)))
#define bM4_TMRA1_CCONR8_HICP3                    (*((volatile unsigned int*)(0x422A23A0UL)))
#define bM4_TMRA1_CCONR8_HICP4                    (*((volatile unsigned int*)(0x422A23A4UL)))
#define bM4_TMRA1_CCONR8_NOFIENCP                 (*((volatile unsigned int*)(0x422A23B0UL)))
#define bM4_TMRA1_CCONR8_NOFICKCP0                (*((volatile unsigned int*)(0x422A23B4UL)))
#define bM4_TMRA1_CCONR8_NOFICKCP1                (*((volatile unsigned int*)(0x422A23B8UL)))
#define bM4_TMRA1_PCONR1_STAC0                    (*((volatile unsigned int*)(0x422A2800UL)))
#define bM4_TMRA1_PCONR1_STAC1                    (*((volatile unsigned int*)(0x422A2804UL)))
#define bM4_TMRA1_PCONR1_STPC0                    (*((volatile unsigned int*)(0x422A2808UL)))
#define bM4_TMRA1_PCONR1_STPC1                    (*((volatile unsigned int*)(0x422A280CUL)))
#define bM4_TMRA1_PCONR1_CMPC0                    (*((volatile unsigned int*)(0x422A2810UL)))
#define bM4_TMRA1_PCONR1_CMPC1                    (*((volatile unsigned int*)(0x422A2814UL)))
#define bM4_TMRA1_PCONR1_PERC0                    (*((volatile unsigned int*)(0x422A2818UL)))
#define bM4_TMRA1_PCONR1_PERC1                    (*((volatile unsigned int*)(0x422A281CUL)))
#define bM4_TMRA1_PCONR1_FORC0                    (*((volatile unsigned int*)(0x422A2820UL)))
#define bM4_TMRA1_PCONR1_FORC1                    (*((volatile unsigned int*)(0x422A2824UL)))
#define bM4_TMRA1_PCONR1_OUTEN                    (*((volatile unsigned int*)(0x422A2830UL)))
#define bM4_TMRA1_PCONR2_STAC0                    (*((volatile unsigned int*)(0x422A2880UL)))
#define bM4_TMRA1_PCONR2_STAC1                    (*((volatile unsigned int*)(0x422A2884UL)))
#define bM4_TMRA1_PCONR2_STPC0                    (*((volatile unsigned int*)(0x422A2888UL)))
#define bM4_TMRA1_PCONR2_STPC1                    (*((volatile unsigned int*)(0x422A288CUL)))
#define bM4_TMRA1_PCONR2_CMPC0                    (*((volatile unsigned int*)(0x422A2890UL)))
#define bM4_TMRA1_PCONR2_CMPC1                    (*((volatile unsigned int*)(0x422A2894UL)))
#define bM4_TMRA1_PCONR2_PERC0                    (*((volatile unsigned int*)(0x422A2898UL)))
#define bM4_TMRA1_PCONR2_PERC1                    (*((volatile unsigned int*)(0x422A289CUL)))
#define bM4_TMRA1_PCONR2_FORC0                    (*((volatile unsigned int*)(0x422A28A0UL)))
#define bM4_TMRA1_PCONR2_FORC1                    (*((volatile unsigned int*)(0x422A28A4UL)))
#define bM4_TMRA1_PCONR2_OUTEN                    (*((volatile unsigned int*)(0x422A28B0UL)))
#define bM4_TMRA1_PCONR3_STAC0                    (*((volatile unsigned int*)(0x422A2900UL)))
#define bM4_TMRA1_PCONR3_STAC1                    (*((volatile unsigned int*)(0x422A2904UL)))
#define bM4_TMRA1_PCONR3_STPC0                    (*((volatile unsigned int*)(0x422A2908UL)))
#define bM4_TMRA1_PCONR3_STPC1                    (*((volatile unsigned int*)(0x422A290CUL)))
#define bM4_TMRA1_PCONR3_CMPC0                    (*((volatile unsigned int*)(0x422A2910UL)))
#define bM4_TMRA1_PCONR3_CMPC1                    (*((volatile unsigned int*)(0x422A2914UL)))
#define bM4_TMRA1_PCONR3_PERC0                    (*((volatile unsigned int*)(0x422A2918UL)))
#define bM4_TMRA1_PCONR3_PERC1                    (*((volatile unsigned int*)(0x422A291CUL)))
#define bM4_TMRA1_PCONR3_FORC0                    (*((volatile unsigned int*)(0x422A2920UL)))
#define bM4_TMRA1_PCONR3_FORC1                    (*((volatile unsigned int*)(0x422A2924UL)))
#define bM4_TMRA1_PCONR3_OUTEN                    (*((volatile unsigned int*)(0x422A2930UL)))
#define bM4_TMRA1_PCONR4_STAC0                    (*((volatile unsigned int*)(0x422A2980UL)))
#define bM4_TMRA1_PCONR4_STAC1                    (*((volatile unsigned int*)(0x422A2984UL)))
#define bM4_TMRA1_PCONR4_STPC0                    (*((volatile unsigned int*)(0x422A2988UL)))
#define bM4_TMRA1_PCONR4_STPC1                    (*((volatile unsigned int*)(0x422A298CUL)))
#define bM4_TMRA1_PCONR4_CMPC0                    (*((volatile unsigned int*)(0x422A2990UL)))
#define bM4_TMRA1_PCONR4_CMPC1                    (*((volatile unsigned int*)(0x422A2994UL)))
#define bM4_TMRA1_PCONR4_PERC0                    (*((volatile unsigned int*)(0x422A2998UL)))
#define bM4_TMRA1_PCONR4_PERC1                    (*((volatile unsigned int*)(0x422A299CUL)))
#define bM4_TMRA1_PCONR4_FORC0                    (*((volatile unsigned int*)(0x422A29A0UL)))
#define bM4_TMRA1_PCONR4_FORC1                    (*((volatile unsigned int*)(0x422A29A4UL)))
#define bM4_TMRA1_PCONR4_OUTEN                    (*((volatile unsigned int*)(0x422A29B0UL)))
#define bM4_TMRA1_PCONR5_STAC0                    (*((volatile unsigned int*)(0x422A2A00UL)))
#define bM4_TMRA1_PCONR5_STAC1                    (*((volatile unsigned int*)(0x422A2A04UL)))
#define bM4_TMRA1_PCONR5_STPC0                    (*((volatile unsigned int*)(0x422A2A08UL)))
#define bM4_TMRA1_PCONR5_STPC1                    (*((volatile unsigned int*)(0x422A2A0CUL)))
#define bM4_TMRA1_PCONR5_CMPC0                    (*((volatile unsigned int*)(0x422A2A10UL)))
#define bM4_TMRA1_PCONR5_CMPC1                    (*((volatile unsigned int*)(0x422A2A14UL)))
#define bM4_TMRA1_PCONR5_PERC0                    (*((volatile unsigned int*)(0x422A2A18UL)))
#define bM4_TMRA1_PCONR5_PERC1                    (*((volatile unsigned int*)(0x422A2A1CUL)))
#define bM4_TMRA1_PCONR5_FORC0                    (*((volatile unsigned int*)(0x422A2A20UL)))
#define bM4_TMRA1_PCONR5_FORC1                    (*((volatile unsigned int*)(0x422A2A24UL)))
#define bM4_TMRA1_PCONR5_OUTEN                    (*((volatile unsigned int*)(0x422A2A30UL)))
#define bM4_TMRA1_PCONR6_STAC0                    (*((volatile unsigned int*)(0x422A2A80UL)))
#define bM4_TMRA1_PCONR6_STAC1                    (*((volatile unsigned int*)(0x422A2A84UL)))
#define bM4_TMRA1_PCONR6_STPC0                    (*((volatile unsigned int*)(0x422A2A88UL)))
#define bM4_TMRA1_PCONR6_STPC1                    (*((volatile unsigned int*)(0x422A2A8CUL)))
#define bM4_TMRA1_PCONR6_CMPC0                    (*((volatile unsigned int*)(0x422A2A90UL)))
#define bM4_TMRA1_PCONR6_CMPC1                    (*((volatile unsigned int*)(0x422A2A94UL)))
#define bM4_TMRA1_PCONR6_PERC0                    (*((volatile unsigned int*)(0x422A2A98UL)))
#define bM4_TMRA1_PCONR6_PERC1                    (*((volatile unsigned int*)(0x422A2A9CUL)))
#define bM4_TMRA1_PCONR6_FORC0                    (*((volatile unsigned int*)(0x422A2AA0UL)))
#define bM4_TMRA1_PCONR6_FORC1                    (*((volatile unsigned int*)(0x422A2AA4UL)))
#define bM4_TMRA1_PCONR6_OUTEN                    (*((volatile unsigned int*)(0x422A2AB0UL)))
#define bM4_TMRA1_PCONR7_STAC0                    (*((volatile unsigned int*)(0x422A2B00UL)))
#define bM4_TMRA1_PCONR7_STAC1                    (*((volatile unsigned int*)(0x422A2B04UL)))
#define bM4_TMRA1_PCONR7_STPC0                    (*((volatile unsigned int*)(0x422A2B08UL)))
#define bM4_TMRA1_PCONR7_STPC1                    (*((volatile unsigned int*)(0x422A2B0CUL)))
#define bM4_TMRA1_PCONR7_CMPC0                    (*((volatile unsigned int*)(0x422A2B10UL)))
#define bM4_TMRA1_PCONR7_CMPC1                    (*((volatile unsigned int*)(0x422A2B14UL)))
#define bM4_TMRA1_PCONR7_PERC0                    (*((volatile unsigned int*)(0x422A2B18UL)))
#define bM4_TMRA1_PCONR7_PERC1                    (*((volatile unsigned int*)(0x422A2B1CUL)))
#define bM4_TMRA1_PCONR7_FORC0                    (*((volatile unsigned int*)(0x422A2B20UL)))
#define bM4_TMRA1_PCONR7_FORC1                    (*((volatile unsigned int*)(0x422A2B24UL)))
#define bM4_TMRA1_PCONR7_OUTEN                    (*((volatile unsigned int*)(0x422A2B30UL)))
#define bM4_TMRA1_PCONR8_STAC0                    (*((volatile unsigned int*)(0x422A2B80UL)))
#define bM4_TMRA1_PCONR8_STAC1                    (*((volatile unsigned int*)(0x422A2B84UL)))
#define bM4_TMRA1_PCONR8_STPC0                    (*((volatile unsigned int*)(0x422A2B88UL)))
#define bM4_TMRA1_PCONR8_STPC1                    (*((volatile unsigned int*)(0x422A2B8CUL)))
#define bM4_TMRA1_PCONR8_CMPC0                    (*((volatile unsigned int*)(0x422A2B90UL)))
#define bM4_TMRA1_PCONR8_CMPC1                    (*((volatile unsigned int*)(0x422A2B94UL)))
#define bM4_TMRA1_PCONR8_PERC0                    (*((volatile unsigned int*)(0x422A2B98UL)))
#define bM4_TMRA1_PCONR8_PERC1                    (*((volatile unsigned int*)(0x422A2B9CUL)))
#define bM4_TMRA1_PCONR8_FORC0                    (*((volatile unsigned int*)(0x422A2BA0UL)))
#define bM4_TMRA1_PCONR8_FORC1                    (*((volatile unsigned int*)(0x422A2BA4UL)))
#define bM4_TMRA1_PCONR8_OUTEN                    (*((volatile unsigned int*)(0x422A2BB0UL)))
#define bM4_TMRA2_CNTER_CNT0                      (*((volatile unsigned int*)(0x422A8000UL)))
#define bM4_TMRA2_CNTER_CNT1                      (*((volatile unsigned int*)(0x422A8004UL)))
#define bM4_TMRA2_CNTER_CNT2                      (*((volatile unsigned int*)(0x422A8008UL)))
#define bM4_TMRA2_CNTER_CNT3                      (*((volatile unsigned int*)(0x422A800CUL)))
#define bM4_TMRA2_CNTER_CNT4                      (*((volatile unsigned int*)(0x422A8010UL)))
#define bM4_TMRA2_CNTER_CNT5                      (*((volatile unsigned int*)(0x422A8014UL)))
#define bM4_TMRA2_CNTER_CNT6                      (*((volatile unsigned int*)(0x422A8018UL)))
#define bM4_TMRA2_CNTER_CNT7                      (*((volatile unsigned int*)(0x422A801CUL)))
#define bM4_TMRA2_CNTER_CNT8                      (*((volatile unsigned int*)(0x422A8020UL)))
#define bM4_TMRA2_CNTER_CNT9                      (*((volatile unsigned int*)(0x422A8024UL)))
#define bM4_TMRA2_CNTER_CNT10                     (*((volatile unsigned int*)(0x422A8028UL)))
#define bM4_TMRA2_CNTER_CNT11                     (*((volatile unsigned int*)(0x422A802CUL)))
#define bM4_TMRA2_CNTER_CNT12                     (*((volatile unsigned int*)(0x422A8030UL)))
#define bM4_TMRA2_CNTER_CNT13                     (*((volatile unsigned int*)(0x422A8034UL)))
#define bM4_TMRA2_CNTER_CNT14                     (*((volatile unsigned int*)(0x422A8038UL)))
#define bM4_TMRA2_CNTER_CNT15                     (*((volatile unsigned int*)(0x422A803CUL)))
#define bM4_TMRA2_PERAR_PER0                      (*((volatile unsigned int*)(0x422A8080UL)))
#define bM4_TMRA2_PERAR_PER1                      (*((volatile unsigned int*)(0x422A8084UL)))
#define bM4_TMRA2_PERAR_PER2                      (*((volatile unsigned int*)(0x422A8088UL)))
#define bM4_TMRA2_PERAR_PER3                      (*((volatile unsigned int*)(0x422A808CUL)))
#define bM4_TMRA2_PERAR_PER4                      (*((volatile unsigned int*)(0x422A8090UL)))
#define bM4_TMRA2_PERAR_PER5                      (*((volatile unsigned int*)(0x422A8094UL)))
#define bM4_TMRA2_PERAR_PER6                      (*((volatile unsigned int*)(0x422A8098UL)))
#define bM4_TMRA2_PERAR_PER7                      (*((volatile unsigned int*)(0x422A809CUL)))
#define bM4_TMRA2_PERAR_PER8                      (*((volatile unsigned int*)(0x422A80A0UL)))
#define bM4_TMRA2_PERAR_PER9                      (*((volatile unsigned int*)(0x422A80A4UL)))
#define bM4_TMRA2_PERAR_PER10                     (*((volatile unsigned int*)(0x422A80A8UL)))
#define bM4_TMRA2_PERAR_PER11                     (*((volatile unsigned int*)(0x422A80ACUL)))
#define bM4_TMRA2_PERAR_PER12                     (*((volatile unsigned int*)(0x422A80B0UL)))
#define bM4_TMRA2_PERAR_PER13                     (*((volatile unsigned int*)(0x422A80B4UL)))
#define bM4_TMRA2_PERAR_PER14                     (*((volatile unsigned int*)(0x422A80B8UL)))
#define bM4_TMRA2_PERAR_PER15                     (*((volatile unsigned int*)(0x422A80BCUL)))
#define bM4_TMRA2_CMPAR1_CMP0                     (*((volatile unsigned int*)(0x422A8800UL)))
#define bM4_TMRA2_CMPAR1_CMP1                     (*((volatile unsigned int*)(0x422A8804UL)))
#define bM4_TMRA2_CMPAR1_CMP2                     (*((volatile unsigned int*)(0x422A8808UL)))
#define bM4_TMRA2_CMPAR1_CMP3                     (*((volatile unsigned int*)(0x422A880CUL)))
#define bM4_TMRA2_CMPAR1_CMP4                     (*((volatile unsigned int*)(0x422A8810UL)))
#define bM4_TMRA2_CMPAR1_CMP5                     (*((volatile unsigned int*)(0x422A8814UL)))
#define bM4_TMRA2_CMPAR1_CMP6                     (*((volatile unsigned int*)(0x422A8818UL)))
#define bM4_TMRA2_CMPAR1_CMP7                     (*((volatile unsigned int*)(0x422A881CUL)))
#define bM4_TMRA2_CMPAR1_CMP8                     (*((volatile unsigned int*)(0x422A8820UL)))
#define bM4_TMRA2_CMPAR1_CMP9                     (*((volatile unsigned int*)(0x422A8824UL)))
#define bM4_TMRA2_CMPAR1_CMP10                    (*((volatile unsigned int*)(0x422A8828UL)))
#define bM4_TMRA2_CMPAR1_CMP11                    (*((volatile unsigned int*)(0x422A882CUL)))
#define bM4_TMRA2_CMPAR1_CMP12                    (*((volatile unsigned int*)(0x422A8830UL)))
#define bM4_TMRA2_CMPAR1_CMP13                    (*((volatile unsigned int*)(0x422A8834UL)))
#define bM4_TMRA2_CMPAR1_CMP14                    (*((volatile unsigned int*)(0x422A8838UL)))
#define bM4_TMRA2_CMPAR1_CMP15                    (*((volatile unsigned int*)(0x422A883CUL)))
#define bM4_TMRA2_CMPAR2_CMP0                     (*((volatile unsigned int*)(0x422A8880UL)))
#define bM4_TMRA2_CMPAR2_CMP1                     (*((volatile unsigned int*)(0x422A8884UL)))
#define bM4_TMRA2_CMPAR2_CMP2                     (*((volatile unsigned int*)(0x422A8888UL)))
#define bM4_TMRA2_CMPAR2_CMP3                     (*((volatile unsigned int*)(0x422A888CUL)))
#define bM4_TMRA2_CMPAR2_CMP4                     (*((volatile unsigned int*)(0x422A8890UL)))
#define bM4_TMRA2_CMPAR2_CMP5                     (*((volatile unsigned int*)(0x422A8894UL)))
#define bM4_TMRA2_CMPAR2_CMP6                     (*((volatile unsigned int*)(0x422A8898UL)))
#define bM4_TMRA2_CMPAR2_CMP7                     (*((volatile unsigned int*)(0x422A889CUL)))
#define bM4_TMRA2_CMPAR2_CMP8                     (*((volatile unsigned int*)(0x422A88A0UL)))
#define bM4_TMRA2_CMPAR2_CMP9                     (*((volatile unsigned int*)(0x422A88A4UL)))
#define bM4_TMRA2_CMPAR2_CMP10                    (*((volatile unsigned int*)(0x422A88A8UL)))
#define bM4_TMRA2_CMPAR2_CMP11                    (*((volatile unsigned int*)(0x422A88ACUL)))
#define bM4_TMRA2_CMPAR2_CMP12                    (*((volatile unsigned int*)(0x422A88B0UL)))
#define bM4_TMRA2_CMPAR2_CMP13                    (*((volatile unsigned int*)(0x422A88B4UL)))
#define bM4_TMRA2_CMPAR2_CMP14                    (*((volatile unsigned int*)(0x422A88B8UL)))
#define bM4_TMRA2_CMPAR2_CMP15                    (*((volatile unsigned int*)(0x422A88BCUL)))
#define bM4_TMRA2_CMPAR3_CMP0                     (*((volatile unsigned int*)(0x422A8900UL)))
#define bM4_TMRA2_CMPAR3_CMP1                     (*((volatile unsigned int*)(0x422A8904UL)))
#define bM4_TMRA2_CMPAR3_CMP2                     (*((volatile unsigned int*)(0x422A8908UL)))
#define bM4_TMRA2_CMPAR3_CMP3                     (*((volatile unsigned int*)(0x422A890CUL)))
#define bM4_TMRA2_CMPAR3_CMP4                     (*((volatile unsigned int*)(0x422A8910UL)))
#define bM4_TMRA2_CMPAR3_CMP5                     (*((volatile unsigned int*)(0x422A8914UL)))
#define bM4_TMRA2_CMPAR3_CMP6                     (*((volatile unsigned int*)(0x422A8918UL)))
#define bM4_TMRA2_CMPAR3_CMP7                     (*((volatile unsigned int*)(0x422A891CUL)))
#define bM4_TMRA2_CMPAR3_CMP8                     (*((volatile unsigned int*)(0x422A8920UL)))
#define bM4_TMRA2_CMPAR3_CMP9                     (*((volatile unsigned int*)(0x422A8924UL)))
#define bM4_TMRA2_CMPAR3_CMP10                    (*((volatile unsigned int*)(0x422A8928UL)))
#define bM4_TMRA2_CMPAR3_CMP11                    (*((volatile unsigned int*)(0x422A892CUL)))
#define bM4_TMRA2_CMPAR3_CMP12                    (*((volatile unsigned int*)(0x422A8930UL)))
#define bM4_TMRA2_CMPAR3_CMP13                    (*((volatile unsigned int*)(0x422A8934UL)))
#define bM4_TMRA2_CMPAR3_CMP14                    (*((volatile unsigned int*)(0x422A8938UL)))
#define bM4_TMRA2_CMPAR3_CMP15                    (*((volatile unsigned int*)(0x422A893CUL)))
#define bM4_TMRA2_CMPAR4_CMP0                     (*((volatile unsigned int*)(0x422A8980UL)))
#define bM4_TMRA2_CMPAR4_CMP1                     (*((volatile unsigned int*)(0x422A8984UL)))
#define bM4_TMRA2_CMPAR4_CMP2                     (*((volatile unsigned int*)(0x422A8988UL)))
#define bM4_TMRA2_CMPAR4_CMP3                     (*((volatile unsigned int*)(0x422A898CUL)))
#define bM4_TMRA2_CMPAR4_CMP4                     (*((volatile unsigned int*)(0x422A8990UL)))
#define bM4_TMRA2_CMPAR4_CMP5                     (*((volatile unsigned int*)(0x422A8994UL)))
#define bM4_TMRA2_CMPAR4_CMP6                     (*((volatile unsigned int*)(0x422A8998UL)))
#define bM4_TMRA2_CMPAR4_CMP7                     (*((volatile unsigned int*)(0x422A899CUL)))
#define bM4_TMRA2_CMPAR4_CMP8                     (*((volatile unsigned int*)(0x422A89A0UL)))
#define bM4_TMRA2_CMPAR4_CMP9                     (*((volatile unsigned int*)(0x422A89A4UL)))
#define bM4_TMRA2_CMPAR4_CMP10                    (*((volatile unsigned int*)(0x422A89A8UL)))
#define bM4_TMRA2_CMPAR4_CMP11                    (*((volatile unsigned int*)(0x422A89ACUL)))
#define bM4_TMRA2_CMPAR4_CMP12                    (*((volatile unsigned int*)(0x422A89B0UL)))
#define bM4_TMRA2_CMPAR4_CMP13                    (*((volatile unsigned int*)(0x422A89B4UL)))
#define bM4_TMRA2_CMPAR4_CMP14                    (*((volatile unsigned int*)(0x422A89B8UL)))
#define bM4_TMRA2_CMPAR4_CMP15                    (*((volatile unsigned int*)(0x422A89BCUL)))
#define bM4_TMRA2_CMPAR5_CMP0                     (*((volatile unsigned int*)(0x422A8A00UL)))
#define bM4_TMRA2_CMPAR5_CMP1                     (*((volatile unsigned int*)(0x422A8A04UL)))
#define bM4_TMRA2_CMPAR5_CMP2                     (*((volatile unsigned int*)(0x422A8A08UL)))
#define bM4_TMRA2_CMPAR5_CMP3                     (*((volatile unsigned int*)(0x422A8A0CUL)))
#define bM4_TMRA2_CMPAR5_CMP4                     (*((volatile unsigned int*)(0x422A8A10UL)))
#define bM4_TMRA2_CMPAR5_CMP5                     (*((volatile unsigned int*)(0x422A8A14UL)))
#define bM4_TMRA2_CMPAR5_CMP6                     (*((volatile unsigned int*)(0x422A8A18UL)))
#define bM4_TMRA2_CMPAR5_CMP7                     (*((volatile unsigned int*)(0x422A8A1CUL)))
#define bM4_TMRA2_CMPAR5_CMP8                     (*((volatile unsigned int*)(0x422A8A20UL)))
#define bM4_TMRA2_CMPAR5_CMP9                     (*((volatile unsigned int*)(0x422A8A24UL)))
#define bM4_TMRA2_CMPAR5_CMP10                    (*((volatile unsigned int*)(0x422A8A28UL)))
#define bM4_TMRA2_CMPAR5_CMP11                    (*((volatile unsigned int*)(0x422A8A2CUL)))
#define bM4_TMRA2_CMPAR5_CMP12                    (*((volatile unsigned int*)(0x422A8A30UL)))
#define bM4_TMRA2_CMPAR5_CMP13                    (*((volatile unsigned int*)(0x422A8A34UL)))
#define bM4_TMRA2_CMPAR5_CMP14                    (*((volatile unsigned int*)(0x422A8A38UL)))
#define bM4_TMRA2_CMPAR5_CMP15                    (*((volatile unsigned int*)(0x422A8A3CUL)))
#define bM4_TMRA2_CMPAR6_CMP0                     (*((volatile unsigned int*)(0x422A8A80UL)))
#define bM4_TMRA2_CMPAR6_CMP1                     (*((volatile unsigned int*)(0x422A8A84UL)))
#define bM4_TMRA2_CMPAR6_CMP2                     (*((volatile unsigned int*)(0x422A8A88UL)))
#define bM4_TMRA2_CMPAR6_CMP3                     (*((volatile unsigned int*)(0x422A8A8CUL)))
#define bM4_TMRA2_CMPAR6_CMP4                     (*((volatile unsigned int*)(0x422A8A90UL)))
#define bM4_TMRA2_CMPAR6_CMP5                     (*((volatile unsigned int*)(0x422A8A94UL)))
#define bM4_TMRA2_CMPAR6_CMP6                     (*((volatile unsigned int*)(0x422A8A98UL)))
#define bM4_TMRA2_CMPAR6_CMP7                     (*((volatile unsigned int*)(0x422A8A9CUL)))
#define bM4_TMRA2_CMPAR6_CMP8                     (*((volatile unsigned int*)(0x422A8AA0UL)))
#define bM4_TMRA2_CMPAR6_CMP9                     (*((volatile unsigned int*)(0x422A8AA4UL)))
#define bM4_TMRA2_CMPAR6_CMP10                    (*((volatile unsigned int*)(0x422A8AA8UL)))
#define bM4_TMRA2_CMPAR6_CMP11                    (*((volatile unsigned int*)(0x422A8AACUL)))
#define bM4_TMRA2_CMPAR6_CMP12                    (*((volatile unsigned int*)(0x422A8AB0UL)))
#define bM4_TMRA2_CMPAR6_CMP13                    (*((volatile unsigned int*)(0x422A8AB4UL)))
#define bM4_TMRA2_CMPAR6_CMP14                    (*((volatile unsigned int*)(0x422A8AB8UL)))
#define bM4_TMRA2_CMPAR6_CMP15                    (*((volatile unsigned int*)(0x422A8ABCUL)))
#define bM4_TMRA2_CMPAR7_CMP0                     (*((volatile unsigned int*)(0x422A8B00UL)))
#define bM4_TMRA2_CMPAR7_CMP1                     (*((volatile unsigned int*)(0x422A8B04UL)))
#define bM4_TMRA2_CMPAR7_CMP2                     (*((volatile unsigned int*)(0x422A8B08UL)))
#define bM4_TMRA2_CMPAR7_CMP3                     (*((volatile unsigned int*)(0x422A8B0CUL)))
#define bM4_TMRA2_CMPAR7_CMP4                     (*((volatile unsigned int*)(0x422A8B10UL)))
#define bM4_TMRA2_CMPAR7_CMP5                     (*((volatile unsigned int*)(0x422A8B14UL)))
#define bM4_TMRA2_CMPAR7_CMP6                     (*((volatile unsigned int*)(0x422A8B18UL)))
#define bM4_TMRA2_CMPAR7_CMP7                     (*((volatile unsigned int*)(0x422A8B1CUL)))
#define bM4_TMRA2_CMPAR7_CMP8                     (*((volatile unsigned int*)(0x422A8B20UL)))
#define bM4_TMRA2_CMPAR7_CMP9                     (*((volatile unsigned int*)(0x422A8B24UL)))
#define bM4_TMRA2_CMPAR7_CMP10                    (*((volatile unsigned int*)(0x422A8B28UL)))
#define bM4_TMRA2_CMPAR7_CMP11                    (*((volatile unsigned int*)(0x422A8B2CUL)))
#define bM4_TMRA2_CMPAR7_CMP12                    (*((volatile unsigned int*)(0x422A8B30UL)))
#define bM4_TMRA2_CMPAR7_CMP13                    (*((volatile unsigned int*)(0x422A8B34UL)))
#define bM4_TMRA2_CMPAR7_CMP14                    (*((volatile unsigned int*)(0x422A8B38UL)))
#define bM4_TMRA2_CMPAR7_CMP15                    (*((volatile unsigned int*)(0x422A8B3CUL)))
#define bM4_TMRA2_CMPAR8_CMP0                     (*((volatile unsigned int*)(0x422A8B80UL)))
#define bM4_TMRA2_CMPAR8_CMP1                     (*((volatile unsigned int*)(0x422A8B84UL)))
#define bM4_TMRA2_CMPAR8_CMP2                     (*((volatile unsigned int*)(0x422A8B88UL)))
#define bM4_TMRA2_CMPAR8_CMP3                     (*((volatile unsigned int*)(0x422A8B8CUL)))
#define bM4_TMRA2_CMPAR8_CMP4                     (*((volatile unsigned int*)(0x422A8B90UL)))
#define bM4_TMRA2_CMPAR8_CMP5                     (*((volatile unsigned int*)(0x422A8B94UL)))
#define bM4_TMRA2_CMPAR8_CMP6                     (*((volatile unsigned int*)(0x422A8B98UL)))
#define bM4_TMRA2_CMPAR8_CMP7                     (*((volatile unsigned int*)(0x422A8B9CUL)))
#define bM4_TMRA2_CMPAR8_CMP8                     (*((volatile unsigned int*)(0x422A8BA0UL)))
#define bM4_TMRA2_CMPAR8_CMP9                     (*((volatile unsigned int*)(0x422A8BA4UL)))
#define bM4_TMRA2_CMPAR8_CMP10                    (*((volatile unsigned int*)(0x422A8BA8UL)))
#define bM4_TMRA2_CMPAR8_CMP11                    (*((volatile unsigned int*)(0x422A8BACUL)))
#define bM4_TMRA2_CMPAR8_CMP12                    (*((volatile unsigned int*)(0x422A8BB0UL)))
#define bM4_TMRA2_CMPAR8_CMP13                    (*((volatile unsigned int*)(0x422A8BB4UL)))
#define bM4_TMRA2_CMPAR8_CMP14                    (*((volatile unsigned int*)(0x422A8BB8UL)))
#define bM4_TMRA2_CMPAR8_CMP15                    (*((volatile unsigned int*)(0x422A8BBCUL)))
#define bM4_TMRA2_BCSTR_START                     (*((volatile unsigned int*)(0x422A9000UL)))
#define bM4_TMRA2_BCSTR_DIR                       (*((volatile unsigned int*)(0x422A9004UL)))
#define bM4_TMRA2_BCSTR_MODE                      (*((volatile unsigned int*)(0x422A9008UL)))
#define bM4_TMRA2_BCSTR_SYNST                     (*((volatile unsigned int*)(0x422A900CUL)))
#define bM4_TMRA2_BCSTR_CKDIV0                    (*((volatile unsigned int*)(0x422A9010UL)))
#define bM4_TMRA2_BCSTR_CKDIV1                    (*((volatile unsigned int*)(0x422A9014UL)))
#define bM4_TMRA2_BCSTR_CKDIV2                    (*((volatile unsigned int*)(0x422A9018UL)))
#define bM4_TMRA2_BCSTR_CKDIV3                    (*((volatile unsigned int*)(0x422A901CUL)))
#define bM4_TMRA2_BCSTR_ITENOVF                   (*((volatile unsigned int*)(0x422A9030UL)))
#define bM4_TMRA2_BCSTR_ITENUDF                   (*((volatile unsigned int*)(0x422A9034UL)))
#define bM4_TMRA2_BCSTR_OVFF                      (*((volatile unsigned int*)(0x422A9038UL)))
#define bM4_TMRA2_BCSTR_UDFF                      (*((volatile unsigned int*)(0x422A903CUL)))
#define bM4_TMRA2_HCONR_HSTA0                     (*((volatile unsigned int*)(0x422A9080UL)))
#define bM4_TMRA2_HCONR_HSTA1                     (*((volatile unsigned int*)(0x422A9084UL)))
#define bM4_TMRA2_HCONR_HSTA2                     (*((volatile unsigned int*)(0x422A9088UL)))
#define bM4_TMRA2_HCONR_HSTP0                     (*((volatile unsigned int*)(0x422A9090UL)))
#define bM4_TMRA2_HCONR_HSTP1                     (*((volatile unsigned int*)(0x422A9094UL)))
#define bM4_TMRA2_HCONR_HSTP2                     (*((volatile unsigned int*)(0x422A9098UL)))
#define bM4_TMRA2_HCONR_HCLE0                     (*((volatile unsigned int*)(0x422A90A0UL)))
#define bM4_TMRA2_HCONR_HCLE1                     (*((volatile unsigned int*)(0x422A90A4UL)))
#define bM4_TMRA2_HCONR_HCLE2                     (*((volatile unsigned int*)(0x422A90A8UL)))
#define bM4_TMRA2_HCONR_HCLE3                     (*((volatile unsigned int*)(0x422A90B0UL)))
#define bM4_TMRA2_HCONR_HCLE4                     (*((volatile unsigned int*)(0x422A90B4UL)))
#define bM4_TMRA2_HCONR_HCLE5                     (*((volatile unsigned int*)(0x422A90B8UL)))
#define bM4_TMRA2_HCONR_HCLE6                     (*((volatile unsigned int*)(0x422A90BCUL)))
#define bM4_TMRA2_HCUPR_HCUP0                     (*((volatile unsigned int*)(0x422A9100UL)))
#define bM4_TMRA2_HCUPR_HCUP1                     (*((volatile unsigned int*)(0x422A9104UL)))
#define bM4_TMRA2_HCUPR_HCUP2                     (*((volatile unsigned int*)(0x422A9108UL)))
#define bM4_TMRA2_HCUPR_HCUP3                     (*((volatile unsigned int*)(0x422A910CUL)))
#define bM4_TMRA2_HCUPR_HCUP4                     (*((volatile unsigned int*)(0x422A9110UL)))
#define bM4_TMRA2_HCUPR_HCUP5                     (*((volatile unsigned int*)(0x422A9114UL)))
#define bM4_TMRA2_HCUPR_HCUP6                     (*((volatile unsigned int*)(0x422A9118UL)))
#define bM4_TMRA2_HCUPR_HCUP7                     (*((volatile unsigned int*)(0x422A911CUL)))
#define bM4_TMRA2_HCUPR_HCUP8                     (*((volatile unsigned int*)(0x422A9120UL)))
#define bM4_TMRA2_HCUPR_HCUP9                     (*((volatile unsigned int*)(0x422A9124UL)))
#define bM4_TMRA2_HCUPR_HCUP10                    (*((volatile unsigned int*)(0x422A9128UL)))
#define bM4_TMRA2_HCUPR_HCUP11                    (*((volatile unsigned int*)(0x422A912CUL)))
#define bM4_TMRA2_HCUPR_HCUP12                    (*((volatile unsigned int*)(0x422A9130UL)))
#define bM4_TMRA2_HCDOR_HCDO0                     (*((volatile unsigned int*)(0x422A9180UL)))
#define bM4_TMRA2_HCDOR_HCDO1                     (*((volatile unsigned int*)(0x422A9184UL)))
#define bM4_TMRA2_HCDOR_HCDO2                     (*((volatile unsigned int*)(0x422A9188UL)))
#define bM4_TMRA2_HCDOR_HCDO3                     (*((volatile unsigned int*)(0x422A918CUL)))
#define bM4_TMRA2_HCDOR_HCDO4                     (*((volatile unsigned int*)(0x422A9190UL)))
#define bM4_TMRA2_HCDOR_HCDO5                     (*((volatile unsigned int*)(0x422A9194UL)))
#define bM4_TMRA2_HCDOR_HCDO6                     (*((volatile unsigned int*)(0x422A9198UL)))
#define bM4_TMRA2_HCDOR_HCDO7                     (*((volatile unsigned int*)(0x422A919CUL)))
#define bM4_TMRA2_HCDOR_HCDO8                     (*((volatile unsigned int*)(0x422A91A0UL)))
#define bM4_TMRA2_HCDOR_HCDO9                     (*((volatile unsigned int*)(0x422A91A4UL)))
#define bM4_TMRA2_HCDOR_HCDO10                    (*((volatile unsigned int*)(0x422A91A8UL)))
#define bM4_TMRA2_HCDOR_HCDO11                    (*((volatile unsigned int*)(0x422A91ACUL)))
#define bM4_TMRA2_HCDOR_HCDO12                    (*((volatile unsigned int*)(0x422A91B0UL)))
#define bM4_TMRA2_ICONR_ITEN1                     (*((volatile unsigned int*)(0x422A9200UL)))
#define bM4_TMRA2_ICONR_ITEN2                     (*((volatile unsigned int*)(0x422A9204UL)))
#define bM4_TMRA2_ICONR_ITEN3                     (*((volatile unsigned int*)(0x422A9208UL)))
#define bM4_TMRA2_ICONR_ITEN4                     (*((volatile unsigned int*)(0x422A920CUL)))
#define bM4_TMRA2_ICONR_ITEN5                     (*((volatile unsigned int*)(0x422A9210UL)))
#define bM4_TMRA2_ICONR_ITEN6                     (*((volatile unsigned int*)(0x422A9214UL)))
#define bM4_TMRA2_ICONR_ITEN7                     (*((volatile unsigned int*)(0x422A9218UL)))
#define bM4_TMRA2_ICONR_ITEN8                     (*((volatile unsigned int*)(0x422A921CUL)))
#define bM4_TMRA2_ECONR_ETEN1                     (*((volatile unsigned int*)(0x422A9280UL)))
#define bM4_TMRA2_ECONR_ETEN2                     (*((volatile unsigned int*)(0x422A9284UL)))
#define bM4_TMRA2_ECONR_ETEN3                     (*((volatile unsigned int*)(0x422A9288UL)))
#define bM4_TMRA2_ECONR_ETEN4                     (*((volatile unsigned int*)(0x422A928CUL)))
#define bM4_TMRA2_ECONR_ETEN5                     (*((volatile unsigned int*)(0x422A9290UL)))
#define bM4_TMRA2_ECONR_ETEN6                     (*((volatile unsigned int*)(0x422A9294UL)))
#define bM4_TMRA2_ECONR_ETEN7                     (*((volatile unsigned int*)(0x422A9298UL)))
#define bM4_TMRA2_ECONR_ETEN8                     (*((volatile unsigned int*)(0x422A929CUL)))
#define bM4_TMRA2_FCONR_NOFIENTG                  (*((volatile unsigned int*)(0x422A9300UL)))
#define bM4_TMRA2_FCONR_NOFICKTG0                 (*((volatile unsigned int*)(0x422A9304UL)))
#define bM4_TMRA2_FCONR_NOFICKTG1                 (*((volatile unsigned int*)(0x422A9308UL)))
#define bM4_TMRA2_FCONR_NOFIENCA                  (*((volatile unsigned int*)(0x422A9320UL)))
#define bM4_TMRA2_FCONR_NOFICKCA0                 (*((volatile unsigned int*)(0x422A9324UL)))
#define bM4_TMRA2_FCONR_NOFICKCA1                 (*((volatile unsigned int*)(0x422A9328UL)))
#define bM4_TMRA2_FCONR_NOFIENCB                  (*((volatile unsigned int*)(0x422A9330UL)))
#define bM4_TMRA2_FCONR_NOFICKCB0                 (*((volatile unsigned int*)(0x422A9334UL)))
#define bM4_TMRA2_FCONR_NOFICKCB1                 (*((volatile unsigned int*)(0x422A9338UL)))
#define bM4_TMRA2_STFLR_CMPF1                     (*((volatile unsigned int*)(0x422A9380UL)))
#define bM4_TMRA2_STFLR_CMPF2                     (*((volatile unsigned int*)(0x422A9384UL)))
#define bM4_TMRA2_STFLR_CMPF3                     (*((volatile unsigned int*)(0x422A9388UL)))
#define bM4_TMRA2_STFLR_CMPF4                     (*((volatile unsigned int*)(0x422A938CUL)))
#define bM4_TMRA2_STFLR_CMPF5                     (*((volatile unsigned int*)(0x422A9390UL)))
#define bM4_TMRA2_STFLR_CMPF6                     (*((volatile unsigned int*)(0x422A9394UL)))
#define bM4_TMRA2_STFLR_CMPF7                     (*((volatile unsigned int*)(0x422A9398UL)))
#define bM4_TMRA2_STFLR_CMPF8                     (*((volatile unsigned int*)(0x422A939CUL)))
#define bM4_TMRA2_BCONR1_BEN                      (*((volatile unsigned int*)(0x422A9800UL)))
#define bM4_TMRA2_BCONR1_BSE0                     (*((volatile unsigned int*)(0x422A9804UL)))
#define bM4_TMRA2_BCONR1_BSE1                     (*((volatile unsigned int*)(0x422A9808UL)))
#define bM4_TMRA2_BCONR2_BEN                      (*((volatile unsigned int*)(0x422A9900UL)))
#define bM4_TMRA2_BCONR2_BSE0                     (*((volatile unsigned int*)(0x422A9904UL)))
#define bM4_TMRA2_BCONR2_BSE1                     (*((volatile unsigned int*)(0x422A9908UL)))
#define bM4_TMRA2_BCONR3_BEN                      (*((volatile unsigned int*)(0x422A9A00UL)))
#define bM4_TMRA2_BCONR3_BSE0                     (*((volatile unsigned int*)(0x422A9A04UL)))
#define bM4_TMRA2_BCONR3_BSE1                     (*((volatile unsigned int*)(0x422A9A08UL)))
#define bM4_TMRA2_BCONR4_BEN                      (*((volatile unsigned int*)(0x422A9B00UL)))
#define bM4_TMRA2_BCONR4_BSE0                     (*((volatile unsigned int*)(0x422A9B04UL)))
#define bM4_TMRA2_BCONR4_BSE1                     (*((volatile unsigned int*)(0x422A9B08UL)))
#define bM4_TMRA2_CCONR1_CAPMD                    (*((volatile unsigned int*)(0x422AA000UL)))
#define bM4_TMRA2_CCONR1_HICP0                    (*((volatile unsigned int*)(0x422AA010UL)))
#define bM4_TMRA2_CCONR1_HICP1                    (*((volatile unsigned int*)(0x422AA014UL)))
#define bM4_TMRA2_CCONR1_HICP2                    (*((volatile unsigned int*)(0x422AA018UL)))
#define bM4_TMRA2_CCONR1_HICP3                    (*((volatile unsigned int*)(0x422AA020UL)))
#define bM4_TMRA2_CCONR1_HICP4                    (*((volatile unsigned int*)(0x422AA024UL)))
#define bM4_TMRA2_CCONR1_NOFIENCP                 (*((volatile unsigned int*)(0x422AA030UL)))
#define bM4_TMRA2_CCONR1_NOFICKCP0                (*((volatile unsigned int*)(0x422AA034UL)))
#define bM4_TMRA2_CCONR1_NOFICKCP1                (*((volatile unsigned int*)(0x422AA038UL)))
#define bM4_TMRA2_CCONR2_CAPMD                    (*((volatile unsigned int*)(0x422AA080UL)))
#define bM4_TMRA2_CCONR2_HICP0                    (*((volatile unsigned int*)(0x422AA090UL)))
#define bM4_TMRA2_CCONR2_HICP1                    (*((volatile unsigned int*)(0x422AA094UL)))
#define bM4_TMRA2_CCONR2_HICP2                    (*((volatile unsigned int*)(0x422AA098UL)))
#define bM4_TMRA2_CCONR2_HICP3                    (*((volatile unsigned int*)(0x422AA0A0UL)))
#define bM4_TMRA2_CCONR2_HICP4                    (*((volatile unsigned int*)(0x422AA0A4UL)))
#define bM4_TMRA2_CCONR2_NOFIENCP                 (*((volatile unsigned int*)(0x422AA0B0UL)))
#define bM4_TMRA2_CCONR2_NOFICKCP0                (*((volatile unsigned int*)(0x422AA0B4UL)))
#define bM4_TMRA2_CCONR2_NOFICKCP1                (*((volatile unsigned int*)(0x422AA0B8UL)))
#define bM4_TMRA2_CCONR3_CAPMD                    (*((volatile unsigned int*)(0x422AA100UL)))
#define bM4_TMRA2_CCONR3_HICP0                    (*((volatile unsigned int*)(0x422AA110UL)))
#define bM4_TMRA2_CCONR3_HICP1                    (*((volatile unsigned int*)(0x422AA114UL)))
#define bM4_TMRA2_CCONR3_HICP2                    (*((volatile unsigned int*)(0x422AA118UL)))
#define bM4_TMRA2_CCONR3_HICP3                    (*((volatile unsigned int*)(0x422AA120UL)))
#define bM4_TMRA2_CCONR3_HICP4                    (*((volatile unsigned int*)(0x422AA124UL)))
#define bM4_TMRA2_CCONR3_NOFIENCP                 (*((volatile unsigned int*)(0x422AA130UL)))
#define bM4_TMRA2_CCONR3_NOFICKCP0                (*((volatile unsigned int*)(0x422AA134UL)))
#define bM4_TMRA2_CCONR3_NOFICKCP1                (*((volatile unsigned int*)(0x422AA138UL)))
#define bM4_TMRA2_CCONR4_CAPMD                    (*((volatile unsigned int*)(0x422AA180UL)))
#define bM4_TMRA2_CCONR4_HICP0                    (*((volatile unsigned int*)(0x422AA190UL)))
#define bM4_TMRA2_CCONR4_HICP1                    (*((volatile unsigned int*)(0x422AA194UL)))
#define bM4_TMRA2_CCONR4_HICP2                    (*((volatile unsigned int*)(0x422AA198UL)))
#define bM4_TMRA2_CCONR4_HICP3                    (*((volatile unsigned int*)(0x422AA1A0UL)))
#define bM4_TMRA2_CCONR4_HICP4                    (*((volatile unsigned int*)(0x422AA1A4UL)))
#define bM4_TMRA2_CCONR4_NOFIENCP                 (*((volatile unsigned int*)(0x422AA1B0UL)))
#define bM4_TMRA2_CCONR4_NOFICKCP0                (*((volatile unsigned int*)(0x422AA1B4UL)))
#define bM4_TMRA2_CCONR4_NOFICKCP1                (*((volatile unsigned int*)(0x422AA1B8UL)))
#define bM4_TMRA2_CCONR5_CAPMD                    (*((volatile unsigned int*)(0x422AA200UL)))
#define bM4_TMRA2_CCONR5_HICP0                    (*((volatile unsigned int*)(0x422AA210UL)))
#define bM4_TMRA2_CCONR5_HICP1                    (*((volatile unsigned int*)(0x422AA214UL)))
#define bM4_TMRA2_CCONR5_HICP2                    (*((volatile unsigned int*)(0x422AA218UL)))
#define bM4_TMRA2_CCONR5_HICP3                    (*((volatile unsigned int*)(0x422AA220UL)))
#define bM4_TMRA2_CCONR5_HICP4                    (*((volatile unsigned int*)(0x422AA224UL)))
#define bM4_TMRA2_CCONR5_NOFIENCP                 (*((volatile unsigned int*)(0x422AA230UL)))
#define bM4_TMRA2_CCONR5_NOFICKCP0                (*((volatile unsigned int*)(0x422AA234UL)))
#define bM4_TMRA2_CCONR5_NOFICKCP1                (*((volatile unsigned int*)(0x422AA238UL)))
#define bM4_TMRA2_CCONR6_CAPMD                    (*((volatile unsigned int*)(0x422AA280UL)))
#define bM4_TMRA2_CCONR6_HICP0                    (*((volatile unsigned int*)(0x422AA290UL)))
#define bM4_TMRA2_CCONR6_HICP1                    (*((volatile unsigned int*)(0x422AA294UL)))
#define bM4_TMRA2_CCONR6_HICP2                    (*((volatile unsigned int*)(0x422AA298UL)))
#define bM4_TMRA2_CCONR6_HICP3                    (*((volatile unsigned int*)(0x422AA2A0UL)))
#define bM4_TMRA2_CCONR6_HICP4                    (*((volatile unsigned int*)(0x422AA2A4UL)))
#define bM4_TMRA2_CCONR6_NOFIENCP                 (*((volatile unsigned int*)(0x422AA2B0UL)))
#define bM4_TMRA2_CCONR6_NOFICKCP0                (*((volatile unsigned int*)(0x422AA2B4UL)))
#define bM4_TMRA2_CCONR6_NOFICKCP1                (*((volatile unsigned int*)(0x422AA2B8UL)))
#define bM4_TMRA2_CCONR7_CAPMD                    (*((volatile unsigned int*)(0x422AA300UL)))
#define bM4_TMRA2_CCONR7_HICP0                    (*((volatile unsigned int*)(0x422AA310UL)))
#define bM4_TMRA2_CCONR7_HICP1                    (*((volatile unsigned int*)(0x422AA314UL)))
#define bM4_TMRA2_CCONR7_HICP2                    (*((volatile unsigned int*)(0x422AA318UL)))
#define bM4_TMRA2_CCONR7_HICP3                    (*((volatile unsigned int*)(0x422AA320UL)))
#define bM4_TMRA2_CCONR7_HICP4                    (*((volatile unsigned int*)(0x422AA324UL)))
#define bM4_TMRA2_CCONR7_NOFIENCP                 (*((volatile unsigned int*)(0x422AA330UL)))
#define bM4_TMRA2_CCONR7_NOFICKCP0                (*((volatile unsigned int*)(0x422AA334UL)))
#define bM4_TMRA2_CCONR7_NOFICKCP1                (*((volatile unsigned int*)(0x422AA338UL)))
#define bM4_TMRA2_CCONR8_CAPMD                    (*((volatile unsigned int*)(0x422AA380UL)))
#define bM4_TMRA2_CCONR8_HICP0                    (*((volatile unsigned int*)(0x422AA390UL)))
#define bM4_TMRA2_CCONR8_HICP1                    (*((volatile unsigned int*)(0x422AA394UL)))
#define bM4_TMRA2_CCONR8_HICP2                    (*((volatile unsigned int*)(0x422AA398UL)))
#define bM4_TMRA2_CCONR8_HICP3                    (*((volatile unsigned int*)(0x422AA3A0UL)))
#define bM4_TMRA2_CCONR8_HICP4                    (*((volatile unsigned int*)(0x422AA3A4UL)))
#define bM4_TMRA2_CCONR8_NOFIENCP                 (*((volatile unsigned int*)(0x422AA3B0UL)))
#define bM4_TMRA2_CCONR8_NOFICKCP0                (*((volatile unsigned int*)(0x422AA3B4UL)))
#define bM4_TMRA2_CCONR8_NOFICKCP1                (*((volatile unsigned int*)(0x422AA3B8UL)))
#define bM4_TMRA2_PCONR1_STAC0                    (*((volatile unsigned int*)(0x422AA800UL)))
#define bM4_TMRA2_PCONR1_STAC1                    (*((volatile unsigned int*)(0x422AA804UL)))
#define bM4_TMRA2_PCONR1_STPC0                    (*((volatile unsigned int*)(0x422AA808UL)))
#define bM4_TMRA2_PCONR1_STPC1                    (*((volatile unsigned int*)(0x422AA80CUL)))
#define bM4_TMRA2_PCONR1_CMPC0                    (*((volatile unsigned int*)(0x422AA810UL)))
#define bM4_TMRA2_PCONR1_CMPC1                    (*((volatile unsigned int*)(0x422AA814UL)))
#define bM4_TMRA2_PCONR1_PERC0                    (*((volatile unsigned int*)(0x422AA818UL)))
#define bM4_TMRA2_PCONR1_PERC1                    (*((volatile unsigned int*)(0x422AA81CUL)))
#define bM4_TMRA2_PCONR1_FORC0                    (*((volatile unsigned int*)(0x422AA820UL)))
#define bM4_TMRA2_PCONR1_FORC1                    (*((volatile unsigned int*)(0x422AA824UL)))
#define bM4_TMRA2_PCONR1_OUTEN                    (*((volatile unsigned int*)(0x422AA830UL)))
#define bM4_TMRA2_PCONR2_STAC0                    (*((volatile unsigned int*)(0x422AA880UL)))
#define bM4_TMRA2_PCONR2_STAC1                    (*((volatile unsigned int*)(0x422AA884UL)))
#define bM4_TMRA2_PCONR2_STPC0                    (*((volatile unsigned int*)(0x422AA888UL)))
#define bM4_TMRA2_PCONR2_STPC1                    (*((volatile unsigned int*)(0x422AA88CUL)))
#define bM4_TMRA2_PCONR2_CMPC0                    (*((volatile unsigned int*)(0x422AA890UL)))
#define bM4_TMRA2_PCONR2_CMPC1                    (*((volatile unsigned int*)(0x422AA894UL)))
#define bM4_TMRA2_PCONR2_PERC0                    (*((volatile unsigned int*)(0x422AA898UL)))
#define bM4_TMRA2_PCONR2_PERC1                    (*((volatile unsigned int*)(0x422AA89CUL)))
#define bM4_TMRA2_PCONR2_FORC0                    (*((volatile unsigned int*)(0x422AA8A0UL)))
#define bM4_TMRA2_PCONR2_FORC1                    (*((volatile unsigned int*)(0x422AA8A4UL)))
#define bM4_TMRA2_PCONR2_OUTEN                    (*((volatile unsigned int*)(0x422AA8B0UL)))
#define bM4_TMRA2_PCONR3_STAC0                    (*((volatile unsigned int*)(0x422AA900UL)))
#define bM4_TMRA2_PCONR3_STAC1                    (*((volatile unsigned int*)(0x422AA904UL)))
#define bM4_TMRA2_PCONR3_STPC0                    (*((volatile unsigned int*)(0x422AA908UL)))
#define bM4_TMRA2_PCONR3_STPC1                    (*((volatile unsigned int*)(0x422AA90CUL)))
#define bM4_TMRA2_PCONR3_CMPC0                    (*((volatile unsigned int*)(0x422AA910UL)))
#define bM4_TMRA2_PCONR3_CMPC1                    (*((volatile unsigned int*)(0x422AA914UL)))
#define bM4_TMRA2_PCONR3_PERC0                    (*((volatile unsigned int*)(0x422AA918UL)))
#define bM4_TMRA2_PCONR3_PERC1                    (*((volatile unsigned int*)(0x422AA91CUL)))
#define bM4_TMRA2_PCONR3_FORC0                    (*((volatile unsigned int*)(0x422AA920UL)))
#define bM4_TMRA2_PCONR3_FORC1                    (*((volatile unsigned int*)(0x422AA924UL)))
#define bM4_TMRA2_PCONR3_OUTEN                    (*((volatile unsigned int*)(0x422AA930UL)))
#define bM4_TMRA2_PCONR4_STAC0                    (*((volatile unsigned int*)(0x422AA980UL)))
#define bM4_TMRA2_PCONR4_STAC1                    (*((volatile unsigned int*)(0x422AA984UL)))
#define bM4_TMRA2_PCONR4_STPC0                    (*((volatile unsigned int*)(0x422AA988UL)))
#define bM4_TMRA2_PCONR4_STPC1                    (*((volatile unsigned int*)(0x422AA98CUL)))
#define bM4_TMRA2_PCONR4_CMPC0                    (*((volatile unsigned int*)(0x422AA990UL)))
#define bM4_TMRA2_PCONR4_CMPC1                    (*((volatile unsigned int*)(0x422AA994UL)))
#define bM4_TMRA2_PCONR4_PERC0                    (*((volatile unsigned int*)(0x422AA998UL)))
#define bM4_TMRA2_PCONR4_PERC1                    (*((volatile unsigned int*)(0x422AA99CUL)))
#define bM4_TMRA2_PCONR4_FORC0                    (*((volatile unsigned int*)(0x422AA9A0UL)))
#define bM4_TMRA2_PCONR4_FORC1                    (*((volatile unsigned int*)(0x422AA9A4UL)))
#define bM4_TMRA2_PCONR4_OUTEN                    (*((volatile unsigned int*)(0x422AA9B0UL)))
#define bM4_TMRA2_PCONR5_STAC0                    (*((volatile unsigned int*)(0x422AAA00UL)))
#define bM4_TMRA2_PCONR5_STAC1                    (*((volatile unsigned int*)(0x422AAA04UL)))
#define bM4_TMRA2_PCONR5_STPC0                    (*((volatile unsigned int*)(0x422AAA08UL)))
#define bM4_TMRA2_PCONR5_STPC1                    (*((volatile unsigned int*)(0x422AAA0CUL)))
#define bM4_TMRA2_PCONR5_CMPC0                    (*((volatile unsigned int*)(0x422AAA10UL)))
#define bM4_TMRA2_PCONR5_CMPC1                    (*((volatile unsigned int*)(0x422AAA14UL)))
#define bM4_TMRA2_PCONR5_PERC0                    (*((volatile unsigned int*)(0x422AAA18UL)))
#define bM4_TMRA2_PCONR5_PERC1                    (*((volatile unsigned int*)(0x422AAA1CUL)))
#define bM4_TMRA2_PCONR5_FORC0                    (*((volatile unsigned int*)(0x422AAA20UL)))
#define bM4_TMRA2_PCONR5_FORC1                    (*((volatile unsigned int*)(0x422AAA24UL)))
#define bM4_TMRA2_PCONR5_OUTEN                    (*((volatile unsigned int*)(0x422AAA30UL)))
#define bM4_TMRA2_PCONR6_STAC0                    (*((volatile unsigned int*)(0x422AAA80UL)))
#define bM4_TMRA2_PCONR6_STAC1                    (*((volatile unsigned int*)(0x422AAA84UL)))
#define bM4_TMRA2_PCONR6_STPC0                    (*((volatile unsigned int*)(0x422AAA88UL)))
#define bM4_TMRA2_PCONR6_STPC1                    (*((volatile unsigned int*)(0x422AAA8CUL)))
#define bM4_TMRA2_PCONR6_CMPC0                    (*((volatile unsigned int*)(0x422AAA90UL)))
#define bM4_TMRA2_PCONR6_CMPC1                    (*((volatile unsigned int*)(0x422AAA94UL)))
#define bM4_TMRA2_PCONR6_PERC0                    (*((volatile unsigned int*)(0x422AAA98UL)))
#define bM4_TMRA2_PCONR6_PERC1                    (*((volatile unsigned int*)(0x422AAA9CUL)))
#define bM4_TMRA2_PCONR6_FORC0                    (*((volatile unsigned int*)(0x422AAAA0UL)))
#define bM4_TMRA2_PCONR6_FORC1                    (*((volatile unsigned int*)(0x422AAAA4UL)))
#define bM4_TMRA2_PCONR6_OUTEN                    (*((volatile unsigned int*)(0x422AAAB0UL)))
#define bM4_TMRA2_PCONR7_STAC0                    (*((volatile unsigned int*)(0x422AAB00UL)))
#define bM4_TMRA2_PCONR7_STAC1                    (*((volatile unsigned int*)(0x422AAB04UL)))
#define bM4_TMRA2_PCONR7_STPC0                    (*((volatile unsigned int*)(0x422AAB08UL)))
#define bM4_TMRA2_PCONR7_STPC1                    (*((volatile unsigned int*)(0x422AAB0CUL)))
#define bM4_TMRA2_PCONR7_CMPC0                    (*((volatile unsigned int*)(0x422AAB10UL)))
#define bM4_TMRA2_PCONR7_CMPC1                    (*((volatile unsigned int*)(0x422AAB14UL)))
#define bM4_TMRA2_PCONR7_PERC0                    (*((volatile unsigned int*)(0x422AAB18UL)))
#define bM4_TMRA2_PCONR7_PERC1                    (*((volatile unsigned int*)(0x422AAB1CUL)))
#define bM4_TMRA2_PCONR7_FORC0                    (*((volatile unsigned int*)(0x422AAB20UL)))
#define bM4_TMRA2_PCONR7_FORC1                    (*((volatile unsigned int*)(0x422AAB24UL)))
#define bM4_TMRA2_PCONR7_OUTEN                    (*((volatile unsigned int*)(0x422AAB30UL)))
#define bM4_TMRA2_PCONR8_STAC0                    (*((volatile unsigned int*)(0x422AAB80UL)))
#define bM4_TMRA2_PCONR8_STAC1                    (*((volatile unsigned int*)(0x422AAB84UL)))
#define bM4_TMRA2_PCONR8_STPC0                    (*((volatile unsigned int*)(0x422AAB88UL)))
#define bM4_TMRA2_PCONR8_STPC1                    (*((volatile unsigned int*)(0x422AAB8CUL)))
#define bM4_TMRA2_PCONR8_CMPC0                    (*((volatile unsigned int*)(0x422AAB90UL)))
#define bM4_TMRA2_PCONR8_CMPC1                    (*((volatile unsigned int*)(0x422AAB94UL)))
#define bM4_TMRA2_PCONR8_PERC0                    (*((volatile unsigned int*)(0x422AAB98UL)))
#define bM4_TMRA2_PCONR8_PERC1                    (*((volatile unsigned int*)(0x422AAB9CUL)))
#define bM4_TMRA2_PCONR8_FORC0                    (*((volatile unsigned int*)(0x422AABA0UL)))
#define bM4_TMRA2_PCONR8_FORC1                    (*((volatile unsigned int*)(0x422AABA4UL)))
#define bM4_TMRA2_PCONR8_OUTEN                    (*((volatile unsigned int*)(0x422AABB0UL)))
#define bM4_TMRA3_CNTER_CNT0                      (*((volatile unsigned int*)(0x422B0000UL)))
#define bM4_TMRA3_CNTER_CNT1                      (*((volatile unsigned int*)(0x422B0004UL)))
#define bM4_TMRA3_CNTER_CNT2                      (*((volatile unsigned int*)(0x422B0008UL)))
#define bM4_TMRA3_CNTER_CNT3                      (*((volatile unsigned int*)(0x422B000CUL)))
#define bM4_TMRA3_CNTER_CNT4                      (*((volatile unsigned int*)(0x422B0010UL)))
#define bM4_TMRA3_CNTER_CNT5                      (*((volatile unsigned int*)(0x422B0014UL)))
#define bM4_TMRA3_CNTER_CNT6                      (*((volatile unsigned int*)(0x422B0018UL)))
#define bM4_TMRA3_CNTER_CNT7                      (*((volatile unsigned int*)(0x422B001CUL)))
#define bM4_TMRA3_CNTER_CNT8                      (*((volatile unsigned int*)(0x422B0020UL)))
#define bM4_TMRA3_CNTER_CNT9                      (*((volatile unsigned int*)(0x422B0024UL)))
#define bM4_TMRA3_CNTER_CNT10                     (*((volatile unsigned int*)(0x422B0028UL)))
#define bM4_TMRA3_CNTER_CNT11                     (*((volatile unsigned int*)(0x422B002CUL)))
#define bM4_TMRA3_CNTER_CNT12                     (*((volatile unsigned int*)(0x422B0030UL)))
#define bM4_TMRA3_CNTER_CNT13                     (*((volatile unsigned int*)(0x422B0034UL)))
#define bM4_TMRA3_CNTER_CNT14                     (*((volatile unsigned int*)(0x422B0038UL)))
#define bM4_TMRA3_CNTER_CNT15                     (*((volatile unsigned int*)(0x422B003CUL)))
#define bM4_TMRA3_PERAR_PER0                      (*((volatile unsigned int*)(0x422B0080UL)))
#define bM4_TMRA3_PERAR_PER1                      (*((volatile unsigned int*)(0x422B0084UL)))
#define bM4_TMRA3_PERAR_PER2                      (*((volatile unsigned int*)(0x422B0088UL)))
#define bM4_TMRA3_PERAR_PER3                      (*((volatile unsigned int*)(0x422B008CUL)))
#define bM4_TMRA3_PERAR_PER4                      (*((volatile unsigned int*)(0x422B0090UL)))
#define bM4_TMRA3_PERAR_PER5                      (*((volatile unsigned int*)(0x422B0094UL)))
#define bM4_TMRA3_PERAR_PER6                      (*((volatile unsigned int*)(0x422B0098UL)))
#define bM4_TMRA3_PERAR_PER7                      (*((volatile unsigned int*)(0x422B009CUL)))
#define bM4_TMRA3_PERAR_PER8                      (*((volatile unsigned int*)(0x422B00A0UL)))
#define bM4_TMRA3_PERAR_PER9                      (*((volatile unsigned int*)(0x422B00A4UL)))
#define bM4_TMRA3_PERAR_PER10                     (*((volatile unsigned int*)(0x422B00A8UL)))
#define bM4_TMRA3_PERAR_PER11                     (*((volatile unsigned int*)(0x422B00ACUL)))
#define bM4_TMRA3_PERAR_PER12                     (*((volatile unsigned int*)(0x422B00B0UL)))
#define bM4_TMRA3_PERAR_PER13                     (*((volatile unsigned int*)(0x422B00B4UL)))
#define bM4_TMRA3_PERAR_PER14                     (*((volatile unsigned int*)(0x422B00B8UL)))
#define bM4_TMRA3_PERAR_PER15                     (*((volatile unsigned int*)(0x422B00BCUL)))
#define bM4_TMRA3_CMPAR1_CMP0                     (*((volatile unsigned int*)(0x422B0800UL)))
#define bM4_TMRA3_CMPAR1_CMP1                     (*((volatile unsigned int*)(0x422B0804UL)))
#define bM4_TMRA3_CMPAR1_CMP2                     (*((volatile unsigned int*)(0x422B0808UL)))
#define bM4_TMRA3_CMPAR1_CMP3                     (*((volatile unsigned int*)(0x422B080CUL)))
#define bM4_TMRA3_CMPAR1_CMP4                     (*((volatile unsigned int*)(0x422B0810UL)))
#define bM4_TMRA3_CMPAR1_CMP5                     (*((volatile unsigned int*)(0x422B0814UL)))
#define bM4_TMRA3_CMPAR1_CMP6                     (*((volatile unsigned int*)(0x422B0818UL)))
#define bM4_TMRA3_CMPAR1_CMP7                     (*((volatile unsigned int*)(0x422B081CUL)))
#define bM4_TMRA3_CMPAR1_CMP8                     (*((volatile unsigned int*)(0x422B0820UL)))
#define bM4_TMRA3_CMPAR1_CMP9                     (*((volatile unsigned int*)(0x422B0824UL)))
#define bM4_TMRA3_CMPAR1_CMP10                    (*((volatile unsigned int*)(0x422B0828UL)))
#define bM4_TMRA3_CMPAR1_CMP11                    (*((volatile unsigned int*)(0x422B082CUL)))
#define bM4_TMRA3_CMPAR1_CMP12                    (*((volatile unsigned int*)(0x422B0830UL)))
#define bM4_TMRA3_CMPAR1_CMP13                    (*((volatile unsigned int*)(0x422B0834UL)))
#define bM4_TMRA3_CMPAR1_CMP14                    (*((volatile unsigned int*)(0x422B0838UL)))
#define bM4_TMRA3_CMPAR1_CMP15                    (*((volatile unsigned int*)(0x422B083CUL)))
#define bM4_TMRA3_CMPAR2_CMP0                     (*((volatile unsigned int*)(0x422B0880UL)))
#define bM4_TMRA3_CMPAR2_CMP1                     (*((volatile unsigned int*)(0x422B0884UL)))
#define bM4_TMRA3_CMPAR2_CMP2                     (*((volatile unsigned int*)(0x422B0888UL)))
#define bM4_TMRA3_CMPAR2_CMP3                     (*((volatile unsigned int*)(0x422B088CUL)))
#define bM4_TMRA3_CMPAR2_CMP4                     (*((volatile unsigned int*)(0x422B0890UL)))
#define bM4_TMRA3_CMPAR2_CMP5                     (*((volatile unsigned int*)(0x422B0894UL)))
#define bM4_TMRA3_CMPAR2_CMP6                     (*((volatile unsigned int*)(0x422B0898UL)))
#define bM4_TMRA3_CMPAR2_CMP7                     (*((volatile unsigned int*)(0x422B089CUL)))
#define bM4_TMRA3_CMPAR2_CMP8                     (*((volatile unsigned int*)(0x422B08A0UL)))
#define bM4_TMRA3_CMPAR2_CMP9                     (*((volatile unsigned int*)(0x422B08A4UL)))
#define bM4_TMRA3_CMPAR2_CMP10                    (*((volatile unsigned int*)(0x422B08A8UL)))
#define bM4_TMRA3_CMPAR2_CMP11                    (*((volatile unsigned int*)(0x422B08ACUL)))
#define bM4_TMRA3_CMPAR2_CMP12                    (*((volatile unsigned int*)(0x422B08B0UL)))
#define bM4_TMRA3_CMPAR2_CMP13                    (*((volatile unsigned int*)(0x422B08B4UL)))
#define bM4_TMRA3_CMPAR2_CMP14                    (*((volatile unsigned int*)(0x422B08B8UL)))
#define bM4_TMRA3_CMPAR2_CMP15                    (*((volatile unsigned int*)(0x422B08BCUL)))
#define bM4_TMRA3_CMPAR3_CMP0                     (*((volatile unsigned int*)(0x422B0900UL)))
#define bM4_TMRA3_CMPAR3_CMP1                     (*((volatile unsigned int*)(0x422B0904UL)))
#define bM4_TMRA3_CMPAR3_CMP2                     (*((volatile unsigned int*)(0x422B0908UL)))
#define bM4_TMRA3_CMPAR3_CMP3                     (*((volatile unsigned int*)(0x422B090CUL)))
#define bM4_TMRA3_CMPAR3_CMP4                     (*((volatile unsigned int*)(0x422B0910UL)))
#define bM4_TMRA3_CMPAR3_CMP5                     (*((volatile unsigned int*)(0x422B0914UL)))
#define bM4_TMRA3_CMPAR3_CMP6                     (*((volatile unsigned int*)(0x422B0918UL)))
#define bM4_TMRA3_CMPAR3_CMP7                     (*((volatile unsigned int*)(0x422B091CUL)))
#define bM4_TMRA3_CMPAR3_CMP8                     (*((volatile unsigned int*)(0x422B0920UL)))
#define bM4_TMRA3_CMPAR3_CMP9                     (*((volatile unsigned int*)(0x422B0924UL)))
#define bM4_TMRA3_CMPAR3_CMP10                    (*((volatile unsigned int*)(0x422B0928UL)))
#define bM4_TMRA3_CMPAR3_CMP11                    (*((volatile unsigned int*)(0x422B092CUL)))
#define bM4_TMRA3_CMPAR3_CMP12                    (*((volatile unsigned int*)(0x422B0930UL)))
#define bM4_TMRA3_CMPAR3_CMP13                    (*((volatile unsigned int*)(0x422B0934UL)))
#define bM4_TMRA3_CMPAR3_CMP14                    (*((volatile unsigned int*)(0x422B0938UL)))
#define bM4_TMRA3_CMPAR3_CMP15                    (*((volatile unsigned int*)(0x422B093CUL)))
#define bM4_TMRA3_CMPAR4_CMP0                     (*((volatile unsigned int*)(0x422B0980UL)))
#define bM4_TMRA3_CMPAR4_CMP1                     (*((volatile unsigned int*)(0x422B0984UL)))
#define bM4_TMRA3_CMPAR4_CMP2                     (*((volatile unsigned int*)(0x422B0988UL)))
#define bM4_TMRA3_CMPAR4_CMP3                     (*((volatile unsigned int*)(0x422B098CUL)))
#define bM4_TMRA3_CMPAR4_CMP4                     (*((volatile unsigned int*)(0x422B0990UL)))
#define bM4_TMRA3_CMPAR4_CMP5                     (*((volatile unsigned int*)(0x422B0994UL)))
#define bM4_TMRA3_CMPAR4_CMP6                     (*((volatile unsigned int*)(0x422B0998UL)))
#define bM4_TMRA3_CMPAR4_CMP7                     (*((volatile unsigned int*)(0x422B099CUL)))
#define bM4_TMRA3_CMPAR4_CMP8                     (*((volatile unsigned int*)(0x422B09A0UL)))
#define bM4_TMRA3_CMPAR4_CMP9                     (*((volatile unsigned int*)(0x422B09A4UL)))
#define bM4_TMRA3_CMPAR4_CMP10                    (*((volatile unsigned int*)(0x422B09A8UL)))
#define bM4_TMRA3_CMPAR4_CMP11                    (*((volatile unsigned int*)(0x422B09ACUL)))
#define bM4_TMRA3_CMPAR4_CMP12                    (*((volatile unsigned int*)(0x422B09B0UL)))
#define bM4_TMRA3_CMPAR4_CMP13                    (*((volatile unsigned int*)(0x422B09B4UL)))
#define bM4_TMRA3_CMPAR4_CMP14                    (*((volatile unsigned int*)(0x422B09B8UL)))
#define bM4_TMRA3_CMPAR4_CMP15                    (*((volatile unsigned int*)(0x422B09BCUL)))
#define bM4_TMRA3_CMPAR5_CMP0                     (*((volatile unsigned int*)(0x422B0A00UL)))
#define bM4_TMRA3_CMPAR5_CMP1                     (*((volatile unsigned int*)(0x422B0A04UL)))
#define bM4_TMRA3_CMPAR5_CMP2                     (*((volatile unsigned int*)(0x422B0A08UL)))
#define bM4_TMRA3_CMPAR5_CMP3                     (*((volatile unsigned int*)(0x422B0A0CUL)))
#define bM4_TMRA3_CMPAR5_CMP4                     (*((volatile unsigned int*)(0x422B0A10UL)))
#define bM4_TMRA3_CMPAR5_CMP5                     (*((volatile unsigned int*)(0x422B0A14UL)))
#define bM4_TMRA3_CMPAR5_CMP6                     (*((volatile unsigned int*)(0x422B0A18UL)))
#define bM4_TMRA3_CMPAR5_CMP7                     (*((volatile unsigned int*)(0x422B0A1CUL)))
#define bM4_TMRA3_CMPAR5_CMP8                     (*((volatile unsigned int*)(0x422B0A20UL)))
#define bM4_TMRA3_CMPAR5_CMP9                     (*((volatile unsigned int*)(0x422B0A24UL)))
#define bM4_TMRA3_CMPAR5_CMP10                    (*((volatile unsigned int*)(0x422B0A28UL)))
#define bM4_TMRA3_CMPAR5_CMP11                    (*((volatile unsigned int*)(0x422B0A2CUL)))
#define bM4_TMRA3_CMPAR5_CMP12                    (*((volatile unsigned int*)(0x422B0A30UL)))
#define bM4_TMRA3_CMPAR5_CMP13                    (*((volatile unsigned int*)(0x422B0A34UL)))
#define bM4_TMRA3_CMPAR5_CMP14                    (*((volatile unsigned int*)(0x422B0A38UL)))
#define bM4_TMRA3_CMPAR5_CMP15                    (*((volatile unsigned int*)(0x422B0A3CUL)))
#define bM4_TMRA3_CMPAR6_CMP0                     (*((volatile unsigned int*)(0x422B0A80UL)))
#define bM4_TMRA3_CMPAR6_CMP1                     (*((volatile unsigned int*)(0x422B0A84UL)))
#define bM4_TMRA3_CMPAR6_CMP2                     (*((volatile unsigned int*)(0x422B0A88UL)))
#define bM4_TMRA3_CMPAR6_CMP3                     (*((volatile unsigned int*)(0x422B0A8CUL)))
#define bM4_TMRA3_CMPAR6_CMP4                     (*((volatile unsigned int*)(0x422B0A90UL)))
#define bM4_TMRA3_CMPAR6_CMP5                     (*((volatile unsigned int*)(0x422B0A94UL)))
#define bM4_TMRA3_CMPAR6_CMP6                     (*((volatile unsigned int*)(0x422B0A98UL)))
#define bM4_TMRA3_CMPAR6_CMP7                     (*((volatile unsigned int*)(0x422B0A9CUL)))
#define bM4_TMRA3_CMPAR6_CMP8                     (*((volatile unsigned int*)(0x422B0AA0UL)))
#define bM4_TMRA3_CMPAR6_CMP9                     (*((volatile unsigned int*)(0x422B0AA4UL)))
#define bM4_TMRA3_CMPAR6_CMP10                    (*((volatile unsigned int*)(0x422B0AA8UL)))
#define bM4_TMRA3_CMPAR6_CMP11                    (*((volatile unsigned int*)(0x422B0AACUL)))
#define bM4_TMRA3_CMPAR6_CMP12                    (*((volatile unsigned int*)(0x422B0AB0UL)))
#define bM4_TMRA3_CMPAR6_CMP13                    (*((volatile unsigned int*)(0x422B0AB4UL)))
#define bM4_TMRA3_CMPAR6_CMP14                    (*((volatile unsigned int*)(0x422B0AB8UL)))
#define bM4_TMRA3_CMPAR6_CMP15                    (*((volatile unsigned int*)(0x422B0ABCUL)))
#define bM4_TMRA3_CMPAR7_CMP0                     (*((volatile unsigned int*)(0x422B0B00UL)))
#define bM4_TMRA3_CMPAR7_CMP1                     (*((volatile unsigned int*)(0x422B0B04UL)))
#define bM4_TMRA3_CMPAR7_CMP2                     (*((volatile unsigned int*)(0x422B0B08UL)))
#define bM4_TMRA3_CMPAR7_CMP3                     (*((volatile unsigned int*)(0x422B0B0CUL)))
#define bM4_TMRA3_CMPAR7_CMP4                     (*((volatile unsigned int*)(0x422B0B10UL)))
#define bM4_TMRA3_CMPAR7_CMP5                     (*((volatile unsigned int*)(0x422B0B14UL)))
#define bM4_TMRA3_CMPAR7_CMP6                     (*((volatile unsigned int*)(0x422B0B18UL)))
#define bM4_TMRA3_CMPAR7_CMP7                     (*((volatile unsigned int*)(0x422B0B1CUL)))
#define bM4_TMRA3_CMPAR7_CMP8                     (*((volatile unsigned int*)(0x422B0B20UL)))
#define bM4_TMRA3_CMPAR7_CMP9                     (*((volatile unsigned int*)(0x422B0B24UL)))
#define bM4_TMRA3_CMPAR7_CMP10                    (*((volatile unsigned int*)(0x422B0B28UL)))
#define bM4_TMRA3_CMPAR7_CMP11                    (*((volatile unsigned int*)(0x422B0B2CUL)))
#define bM4_TMRA3_CMPAR7_CMP12                    (*((volatile unsigned int*)(0x422B0B30UL)))
#define bM4_TMRA3_CMPAR7_CMP13                    (*((volatile unsigned int*)(0x422B0B34UL)))
#define bM4_TMRA3_CMPAR7_CMP14                    (*((volatile unsigned int*)(0x422B0B38UL)))
#define bM4_TMRA3_CMPAR7_CMP15                    (*((volatile unsigned int*)(0x422B0B3CUL)))
#define bM4_TMRA3_CMPAR8_CMP0                     (*((volatile unsigned int*)(0x422B0B80UL)))
#define bM4_TMRA3_CMPAR8_CMP1                     (*((volatile unsigned int*)(0x422B0B84UL)))
#define bM4_TMRA3_CMPAR8_CMP2                     (*((volatile unsigned int*)(0x422B0B88UL)))
#define bM4_TMRA3_CMPAR8_CMP3                     (*((volatile unsigned int*)(0x422B0B8CUL)))
#define bM4_TMRA3_CMPAR8_CMP4                     (*((volatile unsigned int*)(0x422B0B90UL)))
#define bM4_TMRA3_CMPAR8_CMP5                     (*((volatile unsigned int*)(0x422B0B94UL)))
#define bM4_TMRA3_CMPAR8_CMP6                     (*((volatile unsigned int*)(0x422B0B98UL)))
#define bM4_TMRA3_CMPAR8_CMP7                     (*((volatile unsigned int*)(0x422B0B9CUL)))
#define bM4_TMRA3_CMPAR8_CMP8                     (*((volatile unsigned int*)(0x422B0BA0UL)))
#define bM4_TMRA3_CMPAR8_CMP9                     (*((volatile unsigned int*)(0x422B0BA4UL)))
#define bM4_TMRA3_CMPAR8_CMP10                    (*((volatile unsigned int*)(0x422B0BA8UL)))
#define bM4_TMRA3_CMPAR8_CMP11                    (*((volatile unsigned int*)(0x422B0BACUL)))
#define bM4_TMRA3_CMPAR8_CMP12                    (*((volatile unsigned int*)(0x422B0BB0UL)))
#define bM4_TMRA3_CMPAR8_CMP13                    (*((volatile unsigned int*)(0x422B0BB4UL)))
#define bM4_TMRA3_CMPAR8_CMP14                    (*((volatile unsigned int*)(0x422B0BB8UL)))
#define bM4_TMRA3_CMPAR8_CMP15                    (*((volatile unsigned int*)(0x422B0BBCUL)))
#define bM4_TMRA3_BCSTR_START                     (*((volatile unsigned int*)(0x422B1000UL)))
#define bM4_TMRA3_BCSTR_DIR                       (*((volatile unsigned int*)(0x422B1004UL)))
#define bM4_TMRA3_BCSTR_MODE                      (*((volatile unsigned int*)(0x422B1008UL)))
#define bM4_TMRA3_BCSTR_SYNST                     (*((volatile unsigned int*)(0x422B100CUL)))
#define bM4_TMRA3_BCSTR_CKDIV0                    (*((volatile unsigned int*)(0x422B1010UL)))
#define bM4_TMRA3_BCSTR_CKDIV1                    (*((volatile unsigned int*)(0x422B1014UL)))
#define bM4_TMRA3_BCSTR_CKDIV2                    (*((volatile unsigned int*)(0x422B1018UL)))
#define bM4_TMRA3_BCSTR_CKDIV3                    (*((volatile unsigned int*)(0x422B101CUL)))
#define bM4_TMRA3_BCSTR_ITENOVF                   (*((volatile unsigned int*)(0x422B1030UL)))
#define bM4_TMRA3_BCSTR_ITENUDF                   (*((volatile unsigned int*)(0x422B1034UL)))
#define bM4_TMRA3_BCSTR_OVFF                      (*((volatile unsigned int*)(0x422B1038UL)))
#define bM4_TMRA3_BCSTR_UDFF                      (*((volatile unsigned int*)(0x422B103CUL)))
#define bM4_TMRA3_HCONR_HSTA0                     (*((volatile unsigned int*)(0x422B1080UL)))
#define bM4_TMRA3_HCONR_HSTA1                     (*((volatile unsigned int*)(0x422B1084UL)))
#define bM4_TMRA3_HCONR_HSTA2                     (*((volatile unsigned int*)(0x422B1088UL)))
#define bM4_TMRA3_HCONR_HSTP0                     (*((volatile unsigned int*)(0x422B1090UL)))
#define bM4_TMRA3_HCONR_HSTP1                     (*((volatile unsigned int*)(0x422B1094UL)))
#define bM4_TMRA3_HCONR_HSTP2                     (*((volatile unsigned int*)(0x422B1098UL)))
#define bM4_TMRA3_HCONR_HCLE0                     (*((volatile unsigned int*)(0x422B10A0UL)))
#define bM4_TMRA3_HCONR_HCLE1                     (*((volatile unsigned int*)(0x422B10A4UL)))
#define bM4_TMRA3_HCONR_HCLE2                     (*((volatile unsigned int*)(0x422B10A8UL)))
#define bM4_TMRA3_HCONR_HCLE3                     (*((volatile unsigned int*)(0x422B10B0UL)))
#define bM4_TMRA3_HCONR_HCLE4                     (*((volatile unsigned int*)(0x422B10B4UL)))
#define bM4_TMRA3_HCONR_HCLE5                     (*((volatile unsigned int*)(0x422B10B8UL)))
#define bM4_TMRA3_HCONR_HCLE6                     (*((volatile unsigned int*)(0x422B10BCUL)))
#define bM4_TMRA3_HCUPR_HCUP0                     (*((volatile unsigned int*)(0x422B1100UL)))
#define bM4_TMRA3_HCUPR_HCUP1                     (*((volatile unsigned int*)(0x422B1104UL)))
#define bM4_TMRA3_HCUPR_HCUP2                     (*((volatile unsigned int*)(0x422B1108UL)))
#define bM4_TMRA3_HCUPR_HCUP3                     (*((volatile unsigned int*)(0x422B110CUL)))
#define bM4_TMRA3_HCUPR_HCUP4                     (*((volatile unsigned int*)(0x422B1110UL)))
#define bM4_TMRA3_HCUPR_HCUP5                     (*((volatile unsigned int*)(0x422B1114UL)))
#define bM4_TMRA3_HCUPR_HCUP6                     (*((volatile unsigned int*)(0x422B1118UL)))
#define bM4_TMRA3_HCUPR_HCUP7                     (*((volatile unsigned int*)(0x422B111CUL)))
#define bM4_TMRA3_HCUPR_HCUP8                     (*((volatile unsigned int*)(0x422B1120UL)))
#define bM4_TMRA3_HCUPR_HCUP9                     (*((volatile unsigned int*)(0x422B1124UL)))
#define bM4_TMRA3_HCUPR_HCUP10                    (*((volatile unsigned int*)(0x422B1128UL)))
#define bM4_TMRA3_HCUPR_HCUP11                    (*((volatile unsigned int*)(0x422B112CUL)))
#define bM4_TMRA3_HCUPR_HCUP12                    (*((volatile unsigned int*)(0x422B1130UL)))
#define bM4_TMRA3_HCDOR_HCDO0                     (*((volatile unsigned int*)(0x422B1180UL)))
#define bM4_TMRA3_HCDOR_HCDO1                     (*((volatile unsigned int*)(0x422B1184UL)))
#define bM4_TMRA3_HCDOR_HCDO2                     (*((volatile unsigned int*)(0x422B1188UL)))
#define bM4_TMRA3_HCDOR_HCDO3                     (*((volatile unsigned int*)(0x422B118CUL)))
#define bM4_TMRA3_HCDOR_HCDO4                     (*((volatile unsigned int*)(0x422B1190UL)))
#define bM4_TMRA3_HCDOR_HCDO5                     (*((volatile unsigned int*)(0x422B1194UL)))
#define bM4_TMRA3_HCDOR_HCDO6                     (*((volatile unsigned int*)(0x422B1198UL)))
#define bM4_TMRA3_HCDOR_HCDO7                     (*((volatile unsigned int*)(0x422B119CUL)))
#define bM4_TMRA3_HCDOR_HCDO8                     (*((volatile unsigned int*)(0x422B11A0UL)))
#define bM4_TMRA3_HCDOR_HCDO9                     (*((volatile unsigned int*)(0x422B11A4UL)))
#define bM4_TMRA3_HCDOR_HCDO10                    (*((volatile unsigned int*)(0x422B11A8UL)))
#define bM4_TMRA3_HCDOR_HCDO11                    (*((volatile unsigned int*)(0x422B11ACUL)))
#define bM4_TMRA3_HCDOR_HCDO12                    (*((volatile unsigned int*)(0x422B11B0UL)))
#define bM4_TMRA3_ICONR_ITEN1                     (*((volatile unsigned int*)(0x422B1200UL)))
#define bM4_TMRA3_ICONR_ITEN2                     (*((volatile unsigned int*)(0x422B1204UL)))
#define bM4_TMRA3_ICONR_ITEN3                     (*((volatile unsigned int*)(0x422B1208UL)))
#define bM4_TMRA3_ICONR_ITEN4                     (*((volatile unsigned int*)(0x422B120CUL)))
#define bM4_TMRA3_ICONR_ITEN5                     (*((volatile unsigned int*)(0x422B1210UL)))
#define bM4_TMRA3_ICONR_ITEN6                     (*((volatile unsigned int*)(0x422B1214UL)))
#define bM4_TMRA3_ICONR_ITEN7                     (*((volatile unsigned int*)(0x422B1218UL)))
#define bM4_TMRA3_ICONR_ITEN8                     (*((volatile unsigned int*)(0x422B121CUL)))
#define bM4_TMRA3_ECONR_ETEN1                     (*((volatile unsigned int*)(0x422B1280UL)))
#define bM4_TMRA3_ECONR_ETEN2                     (*((volatile unsigned int*)(0x422B1284UL)))
#define bM4_TMRA3_ECONR_ETEN3                     (*((volatile unsigned int*)(0x422B1288UL)))
#define bM4_TMRA3_ECONR_ETEN4                     (*((volatile unsigned int*)(0x422B128CUL)))
#define bM4_TMRA3_ECONR_ETEN5                     (*((volatile unsigned int*)(0x422B1290UL)))
#define bM4_TMRA3_ECONR_ETEN6                     (*((volatile unsigned int*)(0x422B1294UL)))
#define bM4_TMRA3_ECONR_ETEN7                     (*((volatile unsigned int*)(0x422B1298UL)))
#define bM4_TMRA3_ECONR_ETEN8                     (*((volatile unsigned int*)(0x422B129CUL)))
#define bM4_TMRA3_FCONR_NOFIENTG                  (*((volatile unsigned int*)(0x422B1300UL)))
#define bM4_TMRA3_FCONR_NOFICKTG0                 (*((volatile unsigned int*)(0x422B1304UL)))
#define bM4_TMRA3_FCONR_NOFICKTG1                 (*((volatile unsigned int*)(0x422B1308UL)))
#define bM4_TMRA3_FCONR_NOFIENCA                  (*((volatile unsigned int*)(0x422B1320UL)))
#define bM4_TMRA3_FCONR_NOFICKCA0                 (*((volatile unsigned int*)(0x422B1324UL)))
#define bM4_TMRA3_FCONR_NOFICKCA1                 (*((volatile unsigned int*)(0x422B1328UL)))
#define bM4_TMRA3_FCONR_NOFIENCB                  (*((volatile unsigned int*)(0x422B1330UL)))
#define bM4_TMRA3_FCONR_NOFICKCB0                 (*((volatile unsigned int*)(0x422B1334UL)))
#define bM4_TMRA3_FCONR_NOFICKCB1                 (*((volatile unsigned int*)(0x422B1338UL)))
#define bM4_TMRA3_STFLR_CMPF1                     (*((volatile unsigned int*)(0x422B1380UL)))
#define bM4_TMRA3_STFLR_CMPF2                     (*((volatile unsigned int*)(0x422B1384UL)))
#define bM4_TMRA3_STFLR_CMPF3                     (*((volatile unsigned int*)(0x422B1388UL)))
#define bM4_TMRA3_STFLR_CMPF4                     (*((volatile unsigned int*)(0x422B138CUL)))
#define bM4_TMRA3_STFLR_CMPF5                     (*((volatile unsigned int*)(0x422B1390UL)))
#define bM4_TMRA3_STFLR_CMPF6                     (*((volatile unsigned int*)(0x422B1394UL)))
#define bM4_TMRA3_STFLR_CMPF7                     (*((volatile unsigned int*)(0x422B1398UL)))
#define bM4_TMRA3_STFLR_CMPF8                     (*((volatile unsigned int*)(0x422B139CUL)))
#define bM4_TMRA3_BCONR1_BEN                      (*((volatile unsigned int*)(0x422B1800UL)))
#define bM4_TMRA3_BCONR1_BSE0                     (*((volatile unsigned int*)(0x422B1804UL)))
#define bM4_TMRA3_BCONR1_BSE1                     (*((volatile unsigned int*)(0x422B1808UL)))
#define bM4_TMRA3_BCONR2_BEN                      (*((volatile unsigned int*)(0x422B1900UL)))
#define bM4_TMRA3_BCONR2_BSE0                     (*((volatile unsigned int*)(0x422B1904UL)))
#define bM4_TMRA3_BCONR2_BSE1                     (*((volatile unsigned int*)(0x422B1908UL)))
#define bM4_TMRA3_BCONR3_BEN                      (*((volatile unsigned int*)(0x422B1A00UL)))
#define bM4_TMRA3_BCONR3_BSE0                     (*((volatile unsigned int*)(0x422B1A04UL)))
#define bM4_TMRA3_BCONR3_BSE1                     (*((volatile unsigned int*)(0x422B1A08UL)))
#define bM4_TMRA3_BCONR4_BEN                      (*((volatile unsigned int*)(0x422B1B00UL)))
#define bM4_TMRA3_BCONR4_BSE0                     (*((volatile unsigned int*)(0x422B1B04UL)))
#define bM4_TMRA3_BCONR4_BSE1                     (*((volatile unsigned int*)(0x422B1B08UL)))
#define bM4_TMRA3_CCONR1_CAPMD                    (*((volatile unsigned int*)(0x422B2000UL)))
#define bM4_TMRA3_CCONR1_HICP0                    (*((volatile unsigned int*)(0x422B2010UL)))
#define bM4_TMRA3_CCONR1_HICP1                    (*((volatile unsigned int*)(0x422B2014UL)))
#define bM4_TMRA3_CCONR1_HICP2                    (*((volatile unsigned int*)(0x422B2018UL)))
#define bM4_TMRA3_CCONR1_HICP3                    (*((volatile unsigned int*)(0x422B2020UL)))
#define bM4_TMRA3_CCONR1_HICP4                    (*((volatile unsigned int*)(0x422B2024UL)))
#define bM4_TMRA3_CCONR1_NOFIENCP                 (*((volatile unsigned int*)(0x422B2030UL)))
#define bM4_TMRA3_CCONR1_NOFICKCP0                (*((volatile unsigned int*)(0x422B2034UL)))
#define bM4_TMRA3_CCONR1_NOFICKCP1                (*((volatile unsigned int*)(0x422B2038UL)))
#define bM4_TMRA3_CCONR2_CAPMD                    (*((volatile unsigned int*)(0x422B2080UL)))
#define bM4_TMRA3_CCONR2_HICP0                    (*((volatile unsigned int*)(0x422B2090UL)))
#define bM4_TMRA3_CCONR2_HICP1                    (*((volatile unsigned int*)(0x422B2094UL)))
#define bM4_TMRA3_CCONR2_HICP2                    (*((volatile unsigned int*)(0x422B2098UL)))
#define bM4_TMRA3_CCONR2_HICP3                    (*((volatile unsigned int*)(0x422B20A0UL)))
#define bM4_TMRA3_CCONR2_HICP4                    (*((volatile unsigned int*)(0x422B20A4UL)))
#define bM4_TMRA3_CCONR2_NOFIENCP                 (*((volatile unsigned int*)(0x422B20B0UL)))
#define bM4_TMRA3_CCONR2_NOFICKCP0                (*((volatile unsigned int*)(0x422B20B4UL)))
#define bM4_TMRA3_CCONR2_NOFICKCP1                (*((volatile unsigned int*)(0x422B20B8UL)))
#define bM4_TMRA3_CCONR3_CAPMD                    (*((volatile unsigned int*)(0x422B2100UL)))
#define bM4_TMRA3_CCONR3_HICP0                    (*((volatile unsigned int*)(0x422B2110UL)))
#define bM4_TMRA3_CCONR3_HICP1                    (*((volatile unsigned int*)(0x422B2114UL)))
#define bM4_TMRA3_CCONR3_HICP2                    (*((volatile unsigned int*)(0x422B2118UL)))
#define bM4_TMRA3_CCONR3_HICP3                    (*((volatile unsigned int*)(0x422B2120UL)))
#define bM4_TMRA3_CCONR3_HICP4                    (*((volatile unsigned int*)(0x422B2124UL)))
#define bM4_TMRA3_CCONR3_NOFIENCP                 (*((volatile unsigned int*)(0x422B2130UL)))
#define bM4_TMRA3_CCONR3_NOFICKCP0                (*((volatile unsigned int*)(0x422B2134UL)))
#define bM4_TMRA3_CCONR3_NOFICKCP1                (*((volatile unsigned int*)(0x422B2138UL)))
#define bM4_TMRA3_CCONR4_CAPMD                    (*((volatile unsigned int*)(0x422B2180UL)))
#define bM4_TMRA3_CCONR4_HICP0                    (*((volatile unsigned int*)(0x422B2190UL)))
#define bM4_TMRA3_CCONR4_HICP1                    (*((volatile unsigned int*)(0x422B2194UL)))
#define bM4_TMRA3_CCONR4_HICP2                    (*((volatile unsigned int*)(0x422B2198UL)))
#define bM4_TMRA3_CCONR4_HICP3                    (*((volatile unsigned int*)(0x422B21A0UL)))
#define bM4_TMRA3_CCONR4_HICP4                    (*((volatile unsigned int*)(0x422B21A4UL)))
#define bM4_TMRA3_CCONR4_NOFIENCP                 (*((volatile unsigned int*)(0x422B21B0UL)))
#define bM4_TMRA3_CCONR4_NOFICKCP0                (*((volatile unsigned int*)(0x422B21B4UL)))
#define bM4_TMRA3_CCONR4_NOFICKCP1                (*((volatile unsigned int*)(0x422B21B8UL)))
#define bM4_TMRA3_CCONR5_CAPMD                    (*((volatile unsigned int*)(0x422B2200UL)))
#define bM4_TMRA3_CCONR5_HICP0                    (*((volatile unsigned int*)(0x422B2210UL)))
#define bM4_TMRA3_CCONR5_HICP1                    (*((volatile unsigned int*)(0x422B2214UL)))
#define bM4_TMRA3_CCONR5_HICP2                    (*((volatile unsigned int*)(0x422B2218UL)))
#define bM4_TMRA3_CCONR5_HICP3                    (*((volatile unsigned int*)(0x422B2220UL)))
#define bM4_TMRA3_CCONR5_HICP4                    (*((volatile unsigned int*)(0x422B2224UL)))
#define bM4_TMRA3_CCONR5_NOFIENCP                 (*((volatile unsigned int*)(0x422B2230UL)))
#define bM4_TMRA3_CCONR5_NOFICKCP0                (*((volatile unsigned int*)(0x422B2234UL)))
#define bM4_TMRA3_CCONR5_NOFICKCP1                (*((volatile unsigned int*)(0x422B2238UL)))
#define bM4_TMRA3_CCONR6_CAPMD                    (*((volatile unsigned int*)(0x422B2280UL)))
#define bM4_TMRA3_CCONR6_HICP0                    (*((volatile unsigned int*)(0x422B2290UL)))
#define bM4_TMRA3_CCONR6_HICP1                    (*((volatile unsigned int*)(0x422B2294UL)))
#define bM4_TMRA3_CCONR6_HICP2                    (*((volatile unsigned int*)(0x422B2298UL)))
#define bM4_TMRA3_CCONR6_HICP3                    (*((volatile unsigned int*)(0x422B22A0UL)))
#define bM4_TMRA3_CCONR6_HICP4                    (*((volatile unsigned int*)(0x422B22A4UL)))
#define bM4_TMRA3_CCONR6_NOFIENCP                 (*((volatile unsigned int*)(0x422B22B0UL)))
#define bM4_TMRA3_CCONR6_NOFICKCP0                (*((volatile unsigned int*)(0x422B22B4UL)))
#define bM4_TMRA3_CCONR6_NOFICKCP1                (*((volatile unsigned int*)(0x422B22B8UL)))
#define bM4_TMRA3_CCONR7_CAPMD                    (*((volatile unsigned int*)(0x422B2300UL)))
#define bM4_TMRA3_CCONR7_HICP0                    (*((volatile unsigned int*)(0x422B2310UL)))
#define bM4_TMRA3_CCONR7_HICP1                    (*((volatile unsigned int*)(0x422B2314UL)))
#define bM4_TMRA3_CCONR7_HICP2                    (*((volatile unsigned int*)(0x422B2318UL)))
#define bM4_TMRA3_CCONR7_HICP3                    (*((volatile unsigned int*)(0x422B2320UL)))
#define bM4_TMRA3_CCONR7_HICP4                    (*((volatile unsigned int*)(0x422B2324UL)))
#define bM4_TMRA3_CCONR7_NOFIENCP                 (*((volatile unsigned int*)(0x422B2330UL)))
#define bM4_TMRA3_CCONR7_NOFICKCP0                (*((volatile unsigned int*)(0x422B2334UL)))
#define bM4_TMRA3_CCONR7_NOFICKCP1                (*((volatile unsigned int*)(0x422B2338UL)))
#define bM4_TMRA3_CCONR8_CAPMD                    (*((volatile unsigned int*)(0x422B2380UL)))
#define bM4_TMRA3_CCONR8_HICP0                    (*((volatile unsigned int*)(0x422B2390UL)))
#define bM4_TMRA3_CCONR8_HICP1                    (*((volatile unsigned int*)(0x422B2394UL)))
#define bM4_TMRA3_CCONR8_HICP2                    (*((volatile unsigned int*)(0x422B2398UL)))
#define bM4_TMRA3_CCONR8_HICP3                    (*((volatile unsigned int*)(0x422B23A0UL)))
#define bM4_TMRA3_CCONR8_HICP4                    (*((volatile unsigned int*)(0x422B23A4UL)))
#define bM4_TMRA3_CCONR8_NOFIENCP                 (*((volatile unsigned int*)(0x422B23B0UL)))
#define bM4_TMRA3_CCONR8_NOFICKCP0                (*((volatile unsigned int*)(0x422B23B4UL)))
#define bM4_TMRA3_CCONR8_NOFICKCP1                (*((volatile unsigned int*)(0x422B23B8UL)))
#define bM4_TMRA3_PCONR1_STAC0                    (*((volatile unsigned int*)(0x422B2800UL)))
#define bM4_TMRA3_PCONR1_STAC1                    (*((volatile unsigned int*)(0x422B2804UL)))
#define bM4_TMRA3_PCONR1_STPC0                    (*((volatile unsigned int*)(0x422B2808UL)))
#define bM4_TMRA3_PCONR1_STPC1                    (*((volatile unsigned int*)(0x422B280CUL)))
#define bM4_TMRA3_PCONR1_CMPC0                    (*((volatile unsigned int*)(0x422B2810UL)))
#define bM4_TMRA3_PCONR1_CMPC1                    (*((volatile unsigned int*)(0x422B2814UL)))
#define bM4_TMRA3_PCONR1_PERC0                    (*((volatile unsigned int*)(0x422B2818UL)))
#define bM4_TMRA3_PCONR1_PERC1                    (*((volatile unsigned int*)(0x422B281CUL)))
#define bM4_TMRA3_PCONR1_FORC0                    (*((volatile unsigned int*)(0x422B2820UL)))
#define bM4_TMRA3_PCONR1_FORC1                    (*((volatile unsigned int*)(0x422B2824UL)))
#define bM4_TMRA3_PCONR1_OUTEN                    (*((volatile unsigned int*)(0x422B2830UL)))
#define bM4_TMRA3_PCONR2_STAC0                    (*((volatile unsigned int*)(0x422B2880UL)))
#define bM4_TMRA3_PCONR2_STAC1                    (*((volatile unsigned int*)(0x422B2884UL)))
#define bM4_TMRA3_PCONR2_STPC0                    (*((volatile unsigned int*)(0x422B2888UL)))
#define bM4_TMRA3_PCONR2_STPC1                    (*((volatile unsigned int*)(0x422B288CUL)))
#define bM4_TMRA3_PCONR2_CMPC0                    (*((volatile unsigned int*)(0x422B2890UL)))
#define bM4_TMRA3_PCONR2_CMPC1                    (*((volatile unsigned int*)(0x422B2894UL)))
#define bM4_TMRA3_PCONR2_PERC0                    (*((volatile unsigned int*)(0x422B2898UL)))
#define bM4_TMRA3_PCONR2_PERC1                    (*((volatile unsigned int*)(0x422B289CUL)))
#define bM4_TMRA3_PCONR2_FORC0                    (*((volatile unsigned int*)(0x422B28A0UL)))
#define bM4_TMRA3_PCONR2_FORC1                    (*((volatile unsigned int*)(0x422B28A4UL)))
#define bM4_TMRA3_PCONR2_OUTEN                    (*((volatile unsigned int*)(0x422B28B0UL)))
#define bM4_TMRA3_PCONR3_STAC0                    (*((volatile unsigned int*)(0x422B2900UL)))
#define bM4_TMRA3_PCONR3_STAC1                    (*((volatile unsigned int*)(0x422B2904UL)))
#define bM4_TMRA3_PCONR3_STPC0                    (*((volatile unsigned int*)(0x422B2908UL)))
#define bM4_TMRA3_PCONR3_STPC1                    (*((volatile unsigned int*)(0x422B290CUL)))
#define bM4_TMRA3_PCONR3_CMPC0                    (*((volatile unsigned int*)(0x422B2910UL)))
#define bM4_TMRA3_PCONR3_CMPC1                    (*((volatile unsigned int*)(0x422B2914UL)))
#define bM4_TMRA3_PCONR3_PERC0                    (*((volatile unsigned int*)(0x422B2918UL)))
#define bM4_TMRA3_PCONR3_PERC1                    (*((volatile unsigned int*)(0x422B291CUL)))
#define bM4_TMRA3_PCONR3_FORC0                    (*((volatile unsigned int*)(0x422B2920UL)))
#define bM4_TMRA3_PCONR3_FORC1                    (*((volatile unsigned int*)(0x422B2924UL)))
#define bM4_TMRA3_PCONR3_OUTEN                    (*((volatile unsigned int*)(0x422B2930UL)))
#define bM4_TMRA3_PCONR4_STAC0                    (*((volatile unsigned int*)(0x422B2980UL)))
#define bM4_TMRA3_PCONR4_STAC1                    (*((volatile unsigned int*)(0x422B2984UL)))
#define bM4_TMRA3_PCONR4_STPC0                    (*((volatile unsigned int*)(0x422B2988UL)))
#define bM4_TMRA3_PCONR4_STPC1                    (*((volatile unsigned int*)(0x422B298CUL)))
#define bM4_TMRA3_PCONR4_CMPC0                    (*((volatile unsigned int*)(0x422B2990UL)))
#define bM4_TMRA3_PCONR4_CMPC1                    (*((volatile unsigned int*)(0x422B2994UL)))
#define bM4_TMRA3_PCONR4_PERC0                    (*((volatile unsigned int*)(0x422B2998UL)))
#define bM4_TMRA3_PCONR4_PERC1                    (*((volatile unsigned int*)(0x422B299CUL)))
#define bM4_TMRA3_PCONR4_FORC0                    (*((volatile unsigned int*)(0x422B29A0UL)))
#define bM4_TMRA3_PCONR4_FORC1                    (*((volatile unsigned int*)(0x422B29A4UL)))
#define bM4_TMRA3_PCONR4_OUTEN                    (*((volatile unsigned int*)(0x422B29B0UL)))
#define bM4_TMRA3_PCONR5_STAC0                    (*((volatile unsigned int*)(0x422B2A00UL)))
#define bM4_TMRA3_PCONR5_STAC1                    (*((volatile unsigned int*)(0x422B2A04UL)))
#define bM4_TMRA3_PCONR5_STPC0                    (*((volatile unsigned int*)(0x422B2A08UL)))
#define bM4_TMRA3_PCONR5_STPC1                    (*((volatile unsigned int*)(0x422B2A0CUL)))
#define bM4_TMRA3_PCONR5_CMPC0                    (*((volatile unsigned int*)(0x422B2A10UL)))
#define bM4_TMRA3_PCONR5_CMPC1                    (*((volatile unsigned int*)(0x422B2A14UL)))
#define bM4_TMRA3_PCONR5_PERC0                    (*((volatile unsigned int*)(0x422B2A18UL)))
#define bM4_TMRA3_PCONR5_PERC1                    (*((volatile unsigned int*)(0x422B2A1CUL)))
#define bM4_TMRA3_PCONR5_FORC0                    (*((volatile unsigned int*)(0x422B2A20UL)))
#define bM4_TMRA3_PCONR5_FORC1                    (*((volatile unsigned int*)(0x422B2A24UL)))
#define bM4_TMRA3_PCONR5_OUTEN                    (*((volatile unsigned int*)(0x422B2A30UL)))
#define bM4_TMRA3_PCONR6_STAC0                    (*((volatile unsigned int*)(0x422B2A80UL)))
#define bM4_TMRA3_PCONR6_STAC1                    (*((volatile unsigned int*)(0x422B2A84UL)))
#define bM4_TMRA3_PCONR6_STPC0                    (*((volatile unsigned int*)(0x422B2A88UL)))
#define bM4_TMRA3_PCONR6_STPC1                    (*((volatile unsigned int*)(0x422B2A8CUL)))
#define bM4_TMRA3_PCONR6_CMPC0                    (*((volatile unsigned int*)(0x422B2A90UL)))
#define bM4_TMRA3_PCONR6_CMPC1                    (*((volatile unsigned int*)(0x422B2A94UL)))
#define bM4_TMRA3_PCONR6_PERC0                    (*((volatile unsigned int*)(0x422B2A98UL)))
#define bM4_TMRA3_PCONR6_PERC1                    (*((volatile unsigned int*)(0x422B2A9CUL)))
#define bM4_TMRA3_PCONR6_FORC0                    (*((volatile unsigned int*)(0x422B2AA0UL)))
#define bM4_TMRA3_PCONR6_FORC1                    (*((volatile unsigned int*)(0x422B2AA4UL)))
#define bM4_TMRA3_PCONR6_OUTEN                    (*((volatile unsigned int*)(0x422B2AB0UL)))
#define bM4_TMRA3_PCONR7_STAC0                    (*((volatile unsigned int*)(0x422B2B00UL)))
#define bM4_TMRA3_PCONR7_STAC1                    (*((volatile unsigned int*)(0x422B2B04UL)))
#define bM4_TMRA3_PCONR7_STPC0                    (*((volatile unsigned int*)(0x422B2B08UL)))
#define bM4_TMRA3_PCONR7_STPC1                    (*((volatile unsigned int*)(0x422B2B0CUL)))
#define bM4_TMRA3_PCONR7_CMPC0                    (*((volatile unsigned int*)(0x422B2B10UL)))
#define bM4_TMRA3_PCONR7_CMPC1                    (*((volatile unsigned int*)(0x422B2B14UL)))
#define bM4_TMRA3_PCONR7_PERC0                    (*((volatile unsigned int*)(0x422B2B18UL)))
#define bM4_TMRA3_PCONR7_PERC1                    (*((volatile unsigned int*)(0x422B2B1CUL)))
#define bM4_TMRA3_PCONR7_FORC0                    (*((volatile unsigned int*)(0x422B2B20UL)))
#define bM4_TMRA3_PCONR7_FORC1                    (*((volatile unsigned int*)(0x422B2B24UL)))
#define bM4_TMRA3_PCONR7_OUTEN                    (*((volatile unsigned int*)(0x422B2B30UL)))
#define bM4_TMRA3_PCONR8_STAC0                    (*((volatile unsigned int*)(0x422B2B80UL)))
#define bM4_TMRA3_PCONR8_STAC1                    (*((volatile unsigned int*)(0x422B2B84UL)))
#define bM4_TMRA3_PCONR8_STPC0                    (*((volatile unsigned int*)(0x422B2B88UL)))
#define bM4_TMRA3_PCONR8_STPC1                    (*((volatile unsigned int*)(0x422B2B8CUL)))
#define bM4_TMRA3_PCONR8_CMPC0                    (*((volatile unsigned int*)(0x422B2B90UL)))
#define bM4_TMRA3_PCONR8_CMPC1                    (*((volatile unsigned int*)(0x422B2B94UL)))
#define bM4_TMRA3_PCONR8_PERC0                    (*((volatile unsigned int*)(0x422B2B98UL)))
#define bM4_TMRA3_PCONR8_PERC1                    (*((volatile unsigned int*)(0x422B2B9CUL)))
#define bM4_TMRA3_PCONR8_FORC0                    (*((volatile unsigned int*)(0x422B2BA0UL)))
#define bM4_TMRA3_PCONR8_FORC1                    (*((volatile unsigned int*)(0x422B2BA4UL)))
#define bM4_TMRA3_PCONR8_OUTEN                    (*((volatile unsigned int*)(0x422B2BB0UL)))
#define bM4_TMRA4_CNTER_CNT0                      (*((volatile unsigned int*)(0x422B8000UL)))
#define bM4_TMRA4_CNTER_CNT1                      (*((volatile unsigned int*)(0x422B8004UL)))
#define bM4_TMRA4_CNTER_CNT2                      (*((volatile unsigned int*)(0x422B8008UL)))
#define bM4_TMRA4_CNTER_CNT3                      (*((volatile unsigned int*)(0x422B800CUL)))
#define bM4_TMRA4_CNTER_CNT4                      (*((volatile unsigned int*)(0x422B8010UL)))
#define bM4_TMRA4_CNTER_CNT5                      (*((volatile unsigned int*)(0x422B8014UL)))
#define bM4_TMRA4_CNTER_CNT6                      (*((volatile unsigned int*)(0x422B8018UL)))
#define bM4_TMRA4_CNTER_CNT7                      (*((volatile unsigned int*)(0x422B801CUL)))
#define bM4_TMRA4_CNTER_CNT8                      (*((volatile unsigned int*)(0x422B8020UL)))
#define bM4_TMRA4_CNTER_CNT9                      (*((volatile unsigned int*)(0x422B8024UL)))
#define bM4_TMRA4_CNTER_CNT10                     (*((volatile unsigned int*)(0x422B8028UL)))
#define bM4_TMRA4_CNTER_CNT11                     (*((volatile unsigned int*)(0x422B802CUL)))
#define bM4_TMRA4_CNTER_CNT12                     (*((volatile unsigned int*)(0x422B8030UL)))
#define bM4_TMRA4_CNTER_CNT13                     (*((volatile unsigned int*)(0x422B8034UL)))
#define bM4_TMRA4_CNTER_CNT14                     (*((volatile unsigned int*)(0x422B8038UL)))
#define bM4_TMRA4_CNTER_CNT15                     (*((volatile unsigned int*)(0x422B803CUL)))
#define bM4_TMRA4_PERAR_PER0                      (*((volatile unsigned int*)(0x422B8080UL)))
#define bM4_TMRA4_PERAR_PER1                      (*((volatile unsigned int*)(0x422B8084UL)))
#define bM4_TMRA4_PERAR_PER2                      (*((volatile unsigned int*)(0x422B8088UL)))
#define bM4_TMRA4_PERAR_PER3                      (*((volatile unsigned int*)(0x422B808CUL)))
#define bM4_TMRA4_PERAR_PER4                      (*((volatile unsigned int*)(0x422B8090UL)))
#define bM4_TMRA4_PERAR_PER5                      (*((volatile unsigned int*)(0x422B8094UL)))
#define bM4_TMRA4_PERAR_PER6                      (*((volatile unsigned int*)(0x422B8098UL)))
#define bM4_TMRA4_PERAR_PER7                      (*((volatile unsigned int*)(0x422B809CUL)))
#define bM4_TMRA4_PERAR_PER8                      (*((volatile unsigned int*)(0x422B80A0UL)))
#define bM4_TMRA4_PERAR_PER9                      (*((volatile unsigned int*)(0x422B80A4UL)))
#define bM4_TMRA4_PERAR_PER10                     (*((volatile unsigned int*)(0x422B80A8UL)))
#define bM4_TMRA4_PERAR_PER11                     (*((volatile unsigned int*)(0x422B80ACUL)))
#define bM4_TMRA4_PERAR_PER12                     (*((volatile unsigned int*)(0x422B80B0UL)))
#define bM4_TMRA4_PERAR_PER13                     (*((volatile unsigned int*)(0x422B80B4UL)))
#define bM4_TMRA4_PERAR_PER14                     (*((volatile unsigned int*)(0x422B80B8UL)))
#define bM4_TMRA4_PERAR_PER15                     (*((volatile unsigned int*)(0x422B80BCUL)))
#define bM4_TMRA4_CMPAR1_CMP0                     (*((volatile unsigned int*)(0x422B8800UL)))
#define bM4_TMRA4_CMPAR1_CMP1                     (*((volatile unsigned int*)(0x422B8804UL)))
#define bM4_TMRA4_CMPAR1_CMP2                     (*((volatile unsigned int*)(0x422B8808UL)))
#define bM4_TMRA4_CMPAR1_CMP3                     (*((volatile unsigned int*)(0x422B880CUL)))
#define bM4_TMRA4_CMPAR1_CMP4                     (*((volatile unsigned int*)(0x422B8810UL)))
#define bM4_TMRA4_CMPAR1_CMP5                     (*((volatile unsigned int*)(0x422B8814UL)))
#define bM4_TMRA4_CMPAR1_CMP6                     (*((volatile unsigned int*)(0x422B8818UL)))
#define bM4_TMRA4_CMPAR1_CMP7                     (*((volatile unsigned int*)(0x422B881CUL)))
#define bM4_TMRA4_CMPAR1_CMP8                     (*((volatile unsigned int*)(0x422B8820UL)))
#define bM4_TMRA4_CMPAR1_CMP9                     (*((volatile unsigned int*)(0x422B8824UL)))
#define bM4_TMRA4_CMPAR1_CMP10                    (*((volatile unsigned int*)(0x422B8828UL)))
#define bM4_TMRA4_CMPAR1_CMP11                    (*((volatile unsigned int*)(0x422B882CUL)))
#define bM4_TMRA4_CMPAR1_CMP12                    (*((volatile unsigned int*)(0x422B8830UL)))
#define bM4_TMRA4_CMPAR1_CMP13                    (*((volatile unsigned int*)(0x422B8834UL)))
#define bM4_TMRA4_CMPAR1_CMP14                    (*((volatile unsigned int*)(0x422B8838UL)))
#define bM4_TMRA4_CMPAR1_CMP15                    (*((volatile unsigned int*)(0x422B883CUL)))
#define bM4_TMRA4_CMPAR2_CMP0                     (*((volatile unsigned int*)(0x422B8880UL)))
#define bM4_TMRA4_CMPAR2_CMP1                     (*((volatile unsigned int*)(0x422B8884UL)))
#define bM4_TMRA4_CMPAR2_CMP2                     (*((volatile unsigned int*)(0x422B8888UL)))
#define bM4_TMRA4_CMPAR2_CMP3                     (*((volatile unsigned int*)(0x422B888CUL)))
#define bM4_TMRA4_CMPAR2_CMP4                     (*((volatile unsigned int*)(0x422B8890UL)))
#define bM4_TMRA4_CMPAR2_CMP5                     (*((volatile unsigned int*)(0x422B8894UL)))
#define bM4_TMRA4_CMPAR2_CMP6                     (*((volatile unsigned int*)(0x422B8898UL)))
#define bM4_TMRA4_CMPAR2_CMP7                     (*((volatile unsigned int*)(0x422B889CUL)))
#define bM4_TMRA4_CMPAR2_CMP8                     (*((volatile unsigned int*)(0x422B88A0UL)))
#define bM4_TMRA4_CMPAR2_CMP9                     (*((volatile unsigned int*)(0x422B88A4UL)))
#define bM4_TMRA4_CMPAR2_CMP10                    (*((volatile unsigned int*)(0x422B88A8UL)))
#define bM4_TMRA4_CMPAR2_CMP11                    (*((volatile unsigned int*)(0x422B88ACUL)))
#define bM4_TMRA4_CMPAR2_CMP12                    (*((volatile unsigned int*)(0x422B88B0UL)))
#define bM4_TMRA4_CMPAR2_CMP13                    (*((volatile unsigned int*)(0x422B88B4UL)))
#define bM4_TMRA4_CMPAR2_CMP14                    (*((volatile unsigned int*)(0x422B88B8UL)))
#define bM4_TMRA4_CMPAR2_CMP15                    (*((volatile unsigned int*)(0x422B88BCUL)))
#define bM4_TMRA4_CMPAR3_CMP0                     (*((volatile unsigned int*)(0x422B8900UL)))
#define bM4_TMRA4_CMPAR3_CMP1                     (*((volatile unsigned int*)(0x422B8904UL)))
#define bM4_TMRA4_CMPAR3_CMP2                     (*((volatile unsigned int*)(0x422B8908UL)))
#define bM4_TMRA4_CMPAR3_CMP3                     (*((volatile unsigned int*)(0x422B890CUL)))
#define bM4_TMRA4_CMPAR3_CMP4                     (*((volatile unsigned int*)(0x422B8910UL)))
#define bM4_TMRA4_CMPAR3_CMP5                     (*((volatile unsigned int*)(0x422B8914UL)))
#define bM4_TMRA4_CMPAR3_CMP6                     (*((volatile unsigned int*)(0x422B8918UL)))
#define bM4_TMRA4_CMPAR3_CMP7                     (*((volatile unsigned int*)(0x422B891CUL)))
#define bM4_TMRA4_CMPAR3_CMP8                     (*((volatile unsigned int*)(0x422B8920UL)))
#define bM4_TMRA4_CMPAR3_CMP9                     (*((volatile unsigned int*)(0x422B8924UL)))
#define bM4_TMRA4_CMPAR3_CMP10                    (*((volatile unsigned int*)(0x422B8928UL)))
#define bM4_TMRA4_CMPAR3_CMP11                    (*((volatile unsigned int*)(0x422B892CUL)))
#define bM4_TMRA4_CMPAR3_CMP12                    (*((volatile unsigned int*)(0x422B8930UL)))
#define bM4_TMRA4_CMPAR3_CMP13                    (*((volatile unsigned int*)(0x422B8934UL)))
#define bM4_TMRA4_CMPAR3_CMP14                    (*((volatile unsigned int*)(0x422B8938UL)))
#define bM4_TMRA4_CMPAR3_CMP15                    (*((volatile unsigned int*)(0x422B893CUL)))
#define bM4_TMRA4_CMPAR4_CMP0                     (*((volatile unsigned int*)(0x422B8980UL)))
#define bM4_TMRA4_CMPAR4_CMP1                     (*((volatile unsigned int*)(0x422B8984UL)))
#define bM4_TMRA4_CMPAR4_CMP2                     (*((volatile unsigned int*)(0x422B8988UL)))
#define bM4_TMRA4_CMPAR4_CMP3                     (*((volatile unsigned int*)(0x422B898CUL)))
#define bM4_TMRA4_CMPAR4_CMP4                     (*((volatile unsigned int*)(0x422B8990UL)))
#define bM4_TMRA4_CMPAR4_CMP5                     (*((volatile unsigned int*)(0x422B8994UL)))
#define bM4_TMRA4_CMPAR4_CMP6                     (*((volatile unsigned int*)(0x422B8998UL)))
#define bM4_TMRA4_CMPAR4_CMP7                     (*((volatile unsigned int*)(0x422B899CUL)))
#define bM4_TMRA4_CMPAR4_CMP8                     (*((volatile unsigned int*)(0x422B89A0UL)))
#define bM4_TMRA4_CMPAR4_CMP9                     (*((volatile unsigned int*)(0x422B89A4UL)))
#define bM4_TMRA4_CMPAR4_CMP10                    (*((volatile unsigned int*)(0x422B89A8UL)))
#define bM4_TMRA4_CMPAR4_CMP11                    (*((volatile unsigned int*)(0x422B89ACUL)))
#define bM4_TMRA4_CMPAR4_CMP12                    (*((volatile unsigned int*)(0x422B89B0UL)))
#define bM4_TMRA4_CMPAR4_CMP13                    (*((volatile unsigned int*)(0x422B89B4UL)))
#define bM4_TMRA4_CMPAR4_CMP14                    (*((volatile unsigned int*)(0x422B89B8UL)))
#define bM4_TMRA4_CMPAR4_CMP15                    (*((volatile unsigned int*)(0x422B89BCUL)))
#define bM4_TMRA4_CMPAR5_CMP0                     (*((volatile unsigned int*)(0x422B8A00UL)))
#define bM4_TMRA4_CMPAR5_CMP1                     (*((volatile unsigned int*)(0x422B8A04UL)))
#define bM4_TMRA4_CMPAR5_CMP2                     (*((volatile unsigned int*)(0x422B8A08UL)))
#define bM4_TMRA4_CMPAR5_CMP3                     (*((volatile unsigned int*)(0x422B8A0CUL)))
#define bM4_TMRA4_CMPAR5_CMP4                     (*((volatile unsigned int*)(0x422B8A10UL)))
#define bM4_TMRA4_CMPAR5_CMP5                     (*((volatile unsigned int*)(0x422B8A14UL)))
#define bM4_TMRA4_CMPAR5_CMP6                     (*((volatile unsigned int*)(0x422B8A18UL)))
#define bM4_TMRA4_CMPAR5_CMP7                     (*((volatile unsigned int*)(0x422B8A1CUL)))
#define bM4_TMRA4_CMPAR5_CMP8                     (*((volatile unsigned int*)(0x422B8A20UL)))
#define bM4_TMRA4_CMPAR5_CMP9                     (*((volatile unsigned int*)(0x422B8A24UL)))
#define bM4_TMRA4_CMPAR5_CMP10                    (*((volatile unsigned int*)(0x422B8A28UL)))
#define bM4_TMRA4_CMPAR5_CMP11                    (*((volatile unsigned int*)(0x422B8A2CUL)))
#define bM4_TMRA4_CMPAR5_CMP12                    (*((volatile unsigned int*)(0x422B8A30UL)))
#define bM4_TMRA4_CMPAR5_CMP13                    (*((volatile unsigned int*)(0x422B8A34UL)))
#define bM4_TMRA4_CMPAR5_CMP14                    (*((volatile unsigned int*)(0x422B8A38UL)))
#define bM4_TMRA4_CMPAR5_CMP15                    (*((volatile unsigned int*)(0x422B8A3CUL)))
#define bM4_TMRA4_CMPAR6_CMP0                     (*((volatile unsigned int*)(0x422B8A80UL)))
#define bM4_TMRA4_CMPAR6_CMP1                     (*((volatile unsigned int*)(0x422B8A84UL)))
#define bM4_TMRA4_CMPAR6_CMP2                     (*((volatile unsigned int*)(0x422B8A88UL)))
#define bM4_TMRA4_CMPAR6_CMP3                     (*((volatile unsigned int*)(0x422B8A8CUL)))
#define bM4_TMRA4_CMPAR6_CMP4                     (*((volatile unsigned int*)(0x422B8A90UL)))
#define bM4_TMRA4_CMPAR6_CMP5                     (*((volatile unsigned int*)(0x422B8A94UL)))
#define bM4_TMRA4_CMPAR6_CMP6                     (*((volatile unsigned int*)(0x422B8A98UL)))
#define bM4_TMRA4_CMPAR6_CMP7                     (*((volatile unsigned int*)(0x422B8A9CUL)))
#define bM4_TMRA4_CMPAR6_CMP8                     (*((volatile unsigned int*)(0x422B8AA0UL)))
#define bM4_TMRA4_CMPAR6_CMP9                     (*((volatile unsigned int*)(0x422B8AA4UL)))
#define bM4_TMRA4_CMPAR6_CMP10                    (*((volatile unsigned int*)(0x422B8AA8UL)))
#define bM4_TMRA4_CMPAR6_CMP11                    (*((volatile unsigned int*)(0x422B8AACUL)))
#define bM4_TMRA4_CMPAR6_CMP12                    (*((volatile unsigned int*)(0x422B8AB0UL)))
#define bM4_TMRA4_CMPAR6_CMP13                    (*((volatile unsigned int*)(0x422B8AB4UL)))
#define bM4_TMRA4_CMPAR6_CMP14                    (*((volatile unsigned int*)(0x422B8AB8UL)))
#define bM4_TMRA4_CMPAR6_CMP15                    (*((volatile unsigned int*)(0x422B8ABCUL)))
#define bM4_TMRA4_CMPAR7_CMP0                     (*((volatile unsigned int*)(0x422B8B00UL)))
#define bM4_TMRA4_CMPAR7_CMP1                     (*((volatile unsigned int*)(0x422B8B04UL)))
#define bM4_TMRA4_CMPAR7_CMP2                     (*((volatile unsigned int*)(0x422B8B08UL)))
#define bM4_TMRA4_CMPAR7_CMP3                     (*((volatile unsigned int*)(0x422B8B0CUL)))
#define bM4_TMRA4_CMPAR7_CMP4                     (*((volatile unsigned int*)(0x422B8B10UL)))
#define bM4_TMRA4_CMPAR7_CMP5                     (*((volatile unsigned int*)(0x422B8B14UL)))
#define bM4_TMRA4_CMPAR7_CMP6                     (*((volatile unsigned int*)(0x422B8B18UL)))
#define bM4_TMRA4_CMPAR7_CMP7                     (*((volatile unsigned int*)(0x422B8B1CUL)))
#define bM4_TMRA4_CMPAR7_CMP8                     (*((volatile unsigned int*)(0x422B8B20UL)))
#define bM4_TMRA4_CMPAR7_CMP9                     (*((volatile unsigned int*)(0x422B8B24UL)))
#define bM4_TMRA4_CMPAR7_CMP10                    (*((volatile unsigned int*)(0x422B8B28UL)))
#define bM4_TMRA4_CMPAR7_CMP11                    (*((volatile unsigned int*)(0x422B8B2CUL)))
#define bM4_TMRA4_CMPAR7_CMP12                    (*((volatile unsigned int*)(0x422B8B30UL)))
#define bM4_TMRA4_CMPAR7_CMP13                    (*((volatile unsigned int*)(0x422B8B34UL)))
#define bM4_TMRA4_CMPAR7_CMP14                    (*((volatile unsigned int*)(0x422B8B38UL)))
#define bM4_TMRA4_CMPAR7_CMP15                    (*((volatile unsigned int*)(0x422B8B3CUL)))
#define bM4_TMRA4_CMPAR8_CMP0                     (*((volatile unsigned int*)(0x422B8B80UL)))
#define bM4_TMRA4_CMPAR8_CMP1                     (*((volatile unsigned int*)(0x422B8B84UL)))
#define bM4_TMRA4_CMPAR8_CMP2                     (*((volatile unsigned int*)(0x422B8B88UL)))
#define bM4_TMRA4_CMPAR8_CMP3                     (*((volatile unsigned int*)(0x422B8B8CUL)))
#define bM4_TMRA4_CMPAR8_CMP4                     (*((volatile unsigned int*)(0x422B8B90UL)))
#define bM4_TMRA4_CMPAR8_CMP5                     (*((volatile unsigned int*)(0x422B8B94UL)))
#define bM4_TMRA4_CMPAR8_CMP6                     (*((volatile unsigned int*)(0x422B8B98UL)))
#define bM4_TMRA4_CMPAR8_CMP7                     (*((volatile unsigned int*)(0x422B8B9CUL)))
#define bM4_TMRA4_CMPAR8_CMP8                     (*((volatile unsigned int*)(0x422B8BA0UL)))
#define bM4_TMRA4_CMPAR8_CMP9                     (*((volatile unsigned int*)(0x422B8BA4UL)))
#define bM4_TMRA4_CMPAR8_CMP10                    (*((volatile unsigned int*)(0x422B8BA8UL)))
#define bM4_TMRA4_CMPAR8_CMP11                    (*((volatile unsigned int*)(0x422B8BACUL)))
#define bM4_TMRA4_CMPAR8_CMP12                    (*((volatile unsigned int*)(0x422B8BB0UL)))
#define bM4_TMRA4_CMPAR8_CMP13                    (*((volatile unsigned int*)(0x422B8BB4UL)))
#define bM4_TMRA4_CMPAR8_CMP14                    (*((volatile unsigned int*)(0x422B8BB8UL)))
#define bM4_TMRA4_CMPAR8_CMP15                    (*((volatile unsigned int*)(0x422B8BBCUL)))
#define bM4_TMRA4_BCSTR_START                     (*((volatile unsigned int*)(0x422B9000UL)))
#define bM4_TMRA4_BCSTR_DIR                       (*((volatile unsigned int*)(0x422B9004UL)))
#define bM4_TMRA4_BCSTR_MODE                      (*((volatile unsigned int*)(0x422B9008UL)))
#define bM4_TMRA4_BCSTR_SYNST                     (*((volatile unsigned int*)(0x422B900CUL)))
#define bM4_TMRA4_BCSTR_CKDIV0                    (*((volatile unsigned int*)(0x422B9010UL)))
#define bM4_TMRA4_BCSTR_CKDIV1                    (*((volatile unsigned int*)(0x422B9014UL)))
#define bM4_TMRA4_BCSTR_CKDIV2                    (*((volatile unsigned int*)(0x422B9018UL)))
#define bM4_TMRA4_BCSTR_CKDIV3                    (*((volatile unsigned int*)(0x422B901CUL)))
#define bM4_TMRA4_BCSTR_ITENOVF                   (*((volatile unsigned int*)(0x422B9030UL)))
#define bM4_TMRA4_BCSTR_ITENUDF                   (*((volatile unsigned int*)(0x422B9034UL)))
#define bM4_TMRA4_BCSTR_OVFF                      (*((volatile unsigned int*)(0x422B9038UL)))
#define bM4_TMRA4_BCSTR_UDFF                      (*((volatile unsigned int*)(0x422B903CUL)))
#define bM4_TMRA4_HCONR_HSTA0                     (*((volatile unsigned int*)(0x422B9080UL)))
#define bM4_TMRA4_HCONR_HSTA1                     (*((volatile unsigned int*)(0x422B9084UL)))
#define bM4_TMRA4_HCONR_HSTA2                     (*((volatile unsigned int*)(0x422B9088UL)))
#define bM4_TMRA4_HCONR_HSTP0                     (*((volatile unsigned int*)(0x422B9090UL)))
#define bM4_TMRA4_HCONR_HSTP1                     (*((volatile unsigned int*)(0x422B9094UL)))
#define bM4_TMRA4_HCONR_HSTP2                     (*((volatile unsigned int*)(0x422B9098UL)))
#define bM4_TMRA4_HCONR_HCLE0                     (*((volatile unsigned int*)(0x422B90A0UL)))
#define bM4_TMRA4_HCONR_HCLE1                     (*((volatile unsigned int*)(0x422B90A4UL)))
#define bM4_TMRA4_HCONR_HCLE2                     (*((volatile unsigned int*)(0x422B90A8UL)))
#define bM4_TMRA4_HCONR_HCLE3                     (*((volatile unsigned int*)(0x422B90B0UL)))
#define bM4_TMRA4_HCONR_HCLE4                     (*((volatile unsigned int*)(0x422B90B4UL)))
#define bM4_TMRA4_HCONR_HCLE5                     (*((volatile unsigned int*)(0x422B90B8UL)))
#define bM4_TMRA4_HCONR_HCLE6                     (*((volatile unsigned int*)(0x422B90BCUL)))
#define bM4_TMRA4_HCUPR_HCUP0                     (*((volatile unsigned int*)(0x422B9100UL)))
#define bM4_TMRA4_HCUPR_HCUP1                     (*((volatile unsigned int*)(0x422B9104UL)))
#define bM4_TMRA4_HCUPR_HCUP2                     (*((volatile unsigned int*)(0x422B9108UL)))
#define bM4_TMRA4_HCUPR_HCUP3                     (*((volatile unsigned int*)(0x422B910CUL)))
#define bM4_TMRA4_HCUPR_HCUP4                     (*((volatile unsigned int*)(0x422B9110UL)))
#define bM4_TMRA4_HCUPR_HCUP5                     (*((volatile unsigned int*)(0x422B9114UL)))
#define bM4_TMRA4_HCUPR_HCUP6                     (*((volatile unsigned int*)(0x422B9118UL)))
#define bM4_TMRA4_HCUPR_HCUP7                     (*((volatile unsigned int*)(0x422B911CUL)))
#define bM4_TMRA4_HCUPR_HCUP8                     (*((volatile unsigned int*)(0x422B9120UL)))
#define bM4_TMRA4_HCUPR_HCUP9                     (*((volatile unsigned int*)(0x422B9124UL)))
#define bM4_TMRA4_HCUPR_HCUP10                    (*((volatile unsigned int*)(0x422B9128UL)))
#define bM4_TMRA4_HCUPR_HCUP11                    (*((volatile unsigned int*)(0x422B912CUL)))
#define bM4_TMRA4_HCUPR_HCUP12                    (*((volatile unsigned int*)(0x422B9130UL)))
#define bM4_TMRA4_HCDOR_HCDO0                     (*((volatile unsigned int*)(0x422B9180UL)))
#define bM4_TMRA4_HCDOR_HCDO1                     (*((volatile unsigned int*)(0x422B9184UL)))
#define bM4_TMRA4_HCDOR_HCDO2                     (*((volatile unsigned int*)(0x422B9188UL)))
#define bM4_TMRA4_HCDOR_HCDO3                     (*((volatile unsigned int*)(0x422B918CUL)))
#define bM4_TMRA4_HCDOR_HCDO4                     (*((volatile unsigned int*)(0x422B9190UL)))
#define bM4_TMRA4_HCDOR_HCDO5                     (*((volatile unsigned int*)(0x422B9194UL)))
#define bM4_TMRA4_HCDOR_HCDO6                     (*((volatile unsigned int*)(0x422B9198UL)))
#define bM4_TMRA4_HCDOR_HCDO7                     (*((volatile unsigned int*)(0x422B919CUL)))
#define bM4_TMRA4_HCDOR_HCDO8                     (*((volatile unsigned int*)(0x422B91A0UL)))
#define bM4_TMRA4_HCDOR_HCDO9                     (*((volatile unsigned int*)(0x422B91A4UL)))
#define bM4_TMRA4_HCDOR_HCDO10                    (*((volatile unsigned int*)(0x422B91A8UL)))
#define bM4_TMRA4_HCDOR_HCDO11                    (*((volatile unsigned int*)(0x422B91ACUL)))
#define bM4_TMRA4_HCDOR_HCDO12                    (*((volatile unsigned int*)(0x422B91B0UL)))
#define bM4_TMRA4_ICONR_ITEN1                     (*((volatile unsigned int*)(0x422B9200UL)))
#define bM4_TMRA4_ICONR_ITEN2                     (*((volatile unsigned int*)(0x422B9204UL)))
#define bM4_TMRA4_ICONR_ITEN3                     (*((volatile unsigned int*)(0x422B9208UL)))
#define bM4_TMRA4_ICONR_ITEN4                     (*((volatile unsigned int*)(0x422B920CUL)))
#define bM4_TMRA4_ICONR_ITEN5                     (*((volatile unsigned int*)(0x422B9210UL)))
#define bM4_TMRA4_ICONR_ITEN6                     (*((volatile unsigned int*)(0x422B9214UL)))
#define bM4_TMRA4_ICONR_ITEN7                     (*((volatile unsigned int*)(0x422B9218UL)))
#define bM4_TMRA4_ICONR_ITEN8                     (*((volatile unsigned int*)(0x422B921CUL)))
#define bM4_TMRA4_ECONR_ETEN1                     (*((volatile unsigned int*)(0x422B9280UL)))
#define bM4_TMRA4_ECONR_ETEN2                     (*((volatile unsigned int*)(0x422B9284UL)))
#define bM4_TMRA4_ECONR_ETEN3                     (*((volatile unsigned int*)(0x422B9288UL)))
#define bM4_TMRA4_ECONR_ETEN4                     (*((volatile unsigned int*)(0x422B928CUL)))
#define bM4_TMRA4_ECONR_ETEN5                     (*((volatile unsigned int*)(0x422B9290UL)))
#define bM4_TMRA4_ECONR_ETEN6                     (*((volatile unsigned int*)(0x422B9294UL)))
#define bM4_TMRA4_ECONR_ETEN7                     (*((volatile unsigned int*)(0x422B9298UL)))
#define bM4_TMRA4_ECONR_ETEN8                     (*((volatile unsigned int*)(0x422B929CUL)))
#define bM4_TMRA4_FCONR_NOFIENTG                  (*((volatile unsigned int*)(0x422B9300UL)))
#define bM4_TMRA4_FCONR_NOFICKTG0                 (*((volatile unsigned int*)(0x422B9304UL)))
#define bM4_TMRA4_FCONR_NOFICKTG1                 (*((volatile unsigned int*)(0x422B9308UL)))
#define bM4_TMRA4_FCONR_NOFIENCA                  (*((volatile unsigned int*)(0x422B9320UL)))
#define bM4_TMRA4_FCONR_NOFICKCA0                 (*((volatile unsigned int*)(0x422B9324UL)))
#define bM4_TMRA4_FCONR_NOFICKCA1                 (*((volatile unsigned int*)(0x422B9328UL)))
#define bM4_TMRA4_FCONR_NOFIENCB                  (*((volatile unsigned int*)(0x422B9330UL)))
#define bM4_TMRA4_FCONR_NOFICKCB0                 (*((volatile unsigned int*)(0x422B9334UL)))
#define bM4_TMRA4_FCONR_NOFICKCB1                 (*((volatile unsigned int*)(0x422B9338UL)))
#define bM4_TMRA4_STFLR_CMPF1                     (*((volatile unsigned int*)(0x422B9380UL)))
#define bM4_TMRA4_STFLR_CMPF2                     (*((volatile unsigned int*)(0x422B9384UL)))
#define bM4_TMRA4_STFLR_CMPF3                     (*((volatile unsigned int*)(0x422B9388UL)))
#define bM4_TMRA4_STFLR_CMPF4                     (*((volatile unsigned int*)(0x422B938CUL)))
#define bM4_TMRA4_STFLR_CMPF5                     (*((volatile unsigned int*)(0x422B9390UL)))
#define bM4_TMRA4_STFLR_CMPF6                     (*((volatile unsigned int*)(0x422B9394UL)))
#define bM4_TMRA4_STFLR_CMPF7                     (*((volatile unsigned int*)(0x422B9398UL)))
#define bM4_TMRA4_STFLR_CMPF8                     (*((volatile unsigned int*)(0x422B939CUL)))
#define bM4_TMRA4_BCONR1_BEN                      (*((volatile unsigned int*)(0x422B9800UL)))
#define bM4_TMRA4_BCONR1_BSE0                     (*((volatile unsigned int*)(0x422B9804UL)))
#define bM4_TMRA4_BCONR1_BSE1                     (*((volatile unsigned int*)(0x422B9808UL)))
#define bM4_TMRA4_BCONR2_BEN                      (*((volatile unsigned int*)(0x422B9900UL)))
#define bM4_TMRA4_BCONR2_BSE0                     (*((volatile unsigned int*)(0x422B9904UL)))
#define bM4_TMRA4_BCONR2_BSE1                     (*((volatile unsigned int*)(0x422B9908UL)))
#define bM4_TMRA4_BCONR3_BEN                      (*((volatile unsigned int*)(0x422B9A00UL)))
#define bM4_TMRA4_BCONR3_BSE0                     (*((volatile unsigned int*)(0x422B9A04UL)))
#define bM4_TMRA4_BCONR3_BSE1                     (*((volatile unsigned int*)(0x422B9A08UL)))
#define bM4_TMRA4_BCONR4_BEN                      (*((volatile unsigned int*)(0x422B9B00UL)))
#define bM4_TMRA4_BCONR4_BSE0                     (*((volatile unsigned int*)(0x422B9B04UL)))
#define bM4_TMRA4_BCONR4_BSE1                     (*((volatile unsigned int*)(0x422B9B08UL)))
#define bM4_TMRA4_CCONR1_CAPMD                    (*((volatile unsigned int*)(0x422BA000UL)))
#define bM4_TMRA4_CCONR1_HICP0                    (*((volatile unsigned int*)(0x422BA010UL)))
#define bM4_TMRA4_CCONR1_HICP1                    (*((volatile unsigned int*)(0x422BA014UL)))
#define bM4_TMRA4_CCONR1_HICP2                    (*((volatile unsigned int*)(0x422BA018UL)))
#define bM4_TMRA4_CCONR1_HICP3                    (*((volatile unsigned int*)(0x422BA020UL)))
#define bM4_TMRA4_CCONR1_HICP4                    (*((volatile unsigned int*)(0x422BA024UL)))
#define bM4_TMRA4_CCONR1_NOFIENCP                 (*((volatile unsigned int*)(0x422BA030UL)))
#define bM4_TMRA4_CCONR1_NOFICKCP0                (*((volatile unsigned int*)(0x422BA034UL)))
#define bM4_TMRA4_CCONR1_NOFICKCP1                (*((volatile unsigned int*)(0x422BA038UL)))
#define bM4_TMRA4_CCONR2_CAPMD                    (*((volatile unsigned int*)(0x422BA080UL)))
#define bM4_TMRA4_CCONR2_HICP0                    (*((volatile unsigned int*)(0x422BA090UL)))
#define bM4_TMRA4_CCONR2_HICP1                    (*((volatile unsigned int*)(0x422BA094UL)))
#define bM4_TMRA4_CCONR2_HICP2                    (*((volatile unsigned int*)(0x422BA098UL)))
#define bM4_TMRA4_CCONR2_HICP3                    (*((volatile unsigned int*)(0x422BA0A0UL)))
#define bM4_TMRA4_CCONR2_HICP4                    (*((volatile unsigned int*)(0x422BA0A4UL)))
#define bM4_TMRA4_CCONR2_NOFIENCP                 (*((volatile unsigned int*)(0x422BA0B0UL)))
#define bM4_TMRA4_CCONR2_NOFICKCP0                (*((volatile unsigned int*)(0x422BA0B4UL)))
#define bM4_TMRA4_CCONR2_NOFICKCP1                (*((volatile unsigned int*)(0x422BA0B8UL)))
#define bM4_TMRA4_CCONR3_CAPMD                    (*((volatile unsigned int*)(0x422BA100UL)))
#define bM4_TMRA4_CCONR3_HICP0                    (*((volatile unsigned int*)(0x422BA110UL)))
#define bM4_TMRA4_CCONR3_HICP1                    (*((volatile unsigned int*)(0x422BA114UL)))
#define bM4_TMRA4_CCONR3_HICP2                    (*((volatile unsigned int*)(0x422BA118UL)))
#define bM4_TMRA4_CCONR3_HICP3                    (*((volatile unsigned int*)(0x422BA120UL)))
#define bM4_TMRA4_CCONR3_HICP4                    (*((volatile unsigned int*)(0x422BA124UL)))
#define bM4_TMRA4_CCONR3_NOFIENCP                 (*((volatile unsigned int*)(0x422BA130UL)))
#define bM4_TMRA4_CCONR3_NOFICKCP0                (*((volatile unsigned int*)(0x422BA134UL)))
#define bM4_TMRA4_CCONR3_NOFICKCP1                (*((volatile unsigned int*)(0x422BA138UL)))
#define bM4_TMRA4_CCONR4_CAPMD                    (*((volatile unsigned int*)(0x422BA180UL)))
#define bM4_TMRA4_CCONR4_HICP0                    (*((volatile unsigned int*)(0x422BA190UL)))
#define bM4_TMRA4_CCONR4_HICP1                    (*((volatile unsigned int*)(0x422BA194UL)))
#define bM4_TMRA4_CCONR4_HICP2                    (*((volatile unsigned int*)(0x422BA198UL)))
#define bM4_TMRA4_CCONR4_HICP3                    (*((volatile unsigned int*)(0x422BA1A0UL)))
#define bM4_TMRA4_CCONR4_HICP4                    (*((volatile unsigned int*)(0x422BA1A4UL)))
#define bM4_TMRA4_CCONR4_NOFIENCP                 (*((volatile unsigned int*)(0x422BA1B0UL)))
#define bM4_TMRA4_CCONR4_NOFICKCP0                (*((volatile unsigned int*)(0x422BA1B4UL)))
#define bM4_TMRA4_CCONR4_NOFICKCP1                (*((volatile unsigned int*)(0x422BA1B8UL)))
#define bM4_TMRA4_CCONR5_CAPMD                    (*((volatile unsigned int*)(0x422BA200UL)))
#define bM4_TMRA4_CCONR5_HICP0                    (*((volatile unsigned int*)(0x422BA210UL)))
#define bM4_TMRA4_CCONR5_HICP1                    (*((volatile unsigned int*)(0x422BA214UL)))
#define bM4_TMRA4_CCONR5_HICP2                    (*((volatile unsigned int*)(0x422BA218UL)))
#define bM4_TMRA4_CCONR5_HICP3                    (*((volatile unsigned int*)(0x422BA220UL)))
#define bM4_TMRA4_CCONR5_HICP4                    (*((volatile unsigned int*)(0x422BA224UL)))
#define bM4_TMRA4_CCONR5_NOFIENCP                 (*((volatile unsigned int*)(0x422BA230UL)))
#define bM4_TMRA4_CCONR5_NOFICKCP0                (*((volatile unsigned int*)(0x422BA234UL)))
#define bM4_TMRA4_CCONR5_NOFICKCP1                (*((volatile unsigned int*)(0x422BA238UL)))
#define bM4_TMRA4_CCONR6_CAPMD                    (*((volatile unsigned int*)(0x422BA280UL)))
#define bM4_TMRA4_CCONR6_HICP0                    (*((volatile unsigned int*)(0x422BA290UL)))
#define bM4_TMRA4_CCONR6_HICP1                    (*((volatile unsigned int*)(0x422BA294UL)))
#define bM4_TMRA4_CCONR6_HICP2                    (*((volatile unsigned int*)(0x422BA298UL)))
#define bM4_TMRA4_CCONR6_HICP3                    (*((volatile unsigned int*)(0x422BA2A0UL)))
#define bM4_TMRA4_CCONR6_HICP4                    (*((volatile unsigned int*)(0x422BA2A4UL)))
#define bM4_TMRA4_CCONR6_NOFIENCP                 (*((volatile unsigned int*)(0x422BA2B0UL)))
#define bM4_TMRA4_CCONR6_NOFICKCP0                (*((volatile unsigned int*)(0x422BA2B4UL)))
#define bM4_TMRA4_CCONR6_NOFICKCP1                (*((volatile unsigned int*)(0x422BA2B8UL)))
#define bM4_TMRA4_CCONR7_CAPMD                    (*((volatile unsigned int*)(0x422BA300UL)))
#define bM4_TMRA4_CCONR7_HICP0                    (*((volatile unsigned int*)(0x422BA310UL)))
#define bM4_TMRA4_CCONR7_HICP1                    (*((volatile unsigned int*)(0x422BA314UL)))
#define bM4_TMRA4_CCONR7_HICP2                    (*((volatile unsigned int*)(0x422BA318UL)))
#define bM4_TMRA4_CCONR7_HICP3                    (*((volatile unsigned int*)(0x422BA320UL)))
#define bM4_TMRA4_CCONR7_HICP4                    (*((volatile unsigned int*)(0x422BA324UL)))
#define bM4_TMRA4_CCONR7_NOFIENCP                 (*((volatile unsigned int*)(0x422BA330UL)))
#define bM4_TMRA4_CCONR7_NOFICKCP0                (*((volatile unsigned int*)(0x422BA334UL)))
#define bM4_TMRA4_CCONR7_NOFICKCP1                (*((volatile unsigned int*)(0x422BA338UL)))
#define bM4_TMRA4_CCONR8_CAPMD                    (*((volatile unsigned int*)(0x422BA380UL)))
#define bM4_TMRA4_CCONR8_HICP0                    (*((volatile unsigned int*)(0x422BA390UL)))
#define bM4_TMRA4_CCONR8_HICP1                    (*((volatile unsigned int*)(0x422BA394UL)))
#define bM4_TMRA4_CCONR8_HICP2                    (*((volatile unsigned int*)(0x422BA398UL)))
#define bM4_TMRA4_CCONR8_HICP3                    (*((volatile unsigned int*)(0x422BA3A0UL)))
#define bM4_TMRA4_CCONR8_HICP4                    (*((volatile unsigned int*)(0x422BA3A4UL)))
#define bM4_TMRA4_CCONR8_NOFIENCP                 (*((volatile unsigned int*)(0x422BA3B0UL)))
#define bM4_TMRA4_CCONR8_NOFICKCP0                (*((volatile unsigned int*)(0x422BA3B4UL)))
#define bM4_TMRA4_CCONR8_NOFICKCP1                (*((volatile unsigned int*)(0x422BA3B8UL)))
#define bM4_TMRA4_PCONR1_STAC0                    (*((volatile unsigned int*)(0x422BA800UL)))
#define bM4_TMRA4_PCONR1_STAC1                    (*((volatile unsigned int*)(0x422BA804UL)))
#define bM4_TMRA4_PCONR1_STPC0                    (*((volatile unsigned int*)(0x422BA808UL)))
#define bM4_TMRA4_PCONR1_STPC1                    (*((volatile unsigned int*)(0x422BA80CUL)))
#define bM4_TMRA4_PCONR1_CMPC0                    (*((volatile unsigned int*)(0x422BA810UL)))
#define bM4_TMRA4_PCONR1_CMPC1                    (*((volatile unsigned int*)(0x422BA814UL)))
#define bM4_TMRA4_PCONR1_PERC0                    (*((volatile unsigned int*)(0x422BA818UL)))
#define bM4_TMRA4_PCONR1_PERC1                    (*((volatile unsigned int*)(0x422BA81CUL)))
#define bM4_TMRA4_PCONR1_FORC0                    (*((volatile unsigned int*)(0x422BA820UL)))
#define bM4_TMRA4_PCONR1_FORC1                    (*((volatile unsigned int*)(0x422BA824UL)))
#define bM4_TMRA4_PCONR1_OUTEN                    (*((volatile unsigned int*)(0x422BA830UL)))
#define bM4_TMRA4_PCONR2_STAC0                    (*((volatile unsigned int*)(0x422BA880UL)))
#define bM4_TMRA4_PCONR2_STAC1                    (*((volatile unsigned int*)(0x422BA884UL)))
#define bM4_TMRA4_PCONR2_STPC0                    (*((volatile unsigned int*)(0x422BA888UL)))
#define bM4_TMRA4_PCONR2_STPC1                    (*((volatile unsigned int*)(0x422BA88CUL)))
#define bM4_TMRA4_PCONR2_CMPC0                    (*((volatile unsigned int*)(0x422BA890UL)))
#define bM4_TMRA4_PCONR2_CMPC1                    (*((volatile unsigned int*)(0x422BA894UL)))
#define bM4_TMRA4_PCONR2_PERC0                    (*((volatile unsigned int*)(0x422BA898UL)))
#define bM4_TMRA4_PCONR2_PERC1                    (*((volatile unsigned int*)(0x422BA89CUL)))
#define bM4_TMRA4_PCONR2_FORC0                    (*((volatile unsigned int*)(0x422BA8A0UL)))
#define bM4_TMRA4_PCONR2_FORC1                    (*((volatile unsigned int*)(0x422BA8A4UL)))
#define bM4_TMRA4_PCONR2_OUTEN                    (*((volatile unsigned int*)(0x422BA8B0UL)))
#define bM4_TMRA4_PCONR3_STAC0                    (*((volatile unsigned int*)(0x422BA900UL)))
#define bM4_TMRA4_PCONR3_STAC1                    (*((volatile unsigned int*)(0x422BA904UL)))
#define bM4_TMRA4_PCONR3_STPC0                    (*((volatile unsigned int*)(0x422BA908UL)))
#define bM4_TMRA4_PCONR3_STPC1                    (*((volatile unsigned int*)(0x422BA90CUL)))
#define bM4_TMRA4_PCONR3_CMPC0                    (*((volatile unsigned int*)(0x422BA910UL)))
#define bM4_TMRA4_PCONR3_CMPC1                    (*((volatile unsigned int*)(0x422BA914UL)))
#define bM4_TMRA4_PCONR3_PERC0                    (*((volatile unsigned int*)(0x422BA918UL)))
#define bM4_TMRA4_PCONR3_PERC1                    (*((volatile unsigned int*)(0x422BA91CUL)))
#define bM4_TMRA4_PCONR3_FORC0                    (*((volatile unsigned int*)(0x422BA920UL)))
#define bM4_TMRA4_PCONR3_FORC1                    (*((volatile unsigned int*)(0x422BA924UL)))
#define bM4_TMRA4_PCONR3_OUTEN                    (*((volatile unsigned int*)(0x422BA930UL)))
#define bM4_TMRA4_PCONR4_STAC0                    (*((volatile unsigned int*)(0x422BA980UL)))
#define bM4_TMRA4_PCONR4_STAC1                    (*((volatile unsigned int*)(0x422BA984UL)))
#define bM4_TMRA4_PCONR4_STPC0                    (*((volatile unsigned int*)(0x422BA988UL)))
#define bM4_TMRA4_PCONR4_STPC1                    (*((volatile unsigned int*)(0x422BA98CUL)))
#define bM4_TMRA4_PCONR4_CMPC0                    (*((volatile unsigned int*)(0x422BA990UL)))
#define bM4_TMRA4_PCONR4_CMPC1                    (*((volatile unsigned int*)(0x422BA994UL)))
#define bM4_TMRA4_PCONR4_PERC0                    (*((volatile unsigned int*)(0x422BA998UL)))
#define bM4_TMRA4_PCONR4_PERC1                    (*((volatile unsigned int*)(0x422BA99CUL)))
#define bM4_TMRA4_PCONR4_FORC0                    (*((volatile unsigned int*)(0x422BA9A0UL)))
#define bM4_TMRA4_PCONR4_FORC1                    (*((volatile unsigned int*)(0x422BA9A4UL)))
#define bM4_TMRA4_PCONR4_OUTEN                    (*((volatile unsigned int*)(0x422BA9B0UL)))
#define bM4_TMRA4_PCONR5_STAC0                    (*((volatile unsigned int*)(0x422BAA00UL)))
#define bM4_TMRA4_PCONR5_STAC1                    (*((volatile unsigned int*)(0x422BAA04UL)))
#define bM4_TMRA4_PCONR5_STPC0                    (*((volatile unsigned int*)(0x422BAA08UL)))
#define bM4_TMRA4_PCONR5_STPC1                    (*((volatile unsigned int*)(0x422BAA0CUL)))
#define bM4_TMRA4_PCONR5_CMPC0                    (*((volatile unsigned int*)(0x422BAA10UL)))
#define bM4_TMRA4_PCONR5_CMPC1                    (*((volatile unsigned int*)(0x422BAA14UL)))
#define bM4_TMRA4_PCONR5_PERC0                    (*((volatile unsigned int*)(0x422BAA18UL)))
#define bM4_TMRA4_PCONR5_PERC1                    (*((volatile unsigned int*)(0x422BAA1CUL)))
#define bM4_TMRA4_PCONR5_FORC0                    (*((volatile unsigned int*)(0x422BAA20UL)))
#define bM4_TMRA4_PCONR5_FORC1                    (*((volatile unsigned int*)(0x422BAA24UL)))
#define bM4_TMRA4_PCONR5_OUTEN                    (*((volatile unsigned int*)(0x422BAA30UL)))
#define bM4_TMRA4_PCONR6_STAC0                    (*((volatile unsigned int*)(0x422BAA80UL)))
#define bM4_TMRA4_PCONR6_STAC1                    (*((volatile unsigned int*)(0x422BAA84UL)))
#define bM4_TMRA4_PCONR6_STPC0                    (*((volatile unsigned int*)(0x422BAA88UL)))
#define bM4_TMRA4_PCONR6_STPC1                    (*((volatile unsigned int*)(0x422BAA8CUL)))
#define bM4_TMRA4_PCONR6_CMPC0                    (*((volatile unsigned int*)(0x422BAA90UL)))
#define bM4_TMRA4_PCONR6_CMPC1                    (*((volatile unsigned int*)(0x422BAA94UL)))
#define bM4_TMRA4_PCONR6_PERC0                    (*((volatile unsigned int*)(0x422BAA98UL)))
#define bM4_TMRA4_PCONR6_PERC1                    (*((volatile unsigned int*)(0x422BAA9CUL)))
#define bM4_TMRA4_PCONR6_FORC0                    (*((volatile unsigned int*)(0x422BAAA0UL)))
#define bM4_TMRA4_PCONR6_FORC1                    (*((volatile unsigned int*)(0x422BAAA4UL)))
#define bM4_TMRA4_PCONR6_OUTEN                    (*((volatile unsigned int*)(0x422BAAB0UL)))
#define bM4_TMRA4_PCONR7_STAC0                    (*((volatile unsigned int*)(0x422BAB00UL)))
#define bM4_TMRA4_PCONR7_STAC1                    (*((volatile unsigned int*)(0x422BAB04UL)))
#define bM4_TMRA4_PCONR7_STPC0                    (*((volatile unsigned int*)(0x422BAB08UL)))
#define bM4_TMRA4_PCONR7_STPC1                    (*((volatile unsigned int*)(0x422BAB0CUL)))
#define bM4_TMRA4_PCONR7_CMPC0                    (*((volatile unsigned int*)(0x422BAB10UL)))
#define bM4_TMRA4_PCONR7_CMPC1                    (*((volatile unsigned int*)(0x422BAB14UL)))
#define bM4_TMRA4_PCONR7_PERC0                    (*((volatile unsigned int*)(0x422BAB18UL)))
#define bM4_TMRA4_PCONR7_PERC1                    (*((volatile unsigned int*)(0x422BAB1CUL)))
#define bM4_TMRA4_PCONR7_FORC0                    (*((volatile unsigned int*)(0x422BAB20UL)))
#define bM4_TMRA4_PCONR7_FORC1                    (*((volatile unsigned int*)(0x422BAB24UL)))
#define bM4_TMRA4_PCONR7_OUTEN                    (*((volatile unsigned int*)(0x422BAB30UL)))
#define bM4_TMRA4_PCONR8_STAC0                    (*((volatile unsigned int*)(0x422BAB80UL)))
#define bM4_TMRA4_PCONR8_STAC1                    (*((volatile unsigned int*)(0x422BAB84UL)))
#define bM4_TMRA4_PCONR8_STPC0                    (*((volatile unsigned int*)(0x422BAB88UL)))
#define bM4_TMRA4_PCONR8_STPC1                    (*((volatile unsigned int*)(0x422BAB8CUL)))
#define bM4_TMRA4_PCONR8_CMPC0                    (*((volatile unsigned int*)(0x422BAB90UL)))
#define bM4_TMRA4_PCONR8_CMPC1                    (*((volatile unsigned int*)(0x422BAB94UL)))
#define bM4_TMRA4_PCONR8_PERC0                    (*((volatile unsigned int*)(0x422BAB98UL)))
#define bM4_TMRA4_PCONR8_PERC1                    (*((volatile unsigned int*)(0x422BAB9CUL)))
#define bM4_TMRA4_PCONR8_FORC0                    (*((volatile unsigned int*)(0x422BABA0UL)))
#define bM4_TMRA4_PCONR8_FORC1                    (*((volatile unsigned int*)(0x422BABA4UL)))
#define bM4_TMRA4_PCONR8_OUTEN                    (*((volatile unsigned int*)(0x422BABB0UL)))
#define bM4_TMRA5_CNTER_CNT0                      (*((volatile unsigned int*)(0x422C0000UL)))
#define bM4_TMRA5_CNTER_CNT1                      (*((volatile unsigned int*)(0x422C0004UL)))
#define bM4_TMRA5_CNTER_CNT2                      (*((volatile unsigned int*)(0x422C0008UL)))
#define bM4_TMRA5_CNTER_CNT3                      (*((volatile unsigned int*)(0x422C000CUL)))
#define bM4_TMRA5_CNTER_CNT4                      (*((volatile unsigned int*)(0x422C0010UL)))
#define bM4_TMRA5_CNTER_CNT5                      (*((volatile unsigned int*)(0x422C0014UL)))
#define bM4_TMRA5_CNTER_CNT6                      (*((volatile unsigned int*)(0x422C0018UL)))
#define bM4_TMRA5_CNTER_CNT7                      (*((volatile unsigned int*)(0x422C001CUL)))
#define bM4_TMRA5_CNTER_CNT8                      (*((volatile unsigned int*)(0x422C0020UL)))
#define bM4_TMRA5_CNTER_CNT9                      (*((volatile unsigned int*)(0x422C0024UL)))
#define bM4_TMRA5_CNTER_CNT10                     (*((volatile unsigned int*)(0x422C0028UL)))
#define bM4_TMRA5_CNTER_CNT11                     (*((volatile unsigned int*)(0x422C002CUL)))
#define bM4_TMRA5_CNTER_CNT12                     (*((volatile unsigned int*)(0x422C0030UL)))
#define bM4_TMRA5_CNTER_CNT13                     (*((volatile unsigned int*)(0x422C0034UL)))
#define bM4_TMRA5_CNTER_CNT14                     (*((volatile unsigned int*)(0x422C0038UL)))
#define bM4_TMRA5_CNTER_CNT15                     (*((volatile unsigned int*)(0x422C003CUL)))
#define bM4_TMRA5_PERAR_PER0                      (*((volatile unsigned int*)(0x422C0080UL)))
#define bM4_TMRA5_PERAR_PER1                      (*((volatile unsigned int*)(0x422C0084UL)))
#define bM4_TMRA5_PERAR_PER2                      (*((volatile unsigned int*)(0x422C0088UL)))
#define bM4_TMRA5_PERAR_PER3                      (*((volatile unsigned int*)(0x422C008CUL)))
#define bM4_TMRA5_PERAR_PER4                      (*((volatile unsigned int*)(0x422C0090UL)))
#define bM4_TMRA5_PERAR_PER5                      (*((volatile unsigned int*)(0x422C0094UL)))
#define bM4_TMRA5_PERAR_PER6                      (*((volatile unsigned int*)(0x422C0098UL)))
#define bM4_TMRA5_PERAR_PER7                      (*((volatile unsigned int*)(0x422C009CUL)))
#define bM4_TMRA5_PERAR_PER8                      (*((volatile unsigned int*)(0x422C00A0UL)))
#define bM4_TMRA5_PERAR_PER9                      (*((volatile unsigned int*)(0x422C00A4UL)))
#define bM4_TMRA5_PERAR_PER10                     (*((volatile unsigned int*)(0x422C00A8UL)))
#define bM4_TMRA5_PERAR_PER11                     (*((volatile unsigned int*)(0x422C00ACUL)))
#define bM4_TMRA5_PERAR_PER12                     (*((volatile unsigned int*)(0x422C00B0UL)))
#define bM4_TMRA5_PERAR_PER13                     (*((volatile unsigned int*)(0x422C00B4UL)))
#define bM4_TMRA5_PERAR_PER14                     (*((volatile unsigned int*)(0x422C00B8UL)))
#define bM4_TMRA5_PERAR_PER15                     (*((volatile unsigned int*)(0x422C00BCUL)))
#define bM4_TMRA5_CMPAR1_CMP0                     (*((volatile unsigned int*)(0x422C0800UL)))
#define bM4_TMRA5_CMPAR1_CMP1                     (*((volatile unsigned int*)(0x422C0804UL)))
#define bM4_TMRA5_CMPAR1_CMP2                     (*((volatile unsigned int*)(0x422C0808UL)))
#define bM4_TMRA5_CMPAR1_CMP3                     (*((volatile unsigned int*)(0x422C080CUL)))
#define bM4_TMRA5_CMPAR1_CMP4                     (*((volatile unsigned int*)(0x422C0810UL)))
#define bM4_TMRA5_CMPAR1_CMP5                     (*((volatile unsigned int*)(0x422C0814UL)))
#define bM4_TMRA5_CMPAR1_CMP6                     (*((volatile unsigned int*)(0x422C0818UL)))
#define bM4_TMRA5_CMPAR1_CMP7                     (*((volatile unsigned int*)(0x422C081CUL)))
#define bM4_TMRA5_CMPAR1_CMP8                     (*((volatile unsigned int*)(0x422C0820UL)))
#define bM4_TMRA5_CMPAR1_CMP9                     (*((volatile unsigned int*)(0x422C0824UL)))
#define bM4_TMRA5_CMPAR1_CMP10                    (*((volatile unsigned int*)(0x422C0828UL)))
#define bM4_TMRA5_CMPAR1_CMP11                    (*((volatile unsigned int*)(0x422C082CUL)))
#define bM4_TMRA5_CMPAR1_CMP12                    (*((volatile unsigned int*)(0x422C0830UL)))
#define bM4_TMRA5_CMPAR1_CMP13                    (*((volatile unsigned int*)(0x422C0834UL)))
#define bM4_TMRA5_CMPAR1_CMP14                    (*((volatile unsigned int*)(0x422C0838UL)))
#define bM4_TMRA5_CMPAR1_CMP15                    (*((volatile unsigned int*)(0x422C083CUL)))
#define bM4_TMRA5_CMPAR2_CMP0                     (*((volatile unsigned int*)(0x422C0880UL)))
#define bM4_TMRA5_CMPAR2_CMP1                     (*((volatile unsigned int*)(0x422C0884UL)))
#define bM4_TMRA5_CMPAR2_CMP2                     (*((volatile unsigned int*)(0x422C0888UL)))
#define bM4_TMRA5_CMPAR2_CMP3                     (*((volatile unsigned int*)(0x422C088CUL)))
#define bM4_TMRA5_CMPAR2_CMP4                     (*((volatile unsigned int*)(0x422C0890UL)))
#define bM4_TMRA5_CMPAR2_CMP5                     (*((volatile unsigned int*)(0x422C0894UL)))
#define bM4_TMRA5_CMPAR2_CMP6                     (*((volatile unsigned int*)(0x422C0898UL)))
#define bM4_TMRA5_CMPAR2_CMP7                     (*((volatile unsigned int*)(0x422C089CUL)))
#define bM4_TMRA5_CMPAR2_CMP8                     (*((volatile unsigned int*)(0x422C08A0UL)))
#define bM4_TMRA5_CMPAR2_CMP9                     (*((volatile unsigned int*)(0x422C08A4UL)))
#define bM4_TMRA5_CMPAR2_CMP10                    (*((volatile unsigned int*)(0x422C08A8UL)))
#define bM4_TMRA5_CMPAR2_CMP11                    (*((volatile unsigned int*)(0x422C08ACUL)))
#define bM4_TMRA5_CMPAR2_CMP12                    (*((volatile unsigned int*)(0x422C08B0UL)))
#define bM4_TMRA5_CMPAR2_CMP13                    (*((volatile unsigned int*)(0x422C08B4UL)))
#define bM4_TMRA5_CMPAR2_CMP14                    (*((volatile unsigned int*)(0x422C08B8UL)))
#define bM4_TMRA5_CMPAR2_CMP15                    (*((volatile unsigned int*)(0x422C08BCUL)))
#define bM4_TMRA5_CMPAR3_CMP0                     (*((volatile unsigned int*)(0x422C0900UL)))
#define bM4_TMRA5_CMPAR3_CMP1                     (*((volatile unsigned int*)(0x422C0904UL)))
#define bM4_TMRA5_CMPAR3_CMP2                     (*((volatile unsigned int*)(0x422C0908UL)))
#define bM4_TMRA5_CMPAR3_CMP3                     (*((volatile unsigned int*)(0x422C090CUL)))
#define bM4_TMRA5_CMPAR3_CMP4                     (*((volatile unsigned int*)(0x422C0910UL)))
#define bM4_TMRA5_CMPAR3_CMP5                     (*((volatile unsigned int*)(0x422C0914UL)))
#define bM4_TMRA5_CMPAR3_CMP6                     (*((volatile unsigned int*)(0x422C0918UL)))
#define bM4_TMRA5_CMPAR3_CMP7                     (*((volatile unsigned int*)(0x422C091CUL)))
#define bM4_TMRA5_CMPAR3_CMP8                     (*((volatile unsigned int*)(0x422C0920UL)))
#define bM4_TMRA5_CMPAR3_CMP9                     (*((volatile unsigned int*)(0x422C0924UL)))
#define bM4_TMRA5_CMPAR3_CMP10                    (*((volatile unsigned int*)(0x422C0928UL)))
#define bM4_TMRA5_CMPAR3_CMP11                    (*((volatile unsigned int*)(0x422C092CUL)))
#define bM4_TMRA5_CMPAR3_CMP12                    (*((volatile unsigned int*)(0x422C0930UL)))
#define bM4_TMRA5_CMPAR3_CMP13                    (*((volatile unsigned int*)(0x422C0934UL)))
#define bM4_TMRA5_CMPAR3_CMP14                    (*((volatile unsigned int*)(0x422C0938UL)))
#define bM4_TMRA5_CMPAR3_CMP15                    (*((volatile unsigned int*)(0x422C093CUL)))
#define bM4_TMRA5_CMPAR4_CMP0                     (*((volatile unsigned int*)(0x422C0980UL)))
#define bM4_TMRA5_CMPAR4_CMP1                     (*((volatile unsigned int*)(0x422C0984UL)))
#define bM4_TMRA5_CMPAR4_CMP2                     (*((volatile unsigned int*)(0x422C0988UL)))
#define bM4_TMRA5_CMPAR4_CMP3                     (*((volatile unsigned int*)(0x422C098CUL)))
#define bM4_TMRA5_CMPAR4_CMP4                     (*((volatile unsigned int*)(0x422C0990UL)))
#define bM4_TMRA5_CMPAR4_CMP5                     (*((volatile unsigned int*)(0x422C0994UL)))
#define bM4_TMRA5_CMPAR4_CMP6                     (*((volatile unsigned int*)(0x422C0998UL)))
#define bM4_TMRA5_CMPAR4_CMP7                     (*((volatile unsigned int*)(0x422C099CUL)))
#define bM4_TMRA5_CMPAR4_CMP8                     (*((volatile unsigned int*)(0x422C09A0UL)))
#define bM4_TMRA5_CMPAR4_CMP9                     (*((volatile unsigned int*)(0x422C09A4UL)))
#define bM4_TMRA5_CMPAR4_CMP10                    (*((volatile unsigned int*)(0x422C09A8UL)))
#define bM4_TMRA5_CMPAR4_CMP11                    (*((volatile unsigned int*)(0x422C09ACUL)))
#define bM4_TMRA5_CMPAR4_CMP12                    (*((volatile unsigned int*)(0x422C09B0UL)))
#define bM4_TMRA5_CMPAR4_CMP13                    (*((volatile unsigned int*)(0x422C09B4UL)))
#define bM4_TMRA5_CMPAR4_CMP14                    (*((volatile unsigned int*)(0x422C09B8UL)))
#define bM4_TMRA5_CMPAR4_CMP15                    (*((volatile unsigned int*)(0x422C09BCUL)))
#define bM4_TMRA5_CMPAR5_CMP0                     (*((volatile unsigned int*)(0x422C0A00UL)))
#define bM4_TMRA5_CMPAR5_CMP1                     (*((volatile unsigned int*)(0x422C0A04UL)))
#define bM4_TMRA5_CMPAR5_CMP2                     (*((volatile unsigned int*)(0x422C0A08UL)))
#define bM4_TMRA5_CMPAR5_CMP3                     (*((volatile unsigned int*)(0x422C0A0CUL)))
#define bM4_TMRA5_CMPAR5_CMP4                     (*((volatile unsigned int*)(0x422C0A10UL)))
#define bM4_TMRA5_CMPAR5_CMP5                     (*((volatile unsigned int*)(0x422C0A14UL)))
#define bM4_TMRA5_CMPAR5_CMP6                     (*((volatile unsigned int*)(0x422C0A18UL)))
#define bM4_TMRA5_CMPAR5_CMP7                     (*((volatile unsigned int*)(0x422C0A1CUL)))
#define bM4_TMRA5_CMPAR5_CMP8                     (*((volatile unsigned int*)(0x422C0A20UL)))
#define bM4_TMRA5_CMPAR5_CMP9                     (*((volatile unsigned int*)(0x422C0A24UL)))
#define bM4_TMRA5_CMPAR5_CMP10                    (*((volatile unsigned int*)(0x422C0A28UL)))
#define bM4_TMRA5_CMPAR5_CMP11                    (*((volatile unsigned int*)(0x422C0A2CUL)))
#define bM4_TMRA5_CMPAR5_CMP12                    (*((volatile unsigned int*)(0x422C0A30UL)))
#define bM4_TMRA5_CMPAR5_CMP13                    (*((volatile unsigned int*)(0x422C0A34UL)))
#define bM4_TMRA5_CMPAR5_CMP14                    (*((volatile unsigned int*)(0x422C0A38UL)))
#define bM4_TMRA5_CMPAR5_CMP15                    (*((volatile unsigned int*)(0x422C0A3CUL)))
#define bM4_TMRA5_CMPAR6_CMP0                     (*((volatile unsigned int*)(0x422C0A80UL)))
#define bM4_TMRA5_CMPAR6_CMP1                     (*((volatile unsigned int*)(0x422C0A84UL)))
#define bM4_TMRA5_CMPAR6_CMP2                     (*((volatile unsigned int*)(0x422C0A88UL)))
#define bM4_TMRA5_CMPAR6_CMP3                     (*((volatile unsigned int*)(0x422C0A8CUL)))
#define bM4_TMRA5_CMPAR6_CMP4                     (*((volatile unsigned int*)(0x422C0A90UL)))
#define bM4_TMRA5_CMPAR6_CMP5                     (*((volatile unsigned int*)(0x422C0A94UL)))
#define bM4_TMRA5_CMPAR6_CMP6                     (*((volatile unsigned int*)(0x422C0A98UL)))
#define bM4_TMRA5_CMPAR6_CMP7                     (*((volatile unsigned int*)(0x422C0A9CUL)))
#define bM4_TMRA5_CMPAR6_CMP8                     (*((volatile unsigned int*)(0x422C0AA0UL)))
#define bM4_TMRA5_CMPAR6_CMP9                     (*((volatile unsigned int*)(0x422C0AA4UL)))
#define bM4_TMRA5_CMPAR6_CMP10                    (*((volatile unsigned int*)(0x422C0AA8UL)))
#define bM4_TMRA5_CMPAR6_CMP11                    (*((volatile unsigned int*)(0x422C0AACUL)))
#define bM4_TMRA5_CMPAR6_CMP12                    (*((volatile unsigned int*)(0x422C0AB0UL)))
#define bM4_TMRA5_CMPAR6_CMP13                    (*((volatile unsigned int*)(0x422C0AB4UL)))
#define bM4_TMRA5_CMPAR6_CMP14                    (*((volatile unsigned int*)(0x422C0AB8UL)))
#define bM4_TMRA5_CMPAR6_CMP15                    (*((volatile unsigned int*)(0x422C0ABCUL)))
#define bM4_TMRA5_CMPAR7_CMP0                     (*((volatile unsigned int*)(0x422C0B00UL)))
#define bM4_TMRA5_CMPAR7_CMP1                     (*((volatile unsigned int*)(0x422C0B04UL)))
#define bM4_TMRA5_CMPAR7_CMP2                     (*((volatile unsigned int*)(0x422C0B08UL)))
#define bM4_TMRA5_CMPAR7_CMP3                     (*((volatile unsigned int*)(0x422C0B0CUL)))
#define bM4_TMRA5_CMPAR7_CMP4                     (*((volatile unsigned int*)(0x422C0B10UL)))
#define bM4_TMRA5_CMPAR7_CMP5                     (*((volatile unsigned int*)(0x422C0B14UL)))
#define bM4_TMRA5_CMPAR7_CMP6                     (*((volatile unsigned int*)(0x422C0B18UL)))
#define bM4_TMRA5_CMPAR7_CMP7                     (*((volatile unsigned int*)(0x422C0B1CUL)))
#define bM4_TMRA5_CMPAR7_CMP8                     (*((volatile unsigned int*)(0x422C0B20UL)))
#define bM4_TMRA5_CMPAR7_CMP9                     (*((volatile unsigned int*)(0x422C0B24UL)))
#define bM4_TMRA5_CMPAR7_CMP10                    (*((volatile unsigned int*)(0x422C0B28UL)))
#define bM4_TMRA5_CMPAR7_CMP11                    (*((volatile unsigned int*)(0x422C0B2CUL)))
#define bM4_TMRA5_CMPAR7_CMP12                    (*((volatile unsigned int*)(0x422C0B30UL)))
#define bM4_TMRA5_CMPAR7_CMP13                    (*((volatile unsigned int*)(0x422C0B34UL)))
#define bM4_TMRA5_CMPAR7_CMP14                    (*((volatile unsigned int*)(0x422C0B38UL)))
#define bM4_TMRA5_CMPAR7_CMP15                    (*((volatile unsigned int*)(0x422C0B3CUL)))
#define bM4_TMRA5_CMPAR8_CMP0                     (*((volatile unsigned int*)(0x422C0B80UL)))
#define bM4_TMRA5_CMPAR8_CMP1                     (*((volatile unsigned int*)(0x422C0B84UL)))
#define bM4_TMRA5_CMPAR8_CMP2                     (*((volatile unsigned int*)(0x422C0B88UL)))
#define bM4_TMRA5_CMPAR8_CMP3                     (*((volatile unsigned int*)(0x422C0B8CUL)))
#define bM4_TMRA5_CMPAR8_CMP4                     (*((volatile unsigned int*)(0x422C0B90UL)))
#define bM4_TMRA5_CMPAR8_CMP5                     (*((volatile unsigned int*)(0x422C0B94UL)))
#define bM4_TMRA5_CMPAR8_CMP6                     (*((volatile unsigned int*)(0x422C0B98UL)))
#define bM4_TMRA5_CMPAR8_CMP7                     (*((volatile unsigned int*)(0x422C0B9CUL)))
#define bM4_TMRA5_CMPAR8_CMP8                     (*((volatile unsigned int*)(0x422C0BA0UL)))
#define bM4_TMRA5_CMPAR8_CMP9                     (*((volatile unsigned int*)(0x422C0BA4UL)))
#define bM4_TMRA5_CMPAR8_CMP10                    (*((volatile unsigned int*)(0x422C0BA8UL)))
#define bM4_TMRA5_CMPAR8_CMP11                    (*((volatile unsigned int*)(0x422C0BACUL)))
#define bM4_TMRA5_CMPAR8_CMP12                    (*((volatile unsigned int*)(0x422C0BB0UL)))
#define bM4_TMRA5_CMPAR8_CMP13                    (*((volatile unsigned int*)(0x422C0BB4UL)))
#define bM4_TMRA5_CMPAR8_CMP14                    (*((volatile unsigned int*)(0x422C0BB8UL)))
#define bM4_TMRA5_CMPAR8_CMP15                    (*((volatile unsigned int*)(0x422C0BBCUL)))
#define bM4_TMRA5_BCSTR_START                     (*((volatile unsigned int*)(0x422C1000UL)))
#define bM4_TMRA5_BCSTR_DIR                       (*((volatile unsigned int*)(0x422C1004UL)))
#define bM4_TMRA5_BCSTR_MODE                      (*((volatile unsigned int*)(0x422C1008UL)))
#define bM4_TMRA5_BCSTR_SYNST                     (*((volatile unsigned int*)(0x422C100CUL)))
#define bM4_TMRA5_BCSTR_CKDIV0                    (*((volatile unsigned int*)(0x422C1010UL)))
#define bM4_TMRA5_BCSTR_CKDIV1                    (*((volatile unsigned int*)(0x422C1014UL)))
#define bM4_TMRA5_BCSTR_CKDIV2                    (*((volatile unsigned int*)(0x422C1018UL)))
#define bM4_TMRA5_BCSTR_CKDIV3                    (*((volatile unsigned int*)(0x422C101CUL)))
#define bM4_TMRA5_BCSTR_ITENOVF                   (*((volatile unsigned int*)(0x422C1030UL)))
#define bM4_TMRA5_BCSTR_ITENUDF                   (*((volatile unsigned int*)(0x422C1034UL)))
#define bM4_TMRA5_BCSTR_OVFF                      (*((volatile unsigned int*)(0x422C1038UL)))
#define bM4_TMRA5_BCSTR_UDFF                      (*((volatile unsigned int*)(0x422C103CUL)))
#define bM4_TMRA5_HCONR_HSTA0                     (*((volatile unsigned int*)(0x422C1080UL)))
#define bM4_TMRA5_HCONR_HSTA1                     (*((volatile unsigned int*)(0x422C1084UL)))
#define bM4_TMRA5_HCONR_HSTA2                     (*((volatile unsigned int*)(0x422C1088UL)))
#define bM4_TMRA5_HCONR_HSTP0                     (*((volatile unsigned int*)(0x422C1090UL)))
#define bM4_TMRA5_HCONR_HSTP1                     (*((volatile unsigned int*)(0x422C1094UL)))
#define bM4_TMRA5_HCONR_HSTP2                     (*((volatile unsigned int*)(0x422C1098UL)))
#define bM4_TMRA5_HCONR_HCLE0                     (*((volatile unsigned int*)(0x422C10A0UL)))
#define bM4_TMRA5_HCONR_HCLE1                     (*((volatile unsigned int*)(0x422C10A4UL)))
#define bM4_TMRA5_HCONR_HCLE2                     (*((volatile unsigned int*)(0x422C10A8UL)))
#define bM4_TMRA5_HCONR_HCLE3                     (*((volatile unsigned int*)(0x422C10B0UL)))
#define bM4_TMRA5_HCONR_HCLE4                     (*((volatile unsigned int*)(0x422C10B4UL)))
#define bM4_TMRA5_HCONR_HCLE5                     (*((volatile unsigned int*)(0x422C10B8UL)))
#define bM4_TMRA5_HCONR_HCLE6                     (*((volatile unsigned int*)(0x422C10BCUL)))
#define bM4_TMRA5_HCUPR_HCUP0                     (*((volatile unsigned int*)(0x422C1100UL)))
#define bM4_TMRA5_HCUPR_HCUP1                     (*((volatile unsigned int*)(0x422C1104UL)))
#define bM4_TMRA5_HCUPR_HCUP2                     (*((volatile unsigned int*)(0x422C1108UL)))
#define bM4_TMRA5_HCUPR_HCUP3                     (*((volatile unsigned int*)(0x422C110CUL)))
#define bM4_TMRA5_HCUPR_HCUP4                     (*((volatile unsigned int*)(0x422C1110UL)))
#define bM4_TMRA5_HCUPR_HCUP5                     (*((volatile unsigned int*)(0x422C1114UL)))
#define bM4_TMRA5_HCUPR_HCUP6                     (*((volatile unsigned int*)(0x422C1118UL)))
#define bM4_TMRA5_HCUPR_HCUP7                     (*((volatile unsigned int*)(0x422C111CUL)))
#define bM4_TMRA5_HCUPR_HCUP8                     (*((volatile unsigned int*)(0x422C1120UL)))
#define bM4_TMRA5_HCUPR_HCUP9                     (*((volatile unsigned int*)(0x422C1124UL)))
#define bM4_TMRA5_HCUPR_HCUP10                    (*((volatile unsigned int*)(0x422C1128UL)))
#define bM4_TMRA5_HCUPR_HCUP11                    (*((volatile unsigned int*)(0x422C112CUL)))
#define bM4_TMRA5_HCUPR_HCUP12                    (*((volatile unsigned int*)(0x422C1130UL)))
#define bM4_TMRA5_HCDOR_HCDO0                     (*((volatile unsigned int*)(0x422C1180UL)))
#define bM4_TMRA5_HCDOR_HCDO1                     (*((volatile unsigned int*)(0x422C1184UL)))
#define bM4_TMRA5_HCDOR_HCDO2                     (*((volatile unsigned int*)(0x422C1188UL)))
#define bM4_TMRA5_HCDOR_HCDO3                     (*((volatile unsigned int*)(0x422C118CUL)))
#define bM4_TMRA5_HCDOR_HCDO4                     (*((volatile unsigned int*)(0x422C1190UL)))
#define bM4_TMRA5_HCDOR_HCDO5                     (*((volatile unsigned int*)(0x422C1194UL)))
#define bM4_TMRA5_HCDOR_HCDO6                     (*((volatile unsigned int*)(0x422C1198UL)))
#define bM4_TMRA5_HCDOR_HCDO7                     (*((volatile unsigned int*)(0x422C119CUL)))
#define bM4_TMRA5_HCDOR_HCDO8                     (*((volatile unsigned int*)(0x422C11A0UL)))
#define bM4_TMRA5_HCDOR_HCDO9                     (*((volatile unsigned int*)(0x422C11A4UL)))
#define bM4_TMRA5_HCDOR_HCDO10                    (*((volatile unsigned int*)(0x422C11A8UL)))
#define bM4_TMRA5_HCDOR_HCDO11                    (*((volatile unsigned int*)(0x422C11ACUL)))
#define bM4_TMRA5_HCDOR_HCDO12                    (*((volatile unsigned int*)(0x422C11B0UL)))
#define bM4_TMRA5_ICONR_ITEN1                     (*((volatile unsigned int*)(0x422C1200UL)))
#define bM4_TMRA5_ICONR_ITEN2                     (*((volatile unsigned int*)(0x422C1204UL)))
#define bM4_TMRA5_ICONR_ITEN3                     (*((volatile unsigned int*)(0x422C1208UL)))
#define bM4_TMRA5_ICONR_ITEN4                     (*((volatile unsigned int*)(0x422C120CUL)))
#define bM4_TMRA5_ICONR_ITEN5                     (*((volatile unsigned int*)(0x422C1210UL)))
#define bM4_TMRA5_ICONR_ITEN6                     (*((volatile unsigned int*)(0x422C1214UL)))
#define bM4_TMRA5_ICONR_ITEN7                     (*((volatile unsigned int*)(0x422C1218UL)))
#define bM4_TMRA5_ICONR_ITEN8                     (*((volatile unsigned int*)(0x422C121CUL)))
#define bM4_TMRA5_ECONR_ETEN1                     (*((volatile unsigned int*)(0x422C1280UL)))
#define bM4_TMRA5_ECONR_ETEN2                     (*((volatile unsigned int*)(0x422C1284UL)))
#define bM4_TMRA5_ECONR_ETEN3                     (*((volatile unsigned int*)(0x422C1288UL)))
#define bM4_TMRA5_ECONR_ETEN4                     (*((volatile unsigned int*)(0x422C128CUL)))
#define bM4_TMRA5_ECONR_ETEN5                     (*((volatile unsigned int*)(0x422C1290UL)))
#define bM4_TMRA5_ECONR_ETEN6                     (*((volatile unsigned int*)(0x422C1294UL)))
#define bM4_TMRA5_ECONR_ETEN7                     (*((volatile unsigned int*)(0x422C1298UL)))
#define bM4_TMRA5_ECONR_ETEN8                     (*((volatile unsigned int*)(0x422C129CUL)))
#define bM4_TMRA5_FCONR_NOFIENTG                  (*((volatile unsigned int*)(0x422C1300UL)))
#define bM4_TMRA5_FCONR_NOFICKTG0                 (*((volatile unsigned int*)(0x422C1304UL)))
#define bM4_TMRA5_FCONR_NOFICKTG1                 (*((volatile unsigned int*)(0x422C1308UL)))
#define bM4_TMRA5_FCONR_NOFIENCA                  (*((volatile unsigned int*)(0x422C1320UL)))
#define bM4_TMRA5_FCONR_NOFICKCA0                 (*((volatile unsigned int*)(0x422C1324UL)))
#define bM4_TMRA5_FCONR_NOFICKCA1                 (*((volatile unsigned int*)(0x422C1328UL)))
#define bM4_TMRA5_FCONR_NOFIENCB                  (*((volatile unsigned int*)(0x422C1330UL)))
#define bM4_TMRA5_FCONR_NOFICKCB0                 (*((volatile unsigned int*)(0x422C1334UL)))
#define bM4_TMRA5_FCONR_NOFICKCB1                 (*((volatile unsigned int*)(0x422C1338UL)))
#define bM4_TMRA5_STFLR_CMPF1                     (*((volatile unsigned int*)(0x422C1380UL)))
#define bM4_TMRA5_STFLR_CMPF2                     (*((volatile unsigned int*)(0x422C1384UL)))
#define bM4_TMRA5_STFLR_CMPF3                     (*((volatile unsigned int*)(0x422C1388UL)))
#define bM4_TMRA5_STFLR_CMPF4                     (*((volatile unsigned int*)(0x422C138CUL)))
#define bM4_TMRA5_STFLR_CMPF5                     (*((volatile unsigned int*)(0x422C1390UL)))
#define bM4_TMRA5_STFLR_CMPF6                     (*((volatile unsigned int*)(0x422C1394UL)))
#define bM4_TMRA5_STFLR_CMPF7                     (*((volatile unsigned int*)(0x422C1398UL)))
#define bM4_TMRA5_STFLR_CMPF8                     (*((volatile unsigned int*)(0x422C139CUL)))
#define bM4_TMRA5_BCONR1_BEN                      (*((volatile unsigned int*)(0x422C1800UL)))
#define bM4_TMRA5_BCONR1_BSE0                     (*((volatile unsigned int*)(0x422C1804UL)))
#define bM4_TMRA5_BCONR1_BSE1                     (*((volatile unsigned int*)(0x422C1808UL)))
#define bM4_TMRA5_BCONR2_BEN                      (*((volatile unsigned int*)(0x422C1900UL)))
#define bM4_TMRA5_BCONR2_BSE0                     (*((volatile unsigned int*)(0x422C1904UL)))
#define bM4_TMRA5_BCONR2_BSE1                     (*((volatile unsigned int*)(0x422C1908UL)))
#define bM4_TMRA5_BCONR3_BEN                      (*((volatile unsigned int*)(0x422C1A00UL)))
#define bM4_TMRA5_BCONR3_BSE0                     (*((volatile unsigned int*)(0x422C1A04UL)))
#define bM4_TMRA5_BCONR3_BSE1                     (*((volatile unsigned int*)(0x422C1A08UL)))
#define bM4_TMRA5_BCONR4_BEN                      (*((volatile unsigned int*)(0x422C1B00UL)))
#define bM4_TMRA5_BCONR4_BSE0                     (*((volatile unsigned int*)(0x422C1B04UL)))
#define bM4_TMRA5_BCONR4_BSE1                     (*((volatile unsigned int*)(0x422C1B08UL)))
#define bM4_TMRA5_CCONR1_CAPMD                    (*((volatile unsigned int*)(0x422C2000UL)))
#define bM4_TMRA5_CCONR1_HICP0                    (*((volatile unsigned int*)(0x422C2010UL)))
#define bM4_TMRA5_CCONR1_HICP1                    (*((volatile unsigned int*)(0x422C2014UL)))
#define bM4_TMRA5_CCONR1_HICP2                    (*((volatile unsigned int*)(0x422C2018UL)))
#define bM4_TMRA5_CCONR1_HICP3                    (*((volatile unsigned int*)(0x422C2020UL)))
#define bM4_TMRA5_CCONR1_HICP4                    (*((volatile unsigned int*)(0x422C2024UL)))
#define bM4_TMRA5_CCONR1_NOFIENCP                 (*((volatile unsigned int*)(0x422C2030UL)))
#define bM4_TMRA5_CCONR1_NOFICKCP0                (*((volatile unsigned int*)(0x422C2034UL)))
#define bM4_TMRA5_CCONR1_NOFICKCP1                (*((volatile unsigned int*)(0x422C2038UL)))
#define bM4_TMRA5_CCONR2_CAPMD                    (*((volatile unsigned int*)(0x422C2080UL)))
#define bM4_TMRA5_CCONR2_HICP0                    (*((volatile unsigned int*)(0x422C2090UL)))
#define bM4_TMRA5_CCONR2_HICP1                    (*((volatile unsigned int*)(0x422C2094UL)))
#define bM4_TMRA5_CCONR2_HICP2                    (*((volatile unsigned int*)(0x422C2098UL)))
#define bM4_TMRA5_CCONR2_HICP3                    (*((volatile unsigned int*)(0x422C20A0UL)))
#define bM4_TMRA5_CCONR2_HICP4                    (*((volatile unsigned int*)(0x422C20A4UL)))
#define bM4_TMRA5_CCONR2_NOFIENCP                 (*((volatile unsigned int*)(0x422C20B0UL)))
#define bM4_TMRA5_CCONR2_NOFICKCP0                (*((volatile unsigned int*)(0x422C20B4UL)))
#define bM4_TMRA5_CCONR2_NOFICKCP1                (*((volatile unsigned int*)(0x422C20B8UL)))
#define bM4_TMRA5_CCONR3_CAPMD                    (*((volatile unsigned int*)(0x422C2100UL)))
#define bM4_TMRA5_CCONR3_HICP0                    (*((volatile unsigned int*)(0x422C2110UL)))
#define bM4_TMRA5_CCONR3_HICP1                    (*((volatile unsigned int*)(0x422C2114UL)))
#define bM4_TMRA5_CCONR3_HICP2                    (*((volatile unsigned int*)(0x422C2118UL)))
#define bM4_TMRA5_CCONR3_HICP3                    (*((volatile unsigned int*)(0x422C2120UL)))
#define bM4_TMRA5_CCONR3_HICP4                    (*((volatile unsigned int*)(0x422C2124UL)))
#define bM4_TMRA5_CCONR3_NOFIENCP                 (*((volatile unsigned int*)(0x422C2130UL)))
#define bM4_TMRA5_CCONR3_NOFICKCP0                (*((volatile unsigned int*)(0x422C2134UL)))
#define bM4_TMRA5_CCONR3_NOFICKCP1                (*((volatile unsigned int*)(0x422C2138UL)))
#define bM4_TMRA5_CCONR4_CAPMD                    (*((volatile unsigned int*)(0x422C2180UL)))
#define bM4_TMRA5_CCONR4_HICP0                    (*((volatile unsigned int*)(0x422C2190UL)))
#define bM4_TMRA5_CCONR4_HICP1                    (*((volatile unsigned int*)(0x422C2194UL)))
#define bM4_TMRA5_CCONR4_HICP2                    (*((volatile unsigned int*)(0x422C2198UL)))
#define bM4_TMRA5_CCONR4_HICP3                    (*((volatile unsigned int*)(0x422C21A0UL)))
#define bM4_TMRA5_CCONR4_HICP4                    (*((volatile unsigned int*)(0x422C21A4UL)))
#define bM4_TMRA5_CCONR4_NOFIENCP                 (*((volatile unsigned int*)(0x422C21B0UL)))
#define bM4_TMRA5_CCONR4_NOFICKCP0                (*((volatile unsigned int*)(0x422C21B4UL)))
#define bM4_TMRA5_CCONR4_NOFICKCP1                (*((volatile unsigned int*)(0x422C21B8UL)))
#define bM4_TMRA5_CCONR5_CAPMD                    (*((volatile unsigned int*)(0x422C2200UL)))
#define bM4_TMRA5_CCONR5_HICP0                    (*((volatile unsigned int*)(0x422C2210UL)))
#define bM4_TMRA5_CCONR5_HICP1                    (*((volatile unsigned int*)(0x422C2214UL)))
#define bM4_TMRA5_CCONR5_HICP2                    (*((volatile unsigned int*)(0x422C2218UL)))
#define bM4_TMRA5_CCONR5_HICP3                    (*((volatile unsigned int*)(0x422C2220UL)))
#define bM4_TMRA5_CCONR5_HICP4                    (*((volatile unsigned int*)(0x422C2224UL)))
#define bM4_TMRA5_CCONR5_NOFIENCP                 (*((volatile unsigned int*)(0x422C2230UL)))
#define bM4_TMRA5_CCONR5_NOFICKCP0                (*((volatile unsigned int*)(0x422C2234UL)))
#define bM4_TMRA5_CCONR5_NOFICKCP1                (*((volatile unsigned int*)(0x422C2238UL)))
#define bM4_TMRA5_CCONR6_CAPMD                    (*((volatile unsigned int*)(0x422C2280UL)))
#define bM4_TMRA5_CCONR6_HICP0                    (*((volatile unsigned int*)(0x422C2290UL)))
#define bM4_TMRA5_CCONR6_HICP1                    (*((volatile unsigned int*)(0x422C2294UL)))
#define bM4_TMRA5_CCONR6_HICP2                    (*((volatile unsigned int*)(0x422C2298UL)))
#define bM4_TMRA5_CCONR6_HICP3                    (*((volatile unsigned int*)(0x422C22A0UL)))
#define bM4_TMRA5_CCONR6_HICP4                    (*((volatile unsigned int*)(0x422C22A4UL)))
#define bM4_TMRA5_CCONR6_NOFIENCP                 (*((volatile unsigned int*)(0x422C22B0UL)))
#define bM4_TMRA5_CCONR6_NOFICKCP0                (*((volatile unsigned int*)(0x422C22B4UL)))
#define bM4_TMRA5_CCONR6_NOFICKCP1                (*((volatile unsigned int*)(0x422C22B8UL)))
#define bM4_TMRA5_CCONR7_CAPMD                    (*((volatile unsigned int*)(0x422C2300UL)))
#define bM4_TMRA5_CCONR7_HICP0                    (*((volatile unsigned int*)(0x422C2310UL)))
#define bM4_TMRA5_CCONR7_HICP1                    (*((volatile unsigned int*)(0x422C2314UL)))
#define bM4_TMRA5_CCONR7_HICP2                    (*((volatile unsigned int*)(0x422C2318UL)))
#define bM4_TMRA5_CCONR7_HICP3                    (*((volatile unsigned int*)(0x422C2320UL)))
#define bM4_TMRA5_CCONR7_HICP4                    (*((volatile unsigned int*)(0x422C2324UL)))
#define bM4_TMRA5_CCONR7_NOFIENCP                 (*((volatile unsigned int*)(0x422C2330UL)))
#define bM4_TMRA5_CCONR7_NOFICKCP0                (*((volatile unsigned int*)(0x422C2334UL)))
#define bM4_TMRA5_CCONR7_NOFICKCP1                (*((volatile unsigned int*)(0x422C2338UL)))
#define bM4_TMRA5_CCONR8_CAPMD                    (*((volatile unsigned int*)(0x422C2380UL)))
#define bM4_TMRA5_CCONR8_HICP0                    (*((volatile unsigned int*)(0x422C2390UL)))
#define bM4_TMRA5_CCONR8_HICP1                    (*((volatile unsigned int*)(0x422C2394UL)))
#define bM4_TMRA5_CCONR8_HICP2                    (*((volatile unsigned int*)(0x422C2398UL)))
#define bM4_TMRA5_CCONR8_HICP3                    (*((volatile unsigned int*)(0x422C23A0UL)))
#define bM4_TMRA5_CCONR8_HICP4                    (*((volatile unsigned int*)(0x422C23A4UL)))
#define bM4_TMRA5_CCONR8_NOFIENCP                 (*((volatile unsigned int*)(0x422C23B0UL)))
#define bM4_TMRA5_CCONR8_NOFICKCP0                (*((volatile unsigned int*)(0x422C23B4UL)))
#define bM4_TMRA5_CCONR8_NOFICKCP1                (*((volatile unsigned int*)(0x422C23B8UL)))
#define bM4_TMRA5_PCONR1_STAC0                    (*((volatile unsigned int*)(0x422C2800UL)))
#define bM4_TMRA5_PCONR1_STAC1                    (*((volatile unsigned int*)(0x422C2804UL)))
#define bM4_TMRA5_PCONR1_STPC0                    (*((volatile unsigned int*)(0x422C2808UL)))
#define bM4_TMRA5_PCONR1_STPC1                    (*((volatile unsigned int*)(0x422C280CUL)))
#define bM4_TMRA5_PCONR1_CMPC0                    (*((volatile unsigned int*)(0x422C2810UL)))
#define bM4_TMRA5_PCONR1_CMPC1                    (*((volatile unsigned int*)(0x422C2814UL)))
#define bM4_TMRA5_PCONR1_PERC0                    (*((volatile unsigned int*)(0x422C2818UL)))
#define bM4_TMRA5_PCONR1_PERC1                    (*((volatile unsigned int*)(0x422C281CUL)))
#define bM4_TMRA5_PCONR1_FORC0                    (*((volatile unsigned int*)(0x422C2820UL)))
#define bM4_TMRA5_PCONR1_FORC1                    (*((volatile unsigned int*)(0x422C2824UL)))
#define bM4_TMRA5_PCONR1_OUTEN                    (*((volatile unsigned int*)(0x422C2830UL)))
#define bM4_TMRA5_PCONR2_STAC0                    (*((volatile unsigned int*)(0x422C2880UL)))
#define bM4_TMRA5_PCONR2_STAC1                    (*((volatile unsigned int*)(0x422C2884UL)))
#define bM4_TMRA5_PCONR2_STPC0                    (*((volatile unsigned int*)(0x422C2888UL)))
#define bM4_TMRA5_PCONR2_STPC1                    (*((volatile unsigned int*)(0x422C288CUL)))
#define bM4_TMRA5_PCONR2_CMPC0                    (*((volatile unsigned int*)(0x422C2890UL)))
#define bM4_TMRA5_PCONR2_CMPC1                    (*((volatile unsigned int*)(0x422C2894UL)))
#define bM4_TMRA5_PCONR2_PERC0                    (*((volatile unsigned int*)(0x422C2898UL)))
#define bM4_TMRA5_PCONR2_PERC1                    (*((volatile unsigned int*)(0x422C289CUL)))
#define bM4_TMRA5_PCONR2_FORC0                    (*((volatile unsigned int*)(0x422C28A0UL)))
#define bM4_TMRA5_PCONR2_FORC1                    (*((volatile unsigned int*)(0x422C28A4UL)))
#define bM4_TMRA5_PCONR2_OUTEN                    (*((volatile unsigned int*)(0x422C28B0UL)))
#define bM4_TMRA5_PCONR3_STAC0                    (*((volatile unsigned int*)(0x422C2900UL)))
#define bM4_TMRA5_PCONR3_STAC1                    (*((volatile unsigned int*)(0x422C2904UL)))
#define bM4_TMRA5_PCONR3_STPC0                    (*((volatile unsigned int*)(0x422C2908UL)))
#define bM4_TMRA5_PCONR3_STPC1                    (*((volatile unsigned int*)(0x422C290CUL)))
#define bM4_TMRA5_PCONR3_CMPC0                    (*((volatile unsigned int*)(0x422C2910UL)))
#define bM4_TMRA5_PCONR3_CMPC1                    (*((volatile unsigned int*)(0x422C2914UL)))
#define bM4_TMRA5_PCONR3_PERC0                    (*((volatile unsigned int*)(0x422C2918UL)))
#define bM4_TMRA5_PCONR3_PERC1                    (*((volatile unsigned int*)(0x422C291CUL)))
#define bM4_TMRA5_PCONR3_FORC0                    (*((volatile unsigned int*)(0x422C2920UL)))
#define bM4_TMRA5_PCONR3_FORC1                    (*((volatile unsigned int*)(0x422C2924UL)))
#define bM4_TMRA5_PCONR3_OUTEN                    (*((volatile unsigned int*)(0x422C2930UL)))
#define bM4_TMRA5_PCONR4_STAC0                    (*((volatile unsigned int*)(0x422C2980UL)))
#define bM4_TMRA5_PCONR4_STAC1                    (*((volatile unsigned int*)(0x422C2984UL)))
#define bM4_TMRA5_PCONR4_STPC0                    (*((volatile unsigned int*)(0x422C2988UL)))
#define bM4_TMRA5_PCONR4_STPC1                    (*((volatile unsigned int*)(0x422C298CUL)))
#define bM4_TMRA5_PCONR4_CMPC0                    (*((volatile unsigned int*)(0x422C2990UL)))
#define bM4_TMRA5_PCONR4_CMPC1                    (*((volatile unsigned int*)(0x422C2994UL)))
#define bM4_TMRA5_PCONR4_PERC0                    (*((volatile unsigned int*)(0x422C2998UL)))
#define bM4_TMRA5_PCONR4_PERC1                    (*((volatile unsigned int*)(0x422C299CUL)))
#define bM4_TMRA5_PCONR4_FORC0                    (*((volatile unsigned int*)(0x422C29A0UL)))
#define bM4_TMRA5_PCONR4_FORC1                    (*((volatile unsigned int*)(0x422C29A4UL)))
#define bM4_TMRA5_PCONR4_OUTEN                    (*((volatile unsigned int*)(0x422C29B0UL)))
#define bM4_TMRA5_PCONR5_STAC0                    (*((volatile unsigned int*)(0x422C2A00UL)))
#define bM4_TMRA5_PCONR5_STAC1                    (*((volatile unsigned int*)(0x422C2A04UL)))
#define bM4_TMRA5_PCONR5_STPC0                    (*((volatile unsigned int*)(0x422C2A08UL)))
#define bM4_TMRA5_PCONR5_STPC1                    (*((volatile unsigned int*)(0x422C2A0CUL)))
#define bM4_TMRA5_PCONR5_CMPC0                    (*((volatile unsigned int*)(0x422C2A10UL)))
#define bM4_TMRA5_PCONR5_CMPC1                    (*((volatile unsigned int*)(0x422C2A14UL)))
#define bM4_TMRA5_PCONR5_PERC0                    (*((volatile unsigned int*)(0x422C2A18UL)))
#define bM4_TMRA5_PCONR5_PERC1                    (*((volatile unsigned int*)(0x422C2A1CUL)))
#define bM4_TMRA5_PCONR5_FORC0                    (*((volatile unsigned int*)(0x422C2A20UL)))
#define bM4_TMRA5_PCONR5_FORC1                    (*((volatile unsigned int*)(0x422C2A24UL)))
#define bM4_TMRA5_PCONR5_OUTEN                    (*((volatile unsigned int*)(0x422C2A30UL)))
#define bM4_TMRA5_PCONR6_STAC0                    (*((volatile unsigned int*)(0x422C2A80UL)))
#define bM4_TMRA5_PCONR6_STAC1                    (*((volatile unsigned int*)(0x422C2A84UL)))
#define bM4_TMRA5_PCONR6_STPC0                    (*((volatile unsigned int*)(0x422C2A88UL)))
#define bM4_TMRA5_PCONR6_STPC1                    (*((volatile unsigned int*)(0x422C2A8CUL)))
#define bM4_TMRA5_PCONR6_CMPC0                    (*((volatile unsigned int*)(0x422C2A90UL)))
#define bM4_TMRA5_PCONR6_CMPC1                    (*((volatile unsigned int*)(0x422C2A94UL)))
#define bM4_TMRA5_PCONR6_PERC0                    (*((volatile unsigned int*)(0x422C2A98UL)))
#define bM4_TMRA5_PCONR6_PERC1                    (*((volatile unsigned int*)(0x422C2A9CUL)))
#define bM4_TMRA5_PCONR6_FORC0                    (*((volatile unsigned int*)(0x422C2AA0UL)))
#define bM4_TMRA5_PCONR6_FORC1                    (*((volatile unsigned int*)(0x422C2AA4UL)))
#define bM4_TMRA5_PCONR6_OUTEN                    (*((volatile unsigned int*)(0x422C2AB0UL)))
#define bM4_TMRA5_PCONR7_STAC0                    (*((volatile unsigned int*)(0x422C2B00UL)))
#define bM4_TMRA5_PCONR7_STAC1                    (*((volatile unsigned int*)(0x422C2B04UL)))
#define bM4_TMRA5_PCONR7_STPC0                    (*((volatile unsigned int*)(0x422C2B08UL)))
#define bM4_TMRA5_PCONR7_STPC1                    (*((volatile unsigned int*)(0x422C2B0CUL)))
#define bM4_TMRA5_PCONR7_CMPC0                    (*((volatile unsigned int*)(0x422C2B10UL)))
#define bM4_TMRA5_PCONR7_CMPC1                    (*((volatile unsigned int*)(0x422C2B14UL)))
#define bM4_TMRA5_PCONR7_PERC0                    (*((volatile unsigned int*)(0x422C2B18UL)))
#define bM4_TMRA5_PCONR7_PERC1                    (*((volatile unsigned int*)(0x422C2B1CUL)))
#define bM4_TMRA5_PCONR7_FORC0                    (*((volatile unsigned int*)(0x422C2B20UL)))
#define bM4_TMRA5_PCONR7_FORC1                    (*((volatile unsigned int*)(0x422C2B24UL)))
#define bM4_TMRA5_PCONR7_OUTEN                    (*((volatile unsigned int*)(0x422C2B30UL)))
#define bM4_TMRA5_PCONR8_STAC0                    (*((volatile unsigned int*)(0x422C2B80UL)))
#define bM4_TMRA5_PCONR8_STAC1                    (*((volatile unsigned int*)(0x422C2B84UL)))
#define bM4_TMRA5_PCONR8_STPC0                    (*((volatile unsigned int*)(0x422C2B88UL)))
#define bM4_TMRA5_PCONR8_STPC1                    (*((volatile unsigned int*)(0x422C2B8CUL)))
#define bM4_TMRA5_PCONR8_CMPC0                    (*((volatile unsigned int*)(0x422C2B90UL)))
#define bM4_TMRA5_PCONR8_CMPC1                    (*((volatile unsigned int*)(0x422C2B94UL)))
#define bM4_TMRA5_PCONR8_PERC0                    (*((volatile unsigned int*)(0x422C2B98UL)))
#define bM4_TMRA5_PCONR8_PERC1                    (*((volatile unsigned int*)(0x422C2B9CUL)))
#define bM4_TMRA5_PCONR8_FORC0                    (*((volatile unsigned int*)(0x422C2BA0UL)))
#define bM4_TMRA5_PCONR8_FORC1                    (*((volatile unsigned int*)(0x422C2BA4UL)))
#define bM4_TMRA5_PCONR8_OUTEN                    (*((volatile unsigned int*)(0x422C2BB0UL)))
#define bM4_TMRA6_CNTER_CNT0                      (*((volatile unsigned int*)(0x422C8000UL)))
#define bM4_TMRA6_CNTER_CNT1                      (*((volatile unsigned int*)(0x422C8004UL)))
#define bM4_TMRA6_CNTER_CNT2                      (*((volatile unsigned int*)(0x422C8008UL)))
#define bM4_TMRA6_CNTER_CNT3                      (*((volatile unsigned int*)(0x422C800CUL)))
#define bM4_TMRA6_CNTER_CNT4                      (*((volatile unsigned int*)(0x422C8010UL)))
#define bM4_TMRA6_CNTER_CNT5                      (*((volatile unsigned int*)(0x422C8014UL)))
#define bM4_TMRA6_CNTER_CNT6                      (*((volatile unsigned int*)(0x422C8018UL)))
#define bM4_TMRA6_CNTER_CNT7                      (*((volatile unsigned int*)(0x422C801CUL)))
#define bM4_TMRA6_CNTER_CNT8                      (*((volatile unsigned int*)(0x422C8020UL)))
#define bM4_TMRA6_CNTER_CNT9                      (*((volatile unsigned int*)(0x422C8024UL)))
#define bM4_TMRA6_CNTER_CNT10                     (*((volatile unsigned int*)(0x422C8028UL)))
#define bM4_TMRA6_CNTER_CNT11                     (*((volatile unsigned int*)(0x422C802CUL)))
#define bM4_TMRA6_CNTER_CNT12                     (*((volatile unsigned int*)(0x422C8030UL)))
#define bM4_TMRA6_CNTER_CNT13                     (*((volatile unsigned int*)(0x422C8034UL)))
#define bM4_TMRA6_CNTER_CNT14                     (*((volatile unsigned int*)(0x422C8038UL)))
#define bM4_TMRA6_CNTER_CNT15                     (*((volatile unsigned int*)(0x422C803CUL)))
#define bM4_TMRA6_PERAR_PER0                      (*((volatile unsigned int*)(0x422C8080UL)))
#define bM4_TMRA6_PERAR_PER1                      (*((volatile unsigned int*)(0x422C8084UL)))
#define bM4_TMRA6_PERAR_PER2                      (*((volatile unsigned int*)(0x422C8088UL)))
#define bM4_TMRA6_PERAR_PER3                      (*((volatile unsigned int*)(0x422C808CUL)))
#define bM4_TMRA6_PERAR_PER4                      (*((volatile unsigned int*)(0x422C8090UL)))
#define bM4_TMRA6_PERAR_PER5                      (*((volatile unsigned int*)(0x422C8094UL)))
#define bM4_TMRA6_PERAR_PER6                      (*((volatile unsigned int*)(0x422C8098UL)))
#define bM4_TMRA6_PERAR_PER7                      (*((volatile unsigned int*)(0x422C809CUL)))
#define bM4_TMRA6_PERAR_PER8                      (*((volatile unsigned int*)(0x422C80A0UL)))
#define bM4_TMRA6_PERAR_PER9                      (*((volatile unsigned int*)(0x422C80A4UL)))
#define bM4_TMRA6_PERAR_PER10                     (*((volatile unsigned int*)(0x422C80A8UL)))
#define bM4_TMRA6_PERAR_PER11                     (*((volatile unsigned int*)(0x422C80ACUL)))
#define bM4_TMRA6_PERAR_PER12                     (*((volatile unsigned int*)(0x422C80B0UL)))
#define bM4_TMRA6_PERAR_PER13                     (*((volatile unsigned int*)(0x422C80B4UL)))
#define bM4_TMRA6_PERAR_PER14                     (*((volatile unsigned int*)(0x422C80B8UL)))
#define bM4_TMRA6_PERAR_PER15                     (*((volatile unsigned int*)(0x422C80BCUL)))
#define bM4_TMRA6_CMPAR1_CMP0                     (*((volatile unsigned int*)(0x422C8800UL)))
#define bM4_TMRA6_CMPAR1_CMP1                     (*((volatile unsigned int*)(0x422C8804UL)))
#define bM4_TMRA6_CMPAR1_CMP2                     (*((volatile unsigned int*)(0x422C8808UL)))
#define bM4_TMRA6_CMPAR1_CMP3                     (*((volatile unsigned int*)(0x422C880CUL)))
#define bM4_TMRA6_CMPAR1_CMP4                     (*((volatile unsigned int*)(0x422C8810UL)))
#define bM4_TMRA6_CMPAR1_CMP5                     (*((volatile unsigned int*)(0x422C8814UL)))
#define bM4_TMRA6_CMPAR1_CMP6                     (*((volatile unsigned int*)(0x422C8818UL)))
#define bM4_TMRA6_CMPAR1_CMP7                     (*((volatile unsigned int*)(0x422C881CUL)))
#define bM4_TMRA6_CMPAR1_CMP8                     (*((volatile unsigned int*)(0x422C8820UL)))
#define bM4_TMRA6_CMPAR1_CMP9                     (*((volatile unsigned int*)(0x422C8824UL)))
#define bM4_TMRA6_CMPAR1_CMP10                    (*((volatile unsigned int*)(0x422C8828UL)))
#define bM4_TMRA6_CMPAR1_CMP11                    (*((volatile unsigned int*)(0x422C882CUL)))
#define bM4_TMRA6_CMPAR1_CMP12                    (*((volatile unsigned int*)(0x422C8830UL)))
#define bM4_TMRA6_CMPAR1_CMP13                    (*((volatile unsigned int*)(0x422C8834UL)))
#define bM4_TMRA6_CMPAR1_CMP14                    (*((volatile unsigned int*)(0x422C8838UL)))
#define bM4_TMRA6_CMPAR1_CMP15                    (*((volatile unsigned int*)(0x422C883CUL)))
#define bM4_TMRA6_CMPAR2_CMP0                     (*((volatile unsigned int*)(0x422C8880UL)))
#define bM4_TMRA6_CMPAR2_CMP1                     (*((volatile unsigned int*)(0x422C8884UL)))
#define bM4_TMRA6_CMPAR2_CMP2                     (*((volatile unsigned int*)(0x422C8888UL)))
#define bM4_TMRA6_CMPAR2_CMP3                     (*((volatile unsigned int*)(0x422C888CUL)))
#define bM4_TMRA6_CMPAR2_CMP4                     (*((volatile unsigned int*)(0x422C8890UL)))
#define bM4_TMRA6_CMPAR2_CMP5                     (*((volatile unsigned int*)(0x422C8894UL)))
#define bM4_TMRA6_CMPAR2_CMP6                     (*((volatile unsigned int*)(0x422C8898UL)))
#define bM4_TMRA6_CMPAR2_CMP7                     (*((volatile unsigned int*)(0x422C889CUL)))
#define bM4_TMRA6_CMPAR2_CMP8                     (*((volatile unsigned int*)(0x422C88A0UL)))
#define bM4_TMRA6_CMPAR2_CMP9                     (*((volatile unsigned int*)(0x422C88A4UL)))
#define bM4_TMRA6_CMPAR2_CMP10                    (*((volatile unsigned int*)(0x422C88A8UL)))
#define bM4_TMRA6_CMPAR2_CMP11                    (*((volatile unsigned int*)(0x422C88ACUL)))
#define bM4_TMRA6_CMPAR2_CMP12                    (*((volatile unsigned int*)(0x422C88B0UL)))
#define bM4_TMRA6_CMPAR2_CMP13                    (*((volatile unsigned int*)(0x422C88B4UL)))
#define bM4_TMRA6_CMPAR2_CMP14                    (*((volatile unsigned int*)(0x422C88B8UL)))
#define bM4_TMRA6_CMPAR2_CMP15                    (*((volatile unsigned int*)(0x422C88BCUL)))
#define bM4_TMRA6_CMPAR3_CMP0                     (*((volatile unsigned int*)(0x422C8900UL)))
#define bM4_TMRA6_CMPAR3_CMP1                     (*((volatile unsigned int*)(0x422C8904UL)))
#define bM4_TMRA6_CMPAR3_CMP2                     (*((volatile unsigned int*)(0x422C8908UL)))
#define bM4_TMRA6_CMPAR3_CMP3                     (*((volatile unsigned int*)(0x422C890CUL)))
#define bM4_TMRA6_CMPAR3_CMP4                     (*((volatile unsigned int*)(0x422C8910UL)))
#define bM4_TMRA6_CMPAR3_CMP5                     (*((volatile unsigned int*)(0x422C8914UL)))
#define bM4_TMRA6_CMPAR3_CMP6                     (*((volatile unsigned int*)(0x422C8918UL)))
#define bM4_TMRA6_CMPAR3_CMP7                     (*((volatile unsigned int*)(0x422C891CUL)))
#define bM4_TMRA6_CMPAR3_CMP8                     (*((volatile unsigned int*)(0x422C8920UL)))
#define bM4_TMRA6_CMPAR3_CMP9                     (*((volatile unsigned int*)(0x422C8924UL)))
#define bM4_TMRA6_CMPAR3_CMP10                    (*((volatile unsigned int*)(0x422C8928UL)))
#define bM4_TMRA6_CMPAR3_CMP11                    (*((volatile unsigned int*)(0x422C892CUL)))
#define bM4_TMRA6_CMPAR3_CMP12                    (*((volatile unsigned int*)(0x422C8930UL)))
#define bM4_TMRA6_CMPAR3_CMP13                    (*((volatile unsigned int*)(0x422C8934UL)))
#define bM4_TMRA6_CMPAR3_CMP14                    (*((volatile unsigned int*)(0x422C8938UL)))
#define bM4_TMRA6_CMPAR3_CMP15                    (*((volatile unsigned int*)(0x422C893CUL)))
#define bM4_TMRA6_CMPAR4_CMP0                     (*((volatile unsigned int*)(0x422C8980UL)))
#define bM4_TMRA6_CMPAR4_CMP1                     (*((volatile unsigned int*)(0x422C8984UL)))
#define bM4_TMRA6_CMPAR4_CMP2                     (*((volatile unsigned int*)(0x422C8988UL)))
#define bM4_TMRA6_CMPAR4_CMP3                     (*((volatile unsigned int*)(0x422C898CUL)))
#define bM4_TMRA6_CMPAR4_CMP4                     (*((volatile unsigned int*)(0x422C8990UL)))
#define bM4_TMRA6_CMPAR4_CMP5                     (*((volatile unsigned int*)(0x422C8994UL)))
#define bM4_TMRA6_CMPAR4_CMP6                     (*((volatile unsigned int*)(0x422C8998UL)))
#define bM4_TMRA6_CMPAR4_CMP7                     (*((volatile unsigned int*)(0x422C899CUL)))
#define bM4_TMRA6_CMPAR4_CMP8                     (*((volatile unsigned int*)(0x422C89A0UL)))
#define bM4_TMRA6_CMPAR4_CMP9                     (*((volatile unsigned int*)(0x422C89A4UL)))
#define bM4_TMRA6_CMPAR4_CMP10                    (*((volatile unsigned int*)(0x422C89A8UL)))
#define bM4_TMRA6_CMPAR4_CMP11                    (*((volatile unsigned int*)(0x422C89ACUL)))
#define bM4_TMRA6_CMPAR4_CMP12                    (*((volatile unsigned int*)(0x422C89B0UL)))
#define bM4_TMRA6_CMPAR4_CMP13                    (*((volatile unsigned int*)(0x422C89B4UL)))
#define bM4_TMRA6_CMPAR4_CMP14                    (*((volatile unsigned int*)(0x422C89B8UL)))
#define bM4_TMRA6_CMPAR4_CMP15                    (*((volatile unsigned int*)(0x422C89BCUL)))
#define bM4_TMRA6_CMPAR5_CMP0                     (*((volatile unsigned int*)(0x422C8A00UL)))
#define bM4_TMRA6_CMPAR5_CMP1                     (*((volatile unsigned int*)(0x422C8A04UL)))
#define bM4_TMRA6_CMPAR5_CMP2                     (*((volatile unsigned int*)(0x422C8A08UL)))
#define bM4_TMRA6_CMPAR5_CMP3                     (*((volatile unsigned int*)(0x422C8A0CUL)))
#define bM4_TMRA6_CMPAR5_CMP4                     (*((volatile unsigned int*)(0x422C8A10UL)))
#define bM4_TMRA6_CMPAR5_CMP5                     (*((volatile unsigned int*)(0x422C8A14UL)))
#define bM4_TMRA6_CMPAR5_CMP6                     (*((volatile unsigned int*)(0x422C8A18UL)))
#define bM4_TMRA6_CMPAR5_CMP7                     (*((volatile unsigned int*)(0x422C8A1CUL)))
#define bM4_TMRA6_CMPAR5_CMP8                     (*((volatile unsigned int*)(0x422C8A20UL)))
#define bM4_TMRA6_CMPAR5_CMP9                     (*((volatile unsigned int*)(0x422C8A24UL)))
#define bM4_TMRA6_CMPAR5_CMP10                    (*((volatile unsigned int*)(0x422C8A28UL)))
#define bM4_TMRA6_CMPAR5_CMP11                    (*((volatile unsigned int*)(0x422C8A2CUL)))
#define bM4_TMRA6_CMPAR5_CMP12                    (*((volatile unsigned int*)(0x422C8A30UL)))
#define bM4_TMRA6_CMPAR5_CMP13                    (*((volatile unsigned int*)(0x422C8A34UL)))
#define bM4_TMRA6_CMPAR5_CMP14                    (*((volatile unsigned int*)(0x422C8A38UL)))
#define bM4_TMRA6_CMPAR5_CMP15                    (*((volatile unsigned int*)(0x422C8A3CUL)))
#define bM4_TMRA6_CMPAR6_CMP0                     (*((volatile unsigned int*)(0x422C8A80UL)))
#define bM4_TMRA6_CMPAR6_CMP1                     (*((volatile unsigned int*)(0x422C8A84UL)))
#define bM4_TMRA6_CMPAR6_CMP2                     (*((volatile unsigned int*)(0x422C8A88UL)))
#define bM4_TMRA6_CMPAR6_CMP3                     (*((volatile unsigned int*)(0x422C8A8CUL)))
#define bM4_TMRA6_CMPAR6_CMP4                     (*((volatile unsigned int*)(0x422C8A90UL)))
#define bM4_TMRA6_CMPAR6_CMP5                     (*((volatile unsigned int*)(0x422C8A94UL)))
#define bM4_TMRA6_CMPAR6_CMP6                     (*((volatile unsigned int*)(0x422C8A98UL)))
#define bM4_TMRA6_CMPAR6_CMP7                     (*((volatile unsigned int*)(0x422C8A9CUL)))
#define bM4_TMRA6_CMPAR6_CMP8                     (*((volatile unsigned int*)(0x422C8AA0UL)))
#define bM4_TMRA6_CMPAR6_CMP9                     (*((volatile unsigned int*)(0x422C8AA4UL)))
#define bM4_TMRA6_CMPAR6_CMP10                    (*((volatile unsigned int*)(0x422C8AA8UL)))
#define bM4_TMRA6_CMPAR6_CMP11                    (*((volatile unsigned int*)(0x422C8AACUL)))
#define bM4_TMRA6_CMPAR6_CMP12                    (*((volatile unsigned int*)(0x422C8AB0UL)))
#define bM4_TMRA6_CMPAR6_CMP13                    (*((volatile unsigned int*)(0x422C8AB4UL)))
#define bM4_TMRA6_CMPAR6_CMP14                    (*((volatile unsigned int*)(0x422C8AB8UL)))
#define bM4_TMRA6_CMPAR6_CMP15                    (*((volatile unsigned int*)(0x422C8ABCUL)))
#define bM4_TMRA6_CMPAR7_CMP0                     (*((volatile unsigned int*)(0x422C8B00UL)))
#define bM4_TMRA6_CMPAR7_CMP1                     (*((volatile unsigned int*)(0x422C8B04UL)))
#define bM4_TMRA6_CMPAR7_CMP2                     (*((volatile unsigned int*)(0x422C8B08UL)))
#define bM4_TMRA6_CMPAR7_CMP3                     (*((volatile unsigned int*)(0x422C8B0CUL)))
#define bM4_TMRA6_CMPAR7_CMP4                     (*((volatile unsigned int*)(0x422C8B10UL)))
#define bM4_TMRA6_CMPAR7_CMP5                     (*((volatile unsigned int*)(0x422C8B14UL)))
#define bM4_TMRA6_CMPAR7_CMP6                     (*((volatile unsigned int*)(0x422C8B18UL)))
#define bM4_TMRA6_CMPAR7_CMP7                     (*((volatile unsigned int*)(0x422C8B1CUL)))
#define bM4_TMRA6_CMPAR7_CMP8                     (*((volatile unsigned int*)(0x422C8B20UL)))
#define bM4_TMRA6_CMPAR7_CMP9                     (*((volatile unsigned int*)(0x422C8B24UL)))
#define bM4_TMRA6_CMPAR7_CMP10                    (*((volatile unsigned int*)(0x422C8B28UL)))
#define bM4_TMRA6_CMPAR7_CMP11                    (*((volatile unsigned int*)(0x422C8B2CUL)))
#define bM4_TMRA6_CMPAR7_CMP12                    (*((volatile unsigned int*)(0x422C8B30UL)))
#define bM4_TMRA6_CMPAR7_CMP13                    (*((volatile unsigned int*)(0x422C8B34UL)))
#define bM4_TMRA6_CMPAR7_CMP14                    (*((volatile unsigned int*)(0x422C8B38UL)))
#define bM4_TMRA6_CMPAR7_CMP15                    (*((volatile unsigned int*)(0x422C8B3CUL)))
#define bM4_TMRA6_CMPAR8_CMP0                     (*((volatile unsigned int*)(0x422C8B80UL)))
#define bM4_TMRA6_CMPAR8_CMP1                     (*((volatile unsigned int*)(0x422C8B84UL)))
#define bM4_TMRA6_CMPAR8_CMP2                     (*((volatile unsigned int*)(0x422C8B88UL)))
#define bM4_TMRA6_CMPAR8_CMP3                     (*((volatile unsigned int*)(0x422C8B8CUL)))
#define bM4_TMRA6_CMPAR8_CMP4                     (*((volatile unsigned int*)(0x422C8B90UL)))
#define bM4_TMRA6_CMPAR8_CMP5                     (*((volatile unsigned int*)(0x422C8B94UL)))
#define bM4_TMRA6_CMPAR8_CMP6                     (*((volatile unsigned int*)(0x422C8B98UL)))
#define bM4_TMRA6_CMPAR8_CMP7                     (*((volatile unsigned int*)(0x422C8B9CUL)))
#define bM4_TMRA6_CMPAR8_CMP8                     (*((volatile unsigned int*)(0x422C8BA0UL)))
#define bM4_TMRA6_CMPAR8_CMP9                     (*((volatile unsigned int*)(0x422C8BA4UL)))
#define bM4_TMRA6_CMPAR8_CMP10                    (*((volatile unsigned int*)(0x422C8BA8UL)))
#define bM4_TMRA6_CMPAR8_CMP11                    (*((volatile unsigned int*)(0x422C8BACUL)))
#define bM4_TMRA6_CMPAR8_CMP12                    (*((volatile unsigned int*)(0x422C8BB0UL)))
#define bM4_TMRA6_CMPAR8_CMP13                    (*((volatile unsigned int*)(0x422C8BB4UL)))
#define bM4_TMRA6_CMPAR8_CMP14                    (*((volatile unsigned int*)(0x422C8BB8UL)))
#define bM4_TMRA6_CMPAR8_CMP15                    (*((volatile unsigned int*)(0x422C8BBCUL)))
#define bM4_TMRA6_BCSTR_START                     (*((volatile unsigned int*)(0x422C9000UL)))
#define bM4_TMRA6_BCSTR_DIR                       (*((volatile unsigned int*)(0x422C9004UL)))
#define bM4_TMRA6_BCSTR_MODE                      (*((volatile unsigned int*)(0x422C9008UL)))
#define bM4_TMRA6_BCSTR_SYNST                     (*((volatile unsigned int*)(0x422C900CUL)))
#define bM4_TMRA6_BCSTR_CKDIV0                    (*((volatile unsigned int*)(0x422C9010UL)))
#define bM4_TMRA6_BCSTR_CKDIV1                    (*((volatile unsigned int*)(0x422C9014UL)))
#define bM4_TMRA6_BCSTR_CKDIV2                    (*((volatile unsigned int*)(0x422C9018UL)))
#define bM4_TMRA6_BCSTR_CKDIV3                    (*((volatile unsigned int*)(0x422C901CUL)))
#define bM4_TMRA6_BCSTR_ITENOVF                   (*((volatile unsigned int*)(0x422C9030UL)))
#define bM4_TMRA6_BCSTR_ITENUDF                   (*((volatile unsigned int*)(0x422C9034UL)))
#define bM4_TMRA6_BCSTR_OVFF                      (*((volatile unsigned int*)(0x422C9038UL)))
#define bM4_TMRA6_BCSTR_UDFF                      (*((volatile unsigned int*)(0x422C903CUL)))
#define bM4_TMRA6_HCONR_HSTA0                     (*((volatile unsigned int*)(0x422C9080UL)))
#define bM4_TMRA6_HCONR_HSTA1                     (*((volatile unsigned int*)(0x422C9084UL)))
#define bM4_TMRA6_HCONR_HSTA2                     (*((volatile unsigned int*)(0x422C9088UL)))
#define bM4_TMRA6_HCONR_HSTP0                     (*((volatile unsigned int*)(0x422C9090UL)))
#define bM4_TMRA6_HCONR_HSTP1                     (*((volatile unsigned int*)(0x422C9094UL)))
#define bM4_TMRA6_HCONR_HSTP2                     (*((volatile unsigned int*)(0x422C9098UL)))
#define bM4_TMRA6_HCONR_HCLE0                     (*((volatile unsigned int*)(0x422C90A0UL)))
#define bM4_TMRA6_HCONR_HCLE1                     (*((volatile unsigned int*)(0x422C90A4UL)))
#define bM4_TMRA6_HCONR_HCLE2                     (*((volatile unsigned int*)(0x422C90A8UL)))
#define bM4_TMRA6_HCONR_HCLE3                     (*((volatile unsigned int*)(0x422C90B0UL)))
#define bM4_TMRA6_HCONR_HCLE4                     (*((volatile unsigned int*)(0x422C90B4UL)))
#define bM4_TMRA6_HCONR_HCLE5                     (*((volatile unsigned int*)(0x422C90B8UL)))
#define bM4_TMRA6_HCONR_HCLE6                     (*((volatile unsigned int*)(0x422C90BCUL)))
#define bM4_TMRA6_HCUPR_HCUP0                     (*((volatile unsigned int*)(0x422C9100UL)))
#define bM4_TMRA6_HCUPR_HCUP1                     (*((volatile unsigned int*)(0x422C9104UL)))
#define bM4_TMRA6_HCUPR_HCUP2                     (*((volatile unsigned int*)(0x422C9108UL)))
#define bM4_TMRA6_HCUPR_HCUP3                     (*((volatile unsigned int*)(0x422C910CUL)))
#define bM4_TMRA6_HCUPR_HCUP4                     (*((volatile unsigned int*)(0x422C9110UL)))
#define bM4_TMRA6_HCUPR_HCUP5                     (*((volatile unsigned int*)(0x422C9114UL)))
#define bM4_TMRA6_HCUPR_HCUP6                     (*((volatile unsigned int*)(0x422C9118UL)))
#define bM4_TMRA6_HCUPR_HCUP7                     (*((volatile unsigned int*)(0x422C911CUL)))
#define bM4_TMRA6_HCUPR_HCUP8                     (*((volatile unsigned int*)(0x422C9120UL)))
#define bM4_TMRA6_HCUPR_HCUP9                     (*((volatile unsigned int*)(0x422C9124UL)))
#define bM4_TMRA6_HCUPR_HCUP10                    (*((volatile unsigned int*)(0x422C9128UL)))
#define bM4_TMRA6_HCUPR_HCUP11                    (*((volatile unsigned int*)(0x422C912CUL)))
#define bM4_TMRA6_HCUPR_HCUP12                    (*((volatile unsigned int*)(0x422C9130UL)))
#define bM4_TMRA6_HCDOR_HCDO0                     (*((volatile unsigned int*)(0x422C9180UL)))
#define bM4_TMRA6_HCDOR_HCDO1                     (*((volatile unsigned int*)(0x422C9184UL)))
#define bM4_TMRA6_HCDOR_HCDO2                     (*((volatile unsigned int*)(0x422C9188UL)))
#define bM4_TMRA6_HCDOR_HCDO3                     (*((volatile unsigned int*)(0x422C918CUL)))
#define bM4_TMRA6_HCDOR_HCDO4                     (*((volatile unsigned int*)(0x422C9190UL)))
#define bM4_TMRA6_HCDOR_HCDO5                     (*((volatile unsigned int*)(0x422C9194UL)))
#define bM4_TMRA6_HCDOR_HCDO6                     (*((volatile unsigned int*)(0x422C9198UL)))
#define bM4_TMRA6_HCDOR_HCDO7                     (*((volatile unsigned int*)(0x422C919CUL)))
#define bM4_TMRA6_HCDOR_HCDO8                     (*((volatile unsigned int*)(0x422C91A0UL)))
#define bM4_TMRA6_HCDOR_HCDO9                     (*((volatile unsigned int*)(0x422C91A4UL)))
#define bM4_TMRA6_HCDOR_HCDO10                    (*((volatile unsigned int*)(0x422C91A8UL)))
#define bM4_TMRA6_HCDOR_HCDO11                    (*((volatile unsigned int*)(0x422C91ACUL)))
#define bM4_TMRA6_HCDOR_HCDO12                    (*((volatile unsigned int*)(0x422C91B0UL)))
#define bM4_TMRA6_ICONR_ITEN1                     (*((volatile unsigned int*)(0x422C9200UL)))
#define bM4_TMRA6_ICONR_ITEN2                     (*((volatile unsigned int*)(0x422C9204UL)))
#define bM4_TMRA6_ICONR_ITEN3                     (*((volatile unsigned int*)(0x422C9208UL)))
#define bM4_TMRA6_ICONR_ITEN4                     (*((volatile unsigned int*)(0x422C920CUL)))
#define bM4_TMRA6_ICONR_ITEN5                     (*((volatile unsigned int*)(0x422C9210UL)))
#define bM4_TMRA6_ICONR_ITEN6                     (*((volatile unsigned int*)(0x422C9214UL)))
#define bM4_TMRA6_ICONR_ITEN7                     (*((volatile unsigned int*)(0x422C9218UL)))
#define bM4_TMRA6_ICONR_ITEN8                     (*((volatile unsigned int*)(0x422C921CUL)))
#define bM4_TMRA6_ECONR_ETEN1                     (*((volatile unsigned int*)(0x422C9280UL)))
#define bM4_TMRA6_ECONR_ETEN2                     (*((volatile unsigned int*)(0x422C9284UL)))
#define bM4_TMRA6_ECONR_ETEN3                     (*((volatile unsigned int*)(0x422C9288UL)))
#define bM4_TMRA6_ECONR_ETEN4                     (*((volatile unsigned int*)(0x422C928CUL)))
#define bM4_TMRA6_ECONR_ETEN5                     (*((volatile unsigned int*)(0x422C9290UL)))
#define bM4_TMRA6_ECONR_ETEN6                     (*((volatile unsigned int*)(0x422C9294UL)))
#define bM4_TMRA6_ECONR_ETEN7                     (*((volatile unsigned int*)(0x422C9298UL)))
#define bM4_TMRA6_ECONR_ETEN8                     (*((volatile unsigned int*)(0x422C929CUL)))
#define bM4_TMRA6_FCONR_NOFIENTG                  (*((volatile unsigned int*)(0x422C9300UL)))
#define bM4_TMRA6_FCONR_NOFICKTG0                 (*((volatile unsigned int*)(0x422C9304UL)))
#define bM4_TMRA6_FCONR_NOFICKTG1                 (*((volatile unsigned int*)(0x422C9308UL)))
#define bM4_TMRA6_FCONR_NOFIENCA                  (*((volatile unsigned int*)(0x422C9320UL)))
#define bM4_TMRA6_FCONR_NOFICKCA0                 (*((volatile unsigned int*)(0x422C9324UL)))
#define bM4_TMRA6_FCONR_NOFICKCA1                 (*((volatile unsigned int*)(0x422C9328UL)))
#define bM4_TMRA6_FCONR_NOFIENCB                  (*((volatile unsigned int*)(0x422C9330UL)))
#define bM4_TMRA6_FCONR_NOFICKCB0                 (*((volatile unsigned int*)(0x422C9334UL)))
#define bM4_TMRA6_FCONR_NOFICKCB1                 (*((volatile unsigned int*)(0x422C9338UL)))
#define bM4_TMRA6_STFLR_CMPF1                     (*((volatile unsigned int*)(0x422C9380UL)))
#define bM4_TMRA6_STFLR_CMPF2                     (*((volatile unsigned int*)(0x422C9384UL)))
#define bM4_TMRA6_STFLR_CMPF3                     (*((volatile unsigned int*)(0x422C9388UL)))
#define bM4_TMRA6_STFLR_CMPF4                     (*((volatile unsigned int*)(0x422C938CUL)))
#define bM4_TMRA6_STFLR_CMPF5                     (*((volatile unsigned int*)(0x422C9390UL)))
#define bM4_TMRA6_STFLR_CMPF6                     (*((volatile unsigned int*)(0x422C9394UL)))
#define bM4_TMRA6_STFLR_CMPF7                     (*((volatile unsigned int*)(0x422C9398UL)))
#define bM4_TMRA6_STFLR_CMPF8                     (*((volatile unsigned int*)(0x422C939CUL)))
#define bM4_TMRA6_BCONR1_BEN                      (*((volatile unsigned int*)(0x422C9800UL)))
#define bM4_TMRA6_BCONR1_BSE0                     (*((volatile unsigned int*)(0x422C9804UL)))
#define bM4_TMRA6_BCONR1_BSE1                     (*((volatile unsigned int*)(0x422C9808UL)))
#define bM4_TMRA6_BCONR2_BEN                      (*((volatile unsigned int*)(0x422C9900UL)))
#define bM4_TMRA6_BCONR2_BSE0                     (*((volatile unsigned int*)(0x422C9904UL)))
#define bM4_TMRA6_BCONR2_BSE1                     (*((volatile unsigned int*)(0x422C9908UL)))
#define bM4_TMRA6_BCONR3_BEN                      (*((volatile unsigned int*)(0x422C9A00UL)))
#define bM4_TMRA6_BCONR3_BSE0                     (*((volatile unsigned int*)(0x422C9A04UL)))
#define bM4_TMRA6_BCONR3_BSE1                     (*((volatile unsigned int*)(0x422C9A08UL)))
#define bM4_TMRA6_BCONR4_BEN                      (*((volatile unsigned int*)(0x422C9B00UL)))
#define bM4_TMRA6_BCONR4_BSE0                     (*((volatile unsigned int*)(0x422C9B04UL)))
#define bM4_TMRA6_BCONR4_BSE1                     (*((volatile unsigned int*)(0x422C9B08UL)))
#define bM4_TMRA6_CCONR1_CAPMD                    (*((volatile unsigned int*)(0x422CA000UL)))
#define bM4_TMRA6_CCONR1_HICP0                    (*((volatile unsigned int*)(0x422CA010UL)))
#define bM4_TMRA6_CCONR1_HICP1                    (*((volatile unsigned int*)(0x422CA014UL)))
#define bM4_TMRA6_CCONR1_HICP2                    (*((volatile unsigned int*)(0x422CA018UL)))
#define bM4_TMRA6_CCONR1_HICP3                    (*((volatile unsigned int*)(0x422CA020UL)))
#define bM4_TMRA6_CCONR1_HICP4                    (*((volatile unsigned int*)(0x422CA024UL)))
#define bM4_TMRA6_CCONR1_NOFIENCP                 (*((volatile unsigned int*)(0x422CA030UL)))
#define bM4_TMRA6_CCONR1_NOFICKCP0                (*((volatile unsigned int*)(0x422CA034UL)))
#define bM4_TMRA6_CCONR1_NOFICKCP1                (*((volatile unsigned int*)(0x422CA038UL)))
#define bM4_TMRA6_CCONR2_CAPMD                    (*((volatile unsigned int*)(0x422CA080UL)))
#define bM4_TMRA6_CCONR2_HICP0                    (*((volatile unsigned int*)(0x422CA090UL)))
#define bM4_TMRA6_CCONR2_HICP1                    (*((volatile unsigned int*)(0x422CA094UL)))
#define bM4_TMRA6_CCONR2_HICP2                    (*((volatile unsigned int*)(0x422CA098UL)))
#define bM4_TMRA6_CCONR2_HICP3                    (*((volatile unsigned int*)(0x422CA0A0UL)))
#define bM4_TMRA6_CCONR2_HICP4                    (*((volatile unsigned int*)(0x422CA0A4UL)))
#define bM4_TMRA6_CCONR2_NOFIENCP                 (*((volatile unsigned int*)(0x422CA0B0UL)))
#define bM4_TMRA6_CCONR2_NOFICKCP0                (*((volatile unsigned int*)(0x422CA0B4UL)))
#define bM4_TMRA6_CCONR2_NOFICKCP1                (*((volatile unsigned int*)(0x422CA0B8UL)))
#define bM4_TMRA6_CCONR3_CAPMD                    (*((volatile unsigned int*)(0x422CA100UL)))
#define bM4_TMRA6_CCONR3_HICP0                    (*((volatile unsigned int*)(0x422CA110UL)))
#define bM4_TMRA6_CCONR3_HICP1                    (*((volatile unsigned int*)(0x422CA114UL)))
#define bM4_TMRA6_CCONR3_HICP2                    (*((volatile unsigned int*)(0x422CA118UL)))
#define bM4_TMRA6_CCONR3_HICP3                    (*((volatile unsigned int*)(0x422CA120UL)))
#define bM4_TMRA6_CCONR3_HICP4                    (*((volatile unsigned int*)(0x422CA124UL)))
#define bM4_TMRA6_CCONR3_NOFIENCP                 (*((volatile unsigned int*)(0x422CA130UL)))
#define bM4_TMRA6_CCONR3_NOFICKCP0                (*((volatile unsigned int*)(0x422CA134UL)))
#define bM4_TMRA6_CCONR3_NOFICKCP1                (*((volatile unsigned int*)(0x422CA138UL)))
#define bM4_TMRA6_CCONR4_CAPMD                    (*((volatile unsigned int*)(0x422CA180UL)))
#define bM4_TMRA6_CCONR4_HICP0                    (*((volatile unsigned int*)(0x422CA190UL)))
#define bM4_TMRA6_CCONR4_HICP1                    (*((volatile unsigned int*)(0x422CA194UL)))
#define bM4_TMRA6_CCONR4_HICP2                    (*((volatile unsigned int*)(0x422CA198UL)))
#define bM4_TMRA6_CCONR4_HICP3                    (*((volatile unsigned int*)(0x422CA1A0UL)))
#define bM4_TMRA6_CCONR4_HICP4                    (*((volatile unsigned int*)(0x422CA1A4UL)))
#define bM4_TMRA6_CCONR4_NOFIENCP                 (*((volatile unsigned int*)(0x422CA1B0UL)))
#define bM4_TMRA6_CCONR4_NOFICKCP0                (*((volatile unsigned int*)(0x422CA1B4UL)))
#define bM4_TMRA6_CCONR4_NOFICKCP1                (*((volatile unsigned int*)(0x422CA1B8UL)))
#define bM4_TMRA6_CCONR5_CAPMD                    (*((volatile unsigned int*)(0x422CA200UL)))
#define bM4_TMRA6_CCONR5_HICP0                    (*((volatile unsigned int*)(0x422CA210UL)))
#define bM4_TMRA6_CCONR5_HICP1                    (*((volatile unsigned int*)(0x422CA214UL)))
#define bM4_TMRA6_CCONR5_HICP2                    (*((volatile unsigned int*)(0x422CA218UL)))
#define bM4_TMRA6_CCONR5_HICP3                    (*((volatile unsigned int*)(0x422CA220UL)))
#define bM4_TMRA6_CCONR5_HICP4                    (*((volatile unsigned int*)(0x422CA224UL)))
#define bM4_TMRA6_CCONR5_NOFIENCP                 (*((volatile unsigned int*)(0x422CA230UL)))
#define bM4_TMRA6_CCONR5_NOFICKCP0                (*((volatile unsigned int*)(0x422CA234UL)))
#define bM4_TMRA6_CCONR5_NOFICKCP1                (*((volatile unsigned int*)(0x422CA238UL)))
#define bM4_TMRA6_CCONR6_CAPMD                    (*((volatile unsigned int*)(0x422CA280UL)))
#define bM4_TMRA6_CCONR6_HICP0                    (*((volatile unsigned int*)(0x422CA290UL)))
#define bM4_TMRA6_CCONR6_HICP1                    (*((volatile unsigned int*)(0x422CA294UL)))
#define bM4_TMRA6_CCONR6_HICP2                    (*((volatile unsigned int*)(0x422CA298UL)))
#define bM4_TMRA6_CCONR6_HICP3                    (*((volatile unsigned int*)(0x422CA2A0UL)))
#define bM4_TMRA6_CCONR6_HICP4                    (*((volatile unsigned int*)(0x422CA2A4UL)))
#define bM4_TMRA6_CCONR6_NOFIENCP                 (*((volatile unsigned int*)(0x422CA2B0UL)))
#define bM4_TMRA6_CCONR6_NOFICKCP0                (*((volatile unsigned int*)(0x422CA2B4UL)))
#define bM4_TMRA6_CCONR6_NOFICKCP1                (*((volatile unsigned int*)(0x422CA2B8UL)))
#define bM4_TMRA6_CCONR7_CAPMD                    (*((volatile unsigned int*)(0x422CA300UL)))
#define bM4_TMRA6_CCONR7_HICP0                    (*((volatile unsigned int*)(0x422CA310UL)))
#define bM4_TMRA6_CCONR7_HICP1                    (*((volatile unsigned int*)(0x422CA314UL)))
#define bM4_TMRA6_CCONR7_HICP2                    (*((volatile unsigned int*)(0x422CA318UL)))
#define bM4_TMRA6_CCONR7_HICP3                    (*((volatile unsigned int*)(0x422CA320UL)))
#define bM4_TMRA6_CCONR7_HICP4                    (*((volatile unsigned int*)(0x422CA324UL)))
#define bM4_TMRA6_CCONR7_NOFIENCP                 (*((volatile unsigned int*)(0x422CA330UL)))
#define bM4_TMRA6_CCONR7_NOFICKCP0                (*((volatile unsigned int*)(0x422CA334UL)))
#define bM4_TMRA6_CCONR7_NOFICKCP1                (*((volatile unsigned int*)(0x422CA338UL)))
#define bM4_TMRA6_CCONR8_CAPMD                    (*((volatile unsigned int*)(0x422CA380UL)))
#define bM4_TMRA6_CCONR8_HICP0                    (*((volatile unsigned int*)(0x422CA390UL)))
#define bM4_TMRA6_CCONR8_HICP1                    (*((volatile unsigned int*)(0x422CA394UL)))
#define bM4_TMRA6_CCONR8_HICP2                    (*((volatile unsigned int*)(0x422CA398UL)))
#define bM4_TMRA6_CCONR8_HICP3                    (*((volatile unsigned int*)(0x422CA3A0UL)))
#define bM4_TMRA6_CCONR8_HICP4                    (*((volatile unsigned int*)(0x422CA3A4UL)))
#define bM4_TMRA6_CCONR8_NOFIENCP                 (*((volatile unsigned int*)(0x422CA3B0UL)))
#define bM4_TMRA6_CCONR8_NOFICKCP0                (*((volatile unsigned int*)(0x422CA3B4UL)))
#define bM4_TMRA6_CCONR8_NOFICKCP1                (*((volatile unsigned int*)(0x422CA3B8UL)))
#define bM4_TMRA6_PCONR1_STAC0                    (*((volatile unsigned int*)(0x422CA800UL)))
#define bM4_TMRA6_PCONR1_STAC1                    (*((volatile unsigned int*)(0x422CA804UL)))
#define bM4_TMRA6_PCONR1_STPC0                    (*((volatile unsigned int*)(0x422CA808UL)))
#define bM4_TMRA6_PCONR1_STPC1                    (*((volatile unsigned int*)(0x422CA80CUL)))
#define bM4_TMRA6_PCONR1_CMPC0                    (*((volatile unsigned int*)(0x422CA810UL)))
#define bM4_TMRA6_PCONR1_CMPC1                    (*((volatile unsigned int*)(0x422CA814UL)))
#define bM4_TMRA6_PCONR1_PERC0                    (*((volatile unsigned int*)(0x422CA818UL)))
#define bM4_TMRA6_PCONR1_PERC1                    (*((volatile unsigned int*)(0x422CA81CUL)))
#define bM4_TMRA6_PCONR1_FORC0                    (*((volatile unsigned int*)(0x422CA820UL)))
#define bM4_TMRA6_PCONR1_FORC1                    (*((volatile unsigned int*)(0x422CA824UL)))
#define bM4_TMRA6_PCONR1_OUTEN                    (*((volatile unsigned int*)(0x422CA830UL)))
#define bM4_TMRA6_PCONR2_STAC0                    (*((volatile unsigned int*)(0x422CA880UL)))
#define bM4_TMRA6_PCONR2_STAC1                    (*((volatile unsigned int*)(0x422CA884UL)))
#define bM4_TMRA6_PCONR2_STPC0                    (*((volatile unsigned int*)(0x422CA888UL)))
#define bM4_TMRA6_PCONR2_STPC1                    (*((volatile unsigned int*)(0x422CA88CUL)))
#define bM4_TMRA6_PCONR2_CMPC0                    (*((volatile unsigned int*)(0x422CA890UL)))
#define bM4_TMRA6_PCONR2_CMPC1                    (*((volatile unsigned int*)(0x422CA894UL)))
#define bM4_TMRA6_PCONR2_PERC0                    (*((volatile unsigned int*)(0x422CA898UL)))
#define bM4_TMRA6_PCONR2_PERC1                    (*((volatile unsigned int*)(0x422CA89CUL)))
#define bM4_TMRA6_PCONR2_FORC0                    (*((volatile unsigned int*)(0x422CA8A0UL)))
#define bM4_TMRA6_PCONR2_FORC1                    (*((volatile unsigned int*)(0x422CA8A4UL)))
#define bM4_TMRA6_PCONR2_OUTEN                    (*((volatile unsigned int*)(0x422CA8B0UL)))
#define bM4_TMRA6_PCONR3_STAC0                    (*((volatile unsigned int*)(0x422CA900UL)))
#define bM4_TMRA6_PCONR3_STAC1                    (*((volatile unsigned int*)(0x422CA904UL)))
#define bM4_TMRA6_PCONR3_STPC0                    (*((volatile unsigned int*)(0x422CA908UL)))
#define bM4_TMRA6_PCONR3_STPC1                    (*((volatile unsigned int*)(0x422CA90CUL)))
#define bM4_TMRA6_PCONR3_CMPC0                    (*((volatile unsigned int*)(0x422CA910UL)))
#define bM4_TMRA6_PCONR3_CMPC1                    (*((volatile unsigned int*)(0x422CA914UL)))
#define bM4_TMRA6_PCONR3_PERC0                    (*((volatile unsigned int*)(0x422CA918UL)))
#define bM4_TMRA6_PCONR3_PERC1                    (*((volatile unsigned int*)(0x422CA91CUL)))
#define bM4_TMRA6_PCONR3_FORC0                    (*((volatile unsigned int*)(0x422CA920UL)))
#define bM4_TMRA6_PCONR3_FORC1                    (*((volatile unsigned int*)(0x422CA924UL)))
#define bM4_TMRA6_PCONR3_OUTEN                    (*((volatile unsigned int*)(0x422CA930UL)))
#define bM4_TMRA6_PCONR4_STAC0                    (*((volatile unsigned int*)(0x422CA980UL)))
#define bM4_TMRA6_PCONR4_STAC1                    (*((volatile unsigned int*)(0x422CA984UL)))
#define bM4_TMRA6_PCONR4_STPC0                    (*((volatile unsigned int*)(0x422CA988UL)))
#define bM4_TMRA6_PCONR4_STPC1                    (*((volatile unsigned int*)(0x422CA98CUL)))
#define bM4_TMRA6_PCONR4_CMPC0                    (*((volatile unsigned int*)(0x422CA990UL)))
#define bM4_TMRA6_PCONR4_CMPC1                    (*((volatile unsigned int*)(0x422CA994UL)))
#define bM4_TMRA6_PCONR4_PERC0                    (*((volatile unsigned int*)(0x422CA998UL)))
#define bM4_TMRA6_PCONR4_PERC1                    (*((volatile unsigned int*)(0x422CA99CUL)))
#define bM4_TMRA6_PCONR4_FORC0                    (*((volatile unsigned int*)(0x422CA9A0UL)))
#define bM4_TMRA6_PCONR4_FORC1                    (*((volatile unsigned int*)(0x422CA9A4UL)))
#define bM4_TMRA6_PCONR4_OUTEN                    (*((volatile unsigned int*)(0x422CA9B0UL)))
#define bM4_TMRA6_PCONR5_STAC0                    (*((volatile unsigned int*)(0x422CAA00UL)))
#define bM4_TMRA6_PCONR5_STAC1                    (*((volatile unsigned int*)(0x422CAA04UL)))
#define bM4_TMRA6_PCONR5_STPC0                    (*((volatile unsigned int*)(0x422CAA08UL)))
#define bM4_TMRA6_PCONR5_STPC1                    (*((volatile unsigned int*)(0x422CAA0CUL)))
#define bM4_TMRA6_PCONR5_CMPC0                    (*((volatile unsigned int*)(0x422CAA10UL)))
#define bM4_TMRA6_PCONR5_CMPC1                    (*((volatile unsigned int*)(0x422CAA14UL)))
#define bM4_TMRA6_PCONR5_PERC0                    (*((volatile unsigned int*)(0x422CAA18UL)))
#define bM4_TMRA6_PCONR5_PERC1                    (*((volatile unsigned int*)(0x422CAA1CUL)))
#define bM4_TMRA6_PCONR5_FORC0                    (*((volatile unsigned int*)(0x422CAA20UL)))
#define bM4_TMRA6_PCONR5_FORC1                    (*((volatile unsigned int*)(0x422CAA24UL)))
#define bM4_TMRA6_PCONR5_OUTEN                    (*((volatile unsigned int*)(0x422CAA30UL)))
#define bM4_TMRA6_PCONR6_STAC0                    (*((volatile unsigned int*)(0x422CAA80UL)))
#define bM4_TMRA6_PCONR6_STAC1                    (*((volatile unsigned int*)(0x422CAA84UL)))
#define bM4_TMRA6_PCONR6_STPC0                    (*((volatile unsigned int*)(0x422CAA88UL)))
#define bM4_TMRA6_PCONR6_STPC1                    (*((volatile unsigned int*)(0x422CAA8CUL)))
#define bM4_TMRA6_PCONR6_CMPC0                    (*((volatile unsigned int*)(0x422CAA90UL)))
#define bM4_TMRA6_PCONR6_CMPC1                    (*((volatile unsigned int*)(0x422CAA94UL)))
#define bM4_TMRA6_PCONR6_PERC0                    (*((volatile unsigned int*)(0x422CAA98UL)))
#define bM4_TMRA6_PCONR6_PERC1                    (*((volatile unsigned int*)(0x422CAA9CUL)))
#define bM4_TMRA6_PCONR6_FORC0                    (*((volatile unsigned int*)(0x422CAAA0UL)))
#define bM4_TMRA6_PCONR6_FORC1                    (*((volatile unsigned int*)(0x422CAAA4UL)))
#define bM4_TMRA6_PCONR6_OUTEN                    (*((volatile unsigned int*)(0x422CAAB0UL)))
#define bM4_TMRA6_PCONR7_STAC0                    (*((volatile unsigned int*)(0x422CAB00UL)))
#define bM4_TMRA6_PCONR7_STAC1                    (*((volatile unsigned int*)(0x422CAB04UL)))
#define bM4_TMRA6_PCONR7_STPC0                    (*((volatile unsigned int*)(0x422CAB08UL)))
#define bM4_TMRA6_PCONR7_STPC1                    (*((volatile unsigned int*)(0x422CAB0CUL)))
#define bM4_TMRA6_PCONR7_CMPC0                    (*((volatile unsigned int*)(0x422CAB10UL)))
#define bM4_TMRA6_PCONR7_CMPC1                    (*((volatile unsigned int*)(0x422CAB14UL)))
#define bM4_TMRA6_PCONR7_PERC0                    (*((volatile unsigned int*)(0x422CAB18UL)))
#define bM4_TMRA6_PCONR7_PERC1                    (*((volatile unsigned int*)(0x422CAB1CUL)))
#define bM4_TMRA6_PCONR7_FORC0                    (*((volatile unsigned int*)(0x422CAB20UL)))
#define bM4_TMRA6_PCONR7_FORC1                    (*((volatile unsigned int*)(0x422CAB24UL)))
#define bM4_TMRA6_PCONR7_OUTEN                    (*((volatile unsigned int*)(0x422CAB30UL)))
#define bM4_TMRA6_PCONR8_STAC0                    (*((volatile unsigned int*)(0x422CAB80UL)))
#define bM4_TMRA6_PCONR8_STAC1                    (*((volatile unsigned int*)(0x422CAB84UL)))
#define bM4_TMRA6_PCONR8_STPC0                    (*((volatile unsigned int*)(0x422CAB88UL)))
#define bM4_TMRA6_PCONR8_STPC1                    (*((volatile unsigned int*)(0x422CAB8CUL)))
#define bM4_TMRA6_PCONR8_CMPC0                    (*((volatile unsigned int*)(0x422CAB90UL)))
#define bM4_TMRA6_PCONR8_CMPC1                    (*((volatile unsigned int*)(0x422CAB94UL)))
#define bM4_TMRA6_PCONR8_PERC0                    (*((volatile unsigned int*)(0x422CAB98UL)))
#define bM4_TMRA6_PCONR8_PERC1                    (*((volatile unsigned int*)(0x422CAB9CUL)))
#define bM4_TMRA6_PCONR8_FORC0                    (*((volatile unsigned int*)(0x422CABA0UL)))
#define bM4_TMRA6_PCONR8_FORC1                    (*((volatile unsigned int*)(0x422CABA4UL)))
#define bM4_TMRA6_PCONR8_OUTEN                    (*((volatile unsigned int*)(0x422CABB0UL)))
#define bM4_TRNG_CR_EN                            (*((volatile unsigned int*)(0x42820000UL)))
#define bM4_TRNG_CR_RUN                           (*((volatile unsigned int*)(0x42820004UL)))
#define bM4_TRNG_MR_LOAD                          (*((volatile unsigned int*)(0x42820080UL)))
#define bM4_TRNG_MR_CNT0                          (*((volatile unsigned int*)(0x42820088UL)))
#define bM4_TRNG_MR_CNT1                          (*((volatile unsigned int*)(0x4282008CUL)))
#define bM4_TRNG_MR_CNT2                          (*((volatile unsigned int*)(0x42820090UL)))
#define bM4_USART1_SR_PE                          (*((volatile unsigned int*)(0x423A0000UL)))
#define bM4_USART1_SR_FE                          (*((volatile unsigned int*)(0x423A0004UL)))
#define bM4_USART1_SR_ORE                         (*((volatile unsigned int*)(0x423A000CUL)))
#define bM4_USART1_SR_RXNE                        (*((volatile unsigned int*)(0x423A0014UL)))
#define bM4_USART1_SR_TC                          (*((volatile unsigned int*)(0x423A0018UL)))
#define bM4_USART1_SR_TXE                         (*((volatile unsigned int*)(0x423A001CUL)))
#define bM4_USART1_SR_RTOF                        (*((volatile unsigned int*)(0x423A0020UL)))
#define bM4_USART1_SR_MPB                         (*((volatile unsigned int*)(0x423A0040UL)))
#define bM4_USART1_DR_TDR0                        (*((volatile unsigned int*)(0x423A0080UL)))
#define bM4_USART1_DR_TDR1                        (*((volatile unsigned int*)(0x423A0084UL)))
#define bM4_USART1_DR_TDR2                        (*((volatile unsigned int*)(0x423A0088UL)))
#define bM4_USART1_DR_TDR3                        (*((volatile unsigned int*)(0x423A008CUL)))
#define bM4_USART1_DR_TDR4                        (*((volatile unsigned int*)(0x423A0090UL)))
#define bM4_USART1_DR_TDR5                        (*((volatile unsigned int*)(0x423A0094UL)))
#define bM4_USART1_DR_TDR6                        (*((volatile unsigned int*)(0x423A0098UL)))
#define bM4_USART1_DR_TDR7                        (*((volatile unsigned int*)(0x423A009CUL)))
#define bM4_USART1_DR_TDR8                        (*((volatile unsigned int*)(0x423A00A0UL)))
#define bM4_USART1_DR_MPID                        (*((volatile unsigned int*)(0x423A00A4UL)))
#define bM4_USART1_DR_RDR0                        (*((volatile unsigned int*)(0x423A00C0UL)))
#define bM4_USART1_DR_RDR1                        (*((volatile unsigned int*)(0x423A00C4UL)))
#define bM4_USART1_DR_RDR2                        (*((volatile unsigned int*)(0x423A00C8UL)))
#define bM4_USART1_DR_RDR3                        (*((volatile unsigned int*)(0x423A00CCUL)))
#define bM4_USART1_DR_RDR4                        (*((volatile unsigned int*)(0x423A00D0UL)))
#define bM4_USART1_DR_RDR5                        (*((volatile unsigned int*)(0x423A00D4UL)))
#define bM4_USART1_DR_RDR6                        (*((volatile unsigned int*)(0x423A00D8UL)))
#define bM4_USART1_DR_RDR7                        (*((volatile unsigned int*)(0x423A00DCUL)))
#define bM4_USART1_DR_RDR8                        (*((volatile unsigned int*)(0x423A00E0UL)))
#define bM4_USART1_BRR_DIV_FRACTION0              (*((volatile unsigned int*)(0x423A0100UL)))
#define bM4_USART1_BRR_DIV_FRACTION1              (*((volatile unsigned int*)(0x423A0104UL)))
#define bM4_USART1_BRR_DIV_FRACTION2              (*((volatile unsigned int*)(0x423A0108UL)))
#define bM4_USART1_BRR_DIV_FRACTION3              (*((volatile unsigned int*)(0x423A010CUL)))
#define bM4_USART1_BRR_DIV_FRACTION4              (*((volatile unsigned int*)(0x423A0110UL)))
#define bM4_USART1_BRR_DIV_FRACTION5              (*((volatile unsigned int*)(0x423A0114UL)))
#define bM4_USART1_BRR_DIV_FRACTION6              (*((volatile unsigned int*)(0x423A0118UL)))
#define bM4_USART1_BRR_DIV_INTEGER0               (*((volatile unsigned int*)(0x423A0120UL)))
#define bM4_USART1_BRR_DIV_INTEGER1               (*((volatile unsigned int*)(0x423A0124UL)))
#define bM4_USART1_BRR_DIV_INTEGER2               (*((volatile unsigned int*)(0x423A0128UL)))
#define bM4_USART1_BRR_DIV_INTEGER3               (*((volatile unsigned int*)(0x423A012CUL)))
#define bM4_USART1_BRR_DIV_INTEGER4               (*((volatile unsigned int*)(0x423A0130UL)))
#define bM4_USART1_BRR_DIV_INTEGER5               (*((volatile unsigned int*)(0x423A0134UL)))
#define bM4_USART1_BRR_DIV_INTEGER6               (*((volatile unsigned int*)(0x423A0138UL)))
#define bM4_USART1_BRR_DIV_INTEGER7               (*((volatile unsigned int*)(0x423A013CUL)))
#define bM4_USART1_CR1_RTOE                       (*((volatile unsigned int*)(0x423A0180UL)))
#define bM4_USART1_CR1_RTOIE                      (*((volatile unsigned int*)(0x423A0184UL)))
#define bM4_USART1_CR1_RE                         (*((volatile unsigned int*)(0x423A0188UL)))
#define bM4_USART1_CR1_TE                         (*((volatile unsigned int*)(0x423A018CUL)))
#define bM4_USART1_CR1_SLME                       (*((volatile unsigned int*)(0x423A0190UL)))
#define bM4_USART1_CR1_RIE                        (*((volatile unsigned int*)(0x423A0194UL)))
#define bM4_USART1_CR1_TCIE                       (*((volatile unsigned int*)(0x423A0198UL)))
#define bM4_USART1_CR1_TXEIE                      (*((volatile unsigned int*)(0x423A019CUL)))
#define bM4_USART1_CR1_PS                         (*((volatile unsigned int*)(0x423A01A4UL)))
#define bM4_USART1_CR1_PCE                        (*((volatile unsigned int*)(0x423A01A8UL)))
#define bM4_USART1_CR1_M                          (*((volatile unsigned int*)(0x423A01B0UL)))
#define bM4_USART1_CR1_OVER8                      (*((volatile unsigned int*)(0x423A01BCUL)))
#define bM4_USART1_CR1_CPE                        (*((volatile unsigned int*)(0x423A01C0UL)))
#define bM4_USART1_CR1_CFE                        (*((volatile unsigned int*)(0x423A01C4UL)))
#define bM4_USART1_CR1_CORE                       (*((volatile unsigned int*)(0x423A01CCUL)))
#define bM4_USART1_CR1_CRTOF                      (*((volatile unsigned int*)(0x423A01D0UL)))
#define bM4_USART1_CR1_MS                         (*((volatile unsigned int*)(0x423A01E0UL)))
#define bM4_USART1_CR1_ML                         (*((volatile unsigned int*)(0x423A01F0UL)))
#define bM4_USART1_CR1_FBME                       (*((volatile unsigned int*)(0x423A01F4UL)))
#define bM4_USART1_CR1_NFE                        (*((volatile unsigned int*)(0x423A01F8UL)))
#define bM4_USART1_CR1_SBS                        (*((volatile unsigned int*)(0x423A01FCUL)))
#define bM4_USART1_CR2_MPE                        (*((volatile unsigned int*)(0x423A0200UL)))
#define bM4_USART1_CR2_CLKC0                      (*((volatile unsigned int*)(0x423A022CUL)))
#define bM4_USART1_CR2_CLKC1                      (*((volatile unsigned int*)(0x423A0230UL)))
#define bM4_USART1_CR2_STOP                       (*((volatile unsigned int*)(0x423A0234UL)))
#define bM4_USART1_CR3_SCEN                       (*((volatile unsigned int*)(0x423A0294UL)))
#define bM4_USART1_CR3_CTSE                       (*((volatile unsigned int*)(0x423A02A4UL)))
#define bM4_USART1_CR3_BCN0                       (*((volatile unsigned int*)(0x423A02D4UL)))
#define bM4_USART1_CR3_BCN1                       (*((volatile unsigned int*)(0x423A02D8UL)))
#define bM4_USART1_CR3_BCN2                       (*((volatile unsigned int*)(0x423A02DCUL)))
#define bM4_USART1_PR_PSC0                        (*((volatile unsigned int*)(0x423A0300UL)))
#define bM4_USART1_PR_PSC1                        (*((volatile unsigned int*)(0x423A0304UL)))
#define bM4_USART2_SR_PE                          (*((volatile unsigned int*)(0x423A8000UL)))
#define bM4_USART2_SR_FE                          (*((volatile unsigned int*)(0x423A8004UL)))
#define bM4_USART2_SR_ORE                         (*((volatile unsigned int*)(0x423A800CUL)))
#define bM4_USART2_SR_RXNE                        (*((volatile unsigned int*)(0x423A8014UL)))
#define bM4_USART2_SR_TC                          (*((volatile unsigned int*)(0x423A8018UL)))
#define bM4_USART2_SR_TXE                         (*((volatile unsigned int*)(0x423A801CUL)))
#define bM4_USART2_SR_RTOF                        (*((volatile unsigned int*)(0x423A8020UL)))
#define bM4_USART2_SR_MPB                         (*((volatile unsigned int*)(0x423A8040UL)))
#define bM4_USART2_DR_TDR0                        (*((volatile unsigned int*)(0x423A8080UL)))
#define bM4_USART2_DR_TDR1                        (*((volatile unsigned int*)(0x423A8084UL)))
#define bM4_USART2_DR_TDR2                        (*((volatile unsigned int*)(0x423A8088UL)))
#define bM4_USART2_DR_TDR3                        (*((volatile unsigned int*)(0x423A808CUL)))
#define bM4_USART2_DR_TDR4                        (*((volatile unsigned int*)(0x423A8090UL)))
#define bM4_USART2_DR_TDR5                        (*((volatile unsigned int*)(0x423A8094UL)))
#define bM4_USART2_DR_TDR6                        (*((volatile unsigned int*)(0x423A8098UL)))
#define bM4_USART2_DR_TDR7                        (*((volatile unsigned int*)(0x423A809CUL)))
#define bM4_USART2_DR_TDR8                        (*((volatile unsigned int*)(0x423A80A0UL)))
#define bM4_USART2_DR_MPID                        (*((volatile unsigned int*)(0x423A80A4UL)))
#define bM4_USART2_DR_RDR0                        (*((volatile unsigned int*)(0x423A80C0UL)))
#define bM4_USART2_DR_RDR1                        (*((volatile unsigned int*)(0x423A80C4UL)))
#define bM4_USART2_DR_RDR2                        (*((volatile unsigned int*)(0x423A80C8UL)))
#define bM4_USART2_DR_RDR3                        (*((volatile unsigned int*)(0x423A80CCUL)))
#define bM4_USART2_DR_RDR4                        (*((volatile unsigned int*)(0x423A80D0UL)))
#define bM4_USART2_DR_RDR5                        (*((volatile unsigned int*)(0x423A80D4UL)))
#define bM4_USART2_DR_RDR6                        (*((volatile unsigned int*)(0x423A80D8UL)))
#define bM4_USART2_DR_RDR7                        (*((volatile unsigned int*)(0x423A80DCUL)))
#define bM4_USART2_DR_RDR8                        (*((volatile unsigned int*)(0x423A80E0UL)))
#define bM4_USART2_BRR_DIV_FRACTION0              (*((volatile unsigned int*)(0x423A8100UL)))
#define bM4_USART2_BRR_DIV_FRACTION1              (*((volatile unsigned int*)(0x423A8104UL)))
#define bM4_USART2_BRR_DIV_FRACTION2              (*((volatile unsigned int*)(0x423A8108UL)))
#define bM4_USART2_BRR_DIV_FRACTION3              (*((volatile unsigned int*)(0x423A810CUL)))
#define bM4_USART2_BRR_DIV_FRACTION4              (*((volatile unsigned int*)(0x423A8110UL)))
#define bM4_USART2_BRR_DIV_FRACTION5              (*((volatile unsigned int*)(0x423A8114UL)))
#define bM4_USART2_BRR_DIV_FRACTION6              (*((volatile unsigned int*)(0x423A8118UL)))
#define bM4_USART2_BRR_DIV_INTEGER0               (*((volatile unsigned int*)(0x423A8120UL)))
#define bM4_USART2_BRR_DIV_INTEGER1               (*((volatile unsigned int*)(0x423A8124UL)))
#define bM4_USART2_BRR_DIV_INTEGER2               (*((volatile unsigned int*)(0x423A8128UL)))
#define bM4_USART2_BRR_DIV_INTEGER3               (*((volatile unsigned int*)(0x423A812CUL)))
#define bM4_USART2_BRR_DIV_INTEGER4               (*((volatile unsigned int*)(0x423A8130UL)))
#define bM4_USART2_BRR_DIV_INTEGER5               (*((volatile unsigned int*)(0x423A8134UL)))
#define bM4_USART2_BRR_DIV_INTEGER6               (*((volatile unsigned int*)(0x423A8138UL)))
#define bM4_USART2_BRR_DIV_INTEGER7               (*((volatile unsigned int*)(0x423A813CUL)))
#define bM4_USART2_CR1_RTOE                       (*((volatile unsigned int*)(0x423A8180UL)))
#define bM4_USART2_CR1_RTOIE                      (*((volatile unsigned int*)(0x423A8184UL)))
#define bM4_USART2_CR1_RE                         (*((volatile unsigned int*)(0x423A8188UL)))
#define bM4_USART2_CR1_TE                         (*((volatile unsigned int*)(0x423A818CUL)))
#define bM4_USART2_CR1_SLME                       (*((volatile unsigned int*)(0x423A8190UL)))
#define bM4_USART2_CR1_RIE                        (*((volatile unsigned int*)(0x423A8194UL)))
#define bM4_USART2_CR1_TCIE                       (*((volatile unsigned int*)(0x423A8198UL)))
#define bM4_USART2_CR1_TXEIE                      (*((volatile unsigned int*)(0x423A819CUL)))
#define bM4_USART2_CR1_PS                         (*((volatile unsigned int*)(0x423A81A4UL)))
#define bM4_USART2_CR1_PCE                        (*((volatile unsigned int*)(0x423A81A8UL)))
#define bM4_USART2_CR1_M                          (*((volatile unsigned int*)(0x423A81B0UL)))
#define bM4_USART2_CR1_OVER8                      (*((volatile unsigned int*)(0x423A81BCUL)))
#define bM4_USART2_CR1_CPE                        (*((volatile unsigned int*)(0x423A81C0UL)))
#define bM4_USART2_CR1_CFE                        (*((volatile unsigned int*)(0x423A81C4UL)))
#define bM4_USART2_CR1_CORE                       (*((volatile unsigned int*)(0x423A81CCUL)))
#define bM4_USART2_CR1_CRTOF                      (*((volatile unsigned int*)(0x423A81D0UL)))
#define bM4_USART2_CR1_MS                         (*((volatile unsigned int*)(0x423A81E0UL)))
#define bM4_USART2_CR1_ML                         (*((volatile unsigned int*)(0x423A81F0UL)))
#define bM4_USART2_CR1_FBME                       (*((volatile unsigned int*)(0x423A81F4UL)))
#define bM4_USART2_CR1_NFE                        (*((volatile unsigned int*)(0x423A81F8UL)))
#define bM4_USART2_CR1_SBS                        (*((volatile unsigned int*)(0x423A81FCUL)))
#define bM4_USART2_CR2_MPE                        (*((volatile unsigned int*)(0x423A8200UL)))
#define bM4_USART2_CR2_CLKC0                      (*((volatile unsigned int*)(0x423A822CUL)))
#define bM4_USART2_CR2_CLKC1                      (*((volatile unsigned int*)(0x423A8230UL)))
#define bM4_USART2_CR2_STOP                       (*((volatile unsigned int*)(0x423A8234UL)))
#define bM4_USART2_CR3_SCEN                       (*((volatile unsigned int*)(0x423A8294UL)))
#define bM4_USART2_CR3_CTSE                       (*((volatile unsigned int*)(0x423A82A4UL)))
#define bM4_USART2_CR3_BCN0                       (*((volatile unsigned int*)(0x423A82D4UL)))
#define bM4_USART2_CR3_BCN1                       (*((volatile unsigned int*)(0x423A82D8UL)))
#define bM4_USART2_CR3_BCN2                       (*((volatile unsigned int*)(0x423A82DCUL)))
#define bM4_USART2_PR_PSC0                        (*((volatile unsigned int*)(0x423A8300UL)))
#define bM4_USART2_PR_PSC1                        (*((volatile unsigned int*)(0x423A8304UL)))
#define bM4_USART3_SR_PE                          (*((volatile unsigned int*)(0x42420000UL)))
#define bM4_USART3_SR_FE                          (*((volatile unsigned int*)(0x42420004UL)))
#define bM4_USART3_SR_ORE                         (*((volatile unsigned int*)(0x4242000CUL)))
#define bM4_USART3_SR_RXNE                        (*((volatile unsigned int*)(0x42420014UL)))
#define bM4_USART3_SR_TC                          (*((volatile unsigned int*)(0x42420018UL)))
#define bM4_USART3_SR_TXE                         (*((volatile unsigned int*)(0x4242001CUL)))
#define bM4_USART3_SR_RTOF                        (*((volatile unsigned int*)(0x42420020UL)))
#define bM4_USART3_SR_MPB                         (*((volatile unsigned int*)(0x42420040UL)))
#define bM4_USART3_DR_TDR0                        (*((volatile unsigned int*)(0x42420080UL)))
#define bM4_USART3_DR_TDR1                        (*((volatile unsigned int*)(0x42420084UL)))
#define bM4_USART3_DR_TDR2                        (*((volatile unsigned int*)(0x42420088UL)))
#define bM4_USART3_DR_TDR3                        (*((volatile unsigned int*)(0x4242008CUL)))
#define bM4_USART3_DR_TDR4                        (*((volatile unsigned int*)(0x42420090UL)))
#define bM4_USART3_DR_TDR5                        (*((volatile unsigned int*)(0x42420094UL)))
#define bM4_USART3_DR_TDR6                        (*((volatile unsigned int*)(0x42420098UL)))
#define bM4_USART3_DR_TDR7                        (*((volatile unsigned int*)(0x4242009CUL)))
#define bM4_USART3_DR_TDR8                        (*((volatile unsigned int*)(0x424200A0UL)))
#define bM4_USART3_DR_MPID                        (*((volatile unsigned int*)(0x424200A4UL)))
#define bM4_USART3_DR_RDR0                        (*((volatile unsigned int*)(0x424200C0UL)))
#define bM4_USART3_DR_RDR1                        (*((volatile unsigned int*)(0x424200C4UL)))
#define bM4_USART3_DR_RDR2                        (*((volatile unsigned int*)(0x424200C8UL)))
#define bM4_USART3_DR_RDR3                        (*((volatile unsigned int*)(0x424200CCUL)))
#define bM4_USART3_DR_RDR4                        (*((volatile unsigned int*)(0x424200D0UL)))
#define bM4_USART3_DR_RDR5                        (*((volatile unsigned int*)(0x424200D4UL)))
#define bM4_USART3_DR_RDR6                        (*((volatile unsigned int*)(0x424200D8UL)))
#define bM4_USART3_DR_RDR7                        (*((volatile unsigned int*)(0x424200DCUL)))
#define bM4_USART3_DR_RDR8                        (*((volatile unsigned int*)(0x424200E0UL)))
#define bM4_USART3_BRR_DIV_FRACTION0              (*((volatile unsigned int*)(0x42420100UL)))
#define bM4_USART3_BRR_DIV_FRACTION1              (*((volatile unsigned int*)(0x42420104UL)))
#define bM4_USART3_BRR_DIV_FRACTION2              (*((volatile unsigned int*)(0x42420108UL)))
#define bM4_USART3_BRR_DIV_FRACTION3              (*((volatile unsigned int*)(0x4242010CUL)))
#define bM4_USART3_BRR_DIV_FRACTION4              (*((volatile unsigned int*)(0x42420110UL)))
#define bM4_USART3_BRR_DIV_FRACTION5              (*((volatile unsigned int*)(0x42420114UL)))
#define bM4_USART3_BRR_DIV_FRACTION6              (*((volatile unsigned int*)(0x42420118UL)))
#define bM4_USART3_BRR_DIV_INTEGER0               (*((volatile unsigned int*)(0x42420120UL)))
#define bM4_USART3_BRR_DIV_INTEGER1               (*((volatile unsigned int*)(0x42420124UL)))
#define bM4_USART3_BRR_DIV_INTEGER2               (*((volatile unsigned int*)(0x42420128UL)))
#define bM4_USART3_BRR_DIV_INTEGER3               (*((volatile unsigned int*)(0x4242012CUL)))
#define bM4_USART3_BRR_DIV_INTEGER4               (*((volatile unsigned int*)(0x42420130UL)))
#define bM4_USART3_BRR_DIV_INTEGER5               (*((volatile unsigned int*)(0x42420134UL)))
#define bM4_USART3_BRR_DIV_INTEGER6               (*((volatile unsigned int*)(0x42420138UL)))
#define bM4_USART3_BRR_DIV_INTEGER7               (*((volatile unsigned int*)(0x4242013CUL)))
#define bM4_USART3_CR1_RTOE                       (*((volatile unsigned int*)(0x42420180UL)))
#define bM4_USART3_CR1_RTOIE                      (*((volatile unsigned int*)(0x42420184UL)))
#define bM4_USART3_CR1_RE                         (*((volatile unsigned int*)(0x42420188UL)))
#define bM4_USART3_CR1_TE                         (*((volatile unsigned int*)(0x4242018CUL)))
#define bM4_USART3_CR1_SLME                       (*((volatile unsigned int*)(0x42420190UL)))
#define bM4_USART3_CR1_RIE                        (*((volatile unsigned int*)(0x42420194UL)))
#define bM4_USART3_CR1_TCIE                       (*((volatile unsigned int*)(0x42420198UL)))
#define bM4_USART3_CR1_TXEIE                      (*((volatile unsigned int*)(0x4242019CUL)))
#define bM4_USART3_CR1_PS                         (*((volatile unsigned int*)(0x424201A4UL)))
#define bM4_USART3_CR1_PCE                        (*((volatile unsigned int*)(0x424201A8UL)))
#define bM4_USART3_CR1_M                          (*((volatile unsigned int*)(0x424201B0UL)))
#define bM4_USART3_CR1_OVER8                      (*((volatile unsigned int*)(0x424201BCUL)))
#define bM4_USART3_CR1_CPE                        (*((volatile unsigned int*)(0x424201C0UL)))
#define bM4_USART3_CR1_CFE                        (*((volatile unsigned int*)(0x424201C4UL)))
#define bM4_USART3_CR1_CORE                       (*((volatile unsigned int*)(0x424201CCUL)))
#define bM4_USART3_CR1_CRTOF                      (*((volatile unsigned int*)(0x424201D0UL)))
#define bM4_USART3_CR1_MS                         (*((volatile unsigned int*)(0x424201E0UL)))
#define bM4_USART3_CR1_ML                         (*((volatile unsigned int*)(0x424201F0UL)))
#define bM4_USART3_CR1_FBME                       (*((volatile unsigned int*)(0x424201F4UL)))
#define bM4_USART3_CR1_NFE                        (*((volatile unsigned int*)(0x424201F8UL)))
#define bM4_USART3_CR1_SBS                        (*((volatile unsigned int*)(0x424201FCUL)))
#define bM4_USART3_CR2_MPE                        (*((volatile unsigned int*)(0x42420200UL)))
#define bM4_USART3_CR2_CLKC0                      (*((volatile unsigned int*)(0x4242022CUL)))
#define bM4_USART3_CR2_CLKC1                      (*((volatile unsigned int*)(0x42420230UL)))
#define bM4_USART3_CR2_STOP                       (*((volatile unsigned int*)(0x42420234UL)))
#define bM4_USART3_CR3_SCEN                       (*((volatile unsigned int*)(0x42420294UL)))
#define bM4_USART3_CR3_CTSE                       (*((volatile unsigned int*)(0x424202A4UL)))
#define bM4_USART3_CR3_BCN0                       (*((volatile unsigned int*)(0x424202D4UL)))
#define bM4_USART3_CR3_BCN1                       (*((volatile unsigned int*)(0x424202D8UL)))
#define bM4_USART3_CR3_BCN2                       (*((volatile unsigned int*)(0x424202DCUL)))
#define bM4_USART3_PR_PSC0                        (*((volatile unsigned int*)(0x42420300UL)))
#define bM4_USART3_PR_PSC1                        (*((volatile unsigned int*)(0x42420304UL)))
#define bM4_USART4_SR_PE                          (*((volatile unsigned int*)(0x42428000UL)))
#define bM4_USART4_SR_FE                          (*((volatile unsigned int*)(0x42428004UL)))
#define bM4_USART4_SR_ORE                         (*((volatile unsigned int*)(0x4242800CUL)))
#define bM4_USART4_SR_RXNE                        (*((volatile unsigned int*)(0x42428014UL)))
#define bM4_USART4_SR_TC                          (*((volatile unsigned int*)(0x42428018UL)))
#define bM4_USART4_SR_TXE                         (*((volatile unsigned int*)(0x4242801CUL)))
#define bM4_USART4_SR_RTOF                        (*((volatile unsigned int*)(0x42428020UL)))
#define bM4_USART4_SR_MPB                         (*((volatile unsigned int*)(0x42428040UL)))
#define bM4_USART4_DR_TDR0                        (*((volatile unsigned int*)(0x42428080UL)))
#define bM4_USART4_DR_TDR1                        (*((volatile unsigned int*)(0x42428084UL)))
#define bM4_USART4_DR_TDR2                        (*((volatile unsigned int*)(0x42428088UL)))
#define bM4_USART4_DR_TDR3                        (*((volatile unsigned int*)(0x4242808CUL)))
#define bM4_USART4_DR_TDR4                        (*((volatile unsigned int*)(0x42428090UL)))
#define bM4_USART4_DR_TDR5                        (*((volatile unsigned int*)(0x42428094UL)))
#define bM4_USART4_DR_TDR6                        (*((volatile unsigned int*)(0x42428098UL)))
#define bM4_USART4_DR_TDR7                        (*((volatile unsigned int*)(0x4242809CUL)))
#define bM4_USART4_DR_TDR8                        (*((volatile unsigned int*)(0x424280A0UL)))
#define bM4_USART4_DR_MPID                        (*((volatile unsigned int*)(0x424280A4UL)))
#define bM4_USART4_DR_RDR0                        (*((volatile unsigned int*)(0x424280C0UL)))
#define bM4_USART4_DR_RDR1                        (*((volatile unsigned int*)(0x424280C4UL)))
#define bM4_USART4_DR_RDR2                        (*((volatile unsigned int*)(0x424280C8UL)))
#define bM4_USART4_DR_RDR3                        (*((volatile unsigned int*)(0x424280CCUL)))
#define bM4_USART4_DR_RDR4                        (*((volatile unsigned int*)(0x424280D0UL)))
#define bM4_USART4_DR_RDR5                        (*((volatile unsigned int*)(0x424280D4UL)))
#define bM4_USART4_DR_RDR6                        (*((volatile unsigned int*)(0x424280D8UL)))
#define bM4_USART4_DR_RDR7                        (*((volatile unsigned int*)(0x424280DCUL)))
#define bM4_USART4_DR_RDR8                        (*((volatile unsigned int*)(0x424280E0UL)))
#define bM4_USART4_BRR_DIV_FRACTION0              (*((volatile unsigned int*)(0x42428100UL)))
#define bM4_USART4_BRR_DIV_FRACTION1              (*((volatile unsigned int*)(0x42428104UL)))
#define bM4_USART4_BRR_DIV_FRACTION2              (*((volatile unsigned int*)(0x42428108UL)))
#define bM4_USART4_BRR_DIV_FRACTION3              (*((volatile unsigned int*)(0x4242810CUL)))
#define bM4_USART4_BRR_DIV_FRACTION4              (*((volatile unsigned int*)(0x42428110UL)))
#define bM4_USART4_BRR_DIV_FRACTION5              (*((volatile unsigned int*)(0x42428114UL)))
#define bM4_USART4_BRR_DIV_FRACTION6              (*((volatile unsigned int*)(0x42428118UL)))
#define bM4_USART4_BRR_DIV_INTEGER0               (*((volatile unsigned int*)(0x42428120UL)))
#define bM4_USART4_BRR_DIV_INTEGER1               (*((volatile unsigned int*)(0x42428124UL)))
#define bM4_USART4_BRR_DIV_INTEGER2               (*((volatile unsigned int*)(0x42428128UL)))
#define bM4_USART4_BRR_DIV_INTEGER3               (*((volatile unsigned int*)(0x4242812CUL)))
#define bM4_USART4_BRR_DIV_INTEGER4               (*((volatile unsigned int*)(0x42428130UL)))
#define bM4_USART4_BRR_DIV_INTEGER5               (*((volatile unsigned int*)(0x42428134UL)))
#define bM4_USART4_BRR_DIV_INTEGER6               (*((volatile unsigned int*)(0x42428138UL)))
#define bM4_USART4_BRR_DIV_INTEGER7               (*((volatile unsigned int*)(0x4242813CUL)))
#define bM4_USART4_CR1_RTOE                       (*((volatile unsigned int*)(0x42428180UL)))
#define bM4_USART4_CR1_RTOIE                      (*((volatile unsigned int*)(0x42428184UL)))
#define bM4_USART4_CR1_RE                         (*((volatile unsigned int*)(0x42428188UL)))
#define bM4_USART4_CR1_TE                         (*((volatile unsigned int*)(0x4242818CUL)))
#define bM4_USART4_CR1_SLME                       (*((volatile unsigned int*)(0x42428190UL)))
#define bM4_USART4_CR1_RIE                        (*((volatile unsigned int*)(0x42428194UL)))
#define bM4_USART4_CR1_TCIE                       (*((volatile unsigned int*)(0x42428198UL)))
#define bM4_USART4_CR1_TXEIE                      (*((volatile unsigned int*)(0x4242819CUL)))
#define bM4_USART4_CR1_PS                         (*((volatile unsigned int*)(0x424281A4UL)))
#define bM4_USART4_CR1_PCE                        (*((volatile unsigned int*)(0x424281A8UL)))
#define bM4_USART4_CR1_M                          (*((volatile unsigned int*)(0x424281B0UL)))
#define bM4_USART4_CR1_OVER8                      (*((volatile unsigned int*)(0x424281BCUL)))
#define bM4_USART4_CR1_CPE                        (*((volatile unsigned int*)(0x424281C0UL)))
#define bM4_USART4_CR1_CFE                        (*((volatile unsigned int*)(0x424281C4UL)))
#define bM4_USART4_CR1_CORE                       (*((volatile unsigned int*)(0x424281CCUL)))
#define bM4_USART4_CR1_CRTOF                      (*((volatile unsigned int*)(0x424281D0UL)))
#define bM4_USART4_CR1_MS                         (*((volatile unsigned int*)(0x424281E0UL)))
#define bM4_USART4_CR1_ML                         (*((volatile unsigned int*)(0x424281F0UL)))
#define bM4_USART4_CR1_FBME                       (*((volatile unsigned int*)(0x424281F4UL)))
#define bM4_USART4_CR1_NFE                        (*((volatile unsigned int*)(0x424281F8UL)))
#define bM4_USART4_CR1_SBS                        (*((volatile unsigned int*)(0x424281FCUL)))
#define bM4_USART4_CR2_MPE                        (*((volatile unsigned int*)(0x42428200UL)))
#define bM4_USART4_CR2_CLKC0                      (*((volatile unsigned int*)(0x4242822CUL)))
#define bM4_USART4_CR2_CLKC1                      (*((volatile unsigned int*)(0x42428230UL)))
#define bM4_USART4_CR2_STOP                       (*((volatile unsigned int*)(0x42428234UL)))
#define bM4_USART4_CR3_SCEN                       (*((volatile unsigned int*)(0x42428294UL)))
#define bM4_USART4_CR3_CTSE                       (*((volatile unsigned int*)(0x424282A4UL)))
#define bM4_USART4_CR3_BCN0                       (*((volatile unsigned int*)(0x424282D4UL)))
#define bM4_USART4_CR3_BCN1                       (*((volatile unsigned int*)(0x424282D8UL)))
#define bM4_USART4_CR3_BCN2                       (*((volatile unsigned int*)(0x424282DCUL)))
#define bM4_USART4_PR_PSC0                        (*((volatile unsigned int*)(0x42428300UL)))
#define bM4_USART4_PR_PSC1                        (*((volatile unsigned int*)(0x42428304UL)))
#define bM4_USBFS_GVBUSCFG_VBUSOVEN               (*((volatile unsigned int*)(0x43800018UL)))
#define bM4_USBFS_GVBUSCFG_VBUSVAL                (*((volatile unsigned int*)(0x4380001CUL)))
#define bM4_USBFS_GAHBCFG_GINTMSK                 (*((volatile unsigned int*)(0x43800100UL)))
#define bM4_USBFS_GAHBCFG_HBSTLEN0                (*((volatile unsigned int*)(0x43800104UL)))
#define bM4_USBFS_GAHBCFG_HBSTLEN1                (*((volatile unsigned int*)(0x43800108UL)))
#define bM4_USBFS_GAHBCFG_HBSTLEN2                (*((volatile unsigned int*)(0x4380010CUL)))
#define bM4_USBFS_GAHBCFG_HBSTLEN3                (*((volatile unsigned int*)(0x43800110UL)))
#define bM4_USBFS_GAHBCFG_DMAEN                   (*((volatile unsigned int*)(0x43800114UL)))
#define bM4_USBFS_GAHBCFG_TXFELVL                 (*((volatile unsigned int*)(0x4380011CUL)))
#define bM4_USBFS_GAHBCFG_PTXFELVL                (*((volatile unsigned int*)(0x43800120UL)))
#define bM4_USBFS_GUSBCFG_TOCAL0                  (*((volatile unsigned int*)(0x43800180UL)))
#define bM4_USBFS_GUSBCFG_TOCAL1                  (*((volatile unsigned int*)(0x43800184UL)))
#define bM4_USBFS_GUSBCFG_TOCAL2                  (*((volatile unsigned int*)(0x43800188UL)))
#define bM4_USBFS_GUSBCFG_PHYSEL                  (*((volatile unsigned int*)(0x43800198UL)))
#define bM4_USBFS_GUSBCFG_TRDT0                   (*((volatile unsigned int*)(0x438001A8UL)))
#define bM4_USBFS_GUSBCFG_TRDT1                   (*((volatile unsigned int*)(0x438001ACUL)))
#define bM4_USBFS_GUSBCFG_TRDT2                   (*((volatile unsigned int*)(0x438001B0UL)))
#define bM4_USBFS_GUSBCFG_TRDT3                   (*((volatile unsigned int*)(0x438001B4UL)))
#define bM4_USBFS_GUSBCFG_FHMOD                   (*((volatile unsigned int*)(0x438001F4UL)))
#define bM4_USBFS_GUSBCFG_FDMOD                   (*((volatile unsigned int*)(0x438001F8UL)))
#define bM4_USBFS_GRSTCTL_CSRST                   (*((volatile unsigned int*)(0x43800200UL)))
#define bM4_USBFS_GRSTCTL_HSRST                   (*((volatile unsigned int*)(0x43800204UL)))
#define bM4_USBFS_GRSTCTL_FCRST                   (*((volatile unsigned int*)(0x43800208UL)))
#define bM4_USBFS_GRSTCTL_RXFFLSH                 (*((volatile unsigned int*)(0x43800210UL)))
#define bM4_USBFS_GRSTCTL_TXFFLSH                 (*((volatile unsigned int*)(0x43800214UL)))
#define bM4_USBFS_GRSTCTL_TXFNUM0                 (*((volatile unsigned int*)(0x43800218UL)))
#define bM4_USBFS_GRSTCTL_TXFNUM1                 (*((volatile unsigned int*)(0x4380021CUL)))
#define bM4_USBFS_GRSTCTL_TXFNUM2                 (*((volatile unsigned int*)(0x43800220UL)))
#define bM4_USBFS_GRSTCTL_TXFNUM3                 (*((volatile unsigned int*)(0x43800224UL)))
#define bM4_USBFS_GRSTCTL_TXFNUM4                 (*((volatile unsigned int*)(0x43800228UL)))
#define bM4_USBFS_GRSTCTL_DMAREQ                  (*((volatile unsigned int*)(0x43800278UL)))
#define bM4_USBFS_GRSTCTL_AHBIDL                  (*((volatile unsigned int*)(0x4380027CUL)))
#define bM4_USBFS_GINTSTS_CMOD                    (*((volatile unsigned int*)(0x43800280UL)))
#define bM4_USBFS_GINTSTS_MMIS                    (*((volatile unsigned int*)(0x43800284UL)))
#define bM4_USBFS_GINTSTS_SOF                     (*((volatile unsigned int*)(0x4380028CUL)))
#define bM4_USBFS_GINTSTS_RXFNE                   (*((volatile unsigned int*)(0x43800290UL)))
#define bM4_USBFS_GINTSTS_NPTXFE                  (*((volatile unsigned int*)(0x43800294UL)))
#define bM4_USBFS_GINTSTS_GINAKEFF                (*((volatile unsigned int*)(0x43800298UL)))
#define bM4_USBFS_GINTSTS_GONAKEFF                (*((volatile unsigned int*)(0x4380029CUL)))
#define bM4_USBFS_GINTSTS_ESUSP                   (*((volatile unsigned int*)(0x438002A8UL)))
#define bM4_USBFS_GINTSTS_USBSUSP                 (*((volatile unsigned int*)(0x438002ACUL)))
#define bM4_USBFS_GINTSTS_USBRST                  (*((volatile unsigned int*)(0x438002B0UL)))
#define bM4_USBFS_GINTSTS_ENUMDNE                 (*((volatile unsigned int*)(0x438002B4UL)))
#define bM4_USBFS_GINTSTS_ISOODRP                 (*((volatile unsigned int*)(0x438002B8UL)))
#define bM4_USBFS_GINTSTS_EOPF                    (*((volatile unsigned int*)(0x438002BCUL)))
#define bM4_USBFS_GINTSTS_IEPINT                  (*((volatile unsigned int*)(0x438002C8UL)))
#define bM4_USBFS_GINTSTS_OEPINT                  (*((volatile unsigned int*)(0x438002CCUL)))
#define bM4_USBFS_GINTSTS_IISOIXFR                (*((volatile unsigned int*)(0x438002D0UL)))
#define bM4_USBFS_GINTSTS_IPXFR_INCOMPISOOUT      (*((volatile unsigned int*)(0x438002D4UL)))
#define bM4_USBFS_GINTSTS_DATAFSUSP               (*((volatile unsigned int*)(0x438002D8UL)))
#define bM4_USBFS_GINTSTS_HPRTINT                 (*((volatile unsigned int*)(0x438002E0UL)))
#define bM4_USBFS_GINTSTS_HCINT                   (*((volatile unsigned int*)(0x438002E4UL)))
#define bM4_USBFS_GINTSTS_PTXFE                   (*((volatile unsigned int*)(0x438002E8UL)))
#define bM4_USBFS_GINTSTS_CIDSCHG                 (*((volatile unsigned int*)(0x438002F0UL)))
#define bM4_USBFS_GINTSTS_DISCINT                 (*((volatile unsigned int*)(0x438002F4UL)))
#define bM4_USBFS_GINTSTS_VBUSVINT                (*((volatile unsigned int*)(0x438002F8UL)))
#define bM4_USBFS_GINTSTS_WKUINT                  (*((volatile unsigned int*)(0x438002FCUL)))
#define bM4_USBFS_GINTMSK_MMISM                   (*((volatile unsigned int*)(0x43800304UL)))
#define bM4_USBFS_GINTMSK_SOFM                    (*((volatile unsigned int*)(0x4380030CUL)))
#define bM4_USBFS_GINTMSK_RXFNEM                  (*((volatile unsigned int*)(0x43800310UL)))
#define bM4_USBFS_GINTMSK_NPTXFEM                 (*((volatile unsigned int*)(0x43800314UL)))
#define bM4_USBFS_GINTMSK_GINAKEFFM               (*((volatile unsigned int*)(0x43800318UL)))
#define bM4_USBFS_GINTMSK_GONAKEFFM               (*((volatile unsigned int*)(0x4380031CUL)))
#define bM4_USBFS_GINTMSK_ESUSPM                  (*((volatile unsigned int*)(0x43800328UL)))
#define bM4_USBFS_GINTMSK_USBSUSPM                (*((volatile unsigned int*)(0x4380032CUL)))
#define bM4_USBFS_GINTMSK_USBRSTM                 (*((volatile unsigned int*)(0x43800330UL)))
#define bM4_USBFS_GINTMSK_ENUMDNEM                (*((volatile unsigned int*)(0x43800334UL)))
#define bM4_USBFS_GINTMSK_ISOODRPM                (*((volatile unsigned int*)(0x43800338UL)))
#define bM4_USBFS_GINTMSK_EOPFM                   (*((volatile unsigned int*)(0x4380033CUL)))
#define bM4_USBFS_GINTMSK_IEPIM                   (*((volatile unsigned int*)(0x43800348UL)))
#define bM4_USBFS_GINTMSK_OEPIM                   (*((volatile unsigned int*)(0x4380034CUL)))
#define bM4_USBFS_GINTMSK_IISOIXFRM               (*((volatile unsigned int*)(0x43800350UL)))
#define bM4_USBFS_GINTMSK_IPXFRM_INCOMPISOOUTM    (*((volatile unsigned int*)(0x43800354UL)))
#define bM4_USBFS_GINTMSK_DATAFSUSPM              (*((volatile unsigned int*)(0x43800358UL)))
#define bM4_USBFS_GINTMSK_HPRTIM                  (*((volatile unsigned int*)(0x43800360UL)))
#define bM4_USBFS_GINTMSK_HCIM                    (*((volatile unsigned int*)(0x43800364UL)))
#define bM4_USBFS_GINTMSK_PTXFEM                  (*((volatile unsigned int*)(0x43800368UL)))
#define bM4_USBFS_GINTMSK_CIDSCHGM                (*((volatile unsigned int*)(0x43800370UL)))
#define bM4_USBFS_GINTMSK_DISCIM                  (*((volatile unsigned int*)(0x43800374UL)))
#define bM4_USBFS_GINTMSK_VBUSVIM                 (*((volatile unsigned int*)(0x43800378UL)))
#define bM4_USBFS_GINTMSK_WKUIM                   (*((volatile unsigned int*)(0x4380037CUL)))
#define bM4_USBFS_GRXSTSR_CHNUM_EPNUM0            (*((volatile unsigned int*)(0x43800380UL)))
#define bM4_USBFS_GRXSTSR_CHNUM_EPNUM1            (*((volatile unsigned int*)(0x43800384UL)))
#define bM4_USBFS_GRXSTSR_CHNUM_EPNUM2            (*((volatile unsigned int*)(0x43800388UL)))
#define bM4_USBFS_GRXSTSR_CHNUM_EPNUM3            (*((volatile unsigned int*)(0x4380038CUL)))
#define bM4_USBFS_GRXSTSR_BCNT0                   (*((volatile unsigned int*)(0x43800390UL)))
#define bM4_USBFS_GRXSTSR_BCNT1                   (*((volatile unsigned int*)(0x43800394UL)))
#define bM4_USBFS_GRXSTSR_BCNT2                   (*((volatile unsigned int*)(0x43800398UL)))
#define bM4_USBFS_GRXSTSR_BCNT3                   (*((volatile unsigned int*)(0x4380039CUL)))
#define bM4_USBFS_GRXSTSR_BCNT4                   (*((volatile unsigned int*)(0x438003A0UL)))
#define bM4_USBFS_GRXSTSR_BCNT5                   (*((volatile unsigned int*)(0x438003A4UL)))
#define bM4_USBFS_GRXSTSR_BCNT6                   (*((volatile unsigned int*)(0x438003A8UL)))
#define bM4_USBFS_GRXSTSR_BCNT7                   (*((volatile unsigned int*)(0x438003ACUL)))
#define bM4_USBFS_GRXSTSR_BCNT8                   (*((volatile unsigned int*)(0x438003B0UL)))
#define bM4_USBFS_GRXSTSR_BCNT9                   (*((volatile unsigned int*)(0x438003B4UL)))
#define bM4_USBFS_GRXSTSR_BCNT10                  (*((volatile unsigned int*)(0x438003B8UL)))
#define bM4_USBFS_GRXSTSR_DPID0                   (*((volatile unsigned int*)(0x438003BCUL)))
#define bM4_USBFS_GRXSTSR_DPID1                   (*((volatile unsigned int*)(0x438003C0UL)))
#define bM4_USBFS_GRXSTSR_PKTSTS0                 (*((volatile unsigned int*)(0x438003C4UL)))
#define bM4_USBFS_GRXSTSR_PKTSTS1                 (*((volatile unsigned int*)(0x438003C8UL)))
#define bM4_USBFS_GRXSTSR_PKTSTS2                 (*((volatile unsigned int*)(0x438003CCUL)))
#define bM4_USBFS_GRXSTSR_PKTSTS3                 (*((volatile unsigned int*)(0x438003D0UL)))
#define bM4_USBFS_GRXSTSP_CHNUM_EPNUM0            (*((volatile unsigned int*)(0x43800400UL)))
#define bM4_USBFS_GRXSTSP_CHNUM_EPNUM1            (*((volatile unsigned int*)(0x43800404UL)))
#define bM4_USBFS_GRXSTSP_CHNUM_EPNUM2            (*((volatile unsigned int*)(0x43800408UL)))
#define bM4_USBFS_GRXSTSP_CHNUM_EPNUM3            (*((volatile unsigned int*)(0x4380040CUL)))
#define bM4_USBFS_GRXSTSP_BCNT0                   (*((volatile unsigned int*)(0x43800410UL)))
#define bM4_USBFS_GRXSTSP_BCNT1                   (*((volatile unsigned int*)(0x43800414UL)))
#define bM4_USBFS_GRXSTSP_BCNT2                   (*((volatile unsigned int*)(0x43800418UL)))
#define bM4_USBFS_GRXSTSP_BCNT3                   (*((volatile unsigned int*)(0x4380041CUL)))
#define bM4_USBFS_GRXSTSP_BCNT4                   (*((volatile unsigned int*)(0x43800420UL)))
#define bM4_USBFS_GRXSTSP_BCNT5                   (*((volatile unsigned int*)(0x43800424UL)))
#define bM4_USBFS_GRXSTSP_BCNT6                   (*((volatile unsigned int*)(0x43800428UL)))
#define bM4_USBFS_GRXSTSP_BCNT7                   (*((volatile unsigned int*)(0x4380042CUL)))
#define bM4_USBFS_GRXSTSP_BCNT8                   (*((volatile unsigned int*)(0x43800430UL)))
#define bM4_USBFS_GRXSTSP_BCNT9                   (*((volatile unsigned int*)(0x43800434UL)))
#define bM4_USBFS_GRXSTSP_BCNT10                  (*((volatile unsigned int*)(0x43800438UL)))
#define bM4_USBFS_GRXSTSP_DPID0                   (*((volatile unsigned int*)(0x4380043CUL)))
#define bM4_USBFS_GRXSTSP_DPID1                   (*((volatile unsigned int*)(0x43800440UL)))
#define bM4_USBFS_GRXSTSP_PKTSTS0                 (*((volatile unsigned int*)(0x43800444UL)))
#define bM4_USBFS_GRXSTSP_PKTSTS1                 (*((volatile unsigned int*)(0x43800448UL)))
#define bM4_USBFS_GRXSTSP_PKTSTS2                 (*((volatile unsigned int*)(0x4380044CUL)))
#define bM4_USBFS_GRXSTSP_PKTSTS3                 (*((volatile unsigned int*)(0x43800450UL)))
#define bM4_USBFS_GRXFSIZ_RXFD0                   (*((volatile unsigned int*)(0x43800480UL)))
#define bM4_USBFS_GRXFSIZ_RXFD1                   (*((volatile unsigned int*)(0x43800484UL)))
#define bM4_USBFS_GRXFSIZ_RXFD2                   (*((volatile unsigned int*)(0x43800488UL)))
#define bM4_USBFS_GRXFSIZ_RXFD3                   (*((volatile unsigned int*)(0x4380048CUL)))
#define bM4_USBFS_GRXFSIZ_RXFD4                   (*((volatile unsigned int*)(0x43800490UL)))
#define bM4_USBFS_GRXFSIZ_RXFD5                   (*((volatile unsigned int*)(0x43800494UL)))
#define bM4_USBFS_GRXFSIZ_RXFD6                   (*((volatile unsigned int*)(0x43800498UL)))
#define bM4_USBFS_GRXFSIZ_RXFD7                   (*((volatile unsigned int*)(0x4380049CUL)))
#define bM4_USBFS_GRXFSIZ_RXFD8                   (*((volatile unsigned int*)(0x438004A0UL)))
#define bM4_USBFS_GRXFSIZ_RXFD9                   (*((volatile unsigned int*)(0x438004A4UL)))
#define bM4_USBFS_GRXFSIZ_RXFD10                  (*((volatile unsigned int*)(0x438004A8UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA0              (*((volatile unsigned int*)(0x43800500UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA1              (*((volatile unsigned int*)(0x43800504UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA2              (*((volatile unsigned int*)(0x43800508UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA3              (*((volatile unsigned int*)(0x4380050CUL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA4              (*((volatile unsigned int*)(0x43800510UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA5              (*((volatile unsigned int*)(0x43800514UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA6              (*((volatile unsigned int*)(0x43800518UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA7              (*((volatile unsigned int*)(0x4380051CUL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA8              (*((volatile unsigned int*)(0x43800520UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA9              (*((volatile unsigned int*)(0x43800524UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA10             (*((volatile unsigned int*)(0x43800528UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA11             (*((volatile unsigned int*)(0x4380052CUL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA12             (*((volatile unsigned int*)(0x43800530UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA13             (*((volatile unsigned int*)(0x43800534UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA14             (*((volatile unsigned int*)(0x43800538UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFSA15             (*((volatile unsigned int*)(0x4380053CUL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD0               (*((volatile unsigned int*)(0x43800540UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD1               (*((volatile unsigned int*)(0x43800544UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD2               (*((volatile unsigned int*)(0x43800548UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD3               (*((volatile unsigned int*)(0x4380054CUL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD4               (*((volatile unsigned int*)(0x43800550UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD5               (*((volatile unsigned int*)(0x43800554UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD6               (*((volatile unsigned int*)(0x43800558UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD7               (*((volatile unsigned int*)(0x4380055CUL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD8               (*((volatile unsigned int*)(0x43800560UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD9               (*((volatile unsigned int*)(0x43800564UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD10              (*((volatile unsigned int*)(0x43800568UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD11              (*((volatile unsigned int*)(0x4380056CUL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD12              (*((volatile unsigned int*)(0x43800570UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD13              (*((volatile unsigned int*)(0x43800574UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD14              (*((volatile unsigned int*)(0x43800578UL)))
#define bM4_USBFS_HNPTXFSIZ_NPTXFD15              (*((volatile unsigned int*)(0x4380057CUL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV0              (*((volatile unsigned int*)(0x43800580UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV1              (*((volatile unsigned int*)(0x43800584UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV2              (*((volatile unsigned int*)(0x43800588UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV3              (*((volatile unsigned int*)(0x4380058CUL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV4              (*((volatile unsigned int*)(0x43800590UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV5              (*((volatile unsigned int*)(0x43800594UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV6              (*((volatile unsigned int*)(0x43800598UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV7              (*((volatile unsigned int*)(0x4380059CUL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV8              (*((volatile unsigned int*)(0x438005A0UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV9              (*((volatile unsigned int*)(0x438005A4UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV10             (*((volatile unsigned int*)(0x438005A8UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV11             (*((volatile unsigned int*)(0x438005ACUL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV12             (*((volatile unsigned int*)(0x438005B0UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV13             (*((volatile unsigned int*)(0x438005B4UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV14             (*((volatile unsigned int*)(0x438005B8UL)))
#define bM4_USBFS_HNPTXSTS_NPTXFSAV15             (*((volatile unsigned int*)(0x438005BCUL)))
#define bM4_USBFS_HNPTXSTS_NPTQXSAV0              (*((volatile unsigned int*)(0x438005C0UL)))
#define bM4_USBFS_HNPTXSTS_NPTQXSAV1              (*((volatile unsigned int*)(0x438005C4UL)))
#define bM4_USBFS_HNPTXSTS_NPTQXSAV2              (*((volatile unsigned int*)(0x438005C8UL)))
#define bM4_USBFS_HNPTXSTS_NPTQXSAV3              (*((volatile unsigned int*)(0x438005CCUL)))
#define bM4_USBFS_HNPTXSTS_NPTQXSAV4              (*((volatile unsigned int*)(0x438005D0UL)))
#define bM4_USBFS_HNPTXSTS_NPTQXSAV5              (*((volatile unsigned int*)(0x438005D4UL)))
#define bM4_USBFS_HNPTXSTS_NPTQXSAV6              (*((volatile unsigned int*)(0x438005D8UL)))
#define bM4_USBFS_HNPTXSTS_NPTQXSAV7              (*((volatile unsigned int*)(0x438005DCUL)))
#define bM4_USBFS_HNPTXSTS_NPTXQTOP0              (*((volatile unsigned int*)(0x438005E0UL)))
#define bM4_USBFS_HNPTXSTS_NPTXQTOP1              (*((volatile unsigned int*)(0x438005E4UL)))
#define bM4_USBFS_HNPTXSTS_NPTXQTOP2              (*((volatile unsigned int*)(0x438005E8UL)))
#define bM4_USBFS_HNPTXSTS_NPTXQTOP3              (*((volatile unsigned int*)(0x438005ECUL)))
#define bM4_USBFS_HNPTXSTS_NPTXQTOP4              (*((volatile unsigned int*)(0x438005F0UL)))
#define bM4_USBFS_HNPTXSTS_NPTXQTOP5              (*((volatile unsigned int*)(0x438005F4UL)))
#define bM4_USBFS_HNPTXSTS_NPTXQTOP6              (*((volatile unsigned int*)(0x438005F8UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA0                 (*((volatile unsigned int*)(0x43802000UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA1                 (*((volatile unsigned int*)(0x43802004UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA2                 (*((volatile unsigned int*)(0x43802008UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA3                 (*((volatile unsigned int*)(0x4380200CUL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA4                 (*((volatile unsigned int*)(0x43802010UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA5                 (*((volatile unsigned int*)(0x43802014UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA6                 (*((volatile unsigned int*)(0x43802018UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA7                 (*((volatile unsigned int*)(0x4380201CUL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA8                 (*((volatile unsigned int*)(0x43802020UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA9                 (*((volatile unsigned int*)(0x43802024UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA10                (*((volatile unsigned int*)(0x43802028UL)))
#define bM4_USBFS_HPTXFSIZ_PTXSA11                (*((volatile unsigned int*)(0x4380202CUL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD0                 (*((volatile unsigned int*)(0x43802040UL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD1                 (*((volatile unsigned int*)(0x43802044UL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD2                 (*((volatile unsigned int*)(0x43802048UL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD3                 (*((volatile unsigned int*)(0x4380204CUL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD4                 (*((volatile unsigned int*)(0x43802050UL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD5                 (*((volatile unsigned int*)(0x43802054UL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD6                 (*((volatile unsigned int*)(0x43802058UL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD7                 (*((volatile unsigned int*)(0x4380205CUL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD8                 (*((volatile unsigned int*)(0x43802060UL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD9                 (*((volatile unsigned int*)(0x43802064UL)))
#define bM4_USBFS_HPTXFSIZ_PTXFD10                (*((volatile unsigned int*)(0x43802068UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA0              (*((volatile unsigned int*)(0x43802080UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA1              (*((volatile unsigned int*)(0x43802084UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA2              (*((volatile unsigned int*)(0x43802088UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA3              (*((volatile unsigned int*)(0x4380208CUL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA4              (*((volatile unsigned int*)(0x43802090UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA5              (*((volatile unsigned int*)(0x43802094UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA6              (*((volatile unsigned int*)(0x43802098UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA7              (*((volatile unsigned int*)(0x4380209CUL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA8              (*((volatile unsigned int*)(0x438020A0UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA9              (*((volatile unsigned int*)(0x438020A4UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA10             (*((volatile unsigned int*)(0x438020A8UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXSA11             (*((volatile unsigned int*)(0x438020ACUL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD0              (*((volatile unsigned int*)(0x438020C0UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD1              (*((volatile unsigned int*)(0x438020C4UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD2              (*((volatile unsigned int*)(0x438020C8UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD3              (*((volatile unsigned int*)(0x438020CCUL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD4              (*((volatile unsigned int*)(0x438020D0UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD5              (*((volatile unsigned int*)(0x438020D4UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD6              (*((volatile unsigned int*)(0x438020D8UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD7              (*((volatile unsigned int*)(0x438020DCUL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD8              (*((volatile unsigned int*)(0x438020E0UL)))
#define bM4_USBFS_DIEPTXF1_INEPTXFD9              (*((volatile unsigned int*)(0x438020E4UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA0              (*((volatile unsigned int*)(0x43802100UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA1              (*((volatile unsigned int*)(0x43802104UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA2              (*((volatile unsigned int*)(0x43802108UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA3              (*((volatile unsigned int*)(0x4380210CUL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA4              (*((volatile unsigned int*)(0x43802110UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA5              (*((volatile unsigned int*)(0x43802114UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA6              (*((volatile unsigned int*)(0x43802118UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA7              (*((volatile unsigned int*)(0x4380211CUL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA8              (*((volatile unsigned int*)(0x43802120UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA9              (*((volatile unsigned int*)(0x43802124UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA10             (*((volatile unsigned int*)(0x43802128UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXSA11             (*((volatile unsigned int*)(0x4380212CUL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD0              (*((volatile unsigned int*)(0x43802140UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD1              (*((volatile unsigned int*)(0x43802144UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD2              (*((volatile unsigned int*)(0x43802148UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD3              (*((volatile unsigned int*)(0x4380214CUL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD4              (*((volatile unsigned int*)(0x43802150UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD5              (*((volatile unsigned int*)(0x43802154UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD6              (*((volatile unsigned int*)(0x43802158UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD7              (*((volatile unsigned int*)(0x4380215CUL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD8              (*((volatile unsigned int*)(0x43802160UL)))
#define bM4_USBFS_DIEPTXF2_INEPTXFD9              (*((volatile unsigned int*)(0x43802164UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA0              (*((volatile unsigned int*)(0x43802180UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA1              (*((volatile unsigned int*)(0x43802184UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA2              (*((volatile unsigned int*)(0x43802188UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA3              (*((volatile unsigned int*)(0x4380218CUL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA4              (*((volatile unsigned int*)(0x43802190UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA5              (*((volatile unsigned int*)(0x43802194UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA6              (*((volatile unsigned int*)(0x43802198UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA7              (*((volatile unsigned int*)(0x4380219CUL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA8              (*((volatile unsigned int*)(0x438021A0UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA9              (*((volatile unsigned int*)(0x438021A4UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA10             (*((volatile unsigned int*)(0x438021A8UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXSA11             (*((volatile unsigned int*)(0x438021ACUL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD0              (*((volatile unsigned int*)(0x438021C0UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD1              (*((volatile unsigned int*)(0x438021C4UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD2              (*((volatile unsigned int*)(0x438021C8UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD3              (*((volatile unsigned int*)(0x438021CCUL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD4              (*((volatile unsigned int*)(0x438021D0UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD5              (*((volatile unsigned int*)(0x438021D4UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD6              (*((volatile unsigned int*)(0x438021D8UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD7              (*((volatile unsigned int*)(0x438021DCUL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD8              (*((volatile unsigned int*)(0x438021E0UL)))
#define bM4_USBFS_DIEPTXF3_INEPTXFD9              (*((volatile unsigned int*)(0x438021E4UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA0              (*((volatile unsigned int*)(0x43802200UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA1              (*((volatile unsigned int*)(0x43802204UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA2              (*((volatile unsigned int*)(0x43802208UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA3              (*((volatile unsigned int*)(0x4380220CUL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA4              (*((volatile unsigned int*)(0x43802210UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA5              (*((volatile unsigned int*)(0x43802214UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA6              (*((volatile unsigned int*)(0x43802218UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA7              (*((volatile unsigned int*)(0x4380221CUL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA8              (*((volatile unsigned int*)(0x43802220UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA9              (*((volatile unsigned int*)(0x43802224UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA10             (*((volatile unsigned int*)(0x43802228UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXSA11             (*((volatile unsigned int*)(0x4380222CUL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD0              (*((volatile unsigned int*)(0x43802240UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD1              (*((volatile unsigned int*)(0x43802244UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD2              (*((volatile unsigned int*)(0x43802248UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD3              (*((volatile unsigned int*)(0x4380224CUL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD4              (*((volatile unsigned int*)(0x43802250UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD5              (*((volatile unsigned int*)(0x43802254UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD6              (*((volatile unsigned int*)(0x43802258UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD7              (*((volatile unsigned int*)(0x4380225CUL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD8              (*((volatile unsigned int*)(0x43802260UL)))
#define bM4_USBFS_DIEPTXF4_INEPTXFD9              (*((volatile unsigned int*)(0x43802264UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA0              (*((volatile unsigned int*)(0x43802280UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA1              (*((volatile unsigned int*)(0x43802284UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA2              (*((volatile unsigned int*)(0x43802288UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA3              (*((volatile unsigned int*)(0x4380228CUL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA4              (*((volatile unsigned int*)(0x43802290UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA5              (*((volatile unsigned int*)(0x43802294UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA6              (*((volatile unsigned int*)(0x43802298UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA7              (*((volatile unsigned int*)(0x4380229CUL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA8              (*((volatile unsigned int*)(0x438022A0UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA9              (*((volatile unsigned int*)(0x438022A4UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA10             (*((volatile unsigned int*)(0x438022A8UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXSA11             (*((volatile unsigned int*)(0x438022ACUL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD0              (*((volatile unsigned int*)(0x438022C0UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD1              (*((volatile unsigned int*)(0x438022C4UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD2              (*((volatile unsigned int*)(0x438022C8UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD3              (*((volatile unsigned int*)(0x438022CCUL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD4              (*((volatile unsigned int*)(0x438022D0UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD5              (*((volatile unsigned int*)(0x438022D4UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD6              (*((volatile unsigned int*)(0x438022D8UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD7              (*((volatile unsigned int*)(0x438022DCUL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD8              (*((volatile unsigned int*)(0x438022E0UL)))
#define bM4_USBFS_DIEPTXF5_INEPTXFD9              (*((volatile unsigned int*)(0x438022E4UL)))
#define bM4_USBFS_HCFG_FSLSPCS0                   (*((volatile unsigned int*)(0x43808000UL)))
#define bM4_USBFS_HCFG_FSLSPCS1                   (*((volatile unsigned int*)(0x43808004UL)))
#define bM4_USBFS_HCFG_FSLSS                      (*((volatile unsigned int*)(0x43808008UL)))
#define bM4_USBFS_HFIR_FRIVL0                     (*((volatile unsigned int*)(0x43808080UL)))
#define bM4_USBFS_HFIR_FRIVL1                     (*((volatile unsigned int*)(0x43808084UL)))
#define bM4_USBFS_HFIR_FRIVL2                     (*((volatile unsigned int*)(0x43808088UL)))
#define bM4_USBFS_HFIR_FRIVL3                     (*((volatile unsigned int*)(0x4380808CUL)))
#define bM4_USBFS_HFIR_FRIVL4                     (*((volatile unsigned int*)(0x43808090UL)))
#define bM4_USBFS_HFIR_FRIVL5                     (*((volatile unsigned int*)(0x43808094UL)))
#define bM4_USBFS_HFIR_FRIVL6                     (*((volatile unsigned int*)(0x43808098UL)))
#define bM4_USBFS_HFIR_FRIVL7                     (*((volatile unsigned int*)(0x4380809CUL)))
#define bM4_USBFS_HFIR_FRIVL8                     (*((volatile unsigned int*)(0x438080A0UL)))
#define bM4_USBFS_HFIR_FRIVL9                     (*((volatile unsigned int*)(0x438080A4UL)))
#define bM4_USBFS_HFIR_FRIVL10                    (*((volatile unsigned int*)(0x438080A8UL)))
#define bM4_USBFS_HFIR_FRIVL11                    (*((volatile unsigned int*)(0x438080ACUL)))
#define bM4_USBFS_HFIR_FRIVL12                    (*((volatile unsigned int*)(0x438080B0UL)))
#define bM4_USBFS_HFIR_FRIVL13                    (*((volatile unsigned int*)(0x438080B4UL)))
#define bM4_USBFS_HFIR_FRIVL14                    (*((volatile unsigned int*)(0x438080B8UL)))
#define bM4_USBFS_HFIR_FRIVL15                    (*((volatile unsigned int*)(0x438080BCUL)))
#define bM4_USBFS_HFNUM_FRNUM0                    (*((volatile unsigned int*)(0x43808100UL)))
#define bM4_USBFS_HFNUM_FRNUM1                    (*((volatile unsigned int*)(0x43808104UL)))
#define bM4_USBFS_HFNUM_FRNUM2                    (*((volatile unsigned int*)(0x43808108UL)))
#define bM4_USBFS_HFNUM_FRNUM3                    (*((volatile unsigned int*)(0x4380810CUL)))
#define bM4_USBFS_HFNUM_FRNUM4                    (*((volatile unsigned int*)(0x43808110UL)))
#define bM4_USBFS_HFNUM_FRNUM5                    (*((volatile unsigned int*)(0x43808114UL)))
#define bM4_USBFS_HFNUM_FRNUM6                    (*((volatile unsigned int*)(0x43808118UL)))
#define bM4_USBFS_HFNUM_FRNUM7                    (*((volatile unsigned int*)(0x4380811CUL)))
#define bM4_USBFS_HFNUM_FRNUM8                    (*((volatile unsigned int*)(0x43808120UL)))
#define bM4_USBFS_HFNUM_FRNUM9                    (*((volatile unsigned int*)(0x43808124UL)))
#define bM4_USBFS_HFNUM_FRNUM10                   (*((volatile unsigned int*)(0x43808128UL)))
#define bM4_USBFS_HFNUM_FRNUM11                   (*((volatile unsigned int*)(0x4380812CUL)))
#define bM4_USBFS_HFNUM_FRNUM12                   (*((volatile unsigned int*)(0x43808130UL)))
#define bM4_USBFS_HFNUM_FRNUM13                   (*((volatile unsigned int*)(0x43808134UL)))
#define bM4_USBFS_HFNUM_FRNUM14                   (*((volatile unsigned int*)(0x43808138UL)))
#define bM4_USBFS_HFNUM_FRNUM15                   (*((volatile unsigned int*)(0x4380813CUL)))
#define bM4_USBFS_HFNUM_FTREM0                    (*((volatile unsigned int*)(0x43808140UL)))
#define bM4_USBFS_HFNUM_FTREM1                    (*((volatile unsigned int*)(0x43808144UL)))
#define bM4_USBFS_HFNUM_FTREM2                    (*((volatile unsigned int*)(0x43808148UL)))
#define bM4_USBFS_HFNUM_FTREM3                    (*((volatile unsigned int*)(0x4380814CUL)))
#define bM4_USBFS_HFNUM_FTREM4                    (*((volatile unsigned int*)(0x43808150UL)))
#define bM4_USBFS_HFNUM_FTREM5                    (*((volatile unsigned int*)(0x43808154UL)))
#define bM4_USBFS_HFNUM_FTREM6                    (*((volatile unsigned int*)(0x43808158UL)))
#define bM4_USBFS_HFNUM_FTREM7                    (*((volatile unsigned int*)(0x4380815CUL)))
#define bM4_USBFS_HFNUM_FTREM8                    (*((volatile unsigned int*)(0x43808160UL)))
#define bM4_USBFS_HFNUM_FTREM9                    (*((volatile unsigned int*)(0x43808164UL)))
#define bM4_USBFS_HFNUM_FTREM10                   (*((volatile unsigned int*)(0x43808168UL)))
#define bM4_USBFS_HFNUM_FTREM11                   (*((volatile unsigned int*)(0x4380816CUL)))
#define bM4_USBFS_HFNUM_FTREM12                   (*((volatile unsigned int*)(0x43808170UL)))
#define bM4_USBFS_HFNUM_FTREM13                   (*((volatile unsigned int*)(0x43808174UL)))
#define bM4_USBFS_HFNUM_FTREM14                   (*((volatile unsigned int*)(0x43808178UL)))
#define bM4_USBFS_HFNUM_FTREM15                   (*((volatile unsigned int*)(0x4380817CUL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL0               (*((volatile unsigned int*)(0x43808200UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL1               (*((volatile unsigned int*)(0x43808204UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL2               (*((volatile unsigned int*)(0x43808208UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL3               (*((volatile unsigned int*)(0x4380820CUL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL4               (*((volatile unsigned int*)(0x43808210UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL5               (*((volatile unsigned int*)(0x43808214UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL6               (*((volatile unsigned int*)(0x43808218UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL7               (*((volatile unsigned int*)(0x4380821CUL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL8               (*((volatile unsigned int*)(0x43808220UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL9               (*((volatile unsigned int*)(0x43808224UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL10              (*((volatile unsigned int*)(0x43808228UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL11              (*((volatile unsigned int*)(0x4380822CUL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL12              (*((volatile unsigned int*)(0x43808230UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL13              (*((volatile unsigned int*)(0x43808234UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL14              (*((volatile unsigned int*)(0x43808238UL)))
#define bM4_USBFS_HPTXSTS_PTXFSAVL15              (*((volatile unsigned int*)(0x4380823CUL)))
#define bM4_USBFS_HPTXSTS_PTXQSAV0                (*((volatile unsigned int*)(0x43808240UL)))
#define bM4_USBFS_HPTXSTS_PTXQSAV1                (*((volatile unsigned int*)(0x43808244UL)))
#define bM4_USBFS_HPTXSTS_PTXQSAV2                (*((volatile unsigned int*)(0x43808248UL)))
#define bM4_USBFS_HPTXSTS_PTXQSAV3                (*((volatile unsigned int*)(0x4380824CUL)))
#define bM4_USBFS_HPTXSTS_PTXQSAV4                (*((volatile unsigned int*)(0x43808250UL)))
#define bM4_USBFS_HPTXSTS_PTXQSAV5                (*((volatile unsigned int*)(0x43808254UL)))
#define bM4_USBFS_HPTXSTS_PTXQSAV6                (*((volatile unsigned int*)(0x43808258UL)))
#define bM4_USBFS_HPTXSTS_PTXQSAV7                (*((volatile unsigned int*)(0x4380825CUL)))
#define bM4_USBFS_HPTXSTS_PTXQTOP0                (*((volatile unsigned int*)(0x43808260UL)))
#define bM4_USBFS_HPTXSTS_PTXQTOP1                (*((volatile unsigned int*)(0x43808264UL)))
#define bM4_USBFS_HPTXSTS_PTXQTOP2                (*((volatile unsigned int*)(0x43808268UL)))
#define bM4_USBFS_HPTXSTS_PTXQTOP3                (*((volatile unsigned int*)(0x4380826CUL)))
#define bM4_USBFS_HPTXSTS_PTXQTOP4                (*((volatile unsigned int*)(0x43808270UL)))
#define bM4_USBFS_HPTXSTS_PTXQTOP5                (*((volatile unsigned int*)(0x43808274UL)))
#define bM4_USBFS_HPTXSTS_PTXQTOP6                (*((volatile unsigned int*)(0x43808278UL)))
#define bM4_USBFS_HPTXSTS_PTXQTOP7                (*((volatile unsigned int*)(0x4380827CUL)))
#define bM4_USBFS_HAINT_HAINT0                    (*((volatile unsigned int*)(0x43808280UL)))
#define bM4_USBFS_HAINT_HAINT1                    (*((volatile unsigned int*)(0x43808284UL)))
#define bM4_USBFS_HAINT_HAINT2                    (*((volatile unsigned int*)(0x43808288UL)))
#define bM4_USBFS_HAINT_HAINT3                    (*((volatile unsigned int*)(0x4380828CUL)))
#define bM4_USBFS_HAINT_HAINT4                    (*((volatile unsigned int*)(0x43808290UL)))
#define bM4_USBFS_HAINT_HAINT5                    (*((volatile unsigned int*)(0x43808294UL)))
#define bM4_USBFS_HAINT_HAINT6                    (*((volatile unsigned int*)(0x43808298UL)))
#define bM4_USBFS_HAINT_HAINT7                    (*((volatile unsigned int*)(0x4380829CUL)))
#define bM4_USBFS_HAINT_HAINT8                    (*((volatile unsigned int*)(0x438082A0UL)))
#define bM4_USBFS_HAINT_HAINT9                    (*((volatile unsigned int*)(0x438082A4UL)))
#define bM4_USBFS_HAINT_HAINT10                   (*((volatile unsigned int*)(0x438082A8UL)))
#define bM4_USBFS_HAINT_HAINT11                   (*((volatile unsigned int*)(0x438082ACUL)))
#define bM4_USBFS_HAINTMSK_HAINTM0                (*((volatile unsigned int*)(0x43808300UL)))
#define bM4_USBFS_HAINTMSK_HAINTM1                (*((volatile unsigned int*)(0x43808304UL)))
#define bM4_USBFS_HAINTMSK_HAINTM2                (*((volatile unsigned int*)(0x43808308UL)))
#define bM4_USBFS_HAINTMSK_HAINTM3                (*((volatile unsigned int*)(0x4380830CUL)))
#define bM4_USBFS_HAINTMSK_HAINTM4                (*((volatile unsigned int*)(0x43808310UL)))
#define bM4_USBFS_HAINTMSK_HAINTM5                (*((volatile unsigned int*)(0x43808314UL)))
#define bM4_USBFS_HAINTMSK_HAINTM6                (*((volatile unsigned int*)(0x43808318UL)))
#define bM4_USBFS_HAINTMSK_HAINTM7                (*((volatile unsigned int*)(0x4380831CUL)))
#define bM4_USBFS_HAINTMSK_HAINTM8                (*((volatile unsigned int*)(0x43808320UL)))
#define bM4_USBFS_HAINTMSK_HAINTM9                (*((volatile unsigned int*)(0x43808324UL)))
#define bM4_USBFS_HAINTMSK_HAINTM10               (*((volatile unsigned int*)(0x43808328UL)))
#define bM4_USBFS_HAINTMSK_HAINTM11               (*((volatile unsigned int*)(0x4380832CUL)))
#define bM4_USBFS_HPRT_PCSTS                      (*((volatile unsigned int*)(0x43808800UL)))
#define bM4_USBFS_HPRT_PCDET                      (*((volatile unsigned int*)(0x43808804UL)))
#define bM4_USBFS_HPRT_PENA                       (*((volatile unsigned int*)(0x43808808UL)))
#define bM4_USBFS_HPRT_PENCHNG                    (*((volatile unsigned int*)(0x4380880CUL)))
#define bM4_USBFS_HPRT_PRES                       (*((volatile unsigned int*)(0x43808818UL)))
#define bM4_USBFS_HPRT_PSUSP                      (*((volatile unsigned int*)(0x4380881CUL)))
#define bM4_USBFS_HPRT_PRST                       (*((volatile unsigned int*)(0x43808820UL)))
#define bM4_USBFS_HPRT_PLSTS0                     (*((volatile unsigned int*)(0x43808828UL)))
#define bM4_USBFS_HPRT_PLSTS1                     (*((volatile unsigned int*)(0x4380882CUL)))
#define bM4_USBFS_HPRT_PWPR                       (*((volatile unsigned int*)(0x43808830UL)))
#define bM4_USBFS_HPRT_PSPD0                      (*((volatile unsigned int*)(0x43808844UL)))
#define bM4_USBFS_HPRT_PSPD1                      (*((volatile unsigned int*)(0x43808848UL)))
#define bM4_USBFS_HCCHAR0_MPSIZ0                  (*((volatile unsigned int*)(0x4380A000UL)))
#define bM4_USBFS_HCCHAR0_MPSIZ1                  (*((volatile unsigned int*)(0x4380A004UL)))
#define bM4_USBFS_HCCHAR0_MPSIZ2                  (*((volatile unsigned int*)(0x4380A008UL)))
#define bM4_USBFS_HCCHAR0_MPSIZ3                  (*((volatile unsigned int*)(0x4380A00CUL)))
#define bM4_USBFS_HCCHAR0_MPSIZ4                  (*((volatile unsigned int*)(0x4380A010UL)))
#define bM4_USBFS_HCCHAR0_MPSIZ5                  (*((volatile unsigned int*)(0x4380A014UL)))
#define bM4_USBFS_HCCHAR0_MPSIZ6                  (*((volatile unsigned int*)(0x4380A018UL)))
#define bM4_USBFS_HCCHAR0_MPSIZ7                  (*((volatile unsigned int*)(0x4380A01CUL)))
#define bM4_USBFS_HCCHAR0_MPSIZ8                  (*((volatile unsigned int*)(0x4380A020UL)))
#define bM4_USBFS_HCCHAR0_MPSIZ9                  (*((volatile unsigned int*)(0x4380A024UL)))
#define bM4_USBFS_HCCHAR0_MPSIZ10                 (*((volatile unsigned int*)(0x4380A028UL)))
#define bM4_USBFS_HCCHAR0_EPNUM0                  (*((volatile unsigned int*)(0x4380A02CUL)))
#define bM4_USBFS_HCCHAR0_EPNUM1                  (*((volatile unsigned int*)(0x4380A030UL)))
#define bM4_USBFS_HCCHAR0_EPNUM2                  (*((volatile unsigned int*)(0x4380A034UL)))
#define bM4_USBFS_HCCHAR0_EPNUM3                  (*((volatile unsigned int*)(0x4380A038UL)))
#define bM4_USBFS_HCCHAR0_EPDIR                   (*((volatile unsigned int*)(0x4380A03CUL)))
#define bM4_USBFS_HCCHAR0_LSDEV                   (*((volatile unsigned int*)(0x4380A044UL)))
#define bM4_USBFS_HCCHAR0_EPTYP0                  (*((volatile unsigned int*)(0x4380A048UL)))
#define bM4_USBFS_HCCHAR0_EPTYP1                  (*((volatile unsigned int*)(0x4380A04CUL)))
#define bM4_USBFS_HCCHAR0_DAD0                    (*((volatile unsigned int*)(0x4380A058UL)))
#define bM4_USBFS_HCCHAR0_DAD1                    (*((volatile unsigned int*)(0x4380A05CUL)))
#define bM4_USBFS_HCCHAR0_DAD2                    (*((volatile unsigned int*)(0x4380A060UL)))
#define bM4_USBFS_HCCHAR0_DAD3                    (*((volatile unsigned int*)(0x4380A064UL)))
#define bM4_USBFS_HCCHAR0_DAD4                    (*((volatile unsigned int*)(0x4380A068UL)))
#define bM4_USBFS_HCCHAR0_DAD5                    (*((volatile unsigned int*)(0x4380A06CUL)))
#define bM4_USBFS_HCCHAR0_DAD6                    (*((volatile unsigned int*)(0x4380A070UL)))
#define bM4_USBFS_HCCHAR0_ODDFRM                  (*((volatile unsigned int*)(0x4380A074UL)))
#define bM4_USBFS_HCCHAR0_CHDIS                   (*((volatile unsigned int*)(0x4380A078UL)))
#define bM4_USBFS_HCCHAR0_CHENA                   (*((volatile unsigned int*)(0x4380A07CUL)))
#define bM4_USBFS_HCINT0_XFRC                     (*((volatile unsigned int*)(0x4380A100UL)))
#define bM4_USBFS_HCINT0_CHH                      (*((volatile unsigned int*)(0x4380A104UL)))
#define bM4_USBFS_HCINT0_STALL                    (*((volatile unsigned int*)(0x4380A10CUL)))
#define bM4_USBFS_HCINT0_NAK                      (*((volatile unsigned int*)(0x4380A110UL)))
#define bM4_USBFS_HCINT0_ACK                      (*((volatile unsigned int*)(0x4380A114UL)))
#define bM4_USBFS_HCINT0_TXERR                    (*((volatile unsigned int*)(0x4380A11CUL)))
#define bM4_USBFS_HCINT0_BBERR                    (*((volatile unsigned int*)(0x4380A120UL)))
#define bM4_USBFS_HCINT0_FRMOR                    (*((volatile unsigned int*)(0x4380A124UL)))
#define bM4_USBFS_HCINT0_DTERR                    (*((volatile unsigned int*)(0x4380A128UL)))
#define bM4_USBFS_HCINTMSK0_XFRCM                 (*((volatile unsigned int*)(0x4380A180UL)))
#define bM4_USBFS_HCINTMSK0_CHHM                  (*((volatile unsigned int*)(0x4380A184UL)))
#define bM4_USBFS_HCINTMSK0_STALLM                (*((volatile unsigned int*)(0x4380A18CUL)))
#define bM4_USBFS_HCINTMSK0_NAKM                  (*((volatile unsigned int*)(0x4380A190UL)))
#define bM4_USBFS_HCINTMSK0_ACKM                  (*((volatile unsigned int*)(0x4380A194UL)))
#define bM4_USBFS_HCINTMSK0_TXERRM                (*((volatile unsigned int*)(0x4380A19CUL)))
#define bM4_USBFS_HCINTMSK0_BBERRM                (*((volatile unsigned int*)(0x4380A1A0UL)))
#define bM4_USBFS_HCINTMSK0_FRMORM                (*((volatile unsigned int*)(0x4380A1A4UL)))
#define bM4_USBFS_HCINTMSK0_DTERRM                (*((volatile unsigned int*)(0x4380A1A8UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ0                 (*((volatile unsigned int*)(0x4380A200UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ1                 (*((volatile unsigned int*)(0x4380A204UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ2                 (*((volatile unsigned int*)(0x4380A208UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ3                 (*((volatile unsigned int*)(0x4380A20CUL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ4                 (*((volatile unsigned int*)(0x4380A210UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ5                 (*((volatile unsigned int*)(0x4380A214UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ6                 (*((volatile unsigned int*)(0x4380A218UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ7                 (*((volatile unsigned int*)(0x4380A21CUL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ8                 (*((volatile unsigned int*)(0x4380A220UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ9                 (*((volatile unsigned int*)(0x4380A224UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ10                (*((volatile unsigned int*)(0x4380A228UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ11                (*((volatile unsigned int*)(0x4380A22CUL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ12                (*((volatile unsigned int*)(0x4380A230UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ13                (*((volatile unsigned int*)(0x4380A234UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ14                (*((volatile unsigned int*)(0x4380A238UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ15                (*((volatile unsigned int*)(0x4380A23CUL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ16                (*((volatile unsigned int*)(0x4380A240UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ17                (*((volatile unsigned int*)(0x4380A244UL)))
#define bM4_USBFS_HCTSIZ0_XFRSIZ18                (*((volatile unsigned int*)(0x4380A248UL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT0                 (*((volatile unsigned int*)(0x4380A24CUL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT1                 (*((volatile unsigned int*)(0x4380A250UL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT2                 (*((volatile unsigned int*)(0x4380A254UL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT3                 (*((volatile unsigned int*)(0x4380A258UL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT4                 (*((volatile unsigned int*)(0x4380A25CUL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT5                 (*((volatile unsigned int*)(0x4380A260UL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT6                 (*((volatile unsigned int*)(0x4380A264UL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT7                 (*((volatile unsigned int*)(0x4380A268UL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT8                 (*((volatile unsigned int*)(0x4380A26CUL)))
#define bM4_USBFS_HCTSIZ0_PKTCNT9                 (*((volatile unsigned int*)(0x4380A270UL)))
#define bM4_USBFS_HCTSIZ0_DPID0                   (*((volatile unsigned int*)(0x4380A274UL)))
#define bM4_USBFS_HCTSIZ0_DPID1                   (*((volatile unsigned int*)(0x4380A278UL)))
#define bM4_USBFS_HCCHAR1_MPSIZ0                  (*((volatile unsigned int*)(0x4380A400UL)))
#define bM4_USBFS_HCCHAR1_MPSIZ1                  (*((volatile unsigned int*)(0x4380A404UL)))
#define bM4_USBFS_HCCHAR1_MPSIZ2                  (*((volatile unsigned int*)(0x4380A408UL)))
#define bM4_USBFS_HCCHAR1_MPSIZ3                  (*((volatile unsigned int*)(0x4380A40CUL)))
#define bM4_USBFS_HCCHAR1_MPSIZ4                  (*((volatile unsigned int*)(0x4380A410UL)))
#define bM4_USBFS_HCCHAR1_MPSIZ5                  (*((volatile unsigned int*)(0x4380A414UL)))
#define bM4_USBFS_HCCHAR1_MPSIZ6                  (*((volatile unsigned int*)(0x4380A418UL)))
#define bM4_USBFS_HCCHAR1_MPSIZ7                  (*((volatile unsigned int*)(0x4380A41CUL)))
#define bM4_USBFS_HCCHAR1_MPSIZ8                  (*((volatile unsigned int*)(0x4380A420UL)))
#define bM4_USBFS_HCCHAR1_MPSIZ9                  (*((volatile unsigned int*)(0x4380A424UL)))
#define bM4_USBFS_HCCHAR1_MPSIZ10                 (*((volatile unsigned int*)(0x4380A428UL)))
#define bM4_USBFS_HCCHAR1_EPNUM0                  (*((volatile unsigned int*)(0x4380A42CUL)))
#define bM4_USBFS_HCCHAR1_EPNUM1                  (*((volatile unsigned int*)(0x4380A430UL)))
#define bM4_USBFS_HCCHAR1_EPNUM2                  (*((volatile unsigned int*)(0x4380A434UL)))
#define bM4_USBFS_HCCHAR1_EPNUM3                  (*((volatile unsigned int*)(0x4380A438UL)))
#define bM4_USBFS_HCCHAR1_EPDIR                   (*((volatile unsigned int*)(0x4380A43CUL)))
#define bM4_USBFS_HCCHAR1_LSDEV                   (*((volatile unsigned int*)(0x4380A444UL)))
#define bM4_USBFS_HCCHAR1_EPTYP0                  (*((volatile unsigned int*)(0x4380A448UL)))
#define bM4_USBFS_HCCHAR1_EPTYP1                  (*((volatile unsigned int*)(0x4380A44CUL)))
#define bM4_USBFS_HCCHAR1_DAD0                    (*((volatile unsigned int*)(0x4380A458UL)))
#define bM4_USBFS_HCCHAR1_DAD1                    (*((volatile unsigned int*)(0x4380A45CUL)))
#define bM4_USBFS_HCCHAR1_DAD2                    (*((volatile unsigned int*)(0x4380A460UL)))
#define bM4_USBFS_HCCHAR1_DAD3                    (*((volatile unsigned int*)(0x4380A464UL)))
#define bM4_USBFS_HCCHAR1_DAD4                    (*((volatile unsigned int*)(0x4380A468UL)))
#define bM4_USBFS_HCCHAR1_DAD5                    (*((volatile unsigned int*)(0x4380A46CUL)))
#define bM4_USBFS_HCCHAR1_DAD6                    (*((volatile unsigned int*)(0x4380A470UL)))
#define bM4_USBFS_HCCHAR1_ODDFRM                  (*((volatile unsigned int*)(0x4380A474UL)))
#define bM4_USBFS_HCCHAR1_CHDIS                   (*((volatile unsigned int*)(0x4380A478UL)))
#define bM4_USBFS_HCCHAR1_CHENA                   (*((volatile unsigned int*)(0x4380A47CUL)))
#define bM4_USBFS_HCINT1_XFRC                     (*((volatile unsigned int*)(0x4380A500UL)))
#define bM4_USBFS_HCINT1_CHH                      (*((volatile unsigned int*)(0x4380A504UL)))
#define bM4_USBFS_HCINT1_STALL                    (*((volatile unsigned int*)(0x4380A50CUL)))
#define bM4_USBFS_HCINT1_NAK                      (*((volatile unsigned int*)(0x4380A510UL)))
#define bM4_USBFS_HCINT1_ACK                      (*((volatile unsigned int*)(0x4380A514UL)))
#define bM4_USBFS_HCINT1_TXERR                    (*((volatile unsigned int*)(0x4380A51CUL)))
#define bM4_USBFS_HCINT1_BBERR                    (*((volatile unsigned int*)(0x4380A520UL)))
#define bM4_USBFS_HCINT1_FRMOR                    (*((volatile unsigned int*)(0x4380A524UL)))
#define bM4_USBFS_HCINT1_DTERR                    (*((volatile unsigned int*)(0x4380A528UL)))
#define bM4_USBFS_HCINTMSK1_XFRCM                 (*((volatile unsigned int*)(0x4380A580UL)))
#define bM4_USBFS_HCINTMSK1_CHHM                  (*((volatile unsigned int*)(0x4380A584UL)))
#define bM4_USBFS_HCINTMSK1_STALLM                (*((volatile unsigned int*)(0x4380A58CUL)))
#define bM4_USBFS_HCINTMSK1_NAKM                  (*((volatile unsigned int*)(0x4380A590UL)))
#define bM4_USBFS_HCINTMSK1_ACKM                  (*((volatile unsigned int*)(0x4380A594UL)))
#define bM4_USBFS_HCINTMSK1_TXERRM                (*((volatile unsigned int*)(0x4380A59CUL)))
#define bM4_USBFS_HCINTMSK1_BBERRM                (*((volatile unsigned int*)(0x4380A5A0UL)))
#define bM4_USBFS_HCINTMSK1_FRMORM                (*((volatile unsigned int*)(0x4380A5A4UL)))
#define bM4_USBFS_HCINTMSK1_DTERRM                (*((volatile unsigned int*)(0x4380A5A8UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ0                 (*((volatile unsigned int*)(0x4380A600UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ1                 (*((volatile unsigned int*)(0x4380A604UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ2                 (*((volatile unsigned int*)(0x4380A608UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ3                 (*((volatile unsigned int*)(0x4380A60CUL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ4                 (*((volatile unsigned int*)(0x4380A610UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ5                 (*((volatile unsigned int*)(0x4380A614UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ6                 (*((volatile unsigned int*)(0x4380A618UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ7                 (*((volatile unsigned int*)(0x4380A61CUL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ8                 (*((volatile unsigned int*)(0x4380A620UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ9                 (*((volatile unsigned int*)(0x4380A624UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ10                (*((volatile unsigned int*)(0x4380A628UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ11                (*((volatile unsigned int*)(0x4380A62CUL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ12                (*((volatile unsigned int*)(0x4380A630UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ13                (*((volatile unsigned int*)(0x4380A634UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ14                (*((volatile unsigned int*)(0x4380A638UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ15                (*((volatile unsigned int*)(0x4380A63CUL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ16                (*((volatile unsigned int*)(0x4380A640UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ17                (*((volatile unsigned int*)(0x4380A644UL)))
#define bM4_USBFS_HCTSIZ1_XFRSIZ18                (*((volatile unsigned int*)(0x4380A648UL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT0                 (*((volatile unsigned int*)(0x4380A64CUL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT1                 (*((volatile unsigned int*)(0x4380A650UL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT2                 (*((volatile unsigned int*)(0x4380A654UL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT3                 (*((volatile unsigned int*)(0x4380A658UL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT4                 (*((volatile unsigned int*)(0x4380A65CUL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT5                 (*((volatile unsigned int*)(0x4380A660UL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT6                 (*((volatile unsigned int*)(0x4380A664UL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT7                 (*((volatile unsigned int*)(0x4380A668UL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT8                 (*((volatile unsigned int*)(0x4380A66CUL)))
#define bM4_USBFS_HCTSIZ1_PKTCNT9                 (*((volatile unsigned int*)(0x4380A670UL)))
#define bM4_USBFS_HCTSIZ1_DPID0                   (*((volatile unsigned int*)(0x4380A674UL)))
#define bM4_USBFS_HCTSIZ1_DPID1                   (*((volatile unsigned int*)(0x4380A678UL)))
#define bM4_USBFS_HCCHAR2_MPSIZ0                  (*((volatile unsigned int*)(0x4380A800UL)))
#define bM4_USBFS_HCCHAR2_MPSIZ1                  (*((volatile unsigned int*)(0x4380A804UL)))
#define bM4_USBFS_HCCHAR2_MPSIZ2                  (*((volatile unsigned int*)(0x4380A808UL)))
#define bM4_USBFS_HCCHAR2_MPSIZ3                  (*((volatile unsigned int*)(0x4380A80CUL)))
#define bM4_USBFS_HCCHAR2_MPSIZ4                  (*((volatile unsigned int*)(0x4380A810UL)))
#define bM4_USBFS_HCCHAR2_MPSIZ5                  (*((volatile unsigned int*)(0x4380A814UL)))
#define bM4_USBFS_HCCHAR2_MPSIZ6                  (*((volatile unsigned int*)(0x4380A818UL)))
#define bM4_USBFS_HCCHAR2_MPSIZ7                  (*((volatile unsigned int*)(0x4380A81CUL)))
#define bM4_USBFS_HCCHAR2_MPSIZ8                  (*((volatile unsigned int*)(0x4380A820UL)))
#define bM4_USBFS_HCCHAR2_MPSIZ9                  (*((volatile unsigned int*)(0x4380A824UL)))
#define bM4_USBFS_HCCHAR2_MPSIZ10                 (*((volatile unsigned int*)(0x4380A828UL)))
#define bM4_USBFS_HCCHAR2_EPNUM0                  (*((volatile unsigned int*)(0x4380A82CUL)))
#define bM4_USBFS_HCCHAR2_EPNUM1                  (*((volatile unsigned int*)(0x4380A830UL)))
#define bM4_USBFS_HCCHAR2_EPNUM2                  (*((volatile unsigned int*)(0x4380A834UL)))
#define bM4_USBFS_HCCHAR2_EPNUM3                  (*((volatile unsigned int*)(0x4380A838UL)))
#define bM4_USBFS_HCCHAR2_EPDIR                   (*((volatile unsigned int*)(0x4380A83CUL)))
#define bM4_USBFS_HCCHAR2_LSDEV                   (*((volatile unsigned int*)(0x4380A844UL)))
#define bM4_USBFS_HCCHAR2_EPTYP0                  (*((volatile unsigned int*)(0x4380A848UL)))
#define bM4_USBFS_HCCHAR2_EPTYP1                  (*((volatile unsigned int*)(0x4380A84CUL)))
#define bM4_USBFS_HCCHAR2_DAD0                    (*((volatile unsigned int*)(0x4380A858UL)))
#define bM4_USBFS_HCCHAR2_DAD1                    (*((volatile unsigned int*)(0x4380A85CUL)))
#define bM4_USBFS_HCCHAR2_DAD2                    (*((volatile unsigned int*)(0x4380A860UL)))
#define bM4_USBFS_HCCHAR2_DAD3                    (*((volatile unsigned int*)(0x4380A864UL)))
#define bM4_USBFS_HCCHAR2_DAD4                    (*((volatile unsigned int*)(0x4380A868UL)))
#define bM4_USBFS_HCCHAR2_DAD5                    (*((volatile unsigned int*)(0x4380A86CUL)))
#define bM4_USBFS_HCCHAR2_DAD6                    (*((volatile unsigned int*)(0x4380A870UL)))
#define bM4_USBFS_HCCHAR2_ODDFRM                  (*((volatile unsigned int*)(0x4380A874UL)))
#define bM4_USBFS_HCCHAR2_CHDIS                   (*((volatile unsigned int*)(0x4380A878UL)))
#define bM4_USBFS_HCCHAR2_CHENA                   (*((volatile unsigned int*)(0x4380A87CUL)))
#define bM4_USBFS_HCINT2_XFRC                     (*((volatile unsigned int*)(0x4380A900UL)))
#define bM4_USBFS_HCINT2_CHH                      (*((volatile unsigned int*)(0x4380A904UL)))
#define bM4_USBFS_HCINT2_STALL                    (*((volatile unsigned int*)(0x4380A90CUL)))
#define bM4_USBFS_HCINT2_NAK                      (*((volatile unsigned int*)(0x4380A910UL)))
#define bM4_USBFS_HCINT2_ACK                      (*((volatile unsigned int*)(0x4380A914UL)))
#define bM4_USBFS_HCINT2_TXERR                    (*((volatile unsigned int*)(0x4380A91CUL)))
#define bM4_USBFS_HCINT2_BBERR                    (*((volatile unsigned int*)(0x4380A920UL)))
#define bM4_USBFS_HCINT2_FRMOR                    (*((volatile unsigned int*)(0x4380A924UL)))
#define bM4_USBFS_HCINT2_DTERR                    (*((volatile unsigned int*)(0x4380A928UL)))
#define bM4_USBFS_HCINTMSK2_XFRCM                 (*((volatile unsigned int*)(0x4380A980UL)))
#define bM4_USBFS_HCINTMSK2_CHHM                  (*((volatile unsigned int*)(0x4380A984UL)))
#define bM4_USBFS_HCINTMSK2_STALLM                (*((volatile unsigned int*)(0x4380A98CUL)))
#define bM4_USBFS_HCINTMSK2_NAKM                  (*((volatile unsigned int*)(0x4380A990UL)))
#define bM4_USBFS_HCINTMSK2_ACKM                  (*((volatile unsigned int*)(0x4380A994UL)))
#define bM4_USBFS_HCINTMSK2_TXERRM                (*((volatile unsigned int*)(0x4380A99CUL)))
#define bM4_USBFS_HCINTMSK2_BBERRM                (*((volatile unsigned int*)(0x4380A9A0UL)))
#define bM4_USBFS_HCINTMSK2_FRMORM                (*((volatile unsigned int*)(0x4380A9A4UL)))
#define bM4_USBFS_HCINTMSK2_DTERRM                (*((volatile unsigned int*)(0x4380A9A8UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ0                 (*((volatile unsigned int*)(0x4380AA00UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ1                 (*((volatile unsigned int*)(0x4380AA04UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ2                 (*((volatile unsigned int*)(0x4380AA08UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ3                 (*((volatile unsigned int*)(0x4380AA0CUL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ4                 (*((volatile unsigned int*)(0x4380AA10UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ5                 (*((volatile unsigned int*)(0x4380AA14UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ6                 (*((volatile unsigned int*)(0x4380AA18UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ7                 (*((volatile unsigned int*)(0x4380AA1CUL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ8                 (*((volatile unsigned int*)(0x4380AA20UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ9                 (*((volatile unsigned int*)(0x4380AA24UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ10                (*((volatile unsigned int*)(0x4380AA28UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ11                (*((volatile unsigned int*)(0x4380AA2CUL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ12                (*((volatile unsigned int*)(0x4380AA30UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ13                (*((volatile unsigned int*)(0x4380AA34UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ14                (*((volatile unsigned int*)(0x4380AA38UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ15                (*((volatile unsigned int*)(0x4380AA3CUL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ16                (*((volatile unsigned int*)(0x4380AA40UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ17                (*((volatile unsigned int*)(0x4380AA44UL)))
#define bM4_USBFS_HCTSIZ2_XFRSIZ18                (*((volatile unsigned int*)(0x4380AA48UL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT0                 (*((volatile unsigned int*)(0x4380AA4CUL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT1                 (*((volatile unsigned int*)(0x4380AA50UL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT2                 (*((volatile unsigned int*)(0x4380AA54UL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT3                 (*((volatile unsigned int*)(0x4380AA58UL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT4                 (*((volatile unsigned int*)(0x4380AA5CUL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT5                 (*((volatile unsigned int*)(0x4380AA60UL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT6                 (*((volatile unsigned int*)(0x4380AA64UL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT7                 (*((volatile unsigned int*)(0x4380AA68UL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT8                 (*((volatile unsigned int*)(0x4380AA6CUL)))
#define bM4_USBFS_HCTSIZ2_PKTCNT9                 (*((volatile unsigned int*)(0x4380AA70UL)))
#define bM4_USBFS_HCTSIZ2_DPID0                   (*((volatile unsigned int*)(0x4380AA74UL)))
#define bM4_USBFS_HCTSIZ2_DPID1                   (*((volatile unsigned int*)(0x4380AA78UL)))
#define bM4_USBFS_HCCHAR3_MPSIZ0                  (*((volatile unsigned int*)(0x4380AC00UL)))
#define bM4_USBFS_HCCHAR3_MPSIZ1                  (*((volatile unsigned int*)(0x4380AC04UL)))
#define bM4_USBFS_HCCHAR3_MPSIZ2                  (*((volatile unsigned int*)(0x4380AC08UL)))
#define bM4_USBFS_HCCHAR3_MPSIZ3                  (*((volatile unsigned int*)(0x4380AC0CUL)))
#define bM4_USBFS_HCCHAR3_MPSIZ4                  (*((volatile unsigned int*)(0x4380AC10UL)))
#define bM4_USBFS_HCCHAR3_MPSIZ5                  (*((volatile unsigned int*)(0x4380AC14UL)))
#define bM4_USBFS_HCCHAR3_MPSIZ6                  (*((volatile unsigned int*)(0x4380AC18UL)))
#define bM4_USBFS_HCCHAR3_MPSIZ7                  (*((volatile unsigned int*)(0x4380AC1CUL)))
#define bM4_USBFS_HCCHAR3_MPSIZ8                  (*((volatile unsigned int*)(0x4380AC20UL)))
#define bM4_USBFS_HCCHAR3_MPSIZ9                  (*((volatile unsigned int*)(0x4380AC24UL)))
#define bM4_USBFS_HCCHAR3_MPSIZ10                 (*((volatile unsigned int*)(0x4380AC28UL)))
#define bM4_USBFS_HCCHAR3_EPNUM0                  (*((volatile unsigned int*)(0x4380AC2CUL)))
#define bM4_USBFS_HCCHAR3_EPNUM1                  (*((volatile unsigned int*)(0x4380AC30UL)))
#define bM4_USBFS_HCCHAR3_EPNUM2                  (*((volatile unsigned int*)(0x4380AC34UL)))
#define bM4_USBFS_HCCHAR3_EPNUM3                  (*((volatile unsigned int*)(0x4380AC38UL)))
#define bM4_USBFS_HCCHAR3_EPDIR                   (*((volatile unsigned int*)(0x4380AC3CUL)))
#define bM4_USBFS_HCCHAR3_LSDEV                   (*((volatile unsigned int*)(0x4380AC44UL)))
#define bM4_USBFS_HCCHAR3_EPTYP0                  (*((volatile unsigned int*)(0x4380AC48UL)))
#define bM4_USBFS_HCCHAR3_EPTYP1                  (*((volatile unsigned int*)(0x4380AC4CUL)))
#define bM4_USBFS_HCCHAR3_DAD0                    (*((volatile unsigned int*)(0x4380AC58UL)))
#define bM4_USBFS_HCCHAR3_DAD1                    (*((volatile unsigned int*)(0x4380AC5CUL)))
#define bM4_USBFS_HCCHAR3_DAD2                    (*((volatile unsigned int*)(0x4380AC60UL)))
#define bM4_USBFS_HCCHAR3_DAD3                    (*((volatile unsigned int*)(0x4380AC64UL)))
#define bM4_USBFS_HCCHAR3_DAD4                    (*((volatile unsigned int*)(0x4380AC68UL)))
#define bM4_USBFS_HCCHAR3_DAD5                    (*((volatile unsigned int*)(0x4380AC6CUL)))
#define bM4_USBFS_HCCHAR3_DAD6                    (*((volatile unsigned int*)(0x4380AC70UL)))
#define bM4_USBFS_HCCHAR3_ODDFRM                  (*((volatile unsigned int*)(0x4380AC74UL)))
#define bM4_USBFS_HCCHAR3_CHDIS                   (*((volatile unsigned int*)(0x4380AC78UL)))
#define bM4_USBFS_HCCHAR3_CHENA                   (*((volatile unsigned int*)(0x4380AC7CUL)))
#define bM4_USBFS_HCINT3_XFRC                     (*((volatile unsigned int*)(0x4380AD00UL)))
#define bM4_USBFS_HCINT3_CHH                      (*((volatile unsigned int*)(0x4380AD04UL)))
#define bM4_USBFS_HCINT3_STALL                    (*((volatile unsigned int*)(0x4380AD0CUL)))
#define bM4_USBFS_HCINT3_NAK                      (*((volatile unsigned int*)(0x4380AD10UL)))
#define bM4_USBFS_HCINT3_ACK                      (*((volatile unsigned int*)(0x4380AD14UL)))
#define bM4_USBFS_HCINT3_TXERR                    (*((volatile unsigned int*)(0x4380AD1CUL)))
#define bM4_USBFS_HCINT3_BBERR                    (*((volatile unsigned int*)(0x4380AD20UL)))
#define bM4_USBFS_HCINT3_FRMOR                    (*((volatile unsigned int*)(0x4380AD24UL)))
#define bM4_USBFS_HCINT3_DTERR                    (*((volatile unsigned int*)(0x4380AD28UL)))
#define bM4_USBFS_HCINTMSK3_XFRCM                 (*((volatile unsigned int*)(0x4380AD80UL)))
#define bM4_USBFS_HCINTMSK3_CHHM                  (*((volatile unsigned int*)(0x4380AD84UL)))
#define bM4_USBFS_HCINTMSK3_STALLM                (*((volatile unsigned int*)(0x4380AD8CUL)))
#define bM4_USBFS_HCINTMSK3_NAKM                  (*((volatile unsigned int*)(0x4380AD90UL)))
#define bM4_USBFS_HCINTMSK3_ACKM                  (*((volatile unsigned int*)(0x4380AD94UL)))
#define bM4_USBFS_HCINTMSK3_TXERRM                (*((volatile unsigned int*)(0x4380AD9CUL)))
#define bM4_USBFS_HCINTMSK3_BBERRM                (*((volatile unsigned int*)(0x4380ADA0UL)))
#define bM4_USBFS_HCINTMSK3_FRMORM                (*((volatile unsigned int*)(0x4380ADA4UL)))
#define bM4_USBFS_HCINTMSK3_DTERRM                (*((volatile unsigned int*)(0x4380ADA8UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ0                 (*((volatile unsigned int*)(0x4380AE00UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ1                 (*((volatile unsigned int*)(0x4380AE04UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ2                 (*((volatile unsigned int*)(0x4380AE08UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ3                 (*((volatile unsigned int*)(0x4380AE0CUL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ4                 (*((volatile unsigned int*)(0x4380AE10UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ5                 (*((volatile unsigned int*)(0x4380AE14UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ6                 (*((volatile unsigned int*)(0x4380AE18UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ7                 (*((volatile unsigned int*)(0x4380AE1CUL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ8                 (*((volatile unsigned int*)(0x4380AE20UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ9                 (*((volatile unsigned int*)(0x4380AE24UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ10                (*((volatile unsigned int*)(0x4380AE28UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ11                (*((volatile unsigned int*)(0x4380AE2CUL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ12                (*((volatile unsigned int*)(0x4380AE30UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ13                (*((volatile unsigned int*)(0x4380AE34UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ14                (*((volatile unsigned int*)(0x4380AE38UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ15                (*((volatile unsigned int*)(0x4380AE3CUL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ16                (*((volatile unsigned int*)(0x4380AE40UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ17                (*((volatile unsigned int*)(0x4380AE44UL)))
#define bM4_USBFS_HCTSIZ3_XFRSIZ18                (*((volatile unsigned int*)(0x4380AE48UL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT0                 (*((volatile unsigned int*)(0x4380AE4CUL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT1                 (*((volatile unsigned int*)(0x4380AE50UL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT2                 (*((volatile unsigned int*)(0x4380AE54UL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT3                 (*((volatile unsigned int*)(0x4380AE58UL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT4                 (*((volatile unsigned int*)(0x4380AE5CUL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT5                 (*((volatile unsigned int*)(0x4380AE60UL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT6                 (*((volatile unsigned int*)(0x4380AE64UL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT7                 (*((volatile unsigned int*)(0x4380AE68UL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT8                 (*((volatile unsigned int*)(0x4380AE6CUL)))
#define bM4_USBFS_HCTSIZ3_PKTCNT9                 (*((volatile unsigned int*)(0x4380AE70UL)))
#define bM4_USBFS_HCTSIZ3_DPID0                   (*((volatile unsigned int*)(0x4380AE74UL)))
#define bM4_USBFS_HCTSIZ3_DPID1                   (*((volatile unsigned int*)(0x4380AE78UL)))
#define bM4_USBFS_HCCHAR4_MPSIZ0                  (*((volatile unsigned int*)(0x4380B000UL)))
#define bM4_USBFS_HCCHAR4_MPSIZ1                  (*((volatile unsigned int*)(0x4380B004UL)))
#define bM4_USBFS_HCCHAR4_MPSIZ2                  (*((volatile unsigned int*)(0x4380B008UL)))
#define bM4_USBFS_HCCHAR4_MPSIZ3                  (*((volatile unsigned int*)(0x4380B00CUL)))
#define bM4_USBFS_HCCHAR4_MPSIZ4                  (*((volatile unsigned int*)(0x4380B010UL)))
#define bM4_USBFS_HCCHAR4_MPSIZ5                  (*((volatile unsigned int*)(0x4380B014UL)))
#define bM4_USBFS_HCCHAR4_MPSIZ6                  (*((volatile unsigned int*)(0x4380B018UL)))
#define bM4_USBFS_HCCHAR4_MPSIZ7                  (*((volatile unsigned int*)(0x4380B01CUL)))
#define bM4_USBFS_HCCHAR4_MPSIZ8                  (*((volatile unsigned int*)(0x4380B020UL)))
#define bM4_USBFS_HCCHAR4_MPSIZ9                  (*((volatile unsigned int*)(0x4380B024UL)))
#define bM4_USBFS_HCCHAR4_MPSIZ10                 (*((volatile unsigned int*)(0x4380B028UL)))
#define bM4_USBFS_HCCHAR4_EPNUM0                  (*((volatile unsigned int*)(0x4380B02CUL)))
#define bM4_USBFS_HCCHAR4_EPNUM1                  (*((volatile unsigned int*)(0x4380B030UL)))
#define bM4_USBFS_HCCHAR4_EPNUM2                  (*((volatile unsigned int*)(0x4380B034UL)))
#define bM4_USBFS_HCCHAR4_EPNUM3                  (*((volatile unsigned int*)(0x4380B038UL)))
#define bM4_USBFS_HCCHAR4_EPDIR                   (*((volatile unsigned int*)(0x4380B03CUL)))
#define bM4_USBFS_HCCHAR4_LSDEV                   (*((volatile unsigned int*)(0x4380B044UL)))
#define bM4_USBFS_HCCHAR4_EPTYP0                  (*((volatile unsigned int*)(0x4380B048UL)))
#define bM4_USBFS_HCCHAR4_EPTYP1                  (*((volatile unsigned int*)(0x4380B04CUL)))
#define bM4_USBFS_HCCHAR4_DAD0                    (*((volatile unsigned int*)(0x4380B058UL)))
#define bM4_USBFS_HCCHAR4_DAD1                    (*((volatile unsigned int*)(0x4380B05CUL)))
#define bM4_USBFS_HCCHAR4_DAD2                    (*((volatile unsigned int*)(0x4380B060UL)))
#define bM4_USBFS_HCCHAR4_DAD3                    (*((volatile unsigned int*)(0x4380B064UL)))
#define bM4_USBFS_HCCHAR4_DAD4                    (*((volatile unsigned int*)(0x4380B068UL)))
#define bM4_USBFS_HCCHAR4_DAD5                    (*((volatile unsigned int*)(0x4380B06CUL)))
#define bM4_USBFS_HCCHAR4_DAD6                    (*((volatile unsigned int*)(0x4380B070UL)))
#define bM4_USBFS_HCCHAR4_ODDFRM                  (*((volatile unsigned int*)(0x4380B074UL)))
#define bM4_USBFS_HCCHAR4_CHDIS                   (*((volatile unsigned int*)(0x4380B078UL)))
#define bM4_USBFS_HCCHAR4_CHENA                   (*((volatile unsigned int*)(0x4380B07CUL)))
#define bM4_USBFS_HCINT4_XFRC                     (*((volatile unsigned int*)(0x4380B100UL)))
#define bM4_USBFS_HCINT4_CHH                      (*((volatile unsigned int*)(0x4380B104UL)))
#define bM4_USBFS_HCINT4_STALL                    (*((volatile unsigned int*)(0x4380B10CUL)))
#define bM4_USBFS_HCINT4_NAK                      (*((volatile unsigned int*)(0x4380B110UL)))
#define bM4_USBFS_HCINT4_ACK                      (*((volatile unsigned int*)(0x4380B114UL)))
#define bM4_USBFS_HCINT4_TXERR                    (*((volatile unsigned int*)(0x4380B11CUL)))
#define bM4_USBFS_HCINT4_BBERR                    (*((volatile unsigned int*)(0x4380B120UL)))
#define bM4_USBFS_HCINT4_FRMOR                    (*((volatile unsigned int*)(0x4380B124UL)))
#define bM4_USBFS_HCINT4_DTERR                    (*((volatile unsigned int*)(0x4380B128UL)))
#define bM4_USBFS_HCINTMSK4_XFRCM                 (*((volatile unsigned int*)(0x4380B180UL)))
#define bM4_USBFS_HCINTMSK4_CHHM                  (*((volatile unsigned int*)(0x4380B184UL)))
#define bM4_USBFS_HCINTMSK4_STALLM                (*((volatile unsigned int*)(0x4380B18CUL)))
#define bM4_USBFS_HCINTMSK4_NAKM                  (*((volatile unsigned int*)(0x4380B190UL)))
#define bM4_USBFS_HCINTMSK4_ACKM                  (*((volatile unsigned int*)(0x4380B194UL)))
#define bM4_USBFS_HCINTMSK4_TXERRM                (*((volatile unsigned int*)(0x4380B19CUL)))
#define bM4_USBFS_HCINTMSK4_BBERRM                (*((volatile unsigned int*)(0x4380B1A0UL)))
#define bM4_USBFS_HCINTMSK4_FRMORM                (*((volatile unsigned int*)(0x4380B1A4UL)))
#define bM4_USBFS_HCINTMSK4_DTERRM                (*((volatile unsigned int*)(0x4380B1A8UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ0                 (*((volatile unsigned int*)(0x4380B200UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ1                 (*((volatile unsigned int*)(0x4380B204UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ2                 (*((volatile unsigned int*)(0x4380B208UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ3                 (*((volatile unsigned int*)(0x4380B20CUL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ4                 (*((volatile unsigned int*)(0x4380B210UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ5                 (*((volatile unsigned int*)(0x4380B214UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ6                 (*((volatile unsigned int*)(0x4380B218UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ7                 (*((volatile unsigned int*)(0x4380B21CUL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ8                 (*((volatile unsigned int*)(0x4380B220UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ9                 (*((volatile unsigned int*)(0x4380B224UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ10                (*((volatile unsigned int*)(0x4380B228UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ11                (*((volatile unsigned int*)(0x4380B22CUL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ12                (*((volatile unsigned int*)(0x4380B230UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ13                (*((volatile unsigned int*)(0x4380B234UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ14                (*((volatile unsigned int*)(0x4380B238UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ15                (*((volatile unsigned int*)(0x4380B23CUL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ16                (*((volatile unsigned int*)(0x4380B240UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ17                (*((volatile unsigned int*)(0x4380B244UL)))
#define bM4_USBFS_HCTSIZ4_XFRSIZ18                (*((volatile unsigned int*)(0x4380B248UL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT0                 (*((volatile unsigned int*)(0x4380B24CUL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT1                 (*((volatile unsigned int*)(0x4380B250UL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT2                 (*((volatile unsigned int*)(0x4380B254UL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT3                 (*((volatile unsigned int*)(0x4380B258UL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT4                 (*((volatile unsigned int*)(0x4380B25CUL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT5                 (*((volatile unsigned int*)(0x4380B260UL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT6                 (*((volatile unsigned int*)(0x4380B264UL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT7                 (*((volatile unsigned int*)(0x4380B268UL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT8                 (*((volatile unsigned int*)(0x4380B26CUL)))
#define bM4_USBFS_HCTSIZ4_PKTCNT9                 (*((volatile unsigned int*)(0x4380B270UL)))
#define bM4_USBFS_HCTSIZ4_DPID0                   (*((volatile unsigned int*)(0x4380B274UL)))
#define bM4_USBFS_HCTSIZ4_DPID1                   (*((volatile unsigned int*)(0x4380B278UL)))
#define bM4_USBFS_HCCHAR5_MPSIZ0                  (*((volatile unsigned int*)(0x4380B400UL)))
#define bM4_USBFS_HCCHAR5_MPSIZ1                  (*((volatile unsigned int*)(0x4380B404UL)))
#define bM4_USBFS_HCCHAR5_MPSIZ2                  (*((volatile unsigned int*)(0x4380B408UL)))
#define bM4_USBFS_HCCHAR5_MPSIZ3                  (*((volatile unsigned int*)(0x4380B40CUL)))
#define bM4_USBFS_HCCHAR5_MPSIZ4                  (*((volatile unsigned int*)(0x4380B410UL)))
#define bM4_USBFS_HCCHAR5_MPSIZ5                  (*((volatile unsigned int*)(0x4380B414UL)))
#define bM4_USBFS_HCCHAR5_MPSIZ6                  (*((volatile unsigned int*)(0x4380B418UL)))
#define bM4_USBFS_HCCHAR5_MPSIZ7                  (*((volatile unsigned int*)(0x4380B41CUL)))
#define bM4_USBFS_HCCHAR5_MPSIZ8                  (*((volatile unsigned int*)(0x4380B420UL)))
#define bM4_USBFS_HCCHAR5_MPSIZ9                  (*((volatile unsigned int*)(0x4380B424UL)))
#define bM4_USBFS_HCCHAR5_MPSIZ10                 (*((volatile unsigned int*)(0x4380B428UL)))
#define bM4_USBFS_HCCHAR5_EPNUM0                  (*((volatile unsigned int*)(0x4380B42CUL)))
#define bM4_USBFS_HCCHAR5_EPNUM1                  (*((volatile unsigned int*)(0x4380B430UL)))
#define bM4_USBFS_HCCHAR5_EPNUM2                  (*((volatile unsigned int*)(0x4380B434UL)))
#define bM4_USBFS_HCCHAR5_EPNUM3                  (*((volatile unsigned int*)(0x4380B438UL)))
#define bM4_USBFS_HCCHAR5_EPDIR                   (*((volatile unsigned int*)(0x4380B43CUL)))
#define bM4_USBFS_HCCHAR5_LSDEV                   (*((volatile unsigned int*)(0x4380B444UL)))
#define bM4_USBFS_HCCHAR5_EPTYP0                  (*((volatile unsigned int*)(0x4380B448UL)))
#define bM4_USBFS_HCCHAR5_EPTYP1                  (*((volatile unsigned int*)(0x4380B44CUL)))
#define bM4_USBFS_HCCHAR5_DAD0                    (*((volatile unsigned int*)(0x4380B458UL)))
#define bM4_USBFS_HCCHAR5_DAD1                    (*((volatile unsigned int*)(0x4380B45CUL)))
#define bM4_USBFS_HCCHAR5_DAD2                    (*((volatile unsigned int*)(0x4380B460UL)))
#define bM4_USBFS_HCCHAR5_DAD3                    (*((volatile unsigned int*)(0x4380B464UL)))
#define bM4_USBFS_HCCHAR5_DAD4                    (*((volatile unsigned int*)(0x4380B468UL)))
#define bM4_USBFS_HCCHAR5_DAD5                    (*((volatile unsigned int*)(0x4380B46CUL)))
#define bM4_USBFS_HCCHAR5_DAD6                    (*((volatile unsigned int*)(0x4380B470UL)))
#define bM4_USBFS_HCCHAR5_ODDFRM                  (*((volatile unsigned int*)(0x4380B474UL)))
#define bM4_USBFS_HCCHAR5_CHDIS                   (*((volatile unsigned int*)(0x4380B478UL)))
#define bM4_USBFS_HCCHAR5_CHENA                   (*((volatile unsigned int*)(0x4380B47CUL)))
#define bM4_USBFS_HCINT5_XFRC                     (*((volatile unsigned int*)(0x4380B500UL)))
#define bM4_USBFS_HCINT5_CHH                      (*((volatile unsigned int*)(0x4380B504UL)))
#define bM4_USBFS_HCINT5_STALL                    (*((volatile unsigned int*)(0x4380B50CUL)))
#define bM4_USBFS_HCINT5_NAK                      (*((volatile unsigned int*)(0x4380B510UL)))
#define bM4_USBFS_HCINT5_ACK                      (*((volatile unsigned int*)(0x4380B514UL)))
#define bM4_USBFS_HCINT5_TXERR                    (*((volatile unsigned int*)(0x4380B51CUL)))
#define bM4_USBFS_HCINT5_BBERR                    (*((volatile unsigned int*)(0x4380B520UL)))
#define bM4_USBFS_HCINT5_FRMOR                    (*((volatile unsigned int*)(0x4380B524UL)))
#define bM4_USBFS_HCINT5_DTERR                    (*((volatile unsigned int*)(0x4380B528UL)))
#define bM4_USBFS_HCINTMSK5_XFRCM                 (*((volatile unsigned int*)(0x4380B580UL)))
#define bM4_USBFS_HCINTMSK5_CHHM                  (*((volatile unsigned int*)(0x4380B584UL)))
#define bM4_USBFS_HCINTMSK5_STALLM                (*((volatile unsigned int*)(0x4380B58CUL)))
#define bM4_USBFS_HCINTMSK5_NAKM                  (*((volatile unsigned int*)(0x4380B590UL)))
#define bM4_USBFS_HCINTMSK5_ACKM                  (*((volatile unsigned int*)(0x4380B594UL)))
#define bM4_USBFS_HCINTMSK5_TXERRM                (*((volatile unsigned int*)(0x4380B59CUL)))
#define bM4_USBFS_HCINTMSK5_BBERRM                (*((volatile unsigned int*)(0x4380B5A0UL)))
#define bM4_USBFS_HCINTMSK5_FRMORM                (*((volatile unsigned int*)(0x4380B5A4UL)))
#define bM4_USBFS_HCINTMSK5_DTERRM                (*((volatile unsigned int*)(0x4380B5A8UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ0                 (*((volatile unsigned int*)(0x4380B600UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ1                 (*((volatile unsigned int*)(0x4380B604UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ2                 (*((volatile unsigned int*)(0x4380B608UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ3                 (*((volatile unsigned int*)(0x4380B60CUL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ4                 (*((volatile unsigned int*)(0x4380B610UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ5                 (*((volatile unsigned int*)(0x4380B614UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ6                 (*((volatile unsigned int*)(0x4380B618UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ7                 (*((volatile unsigned int*)(0x4380B61CUL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ8                 (*((volatile unsigned int*)(0x4380B620UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ9                 (*((volatile unsigned int*)(0x4380B624UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ10                (*((volatile unsigned int*)(0x4380B628UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ11                (*((volatile unsigned int*)(0x4380B62CUL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ12                (*((volatile unsigned int*)(0x4380B630UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ13                (*((volatile unsigned int*)(0x4380B634UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ14                (*((volatile unsigned int*)(0x4380B638UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ15                (*((volatile unsigned int*)(0x4380B63CUL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ16                (*((volatile unsigned int*)(0x4380B640UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ17                (*((volatile unsigned int*)(0x4380B644UL)))
#define bM4_USBFS_HCTSIZ5_XFRSIZ18                (*((volatile unsigned int*)(0x4380B648UL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT0                 (*((volatile unsigned int*)(0x4380B64CUL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT1                 (*((volatile unsigned int*)(0x4380B650UL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT2                 (*((volatile unsigned int*)(0x4380B654UL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT3                 (*((volatile unsigned int*)(0x4380B658UL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT4                 (*((volatile unsigned int*)(0x4380B65CUL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT5                 (*((volatile unsigned int*)(0x4380B660UL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT6                 (*((volatile unsigned int*)(0x4380B664UL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT7                 (*((volatile unsigned int*)(0x4380B668UL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT8                 (*((volatile unsigned int*)(0x4380B66CUL)))
#define bM4_USBFS_HCTSIZ5_PKTCNT9                 (*((volatile unsigned int*)(0x4380B670UL)))
#define bM4_USBFS_HCTSIZ5_DPID0                   (*((volatile unsigned int*)(0x4380B674UL)))
#define bM4_USBFS_HCTSIZ5_DPID1                   (*((volatile unsigned int*)(0x4380B678UL)))
#define bM4_USBFS_HCCHAR6_MPSIZ0                  (*((volatile unsigned int*)(0x4380B800UL)))
#define bM4_USBFS_HCCHAR6_MPSIZ1                  (*((volatile unsigned int*)(0x4380B804UL)))
#define bM4_USBFS_HCCHAR6_MPSIZ2                  (*((volatile unsigned int*)(0x4380B808UL)))
#define bM4_USBFS_HCCHAR6_MPSIZ3                  (*((volatile unsigned int*)(0x4380B80CUL)))
#define bM4_USBFS_HCCHAR6_MPSIZ4                  (*((volatile unsigned int*)(0x4380B810UL)))
#define bM4_USBFS_HCCHAR6_MPSIZ5                  (*((volatile unsigned int*)(0x4380B814UL)))
#define bM4_USBFS_HCCHAR6_MPSIZ6                  (*((volatile unsigned int*)(0x4380B818UL)))
#define bM4_USBFS_HCCHAR6_MPSIZ7                  (*((volatile unsigned int*)(0x4380B81CUL)))
#define bM4_USBFS_HCCHAR6_MPSIZ8                  (*((volatile unsigned int*)(0x4380B820UL)))
#define bM4_USBFS_HCCHAR6_MPSIZ9                  (*((volatile unsigned int*)(0x4380B824UL)))
#define bM4_USBFS_HCCHAR6_MPSIZ10                 (*((volatile unsigned int*)(0x4380B828UL)))
#define bM4_USBFS_HCCHAR6_EPNUM0                  (*((volatile unsigned int*)(0x4380B82CUL)))
#define bM4_USBFS_HCCHAR6_EPNUM1                  (*((volatile unsigned int*)(0x4380B830UL)))
#define bM4_USBFS_HCCHAR6_EPNUM2                  (*((volatile unsigned int*)(0x4380B834UL)))
#define bM4_USBFS_HCCHAR6_EPNUM3                  (*((volatile unsigned int*)(0x4380B838UL)))
#define bM4_USBFS_HCCHAR6_EPDIR                   (*((volatile unsigned int*)(0x4380B83CUL)))
#define bM4_USBFS_HCCHAR6_LSDEV                   (*((volatile unsigned int*)(0x4380B844UL)))
#define bM4_USBFS_HCCHAR6_EPTYP0                  (*((volatile unsigned int*)(0x4380B848UL)))
#define bM4_USBFS_HCCHAR6_EPTYP1                  (*((volatile unsigned int*)(0x4380B84CUL)))
#define bM4_USBFS_HCCHAR6_DAD0                    (*((volatile unsigned int*)(0x4380B858UL)))
#define bM4_USBFS_HCCHAR6_DAD1                    (*((volatile unsigned int*)(0x4380B85CUL)))
#define bM4_USBFS_HCCHAR6_DAD2                    (*((volatile unsigned int*)(0x4380B860UL)))
#define bM4_USBFS_HCCHAR6_DAD3                    (*((volatile unsigned int*)(0x4380B864UL)))
#define bM4_USBFS_HCCHAR6_DAD4                    (*((volatile unsigned int*)(0x4380B868UL)))
#define bM4_USBFS_HCCHAR6_DAD5                    (*((volatile unsigned int*)(0x4380B86CUL)))
#define bM4_USBFS_HCCHAR6_DAD6                    (*((volatile unsigned int*)(0x4380B870UL)))
#define bM4_USBFS_HCCHAR6_ODDFRM                  (*((volatile unsigned int*)(0x4380B874UL)))
#define bM4_USBFS_HCCHAR6_CHDIS                   (*((volatile unsigned int*)(0x4380B878UL)))
#define bM4_USBFS_HCCHAR6_CHENA                   (*((volatile unsigned int*)(0x4380B87CUL)))
#define bM4_USBFS_HCINT6_XFRC                     (*((volatile unsigned int*)(0x4380B900UL)))
#define bM4_USBFS_HCINT6_CHH                      (*((volatile unsigned int*)(0x4380B904UL)))
#define bM4_USBFS_HCINT6_STALL                    (*((volatile unsigned int*)(0x4380B90CUL)))
#define bM4_USBFS_HCINT6_NAK                      (*((volatile unsigned int*)(0x4380B910UL)))
#define bM4_USBFS_HCINT6_ACK                      (*((volatile unsigned int*)(0x4380B914UL)))
#define bM4_USBFS_HCINT6_TXERR                    (*((volatile unsigned int*)(0x4380B91CUL)))
#define bM4_USBFS_HCINT6_BBERR                    (*((volatile unsigned int*)(0x4380B920UL)))
#define bM4_USBFS_HCINT6_FRMOR                    (*((volatile unsigned int*)(0x4380B924UL)))
#define bM4_USBFS_HCINT6_DTERR                    (*((volatile unsigned int*)(0x4380B928UL)))
#define bM4_USBFS_HCINTMSK6_XFRCM                 (*((volatile unsigned int*)(0x4380B980UL)))
#define bM4_USBFS_HCINTMSK6_CHHM                  (*((volatile unsigned int*)(0x4380B984UL)))
#define bM4_USBFS_HCINTMSK6_STALLM                (*((volatile unsigned int*)(0x4380B98CUL)))
#define bM4_USBFS_HCINTMSK6_NAKM                  (*((volatile unsigned int*)(0x4380B990UL)))
#define bM4_USBFS_HCINTMSK6_ACKM                  (*((volatile unsigned int*)(0x4380B994UL)))
#define bM4_USBFS_HCINTMSK6_TXERRM                (*((volatile unsigned int*)(0x4380B99CUL)))
#define bM4_USBFS_HCINTMSK6_BBERRM                (*((volatile unsigned int*)(0x4380B9A0UL)))
#define bM4_USBFS_HCINTMSK6_FRMORM                (*((volatile unsigned int*)(0x4380B9A4UL)))
#define bM4_USBFS_HCINTMSK6_DTERRM                (*((volatile unsigned int*)(0x4380B9A8UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ0                 (*((volatile unsigned int*)(0x4380BA00UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ1                 (*((volatile unsigned int*)(0x4380BA04UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ2                 (*((volatile unsigned int*)(0x4380BA08UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ3                 (*((volatile unsigned int*)(0x4380BA0CUL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ4                 (*((volatile unsigned int*)(0x4380BA10UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ5                 (*((volatile unsigned int*)(0x4380BA14UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ6                 (*((volatile unsigned int*)(0x4380BA18UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ7                 (*((volatile unsigned int*)(0x4380BA1CUL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ8                 (*((volatile unsigned int*)(0x4380BA20UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ9                 (*((volatile unsigned int*)(0x4380BA24UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ10                (*((volatile unsigned int*)(0x4380BA28UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ11                (*((volatile unsigned int*)(0x4380BA2CUL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ12                (*((volatile unsigned int*)(0x4380BA30UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ13                (*((volatile unsigned int*)(0x4380BA34UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ14                (*((volatile unsigned int*)(0x4380BA38UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ15                (*((volatile unsigned int*)(0x4380BA3CUL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ16                (*((volatile unsigned int*)(0x4380BA40UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ17                (*((volatile unsigned int*)(0x4380BA44UL)))
#define bM4_USBFS_HCTSIZ6_XFRSIZ18                (*((volatile unsigned int*)(0x4380BA48UL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT0                 (*((volatile unsigned int*)(0x4380BA4CUL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT1                 (*((volatile unsigned int*)(0x4380BA50UL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT2                 (*((volatile unsigned int*)(0x4380BA54UL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT3                 (*((volatile unsigned int*)(0x4380BA58UL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT4                 (*((volatile unsigned int*)(0x4380BA5CUL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT5                 (*((volatile unsigned int*)(0x4380BA60UL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT6                 (*((volatile unsigned int*)(0x4380BA64UL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT7                 (*((volatile unsigned int*)(0x4380BA68UL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT8                 (*((volatile unsigned int*)(0x4380BA6CUL)))
#define bM4_USBFS_HCTSIZ6_PKTCNT9                 (*((volatile unsigned int*)(0x4380BA70UL)))
#define bM4_USBFS_HCTSIZ6_DPID0                   (*((volatile unsigned int*)(0x4380BA74UL)))
#define bM4_USBFS_HCTSIZ6_DPID1                   (*((volatile unsigned int*)(0x4380BA78UL)))
#define bM4_USBFS_HCCHAR7_MPSIZ0                  (*((volatile unsigned int*)(0x4380BC00UL)))
#define bM4_USBFS_HCCHAR7_MPSIZ1                  (*((volatile unsigned int*)(0x4380BC04UL)))
#define bM4_USBFS_HCCHAR7_MPSIZ2                  (*((volatile unsigned int*)(0x4380BC08UL)))
#define bM4_USBFS_HCCHAR7_MPSIZ3                  (*((volatile unsigned int*)(0x4380BC0CUL)))
#define bM4_USBFS_HCCHAR7_MPSIZ4                  (*((volatile unsigned int*)(0x4380BC10UL)))
#define bM4_USBFS_HCCHAR7_MPSIZ5                  (*((volatile unsigned int*)(0x4380BC14UL)))
#define bM4_USBFS_HCCHAR7_MPSIZ6                  (*((volatile unsigned int*)(0x4380BC18UL)))
#define bM4_USBFS_HCCHAR7_MPSIZ7                  (*((volatile unsigned int*)(0x4380BC1CUL)))
#define bM4_USBFS_HCCHAR7_MPSIZ8                  (*((volatile unsigned int*)(0x4380BC20UL)))
#define bM4_USBFS_HCCHAR7_MPSIZ9                  (*((volatile unsigned int*)(0x4380BC24UL)))
#define bM4_USBFS_HCCHAR7_MPSIZ10                 (*((volatile unsigned int*)(0x4380BC28UL)))
#define bM4_USBFS_HCCHAR7_EPNUM0                  (*((volatile unsigned int*)(0x4380BC2CUL)))
#define bM4_USBFS_HCCHAR7_EPNUM1                  (*((volatile unsigned int*)(0x4380BC30UL)))
#define bM4_USBFS_HCCHAR7_EPNUM2                  (*((volatile unsigned int*)(0x4380BC34UL)))
#define bM4_USBFS_HCCHAR7_EPNUM3                  (*((volatile unsigned int*)(0x4380BC38UL)))
#define bM4_USBFS_HCCHAR7_EPDIR                   (*((volatile unsigned int*)(0x4380BC3CUL)))
#define bM4_USBFS_HCCHAR7_LSDEV                   (*((volatile unsigned int*)(0x4380BC44UL)))
#define bM4_USBFS_HCCHAR7_EPTYP0                  (*((volatile unsigned int*)(0x4380BC48UL)))
#define bM4_USBFS_HCCHAR7_EPTYP1                  (*((volatile unsigned int*)(0x4380BC4CUL)))
#define bM4_USBFS_HCCHAR7_DAD0                    (*((volatile unsigned int*)(0x4380BC58UL)))
#define bM4_USBFS_HCCHAR7_DAD1                    (*((volatile unsigned int*)(0x4380BC5CUL)))
#define bM4_USBFS_HCCHAR7_DAD2                    (*((volatile unsigned int*)(0x4380BC60UL)))
#define bM4_USBFS_HCCHAR7_DAD3                    (*((volatile unsigned int*)(0x4380BC64UL)))
#define bM4_USBFS_HCCHAR7_DAD4                    (*((volatile unsigned int*)(0x4380BC68UL)))
#define bM4_USBFS_HCCHAR7_DAD5                    (*((volatile unsigned int*)(0x4380BC6CUL)))
#define bM4_USBFS_HCCHAR7_DAD6                    (*((volatile unsigned int*)(0x4380BC70UL)))
#define bM4_USBFS_HCCHAR7_ODDFRM                  (*((volatile unsigned int*)(0x4380BC74UL)))
#define bM4_USBFS_HCCHAR7_CHDIS                   (*((volatile unsigned int*)(0x4380BC78UL)))
#define bM4_USBFS_HCCHAR7_CHENA                   (*((volatile unsigned int*)(0x4380BC7CUL)))
#define bM4_USBFS_HCINT7_XFRC                     (*((volatile unsigned int*)(0x4380BD00UL)))
#define bM4_USBFS_HCINT7_CHH                      (*((volatile unsigned int*)(0x4380BD04UL)))
#define bM4_USBFS_HCINT7_STALL                    (*((volatile unsigned int*)(0x4380BD0CUL)))
#define bM4_USBFS_HCINT7_NAK                      (*((volatile unsigned int*)(0x4380BD10UL)))
#define bM4_USBFS_HCINT7_ACK                      (*((volatile unsigned int*)(0x4380BD14UL)))
#define bM4_USBFS_HCINT7_TXERR                    (*((volatile unsigned int*)(0x4380BD1CUL)))
#define bM4_USBFS_HCINT7_BBERR                    (*((volatile unsigned int*)(0x4380BD20UL)))
#define bM4_USBFS_HCINT7_FRMOR                    (*((volatile unsigned int*)(0x4380BD24UL)))
#define bM4_USBFS_HCINT7_DTERR                    (*((volatile unsigned int*)(0x4380BD28UL)))
#define bM4_USBFS_HCINTMSK7_XFRCM                 (*((volatile unsigned int*)(0x4380BD80UL)))
#define bM4_USBFS_HCINTMSK7_CHHM                  (*((volatile unsigned int*)(0x4380BD84UL)))
#define bM4_USBFS_HCINTMSK7_STALLM                (*((volatile unsigned int*)(0x4380BD8CUL)))
#define bM4_USBFS_HCINTMSK7_NAKM                  (*((volatile unsigned int*)(0x4380BD90UL)))
#define bM4_USBFS_HCINTMSK7_ACKM                  (*((volatile unsigned int*)(0x4380BD94UL)))
#define bM4_USBFS_HCINTMSK7_TXERRM                (*((volatile unsigned int*)(0x4380BD9CUL)))
#define bM4_USBFS_HCINTMSK7_BBERRM                (*((volatile unsigned int*)(0x4380BDA0UL)))
#define bM4_USBFS_HCINTMSK7_FRMORM                (*((volatile unsigned int*)(0x4380BDA4UL)))
#define bM4_USBFS_HCINTMSK7_DTERRM                (*((volatile unsigned int*)(0x4380BDA8UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ0                 (*((volatile unsigned int*)(0x4380BE00UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ1                 (*((volatile unsigned int*)(0x4380BE04UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ2                 (*((volatile unsigned int*)(0x4380BE08UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ3                 (*((volatile unsigned int*)(0x4380BE0CUL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ4                 (*((volatile unsigned int*)(0x4380BE10UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ5                 (*((volatile unsigned int*)(0x4380BE14UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ6                 (*((volatile unsigned int*)(0x4380BE18UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ7                 (*((volatile unsigned int*)(0x4380BE1CUL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ8                 (*((volatile unsigned int*)(0x4380BE20UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ9                 (*((volatile unsigned int*)(0x4380BE24UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ10                (*((volatile unsigned int*)(0x4380BE28UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ11                (*((volatile unsigned int*)(0x4380BE2CUL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ12                (*((volatile unsigned int*)(0x4380BE30UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ13                (*((volatile unsigned int*)(0x4380BE34UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ14                (*((volatile unsigned int*)(0x4380BE38UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ15                (*((volatile unsigned int*)(0x4380BE3CUL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ16                (*((volatile unsigned int*)(0x4380BE40UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ17                (*((volatile unsigned int*)(0x4380BE44UL)))
#define bM4_USBFS_HCTSIZ7_XFRSIZ18                (*((volatile unsigned int*)(0x4380BE48UL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT0                 (*((volatile unsigned int*)(0x4380BE4CUL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT1                 (*((volatile unsigned int*)(0x4380BE50UL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT2                 (*((volatile unsigned int*)(0x4380BE54UL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT3                 (*((volatile unsigned int*)(0x4380BE58UL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT4                 (*((volatile unsigned int*)(0x4380BE5CUL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT5                 (*((volatile unsigned int*)(0x4380BE60UL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT6                 (*((volatile unsigned int*)(0x4380BE64UL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT7                 (*((volatile unsigned int*)(0x4380BE68UL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT8                 (*((volatile unsigned int*)(0x4380BE6CUL)))
#define bM4_USBFS_HCTSIZ7_PKTCNT9                 (*((volatile unsigned int*)(0x4380BE70UL)))
#define bM4_USBFS_HCTSIZ7_DPID0                   (*((volatile unsigned int*)(0x4380BE74UL)))
#define bM4_USBFS_HCTSIZ7_DPID1                   (*((volatile unsigned int*)(0x4380BE78UL)))
#define bM4_USBFS_HCCHAR8_MPSIZ0                  (*((volatile unsigned int*)(0x4380C000UL)))
#define bM4_USBFS_HCCHAR8_MPSIZ1                  (*((volatile unsigned int*)(0x4380C004UL)))
#define bM4_USBFS_HCCHAR8_MPSIZ2                  (*((volatile unsigned int*)(0x4380C008UL)))
#define bM4_USBFS_HCCHAR8_MPSIZ3                  (*((volatile unsigned int*)(0x4380C00CUL)))
#define bM4_USBFS_HCCHAR8_MPSIZ4                  (*((volatile unsigned int*)(0x4380C010UL)))
#define bM4_USBFS_HCCHAR8_MPSIZ5                  (*((volatile unsigned int*)(0x4380C014UL)))
#define bM4_USBFS_HCCHAR8_MPSIZ6                  (*((volatile unsigned int*)(0x4380C018UL)))
#define bM4_USBFS_HCCHAR8_MPSIZ7                  (*((volatile unsigned int*)(0x4380C01CUL)))
#define bM4_USBFS_HCCHAR8_MPSIZ8                  (*((volatile unsigned int*)(0x4380C020UL)))
#define bM4_USBFS_HCCHAR8_MPSIZ9                  (*((volatile unsigned int*)(0x4380C024UL)))
#define bM4_USBFS_HCCHAR8_MPSIZ10                 (*((volatile unsigned int*)(0x4380C028UL)))
#define bM4_USBFS_HCCHAR8_EPNUM0                  (*((volatile unsigned int*)(0x4380C02CUL)))
#define bM4_USBFS_HCCHAR8_EPNUM1                  (*((volatile unsigned int*)(0x4380C030UL)))
#define bM4_USBFS_HCCHAR8_EPNUM2                  (*((volatile unsigned int*)(0x4380C034UL)))
#define bM4_USBFS_HCCHAR8_EPNUM3                  (*((volatile unsigned int*)(0x4380C038UL)))
#define bM4_USBFS_HCCHAR8_EPDIR                   (*((volatile unsigned int*)(0x4380C03CUL)))
#define bM4_USBFS_HCCHAR8_LSDEV                   (*((volatile unsigned int*)(0x4380C044UL)))
#define bM4_USBFS_HCCHAR8_EPTYP0                  (*((volatile unsigned int*)(0x4380C048UL)))
#define bM4_USBFS_HCCHAR8_EPTYP1                  (*((volatile unsigned int*)(0x4380C04CUL)))
#define bM4_USBFS_HCCHAR8_DAD0                    (*((volatile unsigned int*)(0x4380C058UL)))
#define bM4_USBFS_HCCHAR8_DAD1                    (*((volatile unsigned int*)(0x4380C05CUL)))
#define bM4_USBFS_HCCHAR8_DAD2                    (*((volatile unsigned int*)(0x4380C060UL)))
#define bM4_USBFS_HCCHAR8_DAD3                    (*((volatile unsigned int*)(0x4380C064UL)))
#define bM4_USBFS_HCCHAR8_DAD4                    (*((volatile unsigned int*)(0x4380C068UL)))
#define bM4_USBFS_HCCHAR8_DAD5                    (*((volatile unsigned int*)(0x4380C06CUL)))
#define bM4_USBFS_HCCHAR8_DAD6                    (*((volatile unsigned int*)(0x4380C070UL)))
#define bM4_USBFS_HCCHAR8_ODDFRM                  (*((volatile unsigned int*)(0x4380C074UL)))
#define bM4_USBFS_HCCHAR8_CHDIS                   (*((volatile unsigned int*)(0x4380C078UL)))
#define bM4_USBFS_HCCHAR8_CHENA                   (*((volatile unsigned int*)(0x4380C07CUL)))
#define bM4_USBFS_HCINT8_XFRC                     (*((volatile unsigned int*)(0x4380C100UL)))
#define bM4_USBFS_HCINT8_CHH                      (*((volatile unsigned int*)(0x4380C104UL)))
#define bM4_USBFS_HCINT8_STALL                    (*((volatile unsigned int*)(0x4380C10CUL)))
#define bM4_USBFS_HCINT8_NAK                      (*((volatile unsigned int*)(0x4380C110UL)))
#define bM4_USBFS_HCINT8_ACK                      (*((volatile unsigned int*)(0x4380C114UL)))
#define bM4_USBFS_HCINT8_TXERR                    (*((volatile unsigned int*)(0x4380C11CUL)))
#define bM4_USBFS_HCINT8_BBERR                    (*((volatile unsigned int*)(0x4380C120UL)))
#define bM4_USBFS_HCINT8_FRMOR                    (*((volatile unsigned int*)(0x4380C124UL)))
#define bM4_USBFS_HCINT8_DTERR                    (*((volatile unsigned int*)(0x4380C128UL)))
#define bM4_USBFS_HCINTMSK8_XFRCM                 (*((volatile unsigned int*)(0x4380C180UL)))
#define bM4_USBFS_HCINTMSK8_CHHM                  (*((volatile unsigned int*)(0x4380C184UL)))
#define bM4_USBFS_HCINTMSK8_STALLM                (*((volatile unsigned int*)(0x4380C18CUL)))
#define bM4_USBFS_HCINTMSK8_NAKM                  (*((volatile unsigned int*)(0x4380C190UL)))
#define bM4_USBFS_HCINTMSK8_ACKM                  (*((volatile unsigned int*)(0x4380C194UL)))
#define bM4_USBFS_HCINTMSK8_TXERRM                (*((volatile unsigned int*)(0x4380C19CUL)))
#define bM4_USBFS_HCINTMSK8_BBERRM                (*((volatile unsigned int*)(0x4380C1A0UL)))
#define bM4_USBFS_HCINTMSK8_FRMORM                (*((volatile unsigned int*)(0x4380C1A4UL)))
#define bM4_USBFS_HCINTMSK8_DTERRM                (*((volatile unsigned int*)(0x4380C1A8UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ0                 (*((volatile unsigned int*)(0x4380C200UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ1                 (*((volatile unsigned int*)(0x4380C204UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ2                 (*((volatile unsigned int*)(0x4380C208UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ3                 (*((volatile unsigned int*)(0x4380C20CUL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ4                 (*((volatile unsigned int*)(0x4380C210UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ5                 (*((volatile unsigned int*)(0x4380C214UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ6                 (*((volatile unsigned int*)(0x4380C218UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ7                 (*((volatile unsigned int*)(0x4380C21CUL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ8                 (*((volatile unsigned int*)(0x4380C220UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ9                 (*((volatile unsigned int*)(0x4380C224UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ10                (*((volatile unsigned int*)(0x4380C228UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ11                (*((volatile unsigned int*)(0x4380C22CUL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ12                (*((volatile unsigned int*)(0x4380C230UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ13                (*((volatile unsigned int*)(0x4380C234UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ14                (*((volatile unsigned int*)(0x4380C238UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ15                (*((volatile unsigned int*)(0x4380C23CUL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ16                (*((volatile unsigned int*)(0x4380C240UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ17                (*((volatile unsigned int*)(0x4380C244UL)))
#define bM4_USBFS_HCTSIZ8_XFRSIZ18                (*((volatile unsigned int*)(0x4380C248UL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT0                 (*((volatile unsigned int*)(0x4380C24CUL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT1                 (*((volatile unsigned int*)(0x4380C250UL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT2                 (*((volatile unsigned int*)(0x4380C254UL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT3                 (*((volatile unsigned int*)(0x4380C258UL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT4                 (*((volatile unsigned int*)(0x4380C25CUL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT5                 (*((volatile unsigned int*)(0x4380C260UL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT6                 (*((volatile unsigned int*)(0x4380C264UL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT7                 (*((volatile unsigned int*)(0x4380C268UL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT8                 (*((volatile unsigned int*)(0x4380C26CUL)))
#define bM4_USBFS_HCTSIZ8_PKTCNT9                 (*((volatile unsigned int*)(0x4380C270UL)))
#define bM4_USBFS_HCTSIZ8_DPID0                   (*((volatile unsigned int*)(0x4380C274UL)))
#define bM4_USBFS_HCTSIZ8_DPID1                   (*((volatile unsigned int*)(0x4380C278UL)))
#define bM4_USBFS_HCCHAR9_MPSIZ0                  (*((volatile unsigned int*)(0x4380C400UL)))
#define bM4_USBFS_HCCHAR9_MPSIZ1                  (*((volatile unsigned int*)(0x4380C404UL)))
#define bM4_USBFS_HCCHAR9_MPSIZ2                  (*((volatile unsigned int*)(0x4380C408UL)))
#define bM4_USBFS_HCCHAR9_MPSIZ3                  (*((volatile unsigned int*)(0x4380C40CUL)))
#define bM4_USBFS_HCCHAR9_MPSIZ4                  (*((volatile unsigned int*)(0x4380C410UL)))
#define bM4_USBFS_HCCHAR9_MPSIZ5                  (*((volatile unsigned int*)(0x4380C414UL)))
#define bM4_USBFS_HCCHAR9_MPSIZ6                  (*((volatile unsigned int*)(0x4380C418UL)))
#define bM4_USBFS_HCCHAR9_MPSIZ7                  (*((volatile unsigned int*)(0x4380C41CUL)))
#define bM4_USBFS_HCCHAR9_MPSIZ8                  (*((volatile unsigned int*)(0x4380C420UL)))
#define bM4_USBFS_HCCHAR9_MPSIZ9                  (*((volatile unsigned int*)(0x4380C424UL)))
#define bM4_USBFS_HCCHAR9_MPSIZ10                 (*((volatile unsigned int*)(0x4380C428UL)))
#define bM4_USBFS_HCCHAR9_EPNUM0                  (*((volatile unsigned int*)(0x4380C42CUL)))
#define bM4_USBFS_HCCHAR9_EPNUM1                  (*((volatile unsigned int*)(0x4380C430UL)))
#define bM4_USBFS_HCCHAR9_EPNUM2                  (*((volatile unsigned int*)(0x4380C434UL)))
#define bM4_USBFS_HCCHAR9_EPNUM3                  (*((volatile unsigned int*)(0x4380C438UL)))
#define bM4_USBFS_HCCHAR9_EPDIR                   (*((volatile unsigned int*)(0x4380C43CUL)))
#define bM4_USBFS_HCCHAR9_LSDEV                   (*((volatile unsigned int*)(0x4380C444UL)))
#define bM4_USBFS_HCCHAR9_EPTYP0                  (*((volatile unsigned int*)(0x4380C448UL)))
#define bM4_USBFS_HCCHAR9_EPTYP1                  (*((volatile unsigned int*)(0x4380C44CUL)))
#define bM4_USBFS_HCCHAR9_DAD0                    (*((volatile unsigned int*)(0x4380C458UL)))
#define bM4_USBFS_HCCHAR9_DAD1                    (*((volatile unsigned int*)(0x4380C45CUL)))
#define bM4_USBFS_HCCHAR9_DAD2                    (*((volatile unsigned int*)(0x4380C460UL)))
#define bM4_USBFS_HCCHAR9_DAD3                    (*((volatile unsigned int*)(0x4380C464UL)))
#define bM4_USBFS_HCCHAR9_DAD4                    (*((volatile unsigned int*)(0x4380C468UL)))
#define bM4_USBFS_HCCHAR9_DAD5                    (*((volatile unsigned int*)(0x4380C46CUL)))
#define bM4_USBFS_HCCHAR9_DAD6                    (*((volatile unsigned int*)(0x4380C470UL)))
#define bM4_USBFS_HCCHAR9_ODDFRM                  (*((volatile unsigned int*)(0x4380C474UL)))
#define bM4_USBFS_HCCHAR9_CHDIS                   (*((volatile unsigned int*)(0x4380C478UL)))
#define bM4_USBFS_HCCHAR9_CHENA                   (*((volatile unsigned int*)(0x4380C47CUL)))
#define bM4_USBFS_HCINT9_XFRC                     (*((volatile unsigned int*)(0x4380C500UL)))
#define bM4_USBFS_HCINT9_CHH                      (*((volatile unsigned int*)(0x4380C504UL)))
#define bM4_USBFS_HCINT9_STALL                    (*((volatile unsigned int*)(0x4380C50CUL)))
#define bM4_USBFS_HCINT9_NAK                      (*((volatile unsigned int*)(0x4380C510UL)))
#define bM4_USBFS_HCINT9_ACK                      (*((volatile unsigned int*)(0x4380C514UL)))
#define bM4_USBFS_HCINT9_TXERR                    (*((volatile unsigned int*)(0x4380C51CUL)))
#define bM4_USBFS_HCINT9_BBERR                    (*((volatile unsigned int*)(0x4380C520UL)))
#define bM4_USBFS_HCINT9_FRMOR                    (*((volatile unsigned int*)(0x4380C524UL)))
#define bM4_USBFS_HCINT9_DTERR                    (*((volatile unsigned int*)(0x4380C528UL)))
#define bM4_USBFS_HCINTMSK9_XFRCM                 (*((volatile unsigned int*)(0x4380C580UL)))
#define bM4_USBFS_HCINTMSK9_CHHM                  (*((volatile unsigned int*)(0x4380C584UL)))
#define bM4_USBFS_HCINTMSK9_STALLM                (*((volatile unsigned int*)(0x4380C58CUL)))
#define bM4_USBFS_HCINTMSK9_NAKM                  (*((volatile unsigned int*)(0x4380C590UL)))
#define bM4_USBFS_HCINTMSK9_ACKM                  (*((volatile unsigned int*)(0x4380C594UL)))
#define bM4_USBFS_HCINTMSK9_TXERRM                (*((volatile unsigned int*)(0x4380C59CUL)))
#define bM4_USBFS_HCINTMSK9_BBERRM                (*((volatile unsigned int*)(0x4380C5A0UL)))
#define bM4_USBFS_HCINTMSK9_FRMORM                (*((volatile unsigned int*)(0x4380C5A4UL)))
#define bM4_USBFS_HCINTMSK9_DTERRM                (*((volatile unsigned int*)(0x4380C5A8UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ0                 (*((volatile unsigned int*)(0x4380C600UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ1                 (*((volatile unsigned int*)(0x4380C604UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ2                 (*((volatile unsigned int*)(0x4380C608UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ3                 (*((volatile unsigned int*)(0x4380C60CUL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ4                 (*((volatile unsigned int*)(0x4380C610UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ5                 (*((volatile unsigned int*)(0x4380C614UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ6                 (*((volatile unsigned int*)(0x4380C618UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ7                 (*((volatile unsigned int*)(0x4380C61CUL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ8                 (*((volatile unsigned int*)(0x4380C620UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ9                 (*((volatile unsigned int*)(0x4380C624UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ10                (*((volatile unsigned int*)(0x4380C628UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ11                (*((volatile unsigned int*)(0x4380C62CUL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ12                (*((volatile unsigned int*)(0x4380C630UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ13                (*((volatile unsigned int*)(0x4380C634UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ14                (*((volatile unsigned int*)(0x4380C638UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ15                (*((volatile unsigned int*)(0x4380C63CUL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ16                (*((volatile unsigned int*)(0x4380C640UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ17                (*((volatile unsigned int*)(0x4380C644UL)))
#define bM4_USBFS_HCTSIZ9_XFRSIZ18                (*((volatile unsigned int*)(0x4380C648UL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT0                 (*((volatile unsigned int*)(0x4380C64CUL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT1                 (*((volatile unsigned int*)(0x4380C650UL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT2                 (*((volatile unsigned int*)(0x4380C654UL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT3                 (*((volatile unsigned int*)(0x4380C658UL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT4                 (*((volatile unsigned int*)(0x4380C65CUL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT5                 (*((volatile unsigned int*)(0x4380C660UL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT6                 (*((volatile unsigned int*)(0x4380C664UL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT7                 (*((volatile unsigned int*)(0x4380C668UL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT8                 (*((volatile unsigned int*)(0x4380C66CUL)))
#define bM4_USBFS_HCTSIZ9_PKTCNT9                 (*((volatile unsigned int*)(0x4380C670UL)))
#define bM4_USBFS_HCTSIZ9_DPID0                   (*((volatile unsigned int*)(0x4380C674UL)))
#define bM4_USBFS_HCTSIZ9_DPID1                   (*((volatile unsigned int*)(0x4380C678UL)))
#define bM4_USBFS_HCCHAR10_MPSIZ0                 (*((volatile unsigned int*)(0x4380C800UL)))
#define bM4_USBFS_HCCHAR10_MPSIZ1                 (*((volatile unsigned int*)(0x4380C804UL)))
#define bM4_USBFS_HCCHAR10_MPSIZ2                 (*((volatile unsigned int*)(0x4380C808UL)))
#define bM4_USBFS_HCCHAR10_MPSIZ3                 (*((volatile unsigned int*)(0x4380C80CUL)))
#define bM4_USBFS_HCCHAR10_MPSIZ4                 (*((volatile unsigned int*)(0x4380C810UL)))
#define bM4_USBFS_HCCHAR10_MPSIZ5                 (*((volatile unsigned int*)(0x4380C814UL)))
#define bM4_USBFS_HCCHAR10_MPSIZ6                 (*((volatile unsigned int*)(0x4380C818UL)))
#define bM4_USBFS_HCCHAR10_MPSIZ7                 (*((volatile unsigned int*)(0x4380C81CUL)))
#define bM4_USBFS_HCCHAR10_MPSIZ8                 (*((volatile unsigned int*)(0x4380C820UL)))
#define bM4_USBFS_HCCHAR10_MPSIZ9                 (*((volatile unsigned int*)(0x4380C824UL)))
#define bM4_USBFS_HCCHAR10_MPSIZ10                (*((volatile unsigned int*)(0x4380C828UL)))
#define bM4_USBFS_HCCHAR10_EPNUM0                 (*((volatile unsigned int*)(0x4380C82CUL)))
#define bM4_USBFS_HCCHAR10_EPNUM1                 (*((volatile unsigned int*)(0x4380C830UL)))
#define bM4_USBFS_HCCHAR10_EPNUM2                 (*((volatile unsigned int*)(0x4380C834UL)))
#define bM4_USBFS_HCCHAR10_EPNUM3                 (*((volatile unsigned int*)(0x4380C838UL)))
#define bM4_USBFS_HCCHAR10_EPDIR                  (*((volatile unsigned int*)(0x4380C83CUL)))
#define bM4_USBFS_HCCHAR10_LSDEV                  (*((volatile unsigned int*)(0x4380C844UL)))
#define bM4_USBFS_HCCHAR10_EPTYP0                 (*((volatile unsigned int*)(0x4380C848UL)))
#define bM4_USBFS_HCCHAR10_EPTYP1                 (*((volatile unsigned int*)(0x4380C84CUL)))
#define bM4_USBFS_HCCHAR10_DAD0                   (*((volatile unsigned int*)(0x4380C858UL)))
#define bM4_USBFS_HCCHAR10_DAD1                   (*((volatile unsigned int*)(0x4380C85CUL)))
#define bM4_USBFS_HCCHAR10_DAD2                   (*((volatile unsigned int*)(0x4380C860UL)))
#define bM4_USBFS_HCCHAR10_DAD3                   (*((volatile unsigned int*)(0x4380C864UL)))
#define bM4_USBFS_HCCHAR10_DAD4                   (*((volatile unsigned int*)(0x4380C868UL)))
#define bM4_USBFS_HCCHAR10_DAD5                   (*((volatile unsigned int*)(0x4380C86CUL)))
#define bM4_USBFS_HCCHAR10_DAD6                   (*((volatile unsigned int*)(0x4380C870UL)))
#define bM4_USBFS_HCCHAR10_ODDFRM                 (*((volatile unsigned int*)(0x4380C874UL)))
#define bM4_USBFS_HCCHAR10_CHDIS                  (*((volatile unsigned int*)(0x4380C878UL)))
#define bM4_USBFS_HCCHAR10_CHENA                  (*((volatile unsigned int*)(0x4380C87CUL)))
#define bM4_USBFS_HCINT10_XFRC                    (*((volatile unsigned int*)(0x4380C900UL)))
#define bM4_USBFS_HCINT10_CHH                     (*((volatile unsigned int*)(0x4380C904UL)))
#define bM4_USBFS_HCINT10_STALL                   (*((volatile unsigned int*)(0x4380C90CUL)))
#define bM4_USBFS_HCINT10_NAK                     (*((volatile unsigned int*)(0x4380C910UL)))
#define bM4_USBFS_HCINT10_ACK                     (*((volatile unsigned int*)(0x4380C914UL)))
#define bM4_USBFS_HCINT10_TXERR                   (*((volatile unsigned int*)(0x4380C91CUL)))
#define bM4_USBFS_HCINT10_BBERR                   (*((volatile unsigned int*)(0x4380C920UL)))
#define bM4_USBFS_HCINT10_FRMOR                   (*((volatile unsigned int*)(0x4380C924UL)))
#define bM4_USBFS_HCINT10_DTERR                   (*((volatile unsigned int*)(0x4380C928UL)))
#define bM4_USBFS_HCINTMSK10_XFRCM                (*((volatile unsigned int*)(0x4380C980UL)))
#define bM4_USBFS_HCINTMSK10_CHHM                 (*((volatile unsigned int*)(0x4380C984UL)))
#define bM4_USBFS_HCINTMSK10_STALLM               (*((volatile unsigned int*)(0x4380C98CUL)))
#define bM4_USBFS_HCINTMSK10_NAKM                 (*((volatile unsigned int*)(0x4380C990UL)))
#define bM4_USBFS_HCINTMSK10_ACKM                 (*((volatile unsigned int*)(0x4380C994UL)))
#define bM4_USBFS_HCINTMSK10_TXERRM               (*((volatile unsigned int*)(0x4380C99CUL)))
#define bM4_USBFS_HCINTMSK10_BBERRM               (*((volatile unsigned int*)(0x4380C9A0UL)))
#define bM4_USBFS_HCINTMSK10_FRMORM               (*((volatile unsigned int*)(0x4380C9A4UL)))
#define bM4_USBFS_HCINTMSK10_DTERRM               (*((volatile unsigned int*)(0x4380C9A8UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ0                (*((volatile unsigned int*)(0x4380CA00UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ1                (*((volatile unsigned int*)(0x4380CA04UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ2                (*((volatile unsigned int*)(0x4380CA08UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ3                (*((volatile unsigned int*)(0x4380CA0CUL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ4                (*((volatile unsigned int*)(0x4380CA10UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ5                (*((volatile unsigned int*)(0x4380CA14UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ6                (*((volatile unsigned int*)(0x4380CA18UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ7                (*((volatile unsigned int*)(0x4380CA1CUL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ8                (*((volatile unsigned int*)(0x4380CA20UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ9                (*((volatile unsigned int*)(0x4380CA24UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ10               (*((volatile unsigned int*)(0x4380CA28UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ11               (*((volatile unsigned int*)(0x4380CA2CUL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ12               (*((volatile unsigned int*)(0x4380CA30UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ13               (*((volatile unsigned int*)(0x4380CA34UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ14               (*((volatile unsigned int*)(0x4380CA38UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ15               (*((volatile unsigned int*)(0x4380CA3CUL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ16               (*((volatile unsigned int*)(0x4380CA40UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ17               (*((volatile unsigned int*)(0x4380CA44UL)))
#define bM4_USBFS_HCTSIZ10_XFRSIZ18               (*((volatile unsigned int*)(0x4380CA48UL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT0                (*((volatile unsigned int*)(0x4380CA4CUL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT1                (*((volatile unsigned int*)(0x4380CA50UL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT2                (*((volatile unsigned int*)(0x4380CA54UL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT3                (*((volatile unsigned int*)(0x4380CA58UL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT4                (*((volatile unsigned int*)(0x4380CA5CUL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT5                (*((volatile unsigned int*)(0x4380CA60UL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT6                (*((volatile unsigned int*)(0x4380CA64UL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT7                (*((volatile unsigned int*)(0x4380CA68UL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT8                (*((volatile unsigned int*)(0x4380CA6CUL)))
#define bM4_USBFS_HCTSIZ10_PKTCNT9                (*((volatile unsigned int*)(0x4380CA70UL)))
#define bM4_USBFS_HCTSIZ10_DPID0                  (*((volatile unsigned int*)(0x4380CA74UL)))
#define bM4_USBFS_HCTSIZ10_DPID1                  (*((volatile unsigned int*)(0x4380CA78UL)))
#define bM4_USBFS_HCCHAR11_MPSIZ0                 (*((volatile unsigned int*)(0x4380CC00UL)))
#define bM4_USBFS_HCCHAR11_MPSIZ1                 (*((volatile unsigned int*)(0x4380CC04UL)))
#define bM4_USBFS_HCCHAR11_MPSIZ2                 (*((volatile unsigned int*)(0x4380CC08UL)))
#define bM4_USBFS_HCCHAR11_MPSIZ3                 (*((volatile unsigned int*)(0x4380CC0CUL)))
#define bM4_USBFS_HCCHAR11_MPSIZ4                 (*((volatile unsigned int*)(0x4380CC10UL)))
#define bM4_USBFS_HCCHAR11_MPSIZ5                 (*((volatile unsigned int*)(0x4380CC14UL)))
#define bM4_USBFS_HCCHAR11_MPSIZ6                 (*((volatile unsigned int*)(0x4380CC18UL)))
#define bM4_USBFS_HCCHAR11_MPSIZ7                 (*((volatile unsigned int*)(0x4380CC1CUL)))
#define bM4_USBFS_HCCHAR11_MPSIZ8                 (*((volatile unsigned int*)(0x4380CC20UL)))
#define bM4_USBFS_HCCHAR11_MPSIZ9                 (*((volatile unsigned int*)(0x4380CC24UL)))
#define bM4_USBFS_HCCHAR11_MPSIZ10                (*((volatile unsigned int*)(0x4380CC28UL)))
#define bM4_USBFS_HCCHAR11_EPNUM0                 (*((volatile unsigned int*)(0x4380CC2CUL)))
#define bM4_USBFS_HCCHAR11_EPNUM1                 (*((volatile unsigned int*)(0x4380CC30UL)))
#define bM4_USBFS_HCCHAR11_EPNUM2                 (*((volatile unsigned int*)(0x4380CC34UL)))
#define bM4_USBFS_HCCHAR11_EPNUM3                 (*((volatile unsigned int*)(0x4380CC38UL)))
#define bM4_USBFS_HCCHAR11_EPDIR                  (*((volatile unsigned int*)(0x4380CC3CUL)))
#define bM4_USBFS_HCCHAR11_LSDEV                  (*((volatile unsigned int*)(0x4380CC44UL)))
#define bM4_USBFS_HCCHAR11_EPTYP0                 (*((volatile unsigned int*)(0x4380CC48UL)))
#define bM4_USBFS_HCCHAR11_EPTYP1                 (*((volatile unsigned int*)(0x4380CC4CUL)))
#define bM4_USBFS_HCCHAR11_DAD0                   (*((volatile unsigned int*)(0x4380CC58UL)))
#define bM4_USBFS_HCCHAR11_DAD1                   (*((volatile unsigned int*)(0x4380CC5CUL)))
#define bM4_USBFS_HCCHAR11_DAD2                   (*((volatile unsigned int*)(0x4380CC60UL)))
#define bM4_USBFS_HCCHAR11_DAD3                   (*((volatile unsigned int*)(0x4380CC64UL)))
#define bM4_USBFS_HCCHAR11_DAD4                   (*((volatile unsigned int*)(0x4380CC68UL)))
#define bM4_USBFS_HCCHAR11_DAD5                   (*((volatile unsigned int*)(0x4380CC6CUL)))
#define bM4_USBFS_HCCHAR11_DAD6                   (*((volatile unsigned int*)(0x4380CC70UL)))
#define bM4_USBFS_HCCHAR11_ODDFRM                 (*((volatile unsigned int*)(0x4380CC74UL)))
#define bM4_USBFS_HCCHAR11_CHDIS                  (*((volatile unsigned int*)(0x4380CC78UL)))
#define bM4_USBFS_HCCHAR11_CHENA                  (*((volatile unsigned int*)(0x4380CC7CUL)))
#define bM4_USBFS_HCINT11_XFRC                    (*((volatile unsigned int*)(0x4380CD00UL)))
#define bM4_USBFS_HCINT11_CHH                     (*((volatile unsigned int*)(0x4380CD04UL)))
#define bM4_USBFS_HCINT11_STALL                   (*((volatile unsigned int*)(0x4380CD0CUL)))
#define bM4_USBFS_HCINT11_NAK                     (*((volatile unsigned int*)(0x4380CD10UL)))
#define bM4_USBFS_HCINT11_ACK                     (*((volatile unsigned int*)(0x4380CD14UL)))
#define bM4_USBFS_HCINT11_TXERR                   (*((volatile unsigned int*)(0x4380CD1CUL)))
#define bM4_USBFS_HCINT11_BBERR                   (*((volatile unsigned int*)(0x4380CD20UL)))
#define bM4_USBFS_HCINT11_FRMOR                   (*((volatile unsigned int*)(0x4380CD24UL)))
#define bM4_USBFS_HCINT11_DTERR                   (*((volatile unsigned int*)(0x4380CD28UL)))
#define bM4_USBFS_HCINTMSK11_XFRCM                (*((volatile unsigned int*)(0x4380CD80UL)))
#define bM4_USBFS_HCINTMSK11_CHHM                 (*((volatile unsigned int*)(0x4380CD84UL)))
#define bM4_USBFS_HCINTMSK11_STALLM               (*((volatile unsigned int*)(0x4380CD8CUL)))
#define bM4_USBFS_HCINTMSK11_NAKM                 (*((volatile unsigned int*)(0x4380CD90UL)))
#define bM4_USBFS_HCINTMSK11_ACKM                 (*((volatile unsigned int*)(0x4380CD94UL)))
#define bM4_USBFS_HCINTMSK11_TXERRM               (*((volatile unsigned int*)(0x4380CD9CUL)))
#define bM4_USBFS_HCINTMSK11_BBERRM               (*((volatile unsigned int*)(0x4380CDA0UL)))
#define bM4_USBFS_HCINTMSK11_FRMORM               (*((volatile unsigned int*)(0x4380CDA4UL)))
#define bM4_USBFS_HCINTMSK11_DTERRM               (*((volatile unsigned int*)(0x4380CDA8UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ0                (*((volatile unsigned int*)(0x4380CE00UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ1                (*((volatile unsigned int*)(0x4380CE04UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ2                (*((volatile unsigned int*)(0x4380CE08UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ3                (*((volatile unsigned int*)(0x4380CE0CUL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ4                (*((volatile unsigned int*)(0x4380CE10UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ5                (*((volatile unsigned int*)(0x4380CE14UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ6                (*((volatile unsigned int*)(0x4380CE18UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ7                (*((volatile unsigned int*)(0x4380CE1CUL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ8                (*((volatile unsigned int*)(0x4380CE20UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ9                (*((volatile unsigned int*)(0x4380CE24UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ10               (*((volatile unsigned int*)(0x4380CE28UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ11               (*((volatile unsigned int*)(0x4380CE2CUL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ12               (*((volatile unsigned int*)(0x4380CE30UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ13               (*((volatile unsigned int*)(0x4380CE34UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ14               (*((volatile unsigned int*)(0x4380CE38UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ15               (*((volatile unsigned int*)(0x4380CE3CUL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ16               (*((volatile unsigned int*)(0x4380CE40UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ17               (*((volatile unsigned int*)(0x4380CE44UL)))
#define bM4_USBFS_HCTSIZ11_XFRSIZ18               (*((volatile unsigned int*)(0x4380CE48UL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT0                (*((volatile unsigned int*)(0x4380CE4CUL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT1                (*((volatile unsigned int*)(0x4380CE50UL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT2                (*((volatile unsigned int*)(0x4380CE54UL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT3                (*((volatile unsigned int*)(0x4380CE58UL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT4                (*((volatile unsigned int*)(0x4380CE5CUL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT5                (*((volatile unsigned int*)(0x4380CE60UL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT6                (*((volatile unsigned int*)(0x4380CE64UL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT7                (*((volatile unsigned int*)(0x4380CE68UL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT8                (*((volatile unsigned int*)(0x4380CE6CUL)))
#define bM4_USBFS_HCTSIZ11_PKTCNT9                (*((volatile unsigned int*)(0x4380CE70UL)))
#define bM4_USBFS_HCTSIZ11_DPID0                  (*((volatile unsigned int*)(0x4380CE74UL)))
#define bM4_USBFS_HCTSIZ11_DPID1                  (*((volatile unsigned int*)(0x4380CE78UL)))
#define bM4_USBFS_DCFG_DSPD0                      (*((volatile unsigned int*)(0x43810000UL)))
#define bM4_USBFS_DCFG_DSPD1                      (*((volatile unsigned int*)(0x43810004UL)))
#define bM4_USBFS_DCFG_NZLSOHSK                   (*((volatile unsigned int*)(0x43810008UL)))
#define bM4_USBFS_DCFG_DAD0                       (*((volatile unsigned int*)(0x43810010UL)))
#define bM4_USBFS_DCFG_DAD1                       (*((volatile unsigned int*)(0x43810014UL)))
#define bM4_USBFS_DCFG_DAD2                       (*((volatile unsigned int*)(0x43810018UL)))
#define bM4_USBFS_DCFG_DAD3                       (*((volatile unsigned int*)(0x4381001CUL)))
#define bM4_USBFS_DCFG_DAD4                       (*((volatile unsigned int*)(0x43810020UL)))
#define bM4_USBFS_DCFG_DAD5                       (*((volatile unsigned int*)(0x43810024UL)))
#define bM4_USBFS_DCFG_DAD6                       (*((volatile unsigned int*)(0x43810028UL)))
#define bM4_USBFS_DCFG_PFIVL0                     (*((volatile unsigned int*)(0x4381002CUL)))
#define bM4_USBFS_DCFG_PFIVL1                     (*((volatile unsigned int*)(0x43810030UL)))
#define bM4_USBFS_DCTL_RWUSIG                     (*((volatile unsigned int*)(0x43810080UL)))
#define bM4_USBFS_DCTL_SDIS                       (*((volatile unsigned int*)(0x43810084UL)))
#define bM4_USBFS_DCTL_GINSTS                     (*((volatile unsigned int*)(0x43810088UL)))
#define bM4_USBFS_DCTL_GONSTS                     (*((volatile unsigned int*)(0x4381008CUL)))
#define bM4_USBFS_DCTL_SGINAK                     (*((volatile unsigned int*)(0x4381009CUL)))
#define bM4_USBFS_DCTL_CGINAK                     (*((volatile unsigned int*)(0x438100A0UL)))
#define bM4_USBFS_DCTL_SGONAK                     (*((volatile unsigned int*)(0x438100A4UL)))
#define bM4_USBFS_DCTL_CGONAK                     (*((volatile unsigned int*)(0x438100A8UL)))
#define bM4_USBFS_DCTL_POPRGDNE                   (*((volatile unsigned int*)(0x438100ACUL)))
#define bM4_USBFS_DSTS_SUSPSTS                    (*((volatile unsigned int*)(0x43810100UL)))
#define bM4_USBFS_DSTS_ENUMSPD0                   (*((volatile unsigned int*)(0x43810104UL)))
#define bM4_USBFS_DSTS_ENUMSPD1                   (*((volatile unsigned int*)(0x43810108UL)))
#define bM4_USBFS_DSTS_EERR                       (*((volatile unsigned int*)(0x4381010CUL)))
#define bM4_USBFS_DSTS_FNSOF0                     (*((volatile unsigned int*)(0x43810120UL)))
#define bM4_USBFS_DSTS_FNSOF1                     (*((volatile unsigned int*)(0x43810124UL)))
#define bM4_USBFS_DSTS_FNSOF2                     (*((volatile unsigned int*)(0x43810128UL)))
#define bM4_USBFS_DSTS_FNSOF3                     (*((volatile unsigned int*)(0x4381012CUL)))
#define bM4_USBFS_DSTS_FNSOF4                     (*((volatile unsigned int*)(0x43810130UL)))
#define bM4_USBFS_DSTS_FNSOF5                     (*((volatile unsigned int*)(0x43810134UL)))
#define bM4_USBFS_DSTS_FNSOF6                     (*((volatile unsigned int*)(0x43810138UL)))
#define bM4_USBFS_DSTS_FNSOF7                     (*((volatile unsigned int*)(0x4381013CUL)))
#define bM4_USBFS_DSTS_FNSOF8                     (*((volatile unsigned int*)(0x43810140UL)))
#define bM4_USBFS_DSTS_FNSOF9                     (*((volatile unsigned int*)(0x43810144UL)))
#define bM4_USBFS_DSTS_FNSOF10                    (*((volatile unsigned int*)(0x43810148UL)))
#define bM4_USBFS_DSTS_FNSOF11                    (*((volatile unsigned int*)(0x4381014CUL)))
#define bM4_USBFS_DSTS_FNSOF12                    (*((volatile unsigned int*)(0x43810150UL)))
#define bM4_USBFS_DSTS_FNSOF13                    (*((volatile unsigned int*)(0x43810154UL)))
#define bM4_USBFS_DIEPMSK_XFRCM                   (*((volatile unsigned int*)(0x43810200UL)))
#define bM4_USBFS_DIEPMSK_EPDM                    (*((volatile unsigned int*)(0x43810204UL)))
#define bM4_USBFS_DIEPMSK_TOM                     (*((volatile unsigned int*)(0x4381020CUL)))
#define bM4_USBFS_DIEPMSK_ITTXFEMSK               (*((volatile unsigned int*)(0x43810210UL)))
#define bM4_USBFS_DIEPMSK_INEPNMM                 (*((volatile unsigned int*)(0x43810214UL)))
#define bM4_USBFS_DIEPMSK_INEPNEM                 (*((volatile unsigned int*)(0x43810218UL)))
#define bM4_USBFS_DOEPMSK_XFRCM                   (*((volatile unsigned int*)(0x43810280UL)))
#define bM4_USBFS_DOEPMSK_EPDM                    (*((volatile unsigned int*)(0x43810284UL)))
#define bM4_USBFS_DOEPMSK_STUPM                   (*((volatile unsigned int*)(0x4381028CUL)))
#define bM4_USBFS_DOEPMSK_OTEPDM                  (*((volatile unsigned int*)(0x43810290UL)))
#define bM4_USBFS_DAINT_IEPINT0                   (*((volatile unsigned int*)(0x43810300UL)))
#define bM4_USBFS_DAINT_IEPINT1                   (*((volatile unsigned int*)(0x43810304UL)))
#define bM4_USBFS_DAINT_IEPINT2                   (*((volatile unsigned int*)(0x43810308UL)))
#define bM4_USBFS_DAINT_IEPINT3                   (*((volatile unsigned int*)(0x4381030CUL)))
#define bM4_USBFS_DAINT_IEPINT4                   (*((volatile unsigned int*)(0x43810310UL)))
#define bM4_USBFS_DAINT_IEPINT5                   (*((volatile unsigned int*)(0x43810314UL)))
#define bM4_USBFS_DAINT_OEPINT0                   (*((volatile unsigned int*)(0x43810340UL)))
#define bM4_USBFS_DAINT_OEPINT1                   (*((volatile unsigned int*)(0x43810344UL)))
#define bM4_USBFS_DAINT_OEPINT2                   (*((volatile unsigned int*)(0x43810348UL)))
#define bM4_USBFS_DAINT_OEPINT3                   (*((volatile unsigned int*)(0x4381034CUL)))
#define bM4_USBFS_DAINT_OEPINT4                   (*((volatile unsigned int*)(0x43810350UL)))
#define bM4_USBFS_DAINT_OEPINT5                   (*((volatile unsigned int*)(0x43810354UL)))
#define bM4_USBFS_DAINTMSK_IEPINTM0               (*((volatile unsigned int*)(0x43810380UL)))
#define bM4_USBFS_DAINTMSK_IEPINTM1               (*((volatile unsigned int*)(0x43810384UL)))
#define bM4_USBFS_DAINTMSK_IEPINTM2               (*((volatile unsigned int*)(0x43810388UL)))
#define bM4_USBFS_DAINTMSK_IEPINTM3               (*((volatile unsigned int*)(0x4381038CUL)))
#define bM4_USBFS_DAINTMSK_IEPINTM4               (*((volatile unsigned int*)(0x43810390UL)))
#define bM4_USBFS_DAINTMSK_IEPINTM5               (*((volatile unsigned int*)(0x43810394UL)))
#define bM4_USBFS_DAINTMSK_OEPINTM0               (*((volatile unsigned int*)(0x438103C0UL)))
#define bM4_USBFS_DAINTMSK_OEPINTM1               (*((volatile unsigned int*)(0x438103C4UL)))
#define bM4_USBFS_DAINTMSK_OEPINTM2               (*((volatile unsigned int*)(0x438103C8UL)))
#define bM4_USBFS_DAINTMSK_OEPINTM3               (*((volatile unsigned int*)(0x438103CCUL)))
#define bM4_USBFS_DAINTMSK_OEPINTM4               (*((volatile unsigned int*)(0x438103D0UL)))
#define bM4_USBFS_DAINTMSK_OEPINTM5               (*((volatile unsigned int*)(0x438103D4UL)))
#define bM4_USBFS_DIEPEMPMSK_INEPTXFEM0           (*((volatile unsigned int*)(0x43810680UL)))
#define bM4_USBFS_DIEPEMPMSK_INEPTXFEM1           (*((volatile unsigned int*)(0x43810684UL)))
#define bM4_USBFS_DIEPEMPMSK_INEPTXFEM2           (*((volatile unsigned int*)(0x43810688UL)))
#define bM4_USBFS_DIEPEMPMSK_INEPTXFEM3           (*((volatile unsigned int*)(0x4381068CUL)))
#define bM4_USBFS_DIEPEMPMSK_INEPTXFEM4           (*((volatile unsigned int*)(0x43810690UL)))
#define bM4_USBFS_DIEPEMPMSK_INEPTXFEM5           (*((volatile unsigned int*)(0x43810694UL)))
#define bM4_USBFS_DIEPCTL0_MPSIZ0                 (*((volatile unsigned int*)(0x43812000UL)))
#define bM4_USBFS_DIEPCTL0_MPSIZ1                 (*((volatile unsigned int*)(0x43812004UL)))
#define bM4_USBFS_DIEPCTL0_USBAEP                 (*((volatile unsigned int*)(0x4381203CUL)))
#define bM4_USBFS_DIEPCTL0_NAKSTS                 (*((volatile unsigned int*)(0x43812044UL)))
#define bM4_USBFS_DIEPCTL0_EPTYP0                 (*((volatile unsigned int*)(0x43812048UL)))
#define bM4_USBFS_DIEPCTL0_EPTYP1                 (*((volatile unsigned int*)(0x4381204CUL)))
#define bM4_USBFS_DIEPCTL0_STALL                  (*((volatile unsigned int*)(0x43812054UL)))
#define bM4_USBFS_DIEPCTL0_TXFNUM0                (*((volatile unsigned int*)(0x43812058UL)))
#define bM4_USBFS_DIEPCTL0_TXFNUM1                (*((volatile unsigned int*)(0x4381205CUL)))
#define bM4_USBFS_DIEPCTL0_TXFNUM2                (*((volatile unsigned int*)(0x43812060UL)))
#define bM4_USBFS_DIEPCTL0_TXFNUM3                (*((volatile unsigned int*)(0x43812064UL)))
#define bM4_USBFS_DIEPCTL0_CNAK                   (*((volatile unsigned int*)(0x43812068UL)))
#define bM4_USBFS_DIEPCTL0_SNAK                   (*((volatile unsigned int*)(0x4381206CUL)))
#define bM4_USBFS_DIEPCTL0_EPDIS                  (*((volatile unsigned int*)(0x43812078UL)))
#define bM4_USBFS_DIEPCTL0_EPENA                  (*((volatile unsigned int*)(0x4381207CUL)))
#define bM4_USBFS_DIEPINT0_XFRC                   (*((volatile unsigned int*)(0x43812100UL)))
#define bM4_USBFS_DIEPINT0_EPDISD                 (*((volatile unsigned int*)(0x43812104UL)))
#define bM4_USBFS_DIEPINT0_TOC                    (*((volatile unsigned int*)(0x4381210CUL)))
#define bM4_USBFS_DIEPINT0_TTXFE                  (*((volatile unsigned int*)(0x43812110UL)))
#define bM4_USBFS_DIEPINT0_INEPNE                 (*((volatile unsigned int*)(0x43812118UL)))
#define bM4_USBFS_DIEPINT0_TXFE                   (*((volatile unsigned int*)(0x4381211CUL)))
#define bM4_USBFS_DIEPTSIZ0_XFRSIZ0               (*((volatile unsigned int*)(0x43812200UL)))
#define bM4_USBFS_DIEPTSIZ0_XFRSIZ1               (*((volatile unsigned int*)(0x43812204UL)))
#define bM4_USBFS_DIEPTSIZ0_XFRSIZ2               (*((volatile unsigned int*)(0x43812208UL)))
#define bM4_USBFS_DIEPTSIZ0_XFRSIZ3               (*((volatile unsigned int*)(0x4381220CUL)))
#define bM4_USBFS_DIEPTSIZ0_XFRSIZ4               (*((volatile unsigned int*)(0x43812210UL)))
#define bM4_USBFS_DIEPTSIZ0_XFRSIZ5               (*((volatile unsigned int*)(0x43812214UL)))
#define bM4_USBFS_DIEPTSIZ0_XFRSIZ6               (*((volatile unsigned int*)(0x43812218UL)))
#define bM4_USBFS_DIEPTSIZ0_PKTCNT0               (*((volatile unsigned int*)(0x4381224CUL)))
#define bM4_USBFS_DIEPTSIZ0_PKTCNT1               (*((volatile unsigned int*)(0x43812250UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV0             (*((volatile unsigned int*)(0x43812300UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV1             (*((volatile unsigned int*)(0x43812304UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV2             (*((volatile unsigned int*)(0x43812308UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV3             (*((volatile unsigned int*)(0x4381230CUL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV4             (*((volatile unsigned int*)(0x43812310UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV5             (*((volatile unsigned int*)(0x43812314UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV6             (*((volatile unsigned int*)(0x43812318UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV7             (*((volatile unsigned int*)(0x4381231CUL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV8             (*((volatile unsigned int*)(0x43812320UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV9             (*((volatile unsigned int*)(0x43812324UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV10            (*((volatile unsigned int*)(0x43812328UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV11            (*((volatile unsigned int*)(0x4381232CUL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV12            (*((volatile unsigned int*)(0x43812330UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV13            (*((volatile unsigned int*)(0x43812334UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV14            (*((volatile unsigned int*)(0x43812338UL)))
#define bM4_USBFS_DTXFSTS0_INEPTFSAV15            (*((volatile unsigned int*)(0x4381233CUL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ0                 (*((volatile unsigned int*)(0x43812400UL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ1                 (*((volatile unsigned int*)(0x43812404UL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ2                 (*((volatile unsigned int*)(0x43812408UL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ3                 (*((volatile unsigned int*)(0x4381240CUL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ4                 (*((volatile unsigned int*)(0x43812410UL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ5                 (*((volatile unsigned int*)(0x43812414UL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ6                 (*((volatile unsigned int*)(0x43812418UL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ7                 (*((volatile unsigned int*)(0x4381241CUL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ8                 (*((volatile unsigned int*)(0x43812420UL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ9                 (*((volatile unsigned int*)(0x43812424UL)))
#define bM4_USBFS_DIEPCTL1_MPSIZ10                (*((volatile unsigned int*)(0x43812428UL)))
#define bM4_USBFS_DIEPCTL1_USBAEP                 (*((volatile unsigned int*)(0x4381243CUL)))
#define bM4_USBFS_DIEPCTL1_EONUM_DPID             (*((volatile unsigned int*)(0x43812440UL)))
#define bM4_USBFS_DIEPCTL1_NAKSTS                 (*((volatile unsigned int*)(0x43812444UL)))
#define bM4_USBFS_DIEPCTL1_EPTYP0                 (*((volatile unsigned int*)(0x43812448UL)))
#define bM4_USBFS_DIEPCTL1_EPTYP1                 (*((volatile unsigned int*)(0x4381244CUL)))
#define bM4_USBFS_DIEPCTL1_STALL                  (*((volatile unsigned int*)(0x43812454UL)))
#define bM4_USBFS_DIEPCTL1_TXFNUM0                (*((volatile unsigned int*)(0x43812458UL)))
#define bM4_USBFS_DIEPCTL1_TXFNUM1                (*((volatile unsigned int*)(0x4381245CUL)))
#define bM4_USBFS_DIEPCTL1_TXFNUM2                (*((volatile unsigned int*)(0x43812460UL)))
#define bM4_USBFS_DIEPCTL1_TXFNUM3                (*((volatile unsigned int*)(0x43812464UL)))
#define bM4_USBFS_DIEPCTL1_CNAK                   (*((volatile unsigned int*)(0x43812468UL)))
#define bM4_USBFS_DIEPCTL1_SNAK                   (*((volatile unsigned int*)(0x4381246CUL)))
#define bM4_USBFS_DIEPCTL1_SD0PID_SEVNFRM         (*((volatile unsigned int*)(0x43812470UL)))
#define bM4_USBFS_DIEPCTL1_SODDFRM                (*((volatile unsigned int*)(0x43812474UL)))
#define bM4_USBFS_DIEPCTL1_EPDIS                  (*((volatile unsigned int*)(0x43812478UL)))
#define bM4_USBFS_DIEPCTL1_EPENA                  (*((volatile unsigned int*)(0x4381247CUL)))
#define bM4_USBFS_DIEPINT1_XFRC                   (*((volatile unsigned int*)(0x43812500UL)))
#define bM4_USBFS_DIEPINT1_EPDISD                 (*((volatile unsigned int*)(0x43812504UL)))
#define bM4_USBFS_DIEPINT1_TOC                    (*((volatile unsigned int*)(0x4381250CUL)))
#define bM4_USBFS_DIEPINT1_TTXFE                  (*((volatile unsigned int*)(0x43812510UL)))
#define bM4_USBFS_DIEPINT1_INEPNE                 (*((volatile unsigned int*)(0x43812518UL)))
#define bM4_USBFS_DIEPINT1_TXFE                   (*((volatile unsigned int*)(0x4381251CUL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ0               (*((volatile unsigned int*)(0x43812600UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ1               (*((volatile unsigned int*)(0x43812604UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ2               (*((volatile unsigned int*)(0x43812608UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ3               (*((volatile unsigned int*)(0x4381260CUL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ4               (*((volatile unsigned int*)(0x43812610UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ5               (*((volatile unsigned int*)(0x43812614UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ6               (*((volatile unsigned int*)(0x43812618UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ7               (*((volatile unsigned int*)(0x4381261CUL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ8               (*((volatile unsigned int*)(0x43812620UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ9               (*((volatile unsigned int*)(0x43812624UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ10              (*((volatile unsigned int*)(0x43812628UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ11              (*((volatile unsigned int*)(0x4381262CUL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ12              (*((volatile unsigned int*)(0x43812630UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ13              (*((volatile unsigned int*)(0x43812634UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ14              (*((volatile unsigned int*)(0x43812638UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ15              (*((volatile unsigned int*)(0x4381263CUL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ16              (*((volatile unsigned int*)(0x43812640UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ17              (*((volatile unsigned int*)(0x43812644UL)))
#define bM4_USBFS_DIEPTSIZ1_XFRSIZ18              (*((volatile unsigned int*)(0x43812648UL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT0               (*((volatile unsigned int*)(0x4381264CUL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT1               (*((volatile unsigned int*)(0x43812650UL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT2               (*((volatile unsigned int*)(0x43812654UL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT3               (*((volatile unsigned int*)(0x43812658UL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT4               (*((volatile unsigned int*)(0x4381265CUL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT5               (*((volatile unsigned int*)(0x43812660UL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT6               (*((volatile unsigned int*)(0x43812664UL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT7               (*((volatile unsigned int*)(0x43812668UL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT8               (*((volatile unsigned int*)(0x4381266CUL)))
#define bM4_USBFS_DIEPTSIZ1_PKTCNT9               (*((volatile unsigned int*)(0x43812670UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV0             (*((volatile unsigned int*)(0x43812700UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV1             (*((volatile unsigned int*)(0x43812704UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV2             (*((volatile unsigned int*)(0x43812708UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV3             (*((volatile unsigned int*)(0x4381270CUL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV4             (*((volatile unsigned int*)(0x43812710UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV5             (*((volatile unsigned int*)(0x43812714UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV6             (*((volatile unsigned int*)(0x43812718UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV7             (*((volatile unsigned int*)(0x4381271CUL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV8             (*((volatile unsigned int*)(0x43812720UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV9             (*((volatile unsigned int*)(0x43812724UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV10            (*((volatile unsigned int*)(0x43812728UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV11            (*((volatile unsigned int*)(0x4381272CUL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV12            (*((volatile unsigned int*)(0x43812730UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV13            (*((volatile unsigned int*)(0x43812734UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV14            (*((volatile unsigned int*)(0x43812738UL)))
#define bM4_USBFS_DTXFSTS1_INEPTFSAV15            (*((volatile unsigned int*)(0x4381273CUL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ0                 (*((volatile unsigned int*)(0x43812800UL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ1                 (*((volatile unsigned int*)(0x43812804UL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ2                 (*((volatile unsigned int*)(0x43812808UL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ3                 (*((volatile unsigned int*)(0x4381280CUL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ4                 (*((volatile unsigned int*)(0x43812810UL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ5                 (*((volatile unsigned int*)(0x43812814UL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ6                 (*((volatile unsigned int*)(0x43812818UL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ7                 (*((volatile unsigned int*)(0x4381281CUL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ8                 (*((volatile unsigned int*)(0x43812820UL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ9                 (*((volatile unsigned int*)(0x43812824UL)))
#define bM4_USBFS_DIEPCTL2_MPSIZ10                (*((volatile unsigned int*)(0x43812828UL)))
#define bM4_USBFS_DIEPCTL2_USBAEP                 (*((volatile unsigned int*)(0x4381283CUL)))
#define bM4_USBFS_DIEPCTL2_EONUM_DPID             (*((volatile unsigned int*)(0x43812840UL)))
#define bM4_USBFS_DIEPCTL2_NAKSTS                 (*((volatile unsigned int*)(0x43812844UL)))
#define bM4_USBFS_DIEPCTL2_EPTYP0                 (*((volatile unsigned int*)(0x43812848UL)))
#define bM4_USBFS_DIEPCTL2_EPTYP1                 (*((volatile unsigned int*)(0x4381284CUL)))
#define bM4_USBFS_DIEPCTL2_STALL                  (*((volatile unsigned int*)(0x43812854UL)))
#define bM4_USBFS_DIEPCTL2_TXFNUM0                (*((volatile unsigned int*)(0x43812858UL)))
#define bM4_USBFS_DIEPCTL2_TXFNUM1                (*((volatile unsigned int*)(0x4381285CUL)))
#define bM4_USBFS_DIEPCTL2_TXFNUM2                (*((volatile unsigned int*)(0x43812860UL)))
#define bM4_USBFS_DIEPCTL2_TXFNUM3                (*((volatile unsigned int*)(0x43812864UL)))
#define bM4_USBFS_DIEPCTL2_CNAK                   (*((volatile unsigned int*)(0x43812868UL)))
#define bM4_USBFS_DIEPCTL2_SNAK                   (*((volatile unsigned int*)(0x4381286CUL)))
#define bM4_USBFS_DIEPCTL2_SD0PID_SEVNFRM         (*((volatile unsigned int*)(0x43812870UL)))
#define bM4_USBFS_DIEPCTL2_SODDFRM                (*((volatile unsigned int*)(0x43812874UL)))
#define bM4_USBFS_DIEPCTL2_EPDIS                  (*((volatile unsigned int*)(0x43812878UL)))
#define bM4_USBFS_DIEPCTL2_EPENA                  (*((volatile unsigned int*)(0x4381287CUL)))
#define bM4_USBFS_DIEPINT2_XFRC                   (*((volatile unsigned int*)(0x43812900UL)))
#define bM4_USBFS_DIEPINT2_EPDISD                 (*((volatile unsigned int*)(0x43812904UL)))
#define bM4_USBFS_DIEPINT2_TOC                    (*((volatile unsigned int*)(0x4381290CUL)))
#define bM4_USBFS_DIEPINT2_TTXFE                  (*((volatile unsigned int*)(0x43812910UL)))
#define bM4_USBFS_DIEPINT2_INEPNE                 (*((volatile unsigned int*)(0x43812918UL)))
#define bM4_USBFS_DIEPINT2_TXFE                   (*((volatile unsigned int*)(0x4381291CUL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ0               (*((volatile unsigned int*)(0x43812A00UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ1               (*((volatile unsigned int*)(0x43812A04UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ2               (*((volatile unsigned int*)(0x43812A08UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ3               (*((volatile unsigned int*)(0x43812A0CUL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ4               (*((volatile unsigned int*)(0x43812A10UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ5               (*((volatile unsigned int*)(0x43812A14UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ6               (*((volatile unsigned int*)(0x43812A18UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ7               (*((volatile unsigned int*)(0x43812A1CUL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ8               (*((volatile unsigned int*)(0x43812A20UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ9               (*((volatile unsigned int*)(0x43812A24UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ10              (*((volatile unsigned int*)(0x43812A28UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ11              (*((volatile unsigned int*)(0x43812A2CUL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ12              (*((volatile unsigned int*)(0x43812A30UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ13              (*((volatile unsigned int*)(0x43812A34UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ14              (*((volatile unsigned int*)(0x43812A38UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ15              (*((volatile unsigned int*)(0x43812A3CUL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ16              (*((volatile unsigned int*)(0x43812A40UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ17              (*((volatile unsigned int*)(0x43812A44UL)))
#define bM4_USBFS_DIEPTSIZ2_XFRSIZ18              (*((volatile unsigned int*)(0x43812A48UL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT0               (*((volatile unsigned int*)(0x43812A4CUL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT1               (*((volatile unsigned int*)(0x43812A50UL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT2               (*((volatile unsigned int*)(0x43812A54UL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT3               (*((volatile unsigned int*)(0x43812A58UL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT4               (*((volatile unsigned int*)(0x43812A5CUL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT5               (*((volatile unsigned int*)(0x43812A60UL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT6               (*((volatile unsigned int*)(0x43812A64UL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT7               (*((volatile unsigned int*)(0x43812A68UL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT8               (*((volatile unsigned int*)(0x43812A6CUL)))
#define bM4_USBFS_DIEPTSIZ2_PKTCNT9               (*((volatile unsigned int*)(0x43812A70UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV0             (*((volatile unsigned int*)(0x43812B00UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV1             (*((volatile unsigned int*)(0x43812B04UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV2             (*((volatile unsigned int*)(0x43812B08UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV3             (*((volatile unsigned int*)(0x43812B0CUL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV4             (*((volatile unsigned int*)(0x43812B10UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV5             (*((volatile unsigned int*)(0x43812B14UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV6             (*((volatile unsigned int*)(0x43812B18UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV7             (*((volatile unsigned int*)(0x43812B1CUL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV8             (*((volatile unsigned int*)(0x43812B20UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV9             (*((volatile unsigned int*)(0x43812B24UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV10            (*((volatile unsigned int*)(0x43812B28UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV11            (*((volatile unsigned int*)(0x43812B2CUL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV12            (*((volatile unsigned int*)(0x43812B30UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV13            (*((volatile unsigned int*)(0x43812B34UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV14            (*((volatile unsigned int*)(0x43812B38UL)))
#define bM4_USBFS_DTXFSTS2_INEPTFSAV15            (*((volatile unsigned int*)(0x43812B3CUL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ0                 (*((volatile unsigned int*)(0x43812C00UL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ1                 (*((volatile unsigned int*)(0x43812C04UL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ2                 (*((volatile unsigned int*)(0x43812C08UL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ3                 (*((volatile unsigned int*)(0x43812C0CUL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ4                 (*((volatile unsigned int*)(0x43812C10UL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ5                 (*((volatile unsigned int*)(0x43812C14UL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ6                 (*((volatile unsigned int*)(0x43812C18UL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ7                 (*((volatile unsigned int*)(0x43812C1CUL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ8                 (*((volatile unsigned int*)(0x43812C20UL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ9                 (*((volatile unsigned int*)(0x43812C24UL)))
#define bM4_USBFS_DIEPCTL3_MPSIZ10                (*((volatile unsigned int*)(0x43812C28UL)))
#define bM4_USBFS_DIEPCTL3_USBAEP                 (*((volatile unsigned int*)(0x43812C3CUL)))
#define bM4_USBFS_DIEPCTL3_EONUM_DPID             (*((volatile unsigned int*)(0x43812C40UL)))
#define bM4_USBFS_DIEPCTL3_NAKSTS                 (*((volatile unsigned int*)(0x43812C44UL)))
#define bM4_USBFS_DIEPCTL3_EPTYP0                 (*((volatile unsigned int*)(0x43812C48UL)))
#define bM4_USBFS_DIEPCTL3_EPTYP1                 (*((volatile unsigned int*)(0x43812C4CUL)))
#define bM4_USBFS_DIEPCTL3_STALL                  (*((volatile unsigned int*)(0x43812C54UL)))
#define bM4_USBFS_DIEPCTL3_TXFNUM0                (*((volatile unsigned int*)(0x43812C58UL)))
#define bM4_USBFS_DIEPCTL3_TXFNUM1                (*((volatile unsigned int*)(0x43812C5CUL)))
#define bM4_USBFS_DIEPCTL3_TXFNUM2                (*((volatile unsigned int*)(0x43812C60UL)))
#define bM4_USBFS_DIEPCTL3_TXFNUM3                (*((volatile unsigned int*)(0x43812C64UL)))
#define bM4_USBFS_DIEPCTL3_CNAK                   (*((volatile unsigned int*)(0x43812C68UL)))
#define bM4_USBFS_DIEPCTL3_SNAK                   (*((volatile unsigned int*)(0x43812C6CUL)))
#define bM4_USBFS_DIEPCTL3_SD0PID_SEVNFRM         (*((volatile unsigned int*)(0x43812C70UL)))
#define bM4_USBFS_DIEPCTL3_SODDFRM                (*((volatile unsigned int*)(0x43812C74UL)))
#define bM4_USBFS_DIEPCTL3_EPDIS                  (*((volatile unsigned int*)(0x43812C78UL)))
#define bM4_USBFS_DIEPCTL3_EPENA                  (*((volatile unsigned int*)(0x43812C7CUL)))
#define bM4_USBFS_DIEPINT3_XFRC                   (*((volatile unsigned int*)(0x43812D00UL)))
#define bM4_USBFS_DIEPINT3_EPDISD                 (*((volatile unsigned int*)(0x43812D04UL)))
#define bM4_USBFS_DIEPINT3_TOC                    (*((volatile unsigned int*)(0x43812D0CUL)))
#define bM4_USBFS_DIEPINT3_TTXFE                  (*((volatile unsigned int*)(0x43812D10UL)))
#define bM4_USBFS_DIEPINT3_INEPNE                 (*((volatile unsigned int*)(0x43812D18UL)))
#define bM4_USBFS_DIEPINT3_TXFE                   (*((volatile unsigned int*)(0x43812D1CUL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ0               (*((volatile unsigned int*)(0x43812E00UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ1               (*((volatile unsigned int*)(0x43812E04UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ2               (*((volatile unsigned int*)(0x43812E08UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ3               (*((volatile unsigned int*)(0x43812E0CUL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ4               (*((volatile unsigned int*)(0x43812E10UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ5               (*((volatile unsigned int*)(0x43812E14UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ6               (*((volatile unsigned int*)(0x43812E18UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ7               (*((volatile unsigned int*)(0x43812E1CUL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ8               (*((volatile unsigned int*)(0x43812E20UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ9               (*((volatile unsigned int*)(0x43812E24UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ10              (*((volatile unsigned int*)(0x43812E28UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ11              (*((volatile unsigned int*)(0x43812E2CUL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ12              (*((volatile unsigned int*)(0x43812E30UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ13              (*((volatile unsigned int*)(0x43812E34UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ14              (*((volatile unsigned int*)(0x43812E38UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ15              (*((volatile unsigned int*)(0x43812E3CUL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ16              (*((volatile unsigned int*)(0x43812E40UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ17              (*((volatile unsigned int*)(0x43812E44UL)))
#define bM4_USBFS_DIEPTSIZ3_XFRSIZ18              (*((volatile unsigned int*)(0x43812E48UL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT0               (*((volatile unsigned int*)(0x43812E4CUL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT1               (*((volatile unsigned int*)(0x43812E50UL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT2               (*((volatile unsigned int*)(0x43812E54UL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT3               (*((volatile unsigned int*)(0x43812E58UL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT4               (*((volatile unsigned int*)(0x43812E5CUL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT5               (*((volatile unsigned int*)(0x43812E60UL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT6               (*((volatile unsigned int*)(0x43812E64UL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT7               (*((volatile unsigned int*)(0x43812E68UL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT8               (*((volatile unsigned int*)(0x43812E6CUL)))
#define bM4_USBFS_DIEPTSIZ3_PKTCNT9               (*((volatile unsigned int*)(0x43812E70UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV0             (*((volatile unsigned int*)(0x43812F00UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV1             (*((volatile unsigned int*)(0x43812F04UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV2             (*((volatile unsigned int*)(0x43812F08UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV3             (*((volatile unsigned int*)(0x43812F0CUL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV4             (*((volatile unsigned int*)(0x43812F10UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV5             (*((volatile unsigned int*)(0x43812F14UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV6             (*((volatile unsigned int*)(0x43812F18UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV7             (*((volatile unsigned int*)(0x43812F1CUL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV8             (*((volatile unsigned int*)(0x43812F20UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV9             (*((volatile unsigned int*)(0x43812F24UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV10            (*((volatile unsigned int*)(0x43812F28UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV11            (*((volatile unsigned int*)(0x43812F2CUL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV12            (*((volatile unsigned int*)(0x43812F30UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV13            (*((volatile unsigned int*)(0x43812F34UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV14            (*((volatile unsigned int*)(0x43812F38UL)))
#define bM4_USBFS_DTXFSTS3_INEPTFSAV15            (*((volatile unsigned int*)(0x43812F3CUL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ0                 (*((volatile unsigned int*)(0x43813000UL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ1                 (*((volatile unsigned int*)(0x43813004UL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ2                 (*((volatile unsigned int*)(0x43813008UL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ3                 (*((volatile unsigned int*)(0x4381300CUL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ4                 (*((volatile unsigned int*)(0x43813010UL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ5                 (*((volatile unsigned int*)(0x43813014UL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ6                 (*((volatile unsigned int*)(0x43813018UL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ7                 (*((volatile unsigned int*)(0x4381301CUL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ8                 (*((volatile unsigned int*)(0x43813020UL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ9                 (*((volatile unsigned int*)(0x43813024UL)))
#define bM4_USBFS_DIEPCTL4_MPSIZ10                (*((volatile unsigned int*)(0x43813028UL)))
#define bM4_USBFS_DIEPCTL4_USBAEP                 (*((volatile unsigned int*)(0x4381303CUL)))
#define bM4_USBFS_DIEPCTL4_EONUM_DPID             (*((volatile unsigned int*)(0x43813040UL)))
#define bM4_USBFS_DIEPCTL4_NAKSTS                 (*((volatile unsigned int*)(0x43813044UL)))
#define bM4_USBFS_DIEPCTL4_EPTYP0                 (*((volatile unsigned int*)(0x43813048UL)))
#define bM4_USBFS_DIEPCTL4_EPTYP1                 (*((volatile unsigned int*)(0x4381304CUL)))
#define bM4_USBFS_DIEPCTL4_STALL                  (*((volatile unsigned int*)(0x43813054UL)))
#define bM4_USBFS_DIEPCTL4_TXFNUM0                (*((volatile unsigned int*)(0x43813058UL)))
#define bM4_USBFS_DIEPCTL4_TXFNUM1                (*((volatile unsigned int*)(0x4381305CUL)))
#define bM4_USBFS_DIEPCTL4_TXFNUM2                (*((volatile unsigned int*)(0x43813060UL)))
#define bM4_USBFS_DIEPCTL4_TXFNUM3                (*((volatile unsigned int*)(0x43813064UL)))
#define bM4_USBFS_DIEPCTL4_CNAK                   (*((volatile unsigned int*)(0x43813068UL)))
#define bM4_USBFS_DIEPCTL4_SNAK                   (*((volatile unsigned int*)(0x4381306CUL)))
#define bM4_USBFS_DIEPCTL4_SD0PID_SEVNFRM         (*((volatile unsigned int*)(0x43813070UL)))
#define bM4_USBFS_DIEPCTL4_SODDFRM                (*((volatile unsigned int*)(0x43813074UL)))
#define bM4_USBFS_DIEPCTL4_EPDIS                  (*((volatile unsigned int*)(0x43813078UL)))
#define bM4_USBFS_DIEPCTL4_EPENA                  (*((volatile unsigned int*)(0x4381307CUL)))
#define bM4_USBFS_DIEPINT4_XFRC                   (*((volatile unsigned int*)(0x43813100UL)))
#define bM4_USBFS_DIEPINT4_EPDISD                 (*((volatile unsigned int*)(0x43813104UL)))
#define bM4_USBFS_DIEPINT4_TOC                    (*((volatile unsigned int*)(0x4381310CUL)))
#define bM4_USBFS_DIEPINT4_TTXFE                  (*((volatile unsigned int*)(0x43813110UL)))
#define bM4_USBFS_DIEPINT4_INEPNE                 (*((volatile unsigned int*)(0x43813118UL)))
#define bM4_USBFS_DIEPINT4_TXFE                   (*((volatile unsigned int*)(0x4381311CUL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ0               (*((volatile unsigned int*)(0x43813200UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ1               (*((volatile unsigned int*)(0x43813204UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ2               (*((volatile unsigned int*)(0x43813208UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ3               (*((volatile unsigned int*)(0x4381320CUL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ4               (*((volatile unsigned int*)(0x43813210UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ5               (*((volatile unsigned int*)(0x43813214UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ6               (*((volatile unsigned int*)(0x43813218UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ7               (*((volatile unsigned int*)(0x4381321CUL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ8               (*((volatile unsigned int*)(0x43813220UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ9               (*((volatile unsigned int*)(0x43813224UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ10              (*((volatile unsigned int*)(0x43813228UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ11              (*((volatile unsigned int*)(0x4381322CUL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ12              (*((volatile unsigned int*)(0x43813230UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ13              (*((volatile unsigned int*)(0x43813234UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ14              (*((volatile unsigned int*)(0x43813238UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ15              (*((volatile unsigned int*)(0x4381323CUL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ16              (*((volatile unsigned int*)(0x43813240UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ17              (*((volatile unsigned int*)(0x43813244UL)))
#define bM4_USBFS_DIEPTSIZ4_XFRSIZ18              (*((volatile unsigned int*)(0x43813248UL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT0               (*((volatile unsigned int*)(0x4381324CUL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT1               (*((volatile unsigned int*)(0x43813250UL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT2               (*((volatile unsigned int*)(0x43813254UL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT3               (*((volatile unsigned int*)(0x43813258UL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT4               (*((volatile unsigned int*)(0x4381325CUL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT5               (*((volatile unsigned int*)(0x43813260UL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT6               (*((volatile unsigned int*)(0x43813264UL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT7               (*((volatile unsigned int*)(0x43813268UL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT8               (*((volatile unsigned int*)(0x4381326CUL)))
#define bM4_USBFS_DIEPTSIZ4_PKTCNT9               (*((volatile unsigned int*)(0x43813270UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV0             (*((volatile unsigned int*)(0x43813300UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV1             (*((volatile unsigned int*)(0x43813304UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV2             (*((volatile unsigned int*)(0x43813308UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV3             (*((volatile unsigned int*)(0x4381330CUL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV4             (*((volatile unsigned int*)(0x43813310UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV5             (*((volatile unsigned int*)(0x43813314UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV6             (*((volatile unsigned int*)(0x43813318UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV7             (*((volatile unsigned int*)(0x4381331CUL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV8             (*((volatile unsigned int*)(0x43813320UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV9             (*((volatile unsigned int*)(0x43813324UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV10            (*((volatile unsigned int*)(0x43813328UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV11            (*((volatile unsigned int*)(0x4381332CUL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV12            (*((volatile unsigned int*)(0x43813330UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV13            (*((volatile unsigned int*)(0x43813334UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV14            (*((volatile unsigned int*)(0x43813338UL)))
#define bM4_USBFS_DTXFSTS4_INEPTFSAV15            (*((volatile unsigned int*)(0x4381333CUL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ0                 (*((volatile unsigned int*)(0x43813400UL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ1                 (*((volatile unsigned int*)(0x43813404UL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ2                 (*((volatile unsigned int*)(0x43813408UL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ3                 (*((volatile unsigned int*)(0x4381340CUL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ4                 (*((volatile unsigned int*)(0x43813410UL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ5                 (*((volatile unsigned int*)(0x43813414UL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ6                 (*((volatile unsigned int*)(0x43813418UL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ7                 (*((volatile unsigned int*)(0x4381341CUL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ8                 (*((volatile unsigned int*)(0x43813420UL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ9                 (*((volatile unsigned int*)(0x43813424UL)))
#define bM4_USBFS_DIEPCTL5_MPSIZ10                (*((volatile unsigned int*)(0x43813428UL)))
#define bM4_USBFS_DIEPCTL5_USBAEP                 (*((volatile unsigned int*)(0x4381343CUL)))
#define bM4_USBFS_DIEPCTL5_EONUM_DPID             (*((volatile unsigned int*)(0x43813440UL)))
#define bM4_USBFS_DIEPCTL5_NAKSTS                 (*((volatile unsigned int*)(0x43813444UL)))
#define bM4_USBFS_DIEPCTL5_EPTYP0                 (*((volatile unsigned int*)(0x43813448UL)))
#define bM4_USBFS_DIEPCTL5_EPTYP1                 (*((volatile unsigned int*)(0x4381344CUL)))
#define bM4_USBFS_DIEPCTL5_STALL                  (*((volatile unsigned int*)(0x43813454UL)))
#define bM4_USBFS_DIEPCTL5_TXFNUM0                (*((volatile unsigned int*)(0x43813458UL)))
#define bM4_USBFS_DIEPCTL5_TXFNUM1                (*((volatile unsigned int*)(0x4381345CUL)))
#define bM4_USBFS_DIEPCTL5_TXFNUM2                (*((volatile unsigned int*)(0x43813460UL)))
#define bM4_USBFS_DIEPCTL5_TXFNUM3                (*((volatile unsigned int*)(0x43813464UL)))
#define bM4_USBFS_DIEPCTL5_CNAK                   (*((volatile unsigned int*)(0x43813468UL)))
#define bM4_USBFS_DIEPCTL5_SNAK                   (*((volatile unsigned int*)(0x4381346CUL)))
#define bM4_USBFS_DIEPCTL5_SD0PID_SEVNFRM         (*((volatile unsigned int*)(0x43813470UL)))
#define bM4_USBFS_DIEPCTL5_SODDFRM                (*((volatile unsigned int*)(0x43813474UL)))
#define bM4_USBFS_DIEPCTL5_EPDIS                  (*((volatile unsigned int*)(0x43813478UL)))
#define bM4_USBFS_DIEPCTL5_EPENA                  (*((volatile unsigned int*)(0x4381347CUL)))
#define bM4_USBFS_DIEPINT5_XFRC                   (*((volatile unsigned int*)(0x43813500UL)))
#define bM4_USBFS_DIEPINT5_EPDISD                 (*((volatile unsigned int*)(0x43813504UL)))
#define bM4_USBFS_DIEPINT5_TOC                    (*((volatile unsigned int*)(0x4381350CUL)))
#define bM4_USBFS_DIEPINT5_TTXFE                  (*((volatile unsigned int*)(0x43813510UL)))
#define bM4_USBFS_DIEPINT5_INEPNE                 (*((volatile unsigned int*)(0x43813518UL)))
#define bM4_USBFS_DIEPINT5_TXFE                   (*((volatile unsigned int*)(0x4381351CUL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ0               (*((volatile unsigned int*)(0x43813600UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ1               (*((volatile unsigned int*)(0x43813604UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ2               (*((volatile unsigned int*)(0x43813608UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ3               (*((volatile unsigned int*)(0x4381360CUL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ4               (*((volatile unsigned int*)(0x43813610UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ5               (*((volatile unsigned int*)(0x43813614UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ6               (*((volatile unsigned int*)(0x43813618UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ7               (*((volatile unsigned int*)(0x4381361CUL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ8               (*((volatile unsigned int*)(0x43813620UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ9               (*((volatile unsigned int*)(0x43813624UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ10              (*((volatile unsigned int*)(0x43813628UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ11              (*((volatile unsigned int*)(0x4381362CUL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ12              (*((volatile unsigned int*)(0x43813630UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ13              (*((volatile unsigned int*)(0x43813634UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ14              (*((volatile unsigned int*)(0x43813638UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ15              (*((volatile unsigned int*)(0x4381363CUL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ16              (*((volatile unsigned int*)(0x43813640UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ17              (*((volatile unsigned int*)(0x43813644UL)))
#define bM4_USBFS_DIEPTSIZ5_XFRSIZ18              (*((volatile unsigned int*)(0x43813648UL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT0               (*((volatile unsigned int*)(0x4381364CUL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT1               (*((volatile unsigned int*)(0x43813650UL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT2               (*((volatile unsigned int*)(0x43813654UL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT3               (*((volatile unsigned int*)(0x43813658UL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT4               (*((volatile unsigned int*)(0x4381365CUL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT5               (*((volatile unsigned int*)(0x43813660UL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT6               (*((volatile unsigned int*)(0x43813664UL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT7               (*((volatile unsigned int*)(0x43813668UL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT8               (*((volatile unsigned int*)(0x4381366CUL)))
#define bM4_USBFS_DIEPTSIZ5_PKTCNT9               (*((volatile unsigned int*)(0x43813670UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV0             (*((volatile unsigned int*)(0x43813700UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV1             (*((volatile unsigned int*)(0x43813704UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV2             (*((volatile unsigned int*)(0x43813708UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV3             (*((volatile unsigned int*)(0x4381370CUL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV4             (*((volatile unsigned int*)(0x43813710UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV5             (*((volatile unsigned int*)(0x43813714UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV6             (*((volatile unsigned int*)(0x43813718UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV7             (*((volatile unsigned int*)(0x4381371CUL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV8             (*((volatile unsigned int*)(0x43813720UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV9             (*((volatile unsigned int*)(0x43813724UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV10            (*((volatile unsigned int*)(0x43813728UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV11            (*((volatile unsigned int*)(0x4381372CUL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV12            (*((volatile unsigned int*)(0x43813730UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV13            (*((volatile unsigned int*)(0x43813734UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV14            (*((volatile unsigned int*)(0x43813738UL)))
#define bM4_USBFS_DTXFSTS5_INEPTFSAV15            (*((volatile unsigned int*)(0x4381373CUL)))
#define bM4_USBFS_DOEPCTL0_MPSIZ0                 (*((volatile unsigned int*)(0x43816000UL)))
#define bM4_USBFS_DOEPCTL0_MPSIZ1                 (*((volatile unsigned int*)(0x43816004UL)))
#define bM4_USBFS_DOEPCTL0_USBAEP                 (*((volatile unsigned int*)(0x4381603CUL)))
#define bM4_USBFS_DOEPCTL0_NAKSTS                 (*((volatile unsigned int*)(0x43816044UL)))
#define bM4_USBFS_DOEPCTL0_EPTYP0                 (*((volatile unsigned int*)(0x43816048UL)))
#define bM4_USBFS_DOEPCTL0_EPTYP1                 (*((volatile unsigned int*)(0x4381604CUL)))
#define bM4_USBFS_DOEPCTL0_SNPM                   (*((volatile unsigned int*)(0x43816050UL)))
#define bM4_USBFS_DOEPCTL0_STALL                  (*((volatile unsigned int*)(0x43816054UL)))
#define bM4_USBFS_DOEPCTL0_CNAK                   (*((volatile unsigned int*)(0x43816068UL)))
#define bM4_USBFS_DOEPCTL0_SNAK                   (*((volatile unsigned int*)(0x4381606CUL)))
#define bM4_USBFS_DOEPCTL0_EPDIS                  (*((volatile unsigned int*)(0x43816078UL)))
#define bM4_USBFS_DOEPCTL0_EPENA                  (*((volatile unsigned int*)(0x4381607CUL)))
#define bM4_USBFS_DOEPINT0_XFRC                   (*((volatile unsigned int*)(0x43816100UL)))
#define bM4_USBFS_DOEPINT0_EPDISD                 (*((volatile unsigned int*)(0x43816104UL)))
#define bM4_USBFS_DOEPINT0_STUP                   (*((volatile unsigned int*)(0x4381610CUL)))
#define bM4_USBFS_DOEPINT0_OTEPDIS                (*((volatile unsigned int*)(0x43816110UL)))
#define bM4_USBFS_DOEPINT0_B2BSTUP                (*((volatile unsigned int*)(0x43816118UL)))
#define bM4_USBFS_DOEPTSIZ0_XFRSIZ0               (*((volatile unsigned int*)(0x43816200UL)))
#define bM4_USBFS_DOEPTSIZ0_XFRSIZ1               (*((volatile unsigned int*)(0x43816204UL)))
#define bM4_USBFS_DOEPTSIZ0_XFRSIZ2               (*((volatile unsigned int*)(0x43816208UL)))
#define bM4_USBFS_DOEPTSIZ0_XFRSIZ3               (*((volatile unsigned int*)(0x4381620CUL)))
#define bM4_USBFS_DOEPTSIZ0_XFRSIZ4               (*((volatile unsigned int*)(0x43816210UL)))
#define bM4_USBFS_DOEPTSIZ0_XFRSIZ5               (*((volatile unsigned int*)(0x43816214UL)))
#define bM4_USBFS_DOEPTSIZ0_XFRSIZ6               (*((volatile unsigned int*)(0x43816218UL)))
#define bM4_USBFS_DOEPTSIZ0_PKTCNT                (*((volatile unsigned int*)(0x4381624CUL)))
#define bM4_USBFS_DOEPTSIZ0_STUPCNT0              (*((volatile unsigned int*)(0x43816274UL)))
#define bM4_USBFS_DOEPTSIZ0_STUPCNT1              (*((volatile unsigned int*)(0x43816278UL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ0                 (*((volatile unsigned int*)(0x43816400UL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ1                 (*((volatile unsigned int*)(0x43816404UL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ2                 (*((volatile unsigned int*)(0x43816408UL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ3                 (*((volatile unsigned int*)(0x4381640CUL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ4                 (*((volatile unsigned int*)(0x43816410UL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ5                 (*((volatile unsigned int*)(0x43816414UL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ6                 (*((volatile unsigned int*)(0x43816418UL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ7                 (*((volatile unsigned int*)(0x4381641CUL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ8                 (*((volatile unsigned int*)(0x43816420UL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ9                 (*((volatile unsigned int*)(0x43816424UL)))
#define bM4_USBFS_DOEPCTL1_MPSIZ10                (*((volatile unsigned int*)(0x43816428UL)))
#define bM4_USBFS_DOEPCTL1_USBAEP                 (*((volatile unsigned int*)(0x4381643CUL)))
#define bM4_USBFS_DOEPCTL1_DPID                   (*((volatile unsigned int*)(0x43816440UL)))
#define bM4_USBFS_DOEPCTL1_NAKSTS                 (*((volatile unsigned int*)(0x43816444UL)))
#define bM4_USBFS_DOEPCTL1_EPTYP0                 (*((volatile unsigned int*)(0x43816448UL)))
#define bM4_USBFS_DOEPCTL1_EPTYP1                 (*((volatile unsigned int*)(0x4381644CUL)))
#define bM4_USBFS_DOEPCTL1_SNPM                   (*((volatile unsigned int*)(0x43816450UL)))
#define bM4_USBFS_DOEPCTL1_STALL                  (*((volatile unsigned int*)(0x43816454UL)))
#define bM4_USBFS_DOEPCTL1_CNAK                   (*((volatile unsigned int*)(0x43816468UL)))
#define bM4_USBFS_DOEPCTL1_SNAK                   (*((volatile unsigned int*)(0x4381646CUL)))
#define bM4_USBFS_DOEPCTL1_SD0PID                 (*((volatile unsigned int*)(0x43816470UL)))
#define bM4_USBFS_DOEPCTL1_SD1PID                 (*((volatile unsigned int*)(0x43816474UL)))
#define bM4_USBFS_DOEPCTL1_EPDIS                  (*((volatile unsigned int*)(0x43816478UL)))
#define bM4_USBFS_DOEPCTL1_EPENA                  (*((volatile unsigned int*)(0x4381647CUL)))
#define bM4_USBFS_DOEPINT1_XFRC                   (*((volatile unsigned int*)(0x43816500UL)))
#define bM4_USBFS_DOEPINT1_EPDISD                 (*((volatile unsigned int*)(0x43816504UL)))
#define bM4_USBFS_DOEPINT1_STUP                   (*((volatile unsigned int*)(0x4381650CUL)))
#define bM4_USBFS_DOEPINT1_OTEPDIS                (*((volatile unsigned int*)(0x43816510UL)))
#define bM4_USBFS_DOEPINT1_B2BSTUP                (*((volatile unsigned int*)(0x43816518UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ0               (*((volatile unsigned int*)(0x43816600UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ1               (*((volatile unsigned int*)(0x43816604UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ2               (*((volatile unsigned int*)(0x43816608UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ3               (*((volatile unsigned int*)(0x4381660CUL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ4               (*((volatile unsigned int*)(0x43816610UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ5               (*((volatile unsigned int*)(0x43816614UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ6               (*((volatile unsigned int*)(0x43816618UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ7               (*((volatile unsigned int*)(0x4381661CUL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ8               (*((volatile unsigned int*)(0x43816620UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ9               (*((volatile unsigned int*)(0x43816624UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ10              (*((volatile unsigned int*)(0x43816628UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ11              (*((volatile unsigned int*)(0x4381662CUL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ12              (*((volatile unsigned int*)(0x43816630UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ13              (*((volatile unsigned int*)(0x43816634UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ14              (*((volatile unsigned int*)(0x43816638UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ15              (*((volatile unsigned int*)(0x4381663CUL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ16              (*((volatile unsigned int*)(0x43816640UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ17              (*((volatile unsigned int*)(0x43816644UL)))
#define bM4_USBFS_DOEPTSIZ1_XFRSIZ18              (*((volatile unsigned int*)(0x43816648UL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT0               (*((volatile unsigned int*)(0x4381664CUL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT1               (*((volatile unsigned int*)(0x43816650UL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT2               (*((volatile unsigned int*)(0x43816654UL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT3               (*((volatile unsigned int*)(0x43816658UL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT4               (*((volatile unsigned int*)(0x4381665CUL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT5               (*((volatile unsigned int*)(0x43816660UL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT6               (*((volatile unsigned int*)(0x43816664UL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT7               (*((volatile unsigned int*)(0x43816668UL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT8               (*((volatile unsigned int*)(0x4381666CUL)))
#define bM4_USBFS_DOEPTSIZ1_PKTCNT9               (*((volatile unsigned int*)(0x43816670UL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ0                 (*((volatile unsigned int*)(0x43816800UL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ1                 (*((volatile unsigned int*)(0x43816804UL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ2                 (*((volatile unsigned int*)(0x43816808UL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ3                 (*((volatile unsigned int*)(0x4381680CUL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ4                 (*((volatile unsigned int*)(0x43816810UL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ5                 (*((volatile unsigned int*)(0x43816814UL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ6                 (*((volatile unsigned int*)(0x43816818UL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ7                 (*((volatile unsigned int*)(0x4381681CUL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ8                 (*((volatile unsigned int*)(0x43816820UL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ9                 (*((volatile unsigned int*)(0x43816824UL)))
#define bM4_USBFS_DOEPCTL2_MPSIZ10                (*((volatile unsigned int*)(0x43816828UL)))
#define bM4_USBFS_DOEPCTL2_USBAEP                 (*((volatile unsigned int*)(0x4381683CUL)))
#define bM4_USBFS_DOEPCTL2_DPID                   (*((volatile unsigned int*)(0x43816840UL)))
#define bM4_USBFS_DOEPCTL2_NAKSTS                 (*((volatile unsigned int*)(0x43816844UL)))
#define bM4_USBFS_DOEPCTL2_EPTYP0                 (*((volatile unsigned int*)(0x43816848UL)))
#define bM4_USBFS_DOEPCTL2_EPTYP1                 (*((volatile unsigned int*)(0x4381684CUL)))
#define bM4_USBFS_DOEPCTL2_SNPM                   (*((volatile unsigned int*)(0x43816850UL)))
#define bM4_USBFS_DOEPCTL2_STALL                  (*((volatile unsigned int*)(0x43816854UL)))
#define bM4_USBFS_DOEPCTL2_CNAK                   (*((volatile unsigned int*)(0x43816868UL)))
#define bM4_USBFS_DOEPCTL2_SNAK                   (*((volatile unsigned int*)(0x4381686CUL)))
#define bM4_USBFS_DOEPCTL2_SD0PID                 (*((volatile unsigned int*)(0x43816870UL)))
#define bM4_USBFS_DOEPCTL2_SD1PID                 (*((volatile unsigned int*)(0x43816874UL)))
#define bM4_USBFS_DOEPCTL2_EPDIS                  (*((volatile unsigned int*)(0x43816878UL)))
#define bM4_USBFS_DOEPCTL2_EPENA                  (*((volatile unsigned int*)(0x4381687CUL)))
#define bM4_USBFS_DOEPINT2_XFRC                   (*((volatile unsigned int*)(0x43816900UL)))
#define bM4_USBFS_DOEPINT2_EPDISD                 (*((volatile unsigned int*)(0x43816904UL)))
#define bM4_USBFS_DOEPINT2_STUP                   (*((volatile unsigned int*)(0x4381690CUL)))
#define bM4_USBFS_DOEPINT2_OTEPDIS                (*((volatile unsigned int*)(0x43816910UL)))
#define bM4_USBFS_DOEPINT2_B2BSTUP                (*((volatile unsigned int*)(0x43816918UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ0               (*((volatile unsigned int*)(0x43816A00UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ1               (*((volatile unsigned int*)(0x43816A04UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ2               (*((volatile unsigned int*)(0x43816A08UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ3               (*((volatile unsigned int*)(0x43816A0CUL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ4               (*((volatile unsigned int*)(0x43816A10UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ5               (*((volatile unsigned int*)(0x43816A14UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ6               (*((volatile unsigned int*)(0x43816A18UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ7               (*((volatile unsigned int*)(0x43816A1CUL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ8               (*((volatile unsigned int*)(0x43816A20UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ9               (*((volatile unsigned int*)(0x43816A24UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ10              (*((volatile unsigned int*)(0x43816A28UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ11              (*((volatile unsigned int*)(0x43816A2CUL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ12              (*((volatile unsigned int*)(0x43816A30UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ13              (*((volatile unsigned int*)(0x43816A34UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ14              (*((volatile unsigned int*)(0x43816A38UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ15              (*((volatile unsigned int*)(0x43816A3CUL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ16              (*((volatile unsigned int*)(0x43816A40UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ17              (*((volatile unsigned int*)(0x43816A44UL)))
#define bM4_USBFS_DOEPTSIZ2_XFRSIZ18              (*((volatile unsigned int*)(0x43816A48UL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT0               (*((volatile unsigned int*)(0x43816A4CUL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT1               (*((volatile unsigned int*)(0x43816A50UL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT2               (*((volatile unsigned int*)(0x43816A54UL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT3               (*((volatile unsigned int*)(0x43816A58UL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT4               (*((volatile unsigned int*)(0x43816A5CUL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT5               (*((volatile unsigned int*)(0x43816A60UL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT6               (*((volatile unsigned int*)(0x43816A64UL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT7               (*((volatile unsigned int*)(0x43816A68UL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT8               (*((volatile unsigned int*)(0x43816A6CUL)))
#define bM4_USBFS_DOEPTSIZ2_PKTCNT9               (*((volatile unsigned int*)(0x43816A70UL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ0                 (*((volatile unsigned int*)(0x43816C00UL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ1                 (*((volatile unsigned int*)(0x43816C04UL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ2                 (*((volatile unsigned int*)(0x43816C08UL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ3                 (*((volatile unsigned int*)(0x43816C0CUL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ4                 (*((volatile unsigned int*)(0x43816C10UL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ5                 (*((volatile unsigned int*)(0x43816C14UL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ6                 (*((volatile unsigned int*)(0x43816C18UL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ7                 (*((volatile unsigned int*)(0x43816C1CUL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ8                 (*((volatile unsigned int*)(0x43816C20UL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ9                 (*((volatile unsigned int*)(0x43816C24UL)))
#define bM4_USBFS_DOEPCTL3_MPSIZ10                (*((volatile unsigned int*)(0x43816C28UL)))
#define bM4_USBFS_DOEPCTL3_USBAEP                 (*((volatile unsigned int*)(0x43816C3CUL)))
#define bM4_USBFS_DOEPCTL3_DPID                   (*((volatile unsigned int*)(0x43816C40UL)))
#define bM4_USBFS_DOEPCTL3_NAKSTS                 (*((volatile unsigned int*)(0x43816C44UL)))
#define bM4_USBFS_DOEPCTL3_EPTYP0                 (*((volatile unsigned int*)(0x43816C48UL)))
#define bM4_USBFS_DOEPCTL3_EPTYP1                 (*((volatile unsigned int*)(0x43816C4CUL)))
#define bM4_USBFS_DOEPCTL3_SNPM                   (*((volatile unsigned int*)(0x43816C50UL)))
#define bM4_USBFS_DOEPCTL3_STALL                  (*((volatile unsigned int*)(0x43816C54UL)))
#define bM4_USBFS_DOEPCTL3_CNAK                   (*((volatile unsigned int*)(0x43816C68UL)))
#define bM4_USBFS_DOEPCTL3_SNAK                   (*((volatile unsigned int*)(0x43816C6CUL)))
#define bM4_USBFS_DOEPCTL3_SD0PID                 (*((volatile unsigned int*)(0x43816C70UL)))
#define bM4_USBFS_DOEPCTL3_SD1PID                 (*((volatile unsigned int*)(0x43816C74UL)))
#define bM4_USBFS_DOEPCTL3_EPDIS                  (*((volatile unsigned int*)(0x43816C78UL)))
#define bM4_USBFS_DOEPCTL3_EPENA                  (*((volatile unsigned int*)(0x43816C7CUL)))
#define bM4_USBFS_DOEPINT3_XFRC                   (*((volatile unsigned int*)(0x43816D00UL)))
#define bM4_USBFS_DOEPINT3_EPDISD                 (*((volatile unsigned int*)(0x43816D04UL)))
#define bM4_USBFS_DOEPINT3_STUP                   (*((volatile unsigned int*)(0x43816D0CUL)))
#define bM4_USBFS_DOEPINT3_OTEPDIS                (*((volatile unsigned int*)(0x43816D10UL)))
#define bM4_USBFS_DOEPINT3_B2BSTUP                (*((volatile unsigned int*)(0x43816D18UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ0               (*((volatile unsigned int*)(0x43816E00UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ1               (*((volatile unsigned int*)(0x43816E04UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ2               (*((volatile unsigned int*)(0x43816E08UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ3               (*((volatile unsigned int*)(0x43816E0CUL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ4               (*((volatile unsigned int*)(0x43816E10UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ5               (*((volatile unsigned int*)(0x43816E14UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ6               (*((volatile unsigned int*)(0x43816E18UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ7               (*((volatile unsigned int*)(0x43816E1CUL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ8               (*((volatile unsigned int*)(0x43816E20UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ9               (*((volatile unsigned int*)(0x43816E24UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ10              (*((volatile unsigned int*)(0x43816E28UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ11              (*((volatile unsigned int*)(0x43816E2CUL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ12              (*((volatile unsigned int*)(0x43816E30UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ13              (*((volatile unsigned int*)(0x43816E34UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ14              (*((volatile unsigned int*)(0x43816E38UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ15              (*((volatile unsigned int*)(0x43816E3CUL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ16              (*((volatile unsigned int*)(0x43816E40UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ17              (*((volatile unsigned int*)(0x43816E44UL)))
#define bM4_USBFS_DOEPTSIZ3_XFRSIZ18              (*((volatile unsigned int*)(0x43816E48UL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT0               (*((volatile unsigned int*)(0x43816E4CUL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT1               (*((volatile unsigned int*)(0x43816E50UL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT2               (*((volatile unsigned int*)(0x43816E54UL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT3               (*((volatile unsigned int*)(0x43816E58UL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT4               (*((volatile unsigned int*)(0x43816E5CUL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT5               (*((volatile unsigned int*)(0x43816E60UL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT6               (*((volatile unsigned int*)(0x43816E64UL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT7               (*((volatile unsigned int*)(0x43816E68UL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT8               (*((volatile unsigned int*)(0x43816E6CUL)))
#define bM4_USBFS_DOEPTSIZ3_PKTCNT9               (*((volatile unsigned int*)(0x43816E70UL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ0                 (*((volatile unsigned int*)(0x43817000UL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ1                 (*((volatile unsigned int*)(0x43817004UL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ2                 (*((volatile unsigned int*)(0x43817008UL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ3                 (*((volatile unsigned int*)(0x4381700CUL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ4                 (*((volatile unsigned int*)(0x43817010UL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ5                 (*((volatile unsigned int*)(0x43817014UL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ6                 (*((volatile unsigned int*)(0x43817018UL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ7                 (*((volatile unsigned int*)(0x4381701CUL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ8                 (*((volatile unsigned int*)(0x43817020UL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ9                 (*((volatile unsigned int*)(0x43817024UL)))
#define bM4_USBFS_DOEPCTL4_MPSIZ10                (*((volatile unsigned int*)(0x43817028UL)))
#define bM4_USBFS_DOEPCTL4_USBAEP                 (*((volatile unsigned int*)(0x4381703CUL)))
#define bM4_USBFS_DOEPCTL4_DPID                   (*((volatile unsigned int*)(0x43817040UL)))
#define bM4_USBFS_DOEPCTL4_NAKSTS                 (*((volatile unsigned int*)(0x43817044UL)))
#define bM4_USBFS_DOEPCTL4_EPTYP0                 (*((volatile unsigned int*)(0x43817048UL)))
#define bM4_USBFS_DOEPCTL4_EPTYP1                 (*((volatile unsigned int*)(0x4381704CUL)))
#define bM4_USBFS_DOEPCTL4_SNPM                   (*((volatile unsigned int*)(0x43817050UL)))
#define bM4_USBFS_DOEPCTL4_STALL                  (*((volatile unsigned int*)(0x43817054UL)))
#define bM4_USBFS_DOEPCTL4_CNAK                   (*((volatile unsigned int*)(0x43817068UL)))
#define bM4_USBFS_DOEPCTL4_SNAK                   (*((volatile unsigned int*)(0x4381706CUL)))
#define bM4_USBFS_DOEPCTL4_SD0PID                 (*((volatile unsigned int*)(0x43817070UL)))
#define bM4_USBFS_DOEPCTL4_SD1PID                 (*((volatile unsigned int*)(0x43817074UL)))
#define bM4_USBFS_DOEPCTL4_EPDIS                  (*((volatile unsigned int*)(0x43817078UL)))
#define bM4_USBFS_DOEPCTL4_EPENA                  (*((volatile unsigned int*)(0x4381707CUL)))
#define bM4_USBFS_DOEPINT4_XFRC                   (*((volatile unsigned int*)(0x43817100UL)))
#define bM4_USBFS_DOEPINT4_EPDISD                 (*((volatile unsigned int*)(0x43817104UL)))
#define bM4_USBFS_DOEPINT4_STUP                   (*((volatile unsigned int*)(0x4381710CUL)))
#define bM4_USBFS_DOEPINT4_OTEPDIS                (*((volatile unsigned int*)(0x43817110UL)))
#define bM4_USBFS_DOEPINT4_B2BSTUP                (*((volatile unsigned int*)(0x43817118UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ0               (*((volatile unsigned int*)(0x43817200UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ1               (*((volatile unsigned int*)(0x43817204UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ2               (*((volatile unsigned int*)(0x43817208UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ3               (*((volatile unsigned int*)(0x4381720CUL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ4               (*((volatile unsigned int*)(0x43817210UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ5               (*((volatile unsigned int*)(0x43817214UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ6               (*((volatile unsigned int*)(0x43817218UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ7               (*((volatile unsigned int*)(0x4381721CUL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ8               (*((volatile unsigned int*)(0x43817220UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ9               (*((volatile unsigned int*)(0x43817224UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ10              (*((volatile unsigned int*)(0x43817228UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ11              (*((volatile unsigned int*)(0x4381722CUL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ12              (*((volatile unsigned int*)(0x43817230UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ13              (*((volatile unsigned int*)(0x43817234UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ14              (*((volatile unsigned int*)(0x43817238UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ15              (*((volatile unsigned int*)(0x4381723CUL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ16              (*((volatile unsigned int*)(0x43817240UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ17              (*((volatile unsigned int*)(0x43817244UL)))
#define bM4_USBFS_DOEPTSIZ4_XFRSIZ18              (*((volatile unsigned int*)(0x43817248UL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT0               (*((volatile unsigned int*)(0x4381724CUL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT1               (*((volatile unsigned int*)(0x43817250UL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT2               (*((volatile unsigned int*)(0x43817254UL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT3               (*((volatile unsigned int*)(0x43817258UL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT4               (*((volatile unsigned int*)(0x4381725CUL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT5               (*((volatile unsigned int*)(0x43817260UL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT6               (*((volatile unsigned int*)(0x43817264UL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT7               (*((volatile unsigned int*)(0x43817268UL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT8               (*((volatile unsigned int*)(0x4381726CUL)))
#define bM4_USBFS_DOEPTSIZ4_PKTCNT9               (*((volatile unsigned int*)(0x43817270UL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ0                 (*((volatile unsigned int*)(0x43817400UL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ1                 (*((volatile unsigned int*)(0x43817404UL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ2                 (*((volatile unsigned int*)(0x43817408UL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ3                 (*((volatile unsigned int*)(0x4381740CUL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ4                 (*((volatile unsigned int*)(0x43817410UL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ5                 (*((volatile unsigned int*)(0x43817414UL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ6                 (*((volatile unsigned int*)(0x43817418UL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ7                 (*((volatile unsigned int*)(0x4381741CUL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ8                 (*((volatile unsigned int*)(0x43817420UL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ9                 (*((volatile unsigned int*)(0x43817424UL)))
#define bM4_USBFS_DOEPCTL5_MPSIZ10                (*((volatile unsigned int*)(0x43817428UL)))
#define bM4_USBFS_DOEPCTL5_USBAEP                 (*((volatile unsigned int*)(0x4381743CUL)))
#define bM4_USBFS_DOEPCTL5_DPID                   (*((volatile unsigned int*)(0x43817440UL)))
#define bM4_USBFS_DOEPCTL5_NAKSTS                 (*((volatile unsigned int*)(0x43817444UL)))
#define bM4_USBFS_DOEPCTL5_EPTYP0                 (*((volatile unsigned int*)(0x43817448UL)))
#define bM4_USBFS_DOEPCTL5_EPTYP1                 (*((volatile unsigned int*)(0x4381744CUL)))
#define bM4_USBFS_DOEPCTL5_SNPM                   (*((volatile unsigned int*)(0x43817450UL)))
#define bM4_USBFS_DOEPCTL5_STALL                  (*((volatile unsigned int*)(0x43817454UL)))
#define bM4_USBFS_DOEPCTL5_CNAK                   (*((volatile unsigned int*)(0x43817468UL)))
#define bM4_USBFS_DOEPCTL5_SNAK                   (*((volatile unsigned int*)(0x4381746CUL)))
#define bM4_USBFS_DOEPCTL5_SD0PID                 (*((volatile unsigned int*)(0x43817470UL)))
#define bM4_USBFS_DOEPCTL5_SD1PID                 (*((volatile unsigned int*)(0x43817474UL)))
#define bM4_USBFS_DOEPCTL5_EPDIS                  (*((volatile unsigned int*)(0x43817478UL)))
#define bM4_USBFS_DOEPCTL5_EPENA                  (*((volatile unsigned int*)(0x4381747CUL)))
#define bM4_USBFS_DOEPINT5_XFRC                   (*((volatile unsigned int*)(0x43817500UL)))
#define bM4_USBFS_DOEPINT5_EPDISD                 (*((volatile unsigned int*)(0x43817504UL)))
#define bM4_USBFS_DOEPINT5_STUP                   (*((volatile unsigned int*)(0x4381750CUL)))
#define bM4_USBFS_DOEPINT5_OTEPDIS                (*((volatile unsigned int*)(0x43817510UL)))
#define bM4_USBFS_DOEPINT5_B2BSTUP                (*((volatile unsigned int*)(0x43817518UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ0               (*((volatile unsigned int*)(0x43817600UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ1               (*((volatile unsigned int*)(0x43817604UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ2               (*((volatile unsigned int*)(0x43817608UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ3               (*((volatile unsigned int*)(0x4381760CUL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ4               (*((volatile unsigned int*)(0x43817610UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ5               (*((volatile unsigned int*)(0x43817614UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ6               (*((volatile unsigned int*)(0x43817618UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ7               (*((volatile unsigned int*)(0x4381761CUL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ8               (*((volatile unsigned int*)(0x43817620UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ9               (*((volatile unsigned int*)(0x43817624UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ10              (*((volatile unsigned int*)(0x43817628UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ11              (*((volatile unsigned int*)(0x4381762CUL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ12              (*((volatile unsigned int*)(0x43817630UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ13              (*((volatile unsigned int*)(0x43817634UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ14              (*((volatile unsigned int*)(0x43817638UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ15              (*((volatile unsigned int*)(0x4381763CUL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ16              (*((volatile unsigned int*)(0x43817640UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ17              (*((volatile unsigned int*)(0x43817644UL)))
#define bM4_USBFS_DOEPTSIZ5_XFRSIZ18              (*((volatile unsigned int*)(0x43817648UL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT0               (*((volatile unsigned int*)(0x4381764CUL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT1               (*((volatile unsigned int*)(0x43817650UL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT2               (*((volatile unsigned int*)(0x43817654UL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT3               (*((volatile unsigned int*)(0x43817658UL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT4               (*((volatile unsigned int*)(0x4381765CUL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT5               (*((volatile unsigned int*)(0x43817660UL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT6               (*((volatile unsigned int*)(0x43817664UL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT7               (*((volatile unsigned int*)(0x43817668UL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT8               (*((volatile unsigned int*)(0x4381766CUL)))
#define bM4_USBFS_DOEPTSIZ5_PKTCNT9               (*((volatile unsigned int*)(0x43817670UL)))
#define bM4_USBFS_PCGCCTL_STPPCLK                 (*((volatile unsigned int*)(0x4381C000UL)))
#define bM4_USBFS_PCGCCTL_GATEHCLK                (*((volatile unsigned int*)(0x4381C004UL)))
#define bM4_WDT_CR_PERI0                          (*((volatile unsigned int*)(0x42920000UL)))
#define bM4_WDT_CR_PERI1                          (*((volatile unsigned int*)(0x42920004UL)))
#define bM4_WDT_CR_CKS0                           (*((volatile unsigned int*)(0x42920010UL)))
#define bM4_WDT_CR_CKS1                           (*((volatile unsigned int*)(0x42920014UL)))
#define bM4_WDT_CR_CKS2                           (*((volatile unsigned int*)(0x42920018UL)))
#define bM4_WDT_CR_CKS3                           (*((volatile unsigned int*)(0x4292001CUL)))
#define bM4_WDT_CR_WDPT0                          (*((volatile unsigned int*)(0x42920020UL)))
#define bM4_WDT_CR_WDPT1                          (*((volatile unsigned int*)(0x42920024UL)))
#define bM4_WDT_CR_WDPT2                          (*((volatile unsigned int*)(0x42920028UL)))
#define bM4_WDT_CR_WDPT3                          (*((volatile unsigned int*)(0x4292002CUL)))
#define bM4_WDT_CR_SLPOFF                         (*((volatile unsigned int*)(0x42920040UL)))
#define bM4_WDT_CR_ITS                            (*((volatile unsigned int*)(0x4292007CUL)))
#define bM4_WDT_SR_CNT0                           (*((volatile unsigned int*)(0x42920080UL)))
#define bM4_WDT_SR_CNT1                           (*((volatile unsigned int*)(0x42920084UL)))
#define bM4_WDT_SR_CNT2                           (*((volatile unsigned int*)(0x42920088UL)))
#define bM4_WDT_SR_CNT3                           (*((volatile unsigned int*)(0x4292008CUL)))
#define bM4_WDT_SR_CNT4                           (*((volatile unsigned int*)(0x42920090UL)))
#define bM4_WDT_SR_CNT5                           (*((volatile unsigned int*)(0x42920094UL)))
#define bM4_WDT_SR_CNT6                           (*((volatile unsigned int*)(0x42920098UL)))
#define bM4_WDT_SR_CNT7                           (*((volatile unsigned int*)(0x4292009CUL)))
#define bM4_WDT_SR_CNT8                           (*((volatile unsigned int*)(0x429200A0UL)))
#define bM4_WDT_SR_CNT9                           (*((volatile unsigned int*)(0x429200A4UL)))
#define bM4_WDT_SR_CNT10                          (*((volatile unsigned int*)(0x429200A8UL)))
#define bM4_WDT_SR_CNT11                          (*((volatile unsigned int*)(0x429200ACUL)))
#define bM4_WDT_SR_CNT12                          (*((volatile unsigned int*)(0x429200B0UL)))
#define bM4_WDT_SR_CNT13                          (*((volatile unsigned int*)(0x429200B4UL)))
#define bM4_WDT_SR_CNT14                          (*((volatile unsigned int*)(0x429200B8UL)))
#define bM4_WDT_SR_CNT15                          (*((volatile unsigned int*)(0x429200BCUL)))
#define bM4_WDT_SR_UDF                            (*((volatile unsigned int*)(0x429200C0UL)))
#define bM4_WDT_SR_REF                            (*((volatile unsigned int*)(0x429200C4UL)))
#define bM4_WDT_RR_RF0                            (*((volatile unsigned int*)(0x42920100UL)))
#define bM4_WDT_RR_RF1                            (*((volatile unsigned int*)(0x42920104UL)))
#define bM4_WDT_RR_RF2                            (*((volatile unsigned int*)(0x42920108UL)))
#define bM4_WDT_RR_RF3                            (*((volatile unsigned int*)(0x4292010CUL)))
#define bM4_WDT_RR_RF4                            (*((volatile unsigned int*)(0x42920110UL)))
#define bM4_WDT_RR_RF5                            (*((volatile unsigned int*)(0x42920114UL)))
#define bM4_WDT_RR_RF6                            (*((volatile unsigned int*)(0x42920118UL)))
#define bM4_WDT_RR_RF7                            (*((volatile unsigned int*)(0x4292011CUL)))
#define bM4_WDT_RR_RF8                            (*((volatile unsigned int*)(0x42920120UL)))
#define bM4_WDT_RR_RF9                            (*((volatile unsigned int*)(0x42920124UL)))
#define bM4_WDT_RR_RF10                           (*((volatile unsigned int*)(0x42920128UL)))
#define bM4_WDT_RR_RF11                           (*((volatile unsigned int*)(0x4292012CUL)))
#define bM4_WDT_RR_RF12                           (*((volatile unsigned int*)(0x42920130UL)))
#define bM4_WDT_RR_RF13                           (*((volatile unsigned int*)(0x42920134UL)))
#define bM4_WDT_RR_RF14                           (*((volatile unsigned int*)(0x42920138UL)))
#define bM4_WDT_RR_RF15                           (*((volatile unsigned int*)(0x4292013CUL)))
#define bM4_WKTM_CR_WKTMCMP0                      (*((volatile unsigned int*)(0x42988000UL)))
#define bM4_WKTM_CR_WKTMCMP1                      (*((volatile unsigned int*)(0x42988004UL)))
#define bM4_WKTM_CR_WKTMCMP2                      (*((volatile unsigned int*)(0x42988008UL)))
#define bM4_WKTM_CR_WKTMCMP3                      (*((volatile unsigned int*)(0x4298800CUL)))
#define bM4_WKTM_CR_WKTMCMP4                      (*((volatile unsigned int*)(0x42988010UL)))
#define bM4_WKTM_CR_WKTMCMP5                      (*((volatile unsigned int*)(0x42988014UL)))
#define bM4_WKTM_CR_WKTMCMP6                      (*((volatile unsigned int*)(0x42988018UL)))
#define bM4_WKTM_CR_WKTMCMP7                      (*((volatile unsigned int*)(0x4298801CUL)))
#define bM4_WKTM_CR_WKTMCMP8                      (*((volatile unsigned int*)(0x42988020UL)))
#define bM4_WKTM_CR_WKTMCMP9                      (*((volatile unsigned int*)(0x42988024UL)))
#define bM4_WKTM_CR_WKTMCMP10                     (*((volatile unsigned int*)(0x42988028UL)))
#define bM4_WKTM_CR_WKTMCMP11                     (*((volatile unsigned int*)(0x4298802CUL)))
#define bM4_WKTM_CR_WKOVF                         (*((volatile unsigned int*)(0x42988030UL)))
#define bM4_WKTM_CR_WKCKS0                        (*((volatile unsigned int*)(0x42988034UL)))
#define bM4_WKTM_CR_WKCKS1                        (*((volatile unsigned int*)(0x42988038UL)))
#define bM4_WKTM_CR_WKTCE                         (*((volatile unsigned int*)(0x4298803CUL)))



#ifdef __cplusplus
}
#endif

#endif /* __HC32F460_H__ */

